(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1152445,      27509]
NotebookOptionsPosition[   1058974,      26284]
NotebookOutlinePosition[   1059313,      26299]
CellTagsIndexPosition[   1059270,      26296]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["\<\
This Notebook contains the proofs of all the results in the paper
\"Location of Triangle Centers Relative to the Incircle and Circumcircle\" by \
Stanley Rabinowitz,
submitted to the International Journal of Computer Discovered Mathematics 
(http : // www.journal - 1. eu/) on Nov. 2021.
 
This Notebook is Copyright \[Copyright] November 2021 by Stanley Rabinowitz \
(stan.rabinowitz@comcast.net) and is published with open access. This \
Notebook is distributed under the terms of the Creative Commons Attribution \
License which permits any use, distribution, and reproduction in any medium, \
provided the original author and the source are credited.

If you want to reproduce these results, you must evaluate the notebook \
\[OpenCurlyDoubleQuote]proveTriangleInequalityUsing Blundon.nb\
\[CloseCurlyDoubleQuote]
first before evaluating this notebook.\
\>", "Text",
 Evaluatable->False,
 CellChangeTimes->{{3.823362867312365*^9, 3.823362892123764*^9}, {
   3.823362940554699*^9, 3.823363012293025*^9}, {3.823423241988761*^9, 
   3.8234232521964083`*^9}, 3.8247296830582123`*^9, {3.829304183998571*^9, 
   3.829304184727605*^9}, {3.847010924219548*^9, 
   3.847011078875139*^9}},ExpressionUUID->"984c0623-88fe-447b-bc88-\
37db9b647f0e"],

Cell[CellGroupData[{

Cell["Barycentric Coordinates for Centers X1-X100", "Section",
 CellChangeTimes->{{3.824729704472291*^9, 
  3.8247297231587954`*^9}},ExpressionUUID->"58f4c69c-5afe-42ac-8396-\
9ab23b31de6d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ETC1", "=", 
   RowBox[{"{", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"X1", ",", 
       RowBox[{"{", 
        RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X2", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", "1"}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X3", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X4", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X5", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            SuperscriptBox["a", "2"]}], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X6", ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "2"], ",", 
         SuperscriptBox["b", "2"], ",", 
         SuperscriptBox["c", "2"]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X7", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X8", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", "-", "b", "-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "+", "b", "-", "c"}], ",", 
         RowBox[{
          RowBox[{"-", "a"}], "-", "b", "+", "c"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X9", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X10", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", "+", "c"}], ",", 
         RowBox[{"a", "+", "c"}], ",", 
         RowBox[{"a", "+", "b"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X11", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"X12", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X13", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"]}], ")"}], "2"]}], "+", 
          SuperscriptBox["c", "4"], "+", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X14", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["b", "2"], "-", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", 
               SuperscriptBox["a", "2"]}], "+", 
              SuperscriptBox["c", "2"]}], ")"}], "2"]}], "+", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["c", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["a", "2"], "-", 
              SuperscriptBox["b", "2"]}], ")"}], "2"]}], "+", 
          SuperscriptBox["c", "4"], "+", 
          RowBox[{
           SuperscriptBox["c", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X15", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"]}], ")"}]}], "-", 
            RowBox[{"2", " ", "S"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X16", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["b", "2"], "-", 
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox["3"], " ", 
             RowBox[{"(", 
              RowBox[{
               SuperscriptBox["c", "2"], "-", 
               SuperscriptBox["a", "2"], "-", 
               SuperscriptBox["b", "2"]}], ")"}]}], "+", 
            RowBox[{"2", " ", "S"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X17", ",", 
       FormBox[
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "+", 
             SuperscriptBox["b", "2"], "-", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["a", "2"], "-", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], "+", 
             SuperscriptBox["b", "2"], "+", 
             SuperscriptBox["c", "2"], "+", 
             RowBox[{"2", " ", 
              SqrtBox["3"], " ", "S"}]}], ")"}]}]}], "}"}],
        TraditionalForm]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X18", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], "S"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], "S"}]}], ")"}]}], "\[InvisibleSpace]", ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", "S"}]}], ")"}]}]}], "\[InvisibleSpace]", 
        "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X19", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X20", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"3", " ", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["b", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"3", " ", 
           SuperscriptBox["c", "4"]}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X21", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X22", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X23", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X24", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X25", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X26", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["c", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["b", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X27", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X28", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X29", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X30", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"2", " ", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["b", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          SuperscriptBox["c", "4"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "4"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["b", "2"]}], "-", 
          SuperscriptBox["b", "4"], "-", 
          RowBox[{
           SuperscriptBox["a", "2"], " ", 
           SuperscriptBox["c", "2"]}], "-", 
          RowBox[{
           SuperscriptBox["b", "2"], " ", 
           SuperscriptBox["c", "2"]}], "+", 
          RowBox[{"2", " ", 
           SuperscriptBox["c", "4"]}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X31", ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "3"], ",", 
         SuperscriptBox["b", "3"], ",", 
         SuperscriptBox["c", "3"]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X32", ",", 
       RowBox[{"{", 
        RowBox[{
         SuperscriptBox["a", "4"], ",", 
         SuperscriptBox["b", "4"], ",", 
         SuperscriptBox["c", "4"]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X33", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X34", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X35", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X36", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X37", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", "c"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X38", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", "c"}]}], "}"}]}], "}"}], 
     ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X39", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X40", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X41", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X42", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X43", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X44", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "-", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X45", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"2", " ", "b"}], "-", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "+", "b", "-", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "-", 
            RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}]}], "}"}]}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"X46", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X47", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X48", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X49", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X50", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "4"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            RowBox[{"a", " ", "b"}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X51", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X52", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X53", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X54", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X55", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X56", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X57", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X58", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X59", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "-", "b"}], ")"}], "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "-", "c"}], ")"}], "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "a"}], "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X60", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "b"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"a", "+", "c"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"b", "+", "c"}], ")"}], "2"]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X61", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], 
         "\[InvisibleSpace]", ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}]}], 
        "\[InvisibleSpace]", "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X62", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"2", " ", 
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], ",", 
         RowBox[{"2", " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}], 
         "\[InvisibleSpace]", ",", "\[InvisibleSpace]", 
         RowBox[{"2", " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"3", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["a", "2"], " ", "S"}], "-", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["b", "2"], " ", "S"}], "+", 
            RowBox[{"2", " ", 
             SqrtBox["3"], " ", 
             SuperscriptBox["c", "2"], " ", "S"}]}], ")"}]}]}], 
        "\[InvisibleSpace]", "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X63", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X64", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "3"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"3", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X65", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X66", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X67", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "4"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X68", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X69", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], "-", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "+", 
          SuperscriptBox["b", "2"], "-", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          RowBox[{"-", 
           SuperscriptBox["a", "2"]}], "-", 
          SuperscriptBox["b", "2"], "+", 
          SuperscriptBox["c", "2"]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X70", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            SuperscriptBox["c", "8"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "-", 
            SuperscriptBox["b", "8"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "8"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "6"]}], "+", 
            SuperscriptBox["b", "8"], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "6"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "6"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"], " ", 
             SuperscriptBox["c", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "6"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "6"]}], "+", 
            SuperscriptBox["c", "8"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X71", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X72", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X73", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X74", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["c", "4"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["a", "4"]}], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "4"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X75", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", "c"}], ",", 
         RowBox[{"a", " ", "c"}], ",", 
         RowBox[{"a", " ", "b"}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X76", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X77", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X78", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X79", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X80", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X81", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X82", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X83", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["b", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X84", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{"2", " ", "a", " ", "b", " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X85", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "-", "b", "+", "c"}], ")"}]}], ",", 
         RowBox[{"a", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "b", "-", "c"}], ")"}]}]}], "}"}]}], 
      "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{"X86", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X87", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"a", " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "+", 
            RowBox[{"a", " ", "c"}], "-", 
            RowBox[{"b", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "a"}], " ", "b"}], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            RowBox[{"b", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X88", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"2", " ", "b"}], "+", "c"}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "-", 
            RowBox[{"2", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}], 
         ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", 
            RowBox[{"2", " ", "b"}], "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "a"}], "+", "b", "+", "c"}], ")"}]}]}], 
        "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X89", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "a"}], "-", "b", "+", 
            RowBox[{"2", " ", "c"}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", 
            RowBox[{"2", " ", "b"}], "+", 
            RowBox[{"2", " ", "c"}]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X90", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "+", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}], ",", 
         RowBox[{"c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "+", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "3"], "+", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "b"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["b", "2"]}], "-", 
            SuperscriptBox["b", "3"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", "c"}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", "c"}], "-", 
            RowBox[{"a", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            RowBox[{"b", " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "3"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X91", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X92", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"b", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{"a", " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X93", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X94", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "+", 
            RowBox[{"a", " ", "b"}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"a", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "+", 
            RowBox[{"b", " ", "c"}], "+", 
            SuperscriptBox["c", "2"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X95", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X96", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X97", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          SuperscriptBox["a", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "2"], "-", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["b", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "+", 
            SuperscriptBox["b", "2"], "-", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          SuperscriptBox["c", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", 
             SuperscriptBox["a", "2"]}], "-", 
            SuperscriptBox["b", "2"], "+", 
            SuperscriptBox["c", "2"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X98", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", 
              SuperscriptBox["a", "2"]}], " ", 
             SuperscriptBox["b", "2"]}], "+", 
            SuperscriptBox["b", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["a", "4"], "-", 
            RowBox[{
             SuperscriptBox["a", "2"], " ", 
             SuperscriptBox["b", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["b", "2"], " ", 
             SuperscriptBox["c", "2"]}], "+", 
            SuperscriptBox["c", "4"]}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X99", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"a", "+", "c"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"b", "+", "c"}], ")"}]}]}], "}"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"X100", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"a", " ", 
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "-", "b"}], ")"}], " ", "b", " ", 
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}]}], ",", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"b", "-", "c"}], ")"}], " ", "c", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "a"}], "+", "c"}], ")"}]}]}], "}"}]}], "}"}]}], 
    "\[IndentingNewLine]", "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8243788225371437`*^9, 3.824378825377088*^9}},
 CellLabel->
  "In[249]:=",ExpressionUUID->"103026ca-9a33-45ac-8b84-90962100f555"]
}, Closed]],

Cell[CellGroupData[{

Cell["Setup", "Section",
 CellChangeTimes->{{3.824729768409182*^9, 
  3.8247297787826977`*^9}},ExpressionUUID->"6938e9d1-ceb8-4305-b323-\
0cc213693416"],

Cell[TextData[{
 StyleBox["The routine proveTriangleInequalityUsingBlundon must be loaded \
first.\n",
  FontColor->RGBColor[0, 0, 1]],
 StyleBox["These routines were tested with version 14 of routine \
proveTriangleInequalityUsingBlundon.",
  FontColor->GrayLevel[0]]
}], "Text",
 CellChangeTimes->{
  3.824730406282001*^9, {3.824730443569111*^9, 3.824730457896896*^9}, {
   3.82930496890667*^9, 3.829304994194705*^9}, 
   3.829307006183751*^9},ExpressionUUID->"1f9d2c39-46b8-489a-a814-\
40703670efc1"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"x", "[", "i", "]"}], "=", 
       RowBox[{"ETC1", "[", 
        RowBox[{"[", 
         RowBox[{"i", ",", "2"}], "]"}], "]"}]}], ";"}]}], 
    "\[IndentingNewLine]", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"showExpression", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"showSteps", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"showRegions", "=", "False"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"showCounterexample", "=", "False"}], ";"}], "\[IndentingNewLine]", 

 RowBox[{
  RowBox[{
   RowBox[{"showConditionsForEquality", "=", "False"}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Function", " ", "to", " ", "find", " ", "the", " ", "distance", " ", 
    "between", " ", "two", " ", "points", " ", "given", " ", "in", " ", 
    "Barycentric", " ", "coordinates"}], " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"normed", "[", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], "/", 
    RowBox[{"(", 
     RowBox[{"x", "+", "y", "+", "z"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"squaredDistance", "[", 
    RowBox[{"p1_", ",", "p2_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Total", "[", "p2", "]"}], "\[Equal]", "0"}], ",", 
        RowBox[{"Return", "[", "Infinity", "]"}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], "=", 
       RowBox[{
        RowBox[{"normed", "[", "p1", "]"}], "-", 
        RowBox[{"normed", "[", "p2", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"Return", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          RowBox[{"a", "^", "2"}]}], "*", "y", "*", "z"}], "-", 
        RowBox[{
         RowBox[{"b", "^", "2"}], "*", "z", "*", "x"}], "-", 
        RowBox[{
         RowBox[{"c", "^", "2"}], "*", "x", "*", "y"}]}], "]"}], ";"}]}], 
    "\[IndentingNewLine]", "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.82446823405422*^9, 3.824468238813963*^9}, {
   3.824639364376914*^9, 3.824639366254614*^9}, {3.824639489697496*^9, 
   3.824639501047118*^9}, {3.824730489171135*^9, 3.824730550273574*^9}, 
   3.829305063612216*^9, {3.829305236004871*^9, 3.829305240731523*^9}},
 CellLabel->
  "In[250]:=",ExpressionUUID->"2c26ce4c-5a53-4812-be0e-c5e07af7088e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Relationship of Centers to Incircle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 
  3.824729830635277*^9}},ExpressionUUID->"3ad4c45e-5f2c-4f9c-bc0b-\
81ce67b2a5a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "points", " ", "that", " ", "must", " ", "lie", " ", "inside",
     " ", "the", " ", "incircle"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"insideIncircle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sq", "=", 
        RowBox[{"squaredDistance", "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"truth", "=", 
        RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
         RowBox[{"sq", "<", 
          RowBox[{"r", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"truth", ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"insideIncircle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "insideIncircle", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824639376395611*^9, 3.824639474198804*^9}, {
  3.8248175160446863`*^9, 3.824817530919215*^9}},
 CellLabel->
  "In[258]:=",ExpressionUUID->"6ce1e6e6-ed6d-4f62-9584-eb94f51ae1bc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "7", ",", "12", ",", "55", ",", "56", ",", "57", ",", "65"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.824639475371646*^9, 3.8246395219490023`*^9, 
  3.824731574582707*^9, 3.824737926940218*^9, 3.824817547601071*^9, 
  3.8293051440428877`*^9, 3.8293052612748117`*^9, 3.8293053722658243`*^9, 
  3.846923184124083*^9, 3.8470111746024446`*^9, 3.847181776871037*^9, 
  3.847181833846808*^9},
 CellLabel->
  "During evaluation of \
In[258]:=",ExpressionUUID->"8defe32f-058c-47f6-a1ab-1e4648d3e96d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "points", " ", "that", " ", "must", " ", "lie", " ", 
    "outside", " ", "the", " ", "incircle"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"outsideIncircle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sq", "=", 
        RowBox[{"squaredDistance", "[", 
         RowBox[{
          RowBox[{"x", "[", "1", "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"truth", "=", 
        RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
         RowBox[{"sq", ">", 
          RowBox[{"r", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"truth", ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"outsideIncircle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "outsideIncircle", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824639546303382*^9, 3.824639562407548*^9}, {
  3.824817556279907*^9, 3.8248175672151117`*^9}},
 CellLabel->
  "In[261]:=",ExpressionUUID->"a31d1b59-f53d-46a3-9e44-9b7f6233c4a8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "14", ",", "16", ",", "23", ",", "30", ",", "36", ",", "44", ",", "67", ",",
    "74", ",", "80", ",", "88", ",", "98", ",", "99", ",", "100"}], 
  "}"}]], "Print",
 CellChangeTimes->{3.824639582049562*^9, 3.824731587864915*^9, 
  3.824737941831046*^9, 3.8248175881034718`*^9, 3.829305419609062*^9, 
  3.84692321221117*^9, 3.8470112155742607`*^9, 3.847181776916827*^9, 
  3.8471818619995413`*^9},
 CellLabel->
  "During evaluation of \
In[261]:=",ExpressionUUID->"541229c6-743c-4df5-87de-ad1c66b5da8c"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Relationship of Centers to Circumcircle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"19a12d2a-3888-4aff-9dd5-cf417bc4ae03"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "points", " ", "that", " ", "must", " ", "lie", " ", "inside",
     " ", "the", " ", "circumcircle"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"insideCircumcircle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sq", "=", 
        RowBox[{"squaredDistance", "[", 
         RowBox[{
          RowBox[{"x", "[", "3", "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"truth", "=", 
        RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
         RowBox[{"sq", "<", 
          RowBox[{"R", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"truth", ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"insideCircumcircle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "insideCircumcircle", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824639609615567*^9, 3.8246396211116343`*^9}, {
  3.824817619072356*^9, 3.824817633559507*^9}},
 CellLabel->
  "In[264]:=",ExpressionUUID->"58e8a09b-7a3d-4c5e-8c0a-d80156ed19dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", 
   ",", "11", ",", "12", ",", "15", ",", "21", ",", "24", ",", "31", ",", 
   "32", ",", "35", ",", "37", ",", "38", ",", "39", ",", "40", ",", "41", 
   ",", "42", ",", "45", ",", "55", ",", "56", ",", "57", ",", "58", ",", 
   "59", ",", "60", ",", "61", ",", "63", ",", "65", ",", "69", ",", "71", 
   ",", "72", ",", "75", ",", "76", ",", "78", ",", "81", ",", "82", ",", 
   "83", ",", "85", ",", "86", ",", "89"}], "}"}]], "Print",
 CellChangeTimes->{3.8246396411804247`*^9, 3.824731602708045*^9, 
  3.824737956683065*^9, 3.824817652397622*^9, 3.829305495024005*^9, 
  3.8469232378484583`*^9, 3.847011254225906*^9, 3.847181776960664*^9, 
  3.8471818876362867`*^9},
 CellLabel->
  "During evaluation of \
In[264]:=",ExpressionUUID->"9e3e7a5f-689e-4e1c-b40e-8b4ba4b4111d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "points", " ", "that", " ", "must", " ", "lie", " ", 
    "outside", " ", "the", " ", "circumcircle"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"outsideCircumcircle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"sq", "=", 
        RowBox[{"squaredDistance", "[", 
         RowBox[{
          RowBox[{"x", "[", "3", "]"}], ",", 
          RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"truth", "=", 
        RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
         RowBox[{"sq", ">", 
          RowBox[{"R", "^", "2"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{"truth", ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"outsideCircumcircle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", "outsideCircumcircle", "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8246396841917686`*^9, 3.824639700199896*^9}, {
  3.824817657081307*^9, 3.824817666071549*^9}},
 CellLabel->
  "In[267]:=",ExpressionUUID->"d2b05f36-4d74-409b-9116-742188a3dc5a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"16", ",", "23", ",", "30", ",", "36", ",", "44"}], "}"}]], "Print",\

 CellChangeTimes->{3.824639716202827*^9, 3.824731617326023*^9, 
  3.824737971915262*^9, 3.8248176816304083`*^9, 3.829305557977844*^9, 
  3.846923264066877*^9, 3.847011289567614*^9, 3.847181776970315*^9, 
  3.847181914223031*^9},
 CellLabel->
  "During evaluation of \
In[267]:=",ExpressionUUID->"b25c7936-25b9-4f24-b85f-7099c334613b"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distance of Center to X1 Compared With r", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"54313b8c-dba1-4fdc-9efe-9742071ed321"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"kr", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"93", "<=", "i", "<=", "96"}], ",", 
        RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"r", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.82463636715029*^9, 3.824636406998026*^9}, {
   3.824636443487669*^9, 3.8246364567182217`*^9}, {3.8246398519693327`*^9, 
   3.824639853024769*^9}, 3.829306160047224*^9, {3.8293065547914877`*^9, 
   3.829306558038097*^9}, {3.829306631586556*^9, 3.8293066391265593`*^9}, {
   3.8293067248479958`*^9, 3.8293067284946527`*^9}, {3.8293069558742113`*^9, 
   3.829306978511342*^9}, {3.8470127527212143`*^9, 3.847012763400326*^9}, {
   3.847012893297318*^9, 3.8470129100089417`*^9}, {3.847013034777357*^9, 
   3.847013039465404*^9}, {3.847013720085802*^9, 3.847013724581708*^9}, {
   3.8470299277649937`*^9, 3.847029942044063*^9}, {3.847030444431381*^9, 
   3.847030463581921*^9}},
 CellLabel->
  "In[270]:=",ExpressionUUID->"5c14dd3e-400d-40b0-a9ac-fb0b8881975e"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 7, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847181914767818*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"de1d775e-5714-4324-beda-c3eb93ec015a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 11, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847181915021451*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"6f2ed661-570a-41a4-b535-2b26d2528629"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 12, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471819151067266`*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"50efbd35-8341-4101-9324-97f3bea6204e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 35, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847181977101451*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"bcdef3ef-db67-4488-af9f-354ac63c655f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 46, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847181978904896*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"032eed27-c5b3-4d20-bd0f-f49f9af01e52"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 55, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471819841731367`*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"04876e50-3125-457d-9c55-bdd760e7393b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 56, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471819842311153`*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"5d64c95e-564c-4ce6-84bb-cd0c205bec3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 57, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847181984296754*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"5e3d29a9-0e30-44f1-a0f8-3ac736f93f29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 65, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847181989018552*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"5fb22373-346a-4c5e-9196-8ed61c1263c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 79, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182003280772*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"11a88837-e8f5-474e-8080-db04b159af47"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 80, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182003380028*^9},
 CellLabel->
  "During evaluation of \
In[270]:=",ExpressionUUID->"e78e99ba-a22b-4b4f-a9f1-b91005236b65"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "7", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247334747632093`*^9, 3.824733494699181*^9}},
 CellLabel->
  "In[271]:=",ExpressionUUID->"01c288ba-fc76-4050-86c6-da57f0f49aef"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.824733495658278*^9, 3.824738035358005*^9, {3.8293070779196177`*^9, 
   3.8293071029751377`*^9}, 3.846923352286841*^9, 3.847012930017674*^9, 
   3.847181777094779*^9, 3.8471820211447077`*^9},
 CellLabel->
  "Out[272]=",ExpressionUUID->"c713ea0a-a95d-4eff-b690-e3ae458834cc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "11", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847012938249165*^9, 3.8470129404726057`*^9}},
 CellLabel->
  "In[273]:=",ExpressionUUID->"e367f5b4-cee5-4f24-8927-0e5f631ebb06"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.8470129412907057`*^9, 3.8471817771551933`*^9, 
  3.847182021208603*^9},
 CellLabel->
  "Out[274]=",ExpressionUUID->"20130af8-d731-4ce8-9559-b4555b3ece3a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "12", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.82473354774761*^9, 3.824733548299122*^9}},
 CellLabel->
  "In[275]:=",ExpressionUUID->"69b93cd6-529e-4163-9a75-305a92dec0f8"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824733548734017*^9, 3.824738035408387*^9, 
  3.829307109129518*^9, 3.846923352352057*^9, 3.847181777165699*^9, 
  3.847182021269204*^9},
 CellLabel->
  "Out[276]=",ExpressionUUID->"7f15e2ac-f7d5-4e7f-a7d8-52decf833093"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "35", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"4", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824733560051572*^9, 3.824733565292047*^9}},
 CellLabel->
  "In[277]:=",ExpressionUUID->"7679636a-ffbf-45b0-9784-069acf737272"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824733566261848*^9, 3.824738035457718*^9, 
  3.829307121777588*^9, 3.846923352406107*^9, 3.8471817772321157`*^9, 
  3.84718202134204*^9},
 CellLabel->
  "Out[278]=",ExpressionUUID->"b81540a7-ee1e-4c0b-a63a-cf0212fe1c36"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "46", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"4", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.82473357853163*^9, 3.824733579099122*^9}},
 CellLabel->
  "In[279]:=",ExpressionUUID->"0bc53e1d-8add-4136-95e5-b46b15035fc1"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824733580370933*^9, 3.824738035509222*^9, 
  3.829307124656645*^9, 3.846923352468699*^9, 3.847181777245089*^9, 
  3.84718202141018*^9},
 CellLabel->
  "Out[280]=",ExpressionUUID->"742ed91a-c919-4241-bcf0-31835094bdde"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "55", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824733587843872*^9, 3.824733589859173*^9}},
 CellLabel->
  "In[281]:=",ExpressionUUID->"8784ec1c-4a77-4d19-8f51-4cd72aaae3f5"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247335908441963`*^9, 3.824738035563493*^9, 
  3.8469233525223713`*^9, 3.847181777309167*^9, 3.847182021480299*^9},
 CellLabel->
  "Out[282]=",ExpressionUUID->"6792c18e-1816-4ca2-8a24-6253de788947"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "56", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.824733602003922*^9},
 CellLabel->
  "In[283]:=",ExpressionUUID->"fbcad1b5-6d74-4a11-b7ed-1cb337fcb3fc"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247336025239067`*^9, 3.82473803561767*^9, 
  3.82930712832509*^9, 3.846923352582103*^9, 3.8471817773208323`*^9, 
  3.847182021552403*^9},
 CellLabel->
  "Out[284]=",ExpressionUUID->"ad60c4e4-22bd-422f-837e-f2e3551e8f03"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "57", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.824733613907834*^9},
 CellLabel->
  "In[285]:=",ExpressionUUID->"cb01f7ef-ccb9-4a90-9796-0ccb6275e25a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247336144593563`*^9, 3.824738035675025*^9, 
  3.8293071339733973`*^9, 3.846923352639859*^9, 3.847181777374577*^9, 
  3.847182021633588*^9},
 CellLabel->
  "Out[286]=",ExpressionUUID->"6ce16700-61bf-4764-af78-5db824264277"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "65", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"r", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247336245961533`*^9, 3.824733625347291*^9}},
 CellLabel->
  "In[287]:=",ExpressionUUID->"97d323ad-2d50-459d-bb13-3d087ce9772a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824733626287479*^9, 3.824738035737907*^9, 
  3.829307137173163*^9, 3.8469233527184477`*^9, 3.8471817773871727`*^9, 
  3.8471820217100163`*^9},
 CellLabel->
  "Out[288]=",ExpressionUUID->"6af84c50-e9e9-44e4-b17a-fa675da3989d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "79", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"4", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824733635779842*^9, 3.8247336442127953`*^9}},
 CellLabel->
  "In[289]:=",ExpressionUUID->"36d41fae-4108-42d8-b0d4-ae6115365bec"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.824733637253929*^9, 3.824733644742309*^9}, 
   3.824738035811263*^9, 3.829307139887424*^9, 3.846923352797203*^9, 
   3.847181777441029*^9, 3.847182021792801*^9},
 CellLabel->
  "Out[290]=",ExpressionUUID->"eb8be919-ecfc-43fc-b2dd-5fb5573faaf9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "80", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"4", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247336527319193`*^9, 3.824733657379407*^9}},
 CellLabel->
  "In[291]:=",ExpressionUUID->"3e962060-2652-4d41-b4c4-18978c3a4583"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.824733658042487*^9, 3.824738035879134*^9, 
  3.8293071436083612`*^9, 3.8469233528793173`*^9, 3.84718177746349*^9, 
  3.847182021876001*^9},
 CellLabel->
  "Out[292]=",ExpressionUUID->"a6c09331-8ab7-4e84-ab13-1ee05652be50"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"large", "=", "1000000"}]], "Input",
 CellChangeTimes->{{3.847182874246641*^9, 3.847182908501713*^9}},
 CellLabel->
  "In[297]:=",ExpressionUUID->"150908d4-a2bd-42fc-bd65-ab3a062e218f"],

Cell[BoxData["1000000"], "Output",
 CellChangeTimes->{3.847182932545588*^9},
 CellLabel->
  "Out[297]=",ExpressionUUID->"e235f3e3-9343-4038-b408-9508293da7ec"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "93", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"large", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847182866934411*^9, 3.847182867725677*^9}, {
  3.847182913093989*^9, 3.847182916437993*^9}, {3.847182955927544*^9, 
  3.847182956501896*^9}},
 CellLabel->
  "In[300]:=",ExpressionUUID->"b74a9fd7-5246-4e57-97f6-5f7b9222868c"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.847182925273715*^9, 3.8471829593266*^9}},
 CellLabel->
  "Out[301]=",ExpressionUUID->"3bfa7051-fe83-44ac-9456-ae8cb0c7633c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "94", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"large", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.84718298476178*^9, 3.8471829898627157`*^9}},
 CellLabel->
  "In[302]:=",ExpressionUUID->"00e7ab42-a7ba-4d44-9e39-1baae7aee23d"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847182991827559*^9},
 CellLabel->
  "Out[303]=",ExpressionUUID->"6699e85f-4743-428a-8104-de4ddcde153e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "95", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"large", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{3.847183002198803*^9},
 CellLabel->
  "In[304]:=",ExpressionUUID->"8f43f534-33f5-43ad-9591-0ef5d5e95517"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847183010181581*^9},
 CellLabel->
  "Out[305]=",ExpressionUUID->"2a50a769-29e9-40b4-9e32-063dcfd9215b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "96", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"large", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{3.847183019102738*^9},
 CellLabel->
  "In[306]:=",ExpressionUUID->"21a981a2-daa9-4a35-9b2c-548f275f8fd2"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.8471830218175077`*^9},
 CellLabel->
  "Out[307]=",ExpressionUUID->"00bbd2b5-d24c-475f-a890-b97a0a0ce4ef"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"kr", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", " ", 
       RowBox[{
        RowBox[{
         RowBox[{"17", "\[LessEqual]", "i", "\[LessEqual]", "18"}], " ", "||",
          " ", 
         RowBox[{"93", "\[LessEqual]", "i", "\[LessEqual]", "96"}]}], ",", 
        RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"status", "=", 
       RowBox[{"TimeConstrained", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
          RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
           RowBox[{"sq", ">=", 
            RowBox[{"k", "*", 
             RowBox[{"r", "^", "2"}]}]}], "]"}]}], ",", "60"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"status", "===", "$Aborted"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< skipped\>\""}], "]"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"maxK", ">", "0"}], " ", "&&", " ", 
           RowBox[{"maxK", "=!=", "\[Infinity]"}]}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"truth", "=", 
            RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
             RowBox[{"sq", ">", 
              RowBox[{"maxK", "*", 
               RowBox[{"r", "^", "2"}]}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"truth", ",", 
             RowBox[{"addon", "=", "\"\< equality cannot occur\>\""}], ",", 
             RowBox[{"addon", "=", "\"\<\>\""}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
             RowBox[{"displayRealNumber", "[", 
              RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}], ",", "addon"}], 
            "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.824461166521564*^9, 3.824461182656807*^9}, {
   3.824461213772225*^9, 3.824461344649808*^9}, {3.824461653755369*^9, 
   3.824461655714657*^9}, {3.824461696356172*^9, 3.824461719978339*^9}, {
   3.8244618362837477`*^9, 3.824461847306797*^9}, {3.824461877915126*^9, 
   3.824461967522944*^9}, {3.8244620016132*^9, 3.824462002323428*^9}, {
   3.824462053596875*^9, 3.824462106171268*^9}, 3.824462215845264*^9, {
   3.824462363300476*^9, 3.824462434843912*^9}, {3.8244625011649437`*^9, 
   3.824462503482657*^9}, {3.824462652740505*^9, 3.824462656162724*^9}, {
   3.824462967640032*^9, 3.824463004411928*^9}, {3.824463334350154*^9, 
   3.82446333774028*^9}, {3.824545103972289*^9, 3.8245451071467953`*^9}, {
   3.824545271955614*^9, 3.824545274379324*^9}, {3.824635580541388*^9, 
   3.8246357250295467`*^9}, {3.824635760351747*^9, 3.824635821956614*^9}, {
   3.824635968071031*^9, 3.824635979524742*^9}, {3.824636020183251*^9, 
   3.82463602369316*^9}, {3.824636156207407*^9, 3.824636159517654*^9}, {
   3.8246398170411263`*^9, 3.8246398349121637`*^9}, {3.846923501253386*^9, 
   3.846923624315917*^9}, {3.846923659909547*^9, 3.84692366024389*^9}, {
   3.84692396362153*^9, 3.846923969540464*^9}, {3.846924003350803*^9, 
   3.846924070131873*^9}, 3.846924119525423*^9, {3.846924157429665*^9, 
   3.846924157739809*^9}, {3.846924235293537*^9, 3.846924253339911*^9}, {
   3.846924286605463*^9, 3.846924290236058*^9}, {3.8469243828917837`*^9, 
   3.846924386540406*^9}, {3.846924433468356*^9, 3.846924551092276*^9}, {
   3.846924592508423*^9, 3.846924632068387*^9}, {3.846924699406701*^9, 
   3.8469247157325897`*^9}, {3.8469250587084627`*^9, 3.846925059232603*^9}, {
   3.8469256640033693`*^9, 3.846925711786619*^9}, {3.84692610400403*^9, 
   3.846926139170879*^9}, {3.847013000306656*^9, 3.847013010441777*^9}, {
   3.847013253197874*^9, 3.8470133105094337`*^9}, 3.847030991610602*^9},
 CellLabel->
  "In[293]:=",ExpressionUUID->"abc39306-2178-44dc-b7c3-3510a1112983"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["X", 11, " ", "k=\!\(\*RowBox[{\"1\"}]\)", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471820228247347`*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"b147d515-a8fc-4227-af20-4bb87fe7eb72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \
\\\"3\\\"], \\\" \\\", RowBox[{\\\"(\\\", RowBox[{\\\"3\\\", \\\"+\\\", \
SqrtBox[\\\"3\\\"]}], \\\")\\\"}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 14, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"3\"], \" \", RowBox[{\"(\", RowBox[{\
\"3\", \"+\", SqrtBox[\"3\"]}], \")\"}]}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471820686536427`*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"eaa086e5-9e68-404b-97db-9f0eeda559b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\", \\\"+\\\", \
SqrtBox[\\\"3\\\"]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 16, " ", "k=\!\(\*RowBox[{\"1\", \"+\", SqrtBox[\"3\"]}]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182090923506*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"c5697832-9f3c-4373-be82-959043696a75"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"7\\\", \
\\\"3\\\"]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 23, " ", "k=\!\(\*FractionBox[\"7\", \"3\"]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182092984357*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"9d1aad74-2382-412c-819d-50573d83f6ca"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 36, " ", "k=\!\(\*RowBox[{\"2\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471821019160013`*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"6a1c70d5-4b4e-4ebd-bc6d-b6381f9df1f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"3\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 44, " ", "k=\!\(\*RowBox[{\"3\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471821042520037`*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"948c01c1-06ef-4f33-85ec-2cfe6b02e033"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[SqrtBox[\\\"7\\\"], \\\"4\
\\\"]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 59, " ", "k=\!\(\*FractionBox[SqrtBox[\"7\"], \"4\"]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182112831624*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"f0e8eb7d-3c90-4cac-a702-0fcf868bce1d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" skipped\"\>"}],
  SequenceForm["X", 62, " skipped"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182174987418*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"66c53944-b64f-430c-a157-4a68ae570688"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\" skipped\"\>"}],
  SequenceForm["X", 66, " skipped"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182236042718*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"ba604a8e-26d7-4097-abee-394c5fc3ffb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 67, " ", "k=\!\(\*RowBox[{\"1\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182274889349*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"82f0658d-d2d5-4e25-9e2b-deeb21e487e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 74, " ", "k=\!\(\*RowBox[{\"1\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182282804625*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"03356b87-261e-471b-a271-fa0be97cd4e5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["X", 80, " ", "k=\!\(\*RowBox[{\"2\"}]\)", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182284893711*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"f8234067-4a20-4795-9c64-e6e6c74b58b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"3\\\", \
\\\"2\\\"]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 88, " ", "k=\!\(\*FractionBox[\"3\", \"2\"]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182307903968*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"8d5d3498-6030-40fe-b5a5-3b157112a78b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 98, " ", "k=\!\(\*RowBox[{\"1\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.84718232596303*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"a6e539c8-ca7d-4d31-a5ed-9fd8709dbcc2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 99, " ", "k=\!\(\*RowBox[{\"1\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327206111*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"bee8af58-31d8-4c51-85c5-467a26e6b059"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 100, " ", "k=\!\(\*RowBox[{\"1\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8471823273899193`*^9},
 CellLabel->
  "During evaluation of \
In[293]:=",ExpressionUUID->"41f7fe4f-c3be-48c0-b02d-29951090449f"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"small", "=", 
  RowBox[{"1", "/", "1000000"}]}]], "Input",
 CellChangeTimes->{{3.847183132823852*^9, 3.847183138358418*^9}},
 CellLabel->
  "In[308]:=",ExpressionUUID->"cf15d2a9-27da-4e11-9e29-a995f89e7061"],

Cell[BoxData[
 FractionBox["1", "1000000"]], "Output",
 CellChangeTimes->{3.84718314113557*^9},
 CellLabel->
  "Out[308]=",ExpressionUUID->"cb986441-a066-44b8-8efc-7f6d3582b502"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "17", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847183213807132*^9, 3.847183214238759*^9}},
 CellLabel->
  "In[321]:=",ExpressionUUID->"8f1f74ef-ef98-4a7e-a7d1-753dd2e184ae"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847183217805337*^9},
 CellLabel->
  "Out[322]=",ExpressionUUID->"9b8a27ab-f55f-4168-b6ab-abb311670f0f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "18", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847183223423259*^9, 3.847183245959177*^9}},
 CellLabel->
  "In[323]:=",ExpressionUUID->"5c7a25d1-bb74-4f3d-9612-64f0d424c4dc"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.84718324923333*^9},
 CellLabel->
  "Out[324]=",ExpressionUUID->"2b16ad2e-4b5a-4435-a9d9-cedc84eb3d40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "62", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847183314183528*^9, 3.847183314551218*^9}},
 CellLabel->
  "In[325]:=",ExpressionUUID->"b16381dd-7fc3-479d-b712-722d4fb2d067"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847183316188068*^9},
 CellLabel->
  "Out[326]=",ExpressionUUID->"65b389f4-a6a5-4ec9-b456-7eabaf0e1971"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "66", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847183326815702*^9, 3.847183327079048*^9}},
 CellLabel->
  "In[327]:=",ExpressionUUID->"45db1638-a92d-4b4f-bc82-14c4aa2c27e6"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847183328600428*^9},
 CellLabel->
  "Out[328]=",ExpressionUUID->"dfef9626-8c89-4c32-93b7-a03e8477a2ad"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "93", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847183148214675*^9, 3.847183151902515*^9}},
 CellLabel->
  "In[309]:=",ExpressionUUID->"6385f828-c6e2-493c-9c97-e9ab0b53808b"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.8471831553997183`*^9},
 CellLabel->
  "Out[310]=",ExpressionUUID->"7492c2f1-5b6f-4eac-8505-cd29d8d48de6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "94", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8471831659591093`*^9, 3.847183170264081*^9}},
 CellLabel->
  "In[313]:=",ExpressionUUID->"67b93b19-5a13-4e23-859a-5892d1ab5b0f"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.847183166446509*^9, 3.8471831725113983`*^9}},
 CellLabel->
  "Out[314]=",ExpressionUUID->"8c80572e-3ece-46c5-8d19-bc0341a8e2c2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "95", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847183181031169*^9, 3.847183188518745*^9}},
 CellLabel->
  "In[317]:=",ExpressionUUID->"3bf86feb-557f-4178-8685-382dad977864"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.847183182725811*^9, 3.8471831902784986`*^9}},
 CellLabel->
  "Out[318]=",ExpressionUUID->"6abbf565-ac93-4348-8e24-de0ec13bf21f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "96", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{"small", "^", "2"}], " ", 
    RowBox[{"r", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{3.847183196375259*^9},
 CellLabel->
  "In[319]:=",ExpressionUUID->"74447847-131b-44d0-8c13-0f2fb877a032"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847183199090736*^9},
 CellLabel->
  "Out[320]=",ExpressionUUID->"113e09bf-2a13-4345-977b-7d16388a3224"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distance of Center to X3 Compared With R", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824729982408146*^9, 3.824729985455653*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"7ca174cb-99ab-4f6f-bacf-b6daf7cc3eea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], "<=", 
    RowBox[{"kR", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"i", "\[Equal]", "3"}], "||", 
         RowBox[{"i", "\[Equal]", "30"}]}], ",", 
        RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"status", "=", 
       RowBox[{"TimeConstrained", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"{", 
           RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
          RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
           RowBox[{"sq", "<=", 
            RowBox[{"k", "*", 
             RowBox[{"R", "^", "2"}]}]}], "]"}]}], ",", "60"}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"status", "===", "$Aborted"}], ",", "\[IndentingNewLine]", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< skipped\>\""}], "]"}], ",",
         "\[IndentingNewLine]", 
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"minK", ">", "0"}], " ", "&&", " ", 
           RowBox[{"minK", "\[NotEqual]", "1"}]}], ",", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"truth", "=", 
            RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
             RowBox[{"sq", "<", 
              RowBox[{"minK", "*", 
               RowBox[{"R", "^", "2"}]}]}], "]"}]}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"If", "[", 
            RowBox[{"truth", ",", 
             RowBox[{"addon", "=", "\"\< equality cannot occur\>\""}], ",", 
             RowBox[{"addon", "=", "\"\<\>\""}]}], "]"}], ";", 
           "\[IndentingNewLine]", 
           RowBox[{"Print", "[", 
            RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
             RowBox[{"displayRealNumber", "[", 
              RowBox[{"Sqrt", "[", "minK", "]"}], "]"}], ",", "addon"}], 
            "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]}], 
       "\[IndentingNewLine]", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.824463612277162*^9, 3.824463661077183*^9}, {
   3.824463710198827*^9, 3.824463713212811*^9}, {3.824464631724161*^9, 
   3.82446463521832*^9}, {3.8244659130589943`*^9, 3.824465916542891*^9}, {
   3.824471872694209*^9, 3.824471879716907*^9}, {3.8244719372079277`*^9, 
   3.8244719468233213`*^9}, {3.824471999383284*^9, 3.824472017302936*^9}, 
   3.824473476071122*^9, {3.824473629700508*^9, 3.8244736387140007`*^9}, {
   3.8244736695954657`*^9, 3.824473670322299*^9}, {3.824636146494546*^9, 
   3.824636248381619*^9}, {3.824636627792204*^9, 3.824636633031229*^9}, {
   3.82463988301733*^9, 3.824639896104583*^9}, {3.824639939297369*^9, 
   3.8246399398491096`*^9}, {3.846926618344041*^9, 3.846926694548147*^9}, {
   3.846926835611361*^9, 3.846926848404097*^9}, {3.8469268854291763`*^9, 
   3.8469269090701714`*^9}, 3.846926939658278*^9, 3.846927105365296*^9, 
   3.846927278253914*^9, {3.846927483126742*^9, 3.846927483588409*^9}, {
   3.846927753559873*^9, 3.846927768453513*^9}, {3.8469282780340357`*^9, 
   3.8469282787435226`*^9}, {3.8469290745109797`*^9, 3.846929104141101*^9}, {
   3.846929313055341*^9, 3.846929358238517*^9}, {3.846931780570982*^9, 
   3.846931827328129*^9}, {3.8470314393689537`*^9, 3.847031467216337*^9}, {
   3.847183359809828*^9, 3.847183360559773*^9}},
 CellLabel->
  "In[329]:=",ExpressionUUID->"ed9a2e38-03af-41d0-888e-39e2379ebe51"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"3\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 4, " ", "k=\!\(\*RowBox[{\"3\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471833641361227`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"656385ff-c01f-4c86-a5b3-59330218a677"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"3\\\", \
\\\"2\\\"]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 5, " ", "k=\!\(\*FractionBox[\"3\", \"2\"]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183364233707*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"e0a3c25c-43ec-4359-8942-a9f0b39dccc2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
SqrtBox[\\\"3\\\"]]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 13, " ", "k=\!\(\*FractionBox[\"2\", SqrtBox[\"3\"]]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183403569668*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"adc70595-6b22-4151-8fff-a56885687c33"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
SqrtBox[\\\"3\\\"]]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 14, " ", "k=\!\(\*FractionBox[\"2\", SqrtBox[\"3\"]]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471834433810797`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"4f9a01a4-df71-40eb-9751-3abbde322fc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" skipped\"\>"}],
  SequenceForm["X", 17, " skipped"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471835117721043`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"d26fc958-76a7-41d1-96cd-067b434323ac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\" skipped\"\>"}],
  SequenceForm["X", 18, " skipped"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183571802103*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"6a81eb8b-69c7-4a95-a348-455e52e3e225"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.315481999 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"539\\\", \\\"-\\\", \
RowBox[{\\\"337\\\", \\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"730\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"334\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", \
RowBox[{\\\"111\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\"+\
\\\", RowBox[{\\\"19\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"5\\\"]}]}]\
\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 19, " ", 
   "k\[TildeTilde]1.315481999 is the largest positive root of \
\!\(\*RowBox[{\"539\", \"-\", RowBox[{\"337\", \" \", \"x\"}], \"-\", \
RowBox[{\"730\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"334\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"111\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"19\", \" \", SuperscriptBox[\"x\", \"5\"]}]}]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471835726169357`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"f29e4f11-e73d-41d0-a254-d281b1e904f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"3\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 20, " ", "k=\!\(\*RowBox[{\"3\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183572708886*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"e11ace65-41d3-4783-9f3e-fd65bc890374"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
SqrtBox[\\\"3\\\"]]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 25, " ", "k=\!\(\*FractionBox[\"2\", SqrtBox[\"3\"]]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471835737570763`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"8e5ee8ce-ca56-4624-bbe3-0189a4790e2d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.477671258 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"2197\\\", \\\"-\\\", \
RowBox[{\\\"169\\\", \\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"9566\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"4734\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"729\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"27\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"5\\\"]}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 27, " ", 
   "k\[TildeTilde]1.477671258 is the largest positive root of \
\!\(\*RowBox[{\"2197\", \"-\", RowBox[{\"169\", \" \", \"x\"}], \"-\", \
RowBox[{\"9566\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"4734\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"729\
\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"27\", \" \", \
SuperscriptBox[\"x\", \"5\"]}]}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183575185566*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"d7039594-ffd6-48bc-8cac-a71dbb19b75e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.205917120 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"125\\\"}], \\\"-\\\", \
RowBox[{\\\"75\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"77\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"59\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"3\\\"]}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 28, " ", 
   "k\[TildeTilde]1.205917120 is the positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"125\"}], \"-\", RowBox[{\"75\", \" \", \
\"x\"}], \"+\", RowBox[{\"77\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"59\", \" \", SuperscriptBox[\"x\", \"3\"]}]}]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183576004929*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"57977b6b-32b3-4fa0-9bc0-bdd02e9a00b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.054067061 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"171\\\"}], \\\"-\\\", \
RowBox[{\\\"134\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"136\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"126\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", \
RowBox[{\\\"11\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 34, " ", 
   "k\[TildeTilde]1.054067061 is the positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"171\"}], \"-\", RowBox[{\"134\", \" \", \
\"x\"}], \"+\", RowBox[{\"136\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"126\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"11\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471835789798517`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"92363534-1fd7-4929-a432-338b5075c16e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \\\"15\
\\\"], \\\" \\\", RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"3\\\"}], \
\\\"+\\\", RowBox[{\\\"8\\\", \\\" \\\", SqrtBox[\\\"6\\\"]}]}], \
\\\")\\\"}]}]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 43, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"15\"], \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"3\"}], \"+\", RowBox[{\"8\", \" \", \
SqrtBox[\"6\"]}]}], \")\"}]}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183582185337*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"1e97435b-6337-4fad-b2aa-d49ad2804e46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*SqrtBox[RowBox[{\\\"3\\\", \\\" \\\", \
RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"3\\\"}], \\\"+\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]}], \\\")\\\"}]}]]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 46, " ", 
   "k=\!\(\*SqrtBox[RowBox[{\"3\", \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"3\"}], \"+\", RowBox[{\"2\", \" \", \
SqrtBox[\"3\"]}]}], \")\"}]}]]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471835831578074`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"f3ae8c57-20f8-40c2-b919-b130e93931a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[SqrtBox[\\\"10\\\"], \
\\\"3\\\"]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 51, " ", "k=\!\(\*FractionBox[SqrtBox[\"10\"], \"3\"]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183585757526*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"ec2629fc-c36d-47e4-ab56-c2326acb5e90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 52, " ", "k=\!\(\*RowBox[{\"2\"}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183586034985*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"c2a07d5b-4985-402e-a760-bc29140c5f6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.089001927 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"147\\\", \\\"-\\\", \
RowBox[{\\\"204\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"8\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"16\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"32\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 53, " ", 
   "k\[TildeTilde]1.089001927 is the largest positive root of \
\!\(\*RowBox[{\"147\", \"-\", RowBox[{\"204\", \" \", \"x\"}], \"+\", \
RowBox[{\"8\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"16\", \
\" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"32\", \" \", \
SuperscriptBox[\"x\", \"4\"]}]}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183592465397*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"67ccfda7-6fba-447e-bcae-d6e67eafa560"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \
\\\"2\\\"}], \\\" \\\", RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"3\\\
\"}], \\\"+\\\", SqrtBox[\\\"6\\\"]}], \\\")\\\"}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 67, " ", 
   "k=\!\(\*RowBox[{RowBox[{\"-\", \"2\"}], \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"3\"}], \"+\", SqrtBox[\"6\"]}], \")\"}]}]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.84718360897715*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"489bb86a-5fc0-4b26-a569-b185a7b58116"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.057298324 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"117\\\", \\\"-\\\", RowBox[{\\\"2\\\", \
\\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"107\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"4\\\", \\\" \\\
\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 79, " ", 
   "k\[TildeTilde]1.057298324 is the smallest positive root of \!\(\*RowBox[{\
\"117\", \"-\", RowBox[{\"2\", \" \", \"x\"}], \"-\", RowBox[{\"107\", \" \", \
SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"4\", \" \", \
SuperscriptBox[\"x\", \"3\"]}]}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.847183616008768*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"d8d96903-59ba-4cf8-8fc0-de97f278662d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"5\\\", \
\\\"4\\\"]\\)\"\>", "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 80, " ", "k=\!\(\*FractionBox[\"5\", \"4\"]\)", 
   " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471836162541027`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"f6f86d00-cd95-4ebe-9237-dc1607f17306"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"15\\\", \\\"-\\\", \
RowBox[{\\\"8\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]}]\\)\"\>", 
   "\[InvisibleSpace]", "\<\" equality cannot occur\"\>"}],
  SequenceForm[
  "X", 88, " ", 
   "k=\!\(\*RowBox[{\"15\", \"-\", RowBox[{\"8\", \" \", \
SqrtBox[\"3\"]}]}]\)", " equality cannot occur"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847182327628504*^9, 3.8471836231660147`*^9},
 CellLabel->
  "During evaluation of \
In[329]:=",ExpressionUUID->"6075cb52-9136-46d6-9eb9-e756f6df3c33"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{"need", " ", "to", " ", "check", " ", "i"}], "=", 
   RowBox[{"17", " ", "ran", " ", "for", " ", "25", " ", "hours"}]}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.84693239780265*^9, 3.8469324126417427`*^9}, {
  3.847278876021577*^9, 
  3.847278885244336*^9}},ExpressionUUID->"40faa276-5603-410a-8329-\
dee6fa43096b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "17", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
  RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
   RowBox[{"sq", "<=", 
    RowBox[{"k", "*", 
     RowBox[{"R", "^", "2"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.847183753528637*^9, 3.8471837659084682`*^9}},
 CellLabel->
  "In[330]:=",ExpressionUUID->"b4b2fbb8-98df-4dd7-8d1d-ce7b624929a9"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.847278868763826*^9},
 CellLabel->
  "Out[331]=",ExpressionUUID->"a7e3e11f-00b7-4013-8a73-6aa87270391d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"root1", "=", 
  RowBox[{"Root", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"49", 
       RowBox[{"#", "^", "3"}]}], "+", 
      RowBox[{"22", 
       RowBox[{"#", "^", "2"}]}], "-", 
      RowBox[{"39", "#"}], "-", "36"}], "&"}], ",", "1"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.847282875603804*^9, 3.8472828782971287`*^9}, {
  3.8472829371389923`*^9, 3.847282985747254*^9}, {3.847283034653919*^9, 
  3.8472830699158087`*^9}},
 CellLabel->
  "In[399]:=",ExpressionUUID->"d3740d7f-ec2d-408e-862b-b46678292e37"],

Cell[BoxData[
 InterpretationBox[
  TemplateBox[{"Root",TemplateBox[{"\"1.03\"", 
      DynamicBox[
       FEPrivate`FrontEndResource[
       "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
    TagBox[
     RowBox[{"Root", "[", 
       RowBox[{
         RowBox[{
           RowBox[{
             RowBox[{"-", "36"}], "-", 
             RowBox[{"39", " ", "#1"}], "+", 
             RowBox[{"22", " ", 
               SuperscriptBox["#1", "2"]}], "+", 
             RowBox[{"49", " ", 
               SuperscriptBox["#1", "3"]}]}], "&"}], ",", "1"}], "]"}], 
     Short[#, 7]& ],1.0255827185687272`},
   "NumericalApproximation"],
  Root[-36 - 39 # + 22 #^2 + 49 #^3& , 1, 0]]], "Output",
 CellChangeTimes->{3.847282966170751*^9, 3.847283037271914*^9, 
  3.847283071043366*^9},
 CellLabel->
  "Out[399]=",ExpressionUUID->"7e585a72-0041-495a-909a-b635aed3dd3e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{"root1", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.847283074220606*^9, 3.847283091395322*^9}},
 CellLabel->
  "In[401]:=",ExpressionUUID->"8c26f2a2-a259-434b-85ca-aa68921d68af"],

Cell[BoxData["1.02558271856872718075237571611069142818`10."], "Output",
 CellChangeTimes->{{3.847283081573053*^9, 3.847283092441958*^9}},
 CellLabel->
  "Out[401]=",ExpressionUUID->"809e916e-9fbb-466f-996e-4c9a0f7f0eab"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{
    RowBox[{"root1", "^", "2"}], "*", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847283124972229*^9, 3.847283127203792*^9}},
 CellLabel->
  "In[402]:=",ExpressionUUID->"f9a34fb6-efe1-425d-89a3-c907f0ee5a19"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality occurs for (x,y)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     InterpretationBox[
      TemplateBox[{"Root",TemplateBox[{"\"0.0171\"", 
          DynamicBox[
           FEPrivate`FrontEndResource[
           "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
        TagBox[
         RowBox[{"Root", "[", 
           RowBox[{
             RowBox[{
               RowBox[{
                 RowBox[{"-", "27"}], "+", 
                 RowBox[{"1620", " ", "#1"}], "-", 
                 RowBox[{"2676", " ", 
                   SuperscriptBox["#1", "2"]}], "+", 
                 RowBox[{"9312", " ", 
                   SuperscriptBox["#1", "3"]}], "-", 
                 RowBox[{"5648", " ", 
                   SuperscriptBox["#1", "4"]}], "+", 
                 RowBox[{"10304", " ", 
                   SuperscriptBox["#1", "5"]}], "+", 
                 RowBox[{"3136", " ", 
                   SuperscriptBox["#1", "6"]}]}], "&"}], ",", "2"}], "]"}], 
         Short[#, 7]& ],0.017122385397442156`},
       "NumericalApproximation"],
      Root[-27 + 1620 # - 2676 #^2 + 9312 #^3 - 5648 #^4 + 10304 #^5 + 
       3136 #^6& , 2, 0]], ",", 
     InterpretationBox[
      TemplateBox[{"Root",TemplateBox[{"\"0.522\"", 
          DynamicBox[
           FEPrivate`FrontEndResource[
           "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
        TagBox[
         RowBox[{"Root", "[", 
           RowBox[{
             RowBox[{
               RowBox[{"6561", "-", 
                 RowBox[{"1278986760", " ", 
                   SuperscriptBox["#1", "2"]}], "+", 
                 RowBox[{"5617894896", " ", 
                   SuperscriptBox["#1", "4"]}], "-", 
                 RowBox[{"3693162240", " ", 
                   SuperscriptBox["#1", "6"]}], "+", 
                 RowBox[{"1092853504", " ", 
                   SuperscriptBox["#1", "8"]}], "-", 
                 RowBox[{"159057920", " ", 
                   SuperscriptBox["#1", "10"]}], "+", 
                 RowBox[{"9834496", " ", 
                   SuperscriptBox["#1", "12"]}]}], "&"}], ",", "4"}], "]"}], 
         Short[#, 7]& ],0.5222838084489433},
       "NumericalApproximation"],
      Root[
      6561 - 1278986760 #^2 + 5617894896 #^4 - 3693162240 #^6 + 
       1092853504 #^8 - 159057920 #^10 + 9834496 #^12& , 4, 0]]}], "}"}]}],
  SequenceForm["Equality occurs for (x,y)=", {
    Root[-27 + 1620 # - 2676 #^2 + 9312 #^3 - 5648 #^4 + 10304 #^5 + 
     3136 #^6& , 2, 0], 
    Root[6561 - 1278986760 #^2 + 5617894896 #^4 - 3693162240 #^6 + 
     1092853504 #^8 - 159057920 #^10 + 9834496 #^12& , 4, 0]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.847283229735669*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"3e2eb207-d92c-400c-8fe0-f17a1db5f46a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality condition: R=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\", r=\"\>", "\[InvisibleSpace]", 
   InterpretationBox[
    TemplateBox[{"Root",TemplateBox[{"\"0.0171\"", 
        DynamicBox[
         FEPrivate`FrontEndResource[
         "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
      TagBox[
       RowBox[{"Root", "[", 
         RowBox[{
           RowBox[{
             RowBox[{
               RowBox[{"-", "27"}], "+", 
               RowBox[{"1620", " ", "#1"}], "-", 
               RowBox[{"2676", " ", 
                 SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"9312", " ", 
                 SuperscriptBox["#1", "3"]}], "-", 
               RowBox[{"5648", " ", 
                 SuperscriptBox["#1", "4"]}], "+", 
               RowBox[{"10304", " ", 
                 SuperscriptBox["#1", "5"]}], "+", 
               RowBox[{"3136", " ", 
                 SuperscriptBox["#1", "6"]}]}], "&"}], ",", "2"}], "]"}], 
       Short[#, 7]& ],0.017122385397442156`},
     "NumericalApproximation"],
    Root[-27 + 1620 # - 2676 #^2 + 9312 #^3 - 5648 #^4 + 10304 #^5 + 
     3136 #^6& , 2, 0]], "\[InvisibleSpace]", "\<\", s=\"\>", 
   "\[InvisibleSpace]", 
   InterpretationBox[
    TemplateBox[{"Root",TemplateBox[{"\"0.522\"", 
        DynamicBox[
         FEPrivate`FrontEndResource[
         "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
      TagBox[
       RowBox[{"Root", "[", 
         RowBox[{
           RowBox[{
             RowBox[{"6561", "-", 
               RowBox[{"1278986760", " ", 
                 SuperscriptBox["#1", "2"]}], "+", 
               RowBox[{"5617894896", " ", 
                 SuperscriptBox["#1", "4"]}], "-", 
               RowBox[{"3693162240", " ", 
                 SuperscriptBox["#1", "6"]}], "+", 
               RowBox[{"1092853504", " ", 
                 SuperscriptBox["#1", "8"]}], "-", 
               RowBox[{"159057920", " ", 
                 SuperscriptBox["#1", "10"]}], "+", 
               RowBox[{"9834496", " ", 
                 SuperscriptBox["#1", "12"]}]}], "&"}], ",", "4"}], "]"}], 
       Short[#, 7]& ],0.5222838084489433},
     "NumericalApproximation"],
    Root[6561 - 1278986760 #^2 + 5617894896 #^4 - 3693162240 #^6 + 
     1092853504 #^8 - 159057920 #^10 + 9834496 #^12& , 4, 0]]}],
  SequenceForm["Equality condition: R=", 1, ", r=", 
   Root[-27 + 1620 # - 2676 #^2 + 9312 #^3 - 5648 #^4 + 10304 #^5 + 
    3136 #^6& , 2, 0], ", s=", 
   Root[6561 - 1278986760 #^2 + 5617894896 #^4 - 3693162240 #^6 + 
    1092853504 #^8 - 159057920 #^10 + 9834496 #^12& , 4, 0]],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472832299526377`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"307ec12d-2b8b-4e37-b591-491996cc7ee9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"\<\"a, b, c are roots of \"\>", "\[InvisibleSpace]", 
     SuperscriptBox["x", "3"]}], "+", 
    RowBox[{"x", " ", 
     InterpretationBox[
      TemplateBox[{"Root",TemplateBox[{"\"0.342\"", 
          DynamicBox[
           FEPrivate`FrontEndResource[
           "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
        TagBox[
         RowBox[{"Root", "[", 
           RowBox[{
             RowBox[{
               RowBox[{
                 RowBox[{"-", "44469"}], "-", 
                 RowBox[{"70146", " ", "#1"}], "+", 
                 RowBox[{"669285", " ", 
                   SuperscriptBox["#1", "2"]}], "-", 
                 RowBox[{"260604", " ", 
                   SuperscriptBox["#1", "3"]}], "+", 
                 RowBox[{"55681", " ", 
                   SuperscriptBox["#1", "4"]}], "-", 
                 RowBox[{"5978", " ", 
                   SuperscriptBox["#1", "5"]}], "+", 
                 RowBox[{"343", " ", 
                   SuperscriptBox["#1", "6"]}]}], "&"}], ",", "2"}], "]"}], 
         Short[#, 7]& ],0.3415630942393996},
       "NumericalApproximation"],
      Root[-44469 - 70146 # + 669285 #^2 - 260604 #^3 + 55681 #^4 - 5978 #^5 + 
       343 #^6& , 2, 0]]}], "+", 
    InterpretationBox[
     TemplateBox[{"Root",TemplateBox[{"\"-0.0358\"", 
         DynamicBox[
          FEPrivate`FrontEndResource[
          "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
       TagBox[
        RowBox[{"Root", "[", 
          RowBox[{
            RowBox[{
              RowBox[{
                RowBox[{"-", "2187"}], "+", 
                RowBox[{"1709019", " ", 
                  SuperscriptBox["#1", "2"]}], "+", 
                RowBox[{"123783", " ", 
                  SuperscriptBox["#1", "4"]}], "+", 
                RowBox[{"2401", " ", 
                  SuperscriptBox["#1", "6"]}]}], "&"}], ",", "1"}], "]"}], 
        Short[#, 7]& ],-0.03577097862042665},
      "NumericalApproximation"],
     Root[-2187 + 1709019 #^2 + 123783 #^4 + 2401 #^6& , 1, 0]], "+", 
    RowBox[{
     SuperscriptBox["x", "2"], " ", 
     InterpretationBox[
      TemplateBox[{"Root",TemplateBox[{"\"-1.04\"", 
          DynamicBox[
           FEPrivate`FrontEndResource[
           "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
        TagBox[
         RowBox[{"Root", "[", 
           RowBox[{
             RowBox[{
               RowBox[{"6561", "-", 
                 RowBox[{"319746690", " ", 
                   SuperscriptBox["#1", "2"]}], "+", 
                 RowBox[{"351118431", " ", 
                   SuperscriptBox["#1", "4"]}], "-", 
                 RowBox[{"57705660", " ", 
                   SuperscriptBox["#1", "6"]}], "+", 
                 RowBox[{"4268959", " ", 
                   SuperscriptBox["#1", "8"]}], "-", 
                 RowBox[{"155330", " ", 
                   SuperscriptBox["#1", "10"]}], "+", 
                 RowBox[{"2401", " ", 
                   SuperscriptBox["#1", "12"]}]}], "&"}], ",", "1"}], "]"}], 
         Short[#, 7]& ],-1.0445676168978866`},
       "NumericalApproximation"],
      Root[
      6561 - 319746690 #^2 + 351118431 #^4 - 57705660 #^6 + 4268959 #^8 - 
       155330 #^10 + 2401 #^12& , 1, 0]]}]}], "\[Equal]", "0"}],
  SequenceForm[
  "a, b, c are roots of ", $CellContext`x^3 + $CellContext`x 
     Root[-44469 - 70146 # + 669285 #^2 - 260604 #^3 + 55681 #^4 - 5978 #^5 + 
       343 #^6& , 2, 0] + 
    Root[-2187 + 1709019 #^2 + 123783 #^4 + 2401 #^6& , 1, 
      0] + $CellContext`x^2 
     Root[6561 - 319746690 #^2 + 351118431 #^4 - 57705660 #^6 + 4268959 #^8 - 
       155330 #^10 + 2401 #^12& , 1, 0] == 0],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472832299629803`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"197d7cbf-a5ef-4187-98e4-c3b70e7c48b3"]
}, Open  ]],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.847285102255686*^9},
 CellLabel->
  "Out[402]=",ExpressionUUID->"acd008ae-6907-4192-b685-d3c98d2c7104"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"root1", "^", "2"}], "+", 
      RowBox[{"1", "/", "100"}]}], ")"}], "*", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847287536022599*^9, 3.847287541486183*^9}},
 CellLabel->
  "In[421]:=",ExpressionUUID->"ae9746a9-e9f8-404e-8f42-34fe49b7dcfe"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.847287559892276*^9},
 CellLabel->
  "Out[421]=",ExpressionUUID->"686c543b-a4fa-4be6-ac8e-9d2ce5d9b449"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{"R", "^", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{3.8472851153964*^9},
 CellLabel->
  "In[403]:=",ExpressionUUID->"ab1f5e37-fb3d-4107-9775-38a0fb74f9a5"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{3.84728511848528*^9},
 CellLabel->
  "Out[403]=",ExpressionUUID->"a0f5130f-67cb-4768-b9fc-294ff37b0c40"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"N", "[", 
  RowBox[{
   RowBox[{"root1", "^", "2"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.847285128397935*^9, 3.847285141596109*^9}},
 CellLabel->
  "In[405]:=",ExpressionUUID->"b6bc18b3-86d3-433d-bfab-ad2819c2d904"],

Cell[BoxData["1.05181991262682105999644814989854404677`10."], "Output",
 CellChangeTimes->{{3.8472851314221687`*^9, 3.847285142626525*^9}},
 CellLabel->
  "Out[405]=",ExpressionUUID->"ec357ab1-01c4-4fc8-a87b-de445d985592"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{"1.05", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8472851553405037`*^9, 3.84728515651615*^9}},
 CellLabel->
  "In[406]:=",ExpressionUUID->"0ca9f0f2-9d45-4c8c-a7c8-0fbe63c77b72"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.8472869293465347`*^9},
 CellLabel->
  "Out[406]=",ExpressionUUID->"b4c6547e-77d6-47eb-ba6a-3f42a2b1ac5f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"105", "/", "100"}], ")"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847287137773259*^9, 3.847287185132756*^9}},
 CellLabel->
  "In[412]:=",ExpressionUUID->"76fe387b-689e-461c-b7f2-9da3a9b21560"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.847287140908608*^9, 3.847287187451161*^9}},
 CellLabel->
  "Out[412]=",ExpressionUUID->"4f9c4b22-e52e-4562-9c95-8808b50ef7d8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"106", "/", "100"}], ")"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{3.847287212829596*^9},
 CellLabel->
  "In[413]:=",ExpressionUUID->"2aeb42b8-f1af-4504-8e92-2a7fe8a00244"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.8472872159254417`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"70d9aef2-6787-499e-92e9-b6640d9d334b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.847287215927586*^9},
 CellLabel->
  "Out[413]=",ExpressionUUID->"cf5daee3-74a3-4a9d-a3a8-7711a72df972"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"105182", "/", "100000"}], ")"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847287248669466*^9, 3.8472872752292767`*^9}},
 CellLabel->
  "In[414]:=",ExpressionUUID->"f3e2a8ae-ba8f-4ea3-bbd8-b259e05f4ecd"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.84728728062693*^9},
 CellLabel->
  "During evaluation of \
In[414]:=",ExpressionUUID->"b41b2dbe-8374-4e4f-81af-b0ae17fda360"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8472872806290913`*^9},
 CellLabel->
  "Out[414]=",ExpressionUUID->"9ca956fa-f3df-4dba-9a1a-df1823b4e9a1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "17", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
  RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
   RowBox[{"sq", "<=", 
    RowBox[{"k", "*", 
     RowBox[{"R", "^", "2"}]}]}], "]"}]}]}], "Input",
 CellLabel->
  "In[395]:=",ExpressionUUID->"8313d55f-019e-4b0e-b21a-f301a051005f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"expr=\"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"48", " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"24", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "4"]}], "-", 
      RowBox[{"80", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "2"], " ", "y"}], "-", 
      RowBox[{"20", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "3"], " ", "y"}], "-", 
      RowBox[{"24", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"94", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"20", " ", 
       SqrtBox["3"], " ", "x", " ", 
       SuperscriptBox["y", "3"]}], "+", 
      RowBox[{"3", " ", 
       SuperscriptBox["y", "4"]}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "48"}], " ", 
       SuperscriptBox["x", "2"]}], "+", 
      RowBox[{"48", " ", "k", " ", 
       SuperscriptBox["x", "2"]}], "-", 
      RowBox[{"24", " ", 
       SuperscriptBox["x", "3"]}], "+", 
      RowBox[{"24", " ", "k", " ", 
       SuperscriptBox["x", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"3", " ", "k", " ", 
       SuperscriptBox["x", "4"]}], "+", 
      RowBox[{"96", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "2"], " ", "y"}], "-", 
      RowBox[{"80", " ", 
       SqrtBox["3"], " ", "k", " ", 
       SuperscriptBox["x", "2"], " ", "y"}], "+", 
      RowBox[{"88", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "3"], " ", "y"}], "-", 
      RowBox[{"20", " ", 
       SqrtBox["3"], " ", "k", " ", 
       SuperscriptBox["x", "3"], " ", "y"}], "+", 
      RowBox[{"32", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "4"], " ", "y"}], "+", 
      RowBox[{"4", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "5"], " ", "y"}], "+", 
      RowBox[{"24", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"24", " ", "k", " ", "x", " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"102", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"]}], "+", 
      RowBox[{"94", " ", "k", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"128", " ", 
       SuperscriptBox["x", "3"], " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"32", " ", 
       SuperscriptBox["x", "4"], " ", 
       SuperscriptBox["y", "2"]}], "-", 
      RowBox[{"24", " ", 
       SqrtBox["3"], " ", "x", " ", 
       SuperscriptBox["y", "3"]}], "+", 
      RowBox[{"20", " ", 
       SqrtBox["3"], " ", "k", " ", "x", " ", 
       SuperscriptBox["y", "3"]}], "-", 
      RowBox[{"32", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "3"]}], "+", 
      RowBox[{"8", " ", 
       SqrtBox["3"], " ", 
       SuperscriptBox["x", "3"], " ", 
       SuperscriptBox["y", "3"]}], "-", 
      RowBox[{"3", " ", 
       SuperscriptBox["y", "4"]}], "+", 
      RowBox[{"3", " ", "k", " ", 
       SuperscriptBox["y", "4"]}], "+", 
      RowBox[{"32", " ", 
       SuperscriptBox["x", "2"], " ", 
       SuperscriptBox["y", "4"]}], "+", 
      RowBox[{"4", " ", 
       SqrtBox["3"], " ", "x", " ", 
       SuperscriptBox["y", "5"]}]}], ")"}]}]}],
  SequenceForm[
  "expr=", (48 $CellContext`x^2 + 24 $CellContext`x^3 + 3 $CellContext`x^4 - 
    80 3^Rational[1, 2] $CellContext`x^2 $CellContext`y - 20 
    3^Rational[1, 2] $CellContext`x^3 $CellContext`y - 
    24 $CellContext`x $CellContext`y^2 + 94 $CellContext`x^2 $CellContext`y^2 + 
    20 3^Rational[1, 2] $CellContext`x $CellContext`y^3 + 
    3 $CellContext`y^4) ((-48) $CellContext`x^2 + 
    48 $CellContext`k $CellContext`x^2 - 24 $CellContext`x^3 + 
    24 $CellContext`k $CellContext`x^3 - 3 $CellContext`x^4 + 
    3 $CellContext`k $CellContext`x^4 + 
    96 3^Rational[1, 2] $CellContext`x^2 $CellContext`y - 80 
    3^Rational[1, 2] $CellContext`k $CellContext`x^2 $CellContext`y + 
    88 3^Rational[1, 2] $CellContext`x^3 $CellContext`y - 20 
    3^Rational[1, 2] $CellContext`k $CellContext`x^3 $CellContext`y + 
    32 3^Rational[1, 2] $CellContext`x^4 $CellContext`y + 
    4 3^Rational[1, 2] $CellContext`x^5 $CellContext`y + 
    24 $CellContext`x $CellContext`y^2 - 
    24 $CellContext`k $CellContext`x $CellContext`y^2 - 
    102 $CellContext`x^2 $CellContext`y^2 + 
    94 $CellContext`k $CellContext`x^2 $CellContext`y^2 - 
    128 $CellContext`x^3 $CellContext`y^2 - 
    32 $CellContext`x^4 $CellContext`y^2 - 24 
    3^Rational[1, 2] $CellContext`x $CellContext`y^3 + 
    20 3^Rational[1, 2] $CellContext`k $CellContext`x $CellContext`y^3 - 32 
    3^Rational[1, 2] $CellContext`x^2 $CellContext`y^3 + 
    8 3^Rational[1, 2] $CellContext`x^3 $CellContext`y^3 - 3 $CellContext`y^4 + 
    3 $CellContext`k $CellContext`y^4 + 32 $CellContext`x^2 $CellContext`y^4 + 
    4 3^Rational[1, 2] $CellContext`x $CellContext`y^5)],
  Editable->False]], "Print",
 CellChangeTimes->{3.847279003049408*^9},
 CellLabel->
  "During evaluation of \
In[395]:=",ExpressionUUID->"f13828e1-bee2-4d10-8f9b-170a06f5e731"],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.847282857298484*^9},
 CellLabel->
  "Out[396]=",ExpressionUUID->"8c107c30-fc0d-4091-845e-85807c81aa6b"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "18", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{3.8472873826221437`*^9},
 CellLabel->
  "In[415]:=",ExpressionUUID->"5ffa2589-1cc3-4b42-b345-5f67749699ea"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "\[LessEqual]", 
   RowBox[{
    RowBox[{"large", "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.847287426215515*^9, 3.84728745495016*^9}},
 CellLabel->
  "In[420]:=",ExpressionUUID->"e8bb4581-2df4-4c99-ac3e-1577319f620a"],

Cell[BoxData["False"], "Output",
 CellChangeTimes->{{3.847287422329007*^9, 3.847287458455205*^9}},
 CellLabel->
  "Out[420]=",ExpressionUUID->"2b50b1a7-8904-4b52-9894-b7b6430a862d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"kR", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"13", "\[LessEqual]", "i", "\[LessEqual]", "14"}], " ", "||",
          " ", 
         RowBox[{"17", "<=", "i", "\[LessEqual]", "18"}]}], ",", 
        RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"R", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824638035827116*^9, 3.824638040123055*^9}, {
  3.8246386063820353`*^9, 3.824638610332445*^9}, {3.824638739446418*^9, 
  3.824638742108986*^9}, {3.824639906234026*^9, 3.824639914193142*^9}, {
  3.8469331040671377`*^9, 3.846933147567418*^9}, {3.8469339458409977`*^9, 
  3.846933949415902*^9}, {3.8469339952570763`*^9, 3.8469340025280733`*^9}},
 CellLabel->
  "In[486]:=",ExpressionUUID->"4dbf02f2-3523-489a-a1e8-98effa1ea576"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 16, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287821632258*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"2f651193-5a95-4e7b-88bb-7336996ea316"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 23, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287822678267*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"7c64b38e-dd62-4345-99e6-d2fddbf08583"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*RowBox[{\\\"\[Infinity]\\\"}]\\)\"\>"}],
  SequenceForm["X", 30, " ", "k=\!\(\*RowBox[{\"\[Infinity]\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.8472878250642843`*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"d4357da0-ae7a-4ac3-bb9f-5786082a8e7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 36, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287827031489*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"131b0b1c-2b57-4119-9970-c048383a1cfc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 44, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287829244102*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"a1049440-f488-4162-b1ac-1941f9106839"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 62, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287838373122*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"18f8ffea-c110-4049-b570-62b2b55a6d0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 74, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287861210434*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"2cf8db4b-6ddf-4899-b0b9-50578a3d5051"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[SqrtBox[\\\"3\\\"], \\\"2\
\\\"]\\)\"\>"}],
  SequenceForm["X", 94, " ", "k=\!\(\*FractionBox[SqrtBox[\"3\"], \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.84728788203209*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"2ea7ea8b-9213-49d5-855f-1d58d5fa423b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 98, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287891110076*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"800953e7-ca94-44c9-9448-f0f5426db1aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 99, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287891163106*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"107daa41-0b19-4f87-8d1a-8d78fa24c151"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 100, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472877383114223`*^9, 3.847287891165029*^9},
 CellLabel->
  "During evaluation of \
In[486]:=",ExpressionUUID->"8466a7c9-2ed3-4b51-9c30-5113631a374a"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "62", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824734954072097*^9, 3.824734965863641*^9}},
 CellLabel->
  "In[487]:=",ExpressionUUID->"e0a433f7-b4ef-4f51-b384-e4439fca03e4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality occurs for (x,y)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     FractionBox[
      RowBox[{"3", " ", 
       SqrtBox["3"]}], "2"]}], "}"}]}],
  SequenceForm["Equality occurs for (x,y)=", {
    Rational[1, 2], Rational[3, 2] 3^Rational[1, 2]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.847287909922447*^9},
 CellLabel->
  "During evaluation of \
In[487]:=",ExpressionUUID->"3d96b3d1-3412-44d7-94e7-51674a396a7a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824734966744586*^9, 3.824738362829769*^9, 
  3.846934109312093*^9, 3.84718177771507*^9, 3.847287909924899*^9},
 CellLabel->
  "Out[488]=",ExpressionUUID->"34dc8fe3-d984-4930-ad2d-1d3b6aee0630"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "94", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Sqrt", "[", "3", "]"}], "/", "2"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247349811761007`*^9, 3.824735005535758*^9}},
 CellLabel->
  "In[489]:=",ExpressionUUID->"bb31822a-9dfb-489b-baec-cb38cd325b88"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality occurs for (x,y)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       RowBox[{"Root", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"27", "+", 
           RowBox[{"96", " ", "x"}], "+", 
           RowBox[{"104", " ", 
            SuperscriptBox["x", "2"]}], "+", 
           RowBox[{"40", " ", 
            SuperscriptBox["x", "3"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["x", "4"]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "24"}], "-", 
              RowBox[{"40", " ", "x"}], "-", 
              RowBox[{"22", " ", 
               SuperscriptBox["x", "2"]}]}], ")"}], " ", 
            SuperscriptBox["#1", "2"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}], ",", 
       RowBox[{
        RowBox[{"x", ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"5", "+", 
          SqrtBox["3"], "+", 
          RowBox[{"4", " ", "x"}]}], "\[LessEqual]", 
         InterpretationBox[
          TemplateBox[{"Root",TemplateBox[{"\"7.34\"", 
              DynamicBox[
               FEPrivate`FrontEndResource[
               "FEExpressions", "NumericalApproximationElider"]]}, 
             "RowDefault"],TagBox[
             RowBox[{"Root", "[", 
               RowBox[{
                 RowBox[{
                   RowBox[{"1408", "-", 
                    RowBox[{"80", " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                    SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}], 
             Short[#, 7]& ],7.338692421715943},
           "NumericalApproximation"],
          Root[1408 - 80 #^2 + #^4& , 4, 0]]}]}]}], "]"}]}], "}"}]}],
  SequenceForm["Equality occurs for (x,y)=", {$CellContext`x, 
    ConditionalExpression[
     Root[
     27 + 96 $CellContext`x + 104 $CellContext`x^2 + 40 $CellContext`x^3 + 
      5 $CellContext`x^4 + (-24 - 40 $CellContext`x - 
        22 $CellContext`x^2) #^2 + 5 #^4& , 3], 
     And[$CellContext`x > 0, 5 + 3^Rational[1, 2] + 4 $CellContext`x <= 
      Root[1408 - 80 #^2 + #^4& , 4, 0]]]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.847287928472653*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"7c34f7de-8574-42b4-bba8-2db25f187951"],

Cell[BoxData["\<\"Taking too long to find a, b, and c.\\n\"\>"], "Print",
 CellChangeTimes->{3.847287930479056*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"8fb5446e-6901-4461-b1f7-c4277d5eb6de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality condition: R=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\", r=\"\>", "\[InvisibleSpace]", "x", 
   "\[InvisibleSpace]", "\<\", s=\"\>", "\[InvisibleSpace]", 
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     RowBox[{"Root", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"27", "+", 
         RowBox[{"96", " ", "x"}], "+", 
         RowBox[{"104", " ", 
          SuperscriptBox["x", "2"]}], "+", 
         RowBox[{"40", " ", 
          SuperscriptBox["x", "3"]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["x", "4"]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "24"}], "-", 
            RowBox[{"40", " ", "x"}], "-", 
            RowBox[{"22", " ", 
             SuperscriptBox["x", "2"]}]}], ")"}], " ", 
          SuperscriptBox["#1", "2"]}], "+", 
         RowBox[{"5", " ", 
          SuperscriptBox["#1", "4"]}]}], "&"}], ",", "3"}], "]"}], ",", 
     RowBox[{
      RowBox[{"x", ">", "0"}], "&&", 
      RowBox[{
       RowBox[{"5", "+", 
        SqrtBox["3"], "+", 
        RowBox[{"4", " ", "x"}]}], "\[LessEqual]", 
       InterpretationBox[
        TemplateBox[{"Root",TemplateBox[{"\"7.34\"", 
            DynamicBox[
             FEPrivate`FrontEndResource[
             "FEExpressions", "NumericalApproximationElider"]]}, 
           "RowDefault"],TagBox[
           RowBox[{"Root", "[", 
             RowBox[{
               RowBox[{
                 RowBox[{"1408", "-", 
                   RowBox[{"80", " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                   SuperscriptBox["#1", "4"]}], "&"}], ",", "4"}], "]"}], 
           Short[#, 7]& ],7.338692421715943},
         "NumericalApproximation"],
        Root[1408 - 80 #^2 + #^4& , 4, 0]]}]}]}], "]"}]}],
  SequenceForm["Equality condition: R=", 1, ", r=", $CellContext`x, ", s=", 
   ConditionalExpression[
    Root[27 + 96 $CellContext`x + 104 $CellContext`x^2 + 40 $CellContext`x^3 + 
     5 $CellContext`x^4 + (-24 - 40 $CellContext`x - 22 $CellContext`x^2) #^2 + 
     5 #^4& , 3], 
    And[$CellContext`x > 0, 5 + 3^Rational[1, 2] + 4 $CellContext`x <= 
     Root[1408 - 80 #^2 + #^4& , 4, 0]]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.847287930484799*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"6fed21da-a009-4f20-85b0-bad9bda85647"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality occurs for (x,y)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"x", ",", 
     RowBox[{"ConditionalExpression", "[", 
      RowBox[{
       FractionBox[
        SqrtBox[
         RowBox[{"12", "+", 
          RowBox[{"x", " ", 
           RowBox[{"(", 
            RowBox[{"20", "+", 
             RowBox[{"11", " ", "x"}]}], ")"}]}], "+", 
          SqrtBox[
           RowBox[{"9", "+", 
            RowBox[{"48", " ", 
             SuperscriptBox["x", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "x"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{"3", "+", 
               RowBox[{"2", " ", "x"}]}], ")"}]}]}]]}]], 
        SqrtBox["5"]], ",", 
       RowBox[{"0", "<", "x", "\[LessEqual]", 
        InterpretationBox[
         TemplateBox[{"Root",TemplateBox[{"\"0.461\"", 
             DynamicBox[
              FEPrivate`FrontEndResource[
              "FEExpressions", "NumericalApproximationElider"]]}, 
            "RowDefault"],TagBox[
            RowBox[{"Root", "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"33", "-", 
                    RowBox[{"264", " ", "#1"}], "+", 
                    RowBox[{"256", " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                    RowBox[{"320", " ", 
                    SuperscriptBox["#1", "3"]}], "+", 
                    RowBox[{"64", " ", 
                    SuperscriptBox["#1", "4"]}]}], "&"}], ",", "4"}], "]"}], 
            Short[#, 7]& ],0.46128285965057103`},
          "NumericalApproximation"],
         Root[33 - 264 # + 256 #^2 + 320 #^3 + 64 #^4& , 4, 0]]}]}], "]"}]}], 
    "}"}]}],
  SequenceForm["Equality occurs for (x,y)=", {$CellContext`x, 
    ConditionalExpression[
    5^Rational[-1, 2] (
       12 + $CellContext`x (20 + 11 $CellContext`x) + (9 + 
         48 $CellContext`x^2 (1 + $CellContext`x) (3 + 2 $CellContext`x))^
        Rational[1, 2])^Rational[1, 2], 
     Inequality[0, Less, $CellContext`x, LessEqual, 
      Root[33 - 264 # + 256 #^2 + 320 #^3 + 64 #^4& , 4, 0]]]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.847287930488647*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"62e5bb2d-cec8-4d47-8500-a5b2033e2dd2"],

Cell[BoxData["\<\"Taking too long to find a, b, and c.\\n\"\>"], "Print",
 CellChangeTimes->{3.8472879324938297`*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"a9c87a0c-1de7-4eef-ace0-cf01adaef6a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality condition: R=\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\", r=\"\>", "\[InvisibleSpace]", "x", 
   "\[InvisibleSpace]", "\<\", s=\"\>", "\[InvisibleSpace]", 
   RowBox[{"ConditionalExpression", "[", 
    RowBox[{
     FractionBox[
      SqrtBox[
       RowBox[{"12", "+", 
        RowBox[{"x", " ", 
         RowBox[{"(", 
          RowBox[{"20", "+", 
           RowBox[{"11", " ", "x"}]}], ")"}]}], "+", 
        SqrtBox[
         RowBox[{"9", "+", 
          RowBox[{"48", " ", 
           SuperscriptBox["x", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "x"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"3", "+", 
             RowBox[{"2", " ", "x"}]}], ")"}]}]}]]}]], 
      SqrtBox["5"]], ",", 
     RowBox[{"0", "<", "x", "\[LessEqual]", 
      InterpretationBox[
       TemplateBox[{"Root",TemplateBox[{"\"0.461\"", 
           DynamicBox[
            FEPrivate`FrontEndResource[
            "FEExpressions", "NumericalApproximationElider"]]}, "RowDefault"],
         TagBox[
          RowBox[{"Root", "[", 
            RowBox[{
              RowBox[{
                RowBox[{"33", "-", 
                  RowBox[{"264", " ", "#1"}], "+", 
                  RowBox[{"256", " ", 
                    SuperscriptBox["#1", "2"]}], "+", 
                  RowBox[{"320", " ", 
                    SuperscriptBox["#1", "3"]}], "+", 
                  RowBox[{"64", " ", 
                    SuperscriptBox["#1", "4"]}]}], "&"}], ",", "4"}], "]"}], 
          Short[#, 7]& ],0.46128285965057103`},
        "NumericalApproximation"],
       Root[33 - 264 # + 256 #^2 + 320 #^3 + 64 #^4& , 4, 0]]}]}], "]"}]}],
  SequenceForm["Equality condition: R=", 1, ", r=", $CellContext`x, ", s=", 
   ConditionalExpression[
   5^Rational[-1, 2] (
      12 + $CellContext`x (20 + 11 $CellContext`x) + (9 + 
        48 $CellContext`x^2 (1 + $CellContext`x) (3 + 2 $CellContext`x))^
       Rational[1, 2])^Rational[1, 2], 
    Inequality[0, Less, $CellContext`x, LessEqual, 
     Root[33 - 264 # + 256 #^2 + 320 #^3 + 64 #^4& , 4, 0]]]],
  Editable->False]], "Print",
 CellChangeTimes->{3.847287932495755*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"fd1bd553-8d7a-4aa0-a029-954d81f2bfc2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Equality occurs for (x,y)=\"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     FractionBox["1", "2"], ",", 
     FractionBox[
      RowBox[{"3", " ", 
       SqrtBox["3"]}], "2"]}], "}"}]}],
  SequenceForm["Equality occurs for (x,y)=", {
    Rational[1, 2], Rational[3, 2] 3^Rational[1, 2]}],
  Editable->False]], "Print",
 CellChangeTimes->{3.84728793249889*^9},
 CellLabel->
  "During evaluation of \
In[489]:=",ExpressionUUID->"e13d900d-a879-48f3-aba5-8d90bf6247cf"]
}, Open  ]],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824735010886208*^9, 3.82473836343552*^9, 
  3.846934114225377*^9, 3.847181777765231*^9, 3.847287932500269*^9},
 CellLabel->
  "Out[490]=",ExpressionUUID->"46bea1c0-b0e4-4e13-a9bd-5dab58f852b2"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distance of Center to X1 Compared With R", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
   3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
   3.824729944583457*^9}, 
   3.824730016103642*^9},ExpressionUUID->"943fb183-e47b-48fb-8b8c-\
212614e9fb5f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"kR", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"R", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824642580811508*^9, 3.8246425880354443`*^9}},
 CellLabel->
  "In[349]:=",ExpressionUUID->"da803e98-18ba-40db-ab34-0be7c8935fd7"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 2, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738363518838*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"7f13da8d-aa54-4bb5-940a-adbd9e0b36c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 3, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738363536293*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"f997a964-2d3e-485e-82d5-4f85f8490bf2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 4, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383636193857`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"31a5afcb-fcbd-4ca5-b65e-ae38602b1808"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 5, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738363694377*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"f76b985a-a3f3-47ca-9c19-d509054c5540"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1780038541 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"1\\\"}], \\\"-\\\", \
RowBox[{\\\"6\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"62\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"18\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"2\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 6, " ", 
   "k\[TildeTilde]0.1780038541 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"1\"}], \"-\", RowBox[{\"6\", \" \", \"x\"}], \"+\", RowBox[{\"62\", \
\" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"18\", \" \", \
SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"2\", \" \", \
SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738364084692*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"085d0ccc-5b44-430a-84d9-b8ef8a58c451"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1603692863 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"4\\\", \\\"+\\\", RowBox[{\\\"12\\\", \
\\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"231\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"4\\\", \\\" \\\
\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 7, " ", 
   "k\[TildeTilde]0.1603692863 is the smallest positive root of \
\!\(\*RowBox[{\"4\", \"+\", RowBox[{\"12\", \" \", \"x\"}], \"-\", \
RowBox[{\"231\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"4\", \
\" \", SuperscriptBox[\"x\", \"3\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738364343473*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"68a0ad8c-c79e-4839-b381-23a34b4012d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 8, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738364418586*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"0732d269-12f3-4518-8e88-26bc25c5ded9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 9, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383644875917`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"7c831cd5-484a-4c6a-84ca-819b2cd59220"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 10, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383645575047`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"1b16e6c8-f339-4a4e-b5a9-5e3bd83e9c09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 11, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738364636456*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"4d5ec8ee-2138-4a01-9d2f-a89c774425f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \
\\\"2\\\"], \\\" \\\", RowBox[{\\\"(\\\", RowBox[{\\\"3\\\", \\\"-\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"2\\\"]}]}], \\\")\\\"}]}]\\)\"\>"}],
  
  SequenceForm[
  "X", 12, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"2\"], \" \", RowBox[{\"(\", RowBox[{\
\"3\", \"-\", RowBox[{\"2\", \" \", SqrtBox[\"2\"]}]}], \")\"}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738364724389*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"6df85db7-67e6-4bd4-8ee3-97185eba9f89"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2730588425 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"16\\\", \\\"+\\\", RowBox[{\\\"120\\\", \
\\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"537\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", RowBox[{\\\"468\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", RowBox[{\\\"144\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 13, " ", 
   "k\[TildeTilde]0.2730588425 is the smallest positive root of \
\!\(\*RowBox[{\"16\", \"+\", RowBox[{\"120\", \" \", \"x\"}], \"-\", RowBox[{\
\"537\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", RowBox[{\"468\", \" \
\", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"144\", \" \", \
SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738367046401*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"9ae44b7c-7b90-4ae7-8856-b9eec197cfc7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.034257471 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"16\\\", \\\"-\\\", RowBox[{\\\"120\\\", \
\\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"537\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"468\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", RowBox[{\\\"144\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 14, " ", 
   "k\[TildeTilde]1.034257471 is the largest positive root of \
\!\(\*RowBox[{\"16\", \"-\", RowBox[{\"120\", \" \", \"x\"}], \"-\", RowBox[{\
\"537\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"468\", \" \
\", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"144\", \" \", \
SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738369325471*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"e2f3a35a-918a-4f09-8408-56b528814513"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2370406267 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"16\\\"}], \\\"-\\\", \
RowBox[{\\\"72\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"513\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"288\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", \
RowBox[{\\\"120\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\"+\
\\\", RowBox[{\\\"36\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"5\\\"]}], \
\\\"+\\\", RowBox[{\\\"4\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 15, " ", 
   "k\[TildeTilde]0.2370406267 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"16\"}], \"-\", RowBox[{\"72\", \" \", \"x\"}], \"+\", \
RowBox[{\"513\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"288\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"120\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"36\", \" \", SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"4\", \
\" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738369895204*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"82422b25-7211-48eb-98a2-a4843edc59af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.07582214127 is a root of \
\\!\\(\\*RowBox[{\\\"288\\\", \\\"-\\\", RowBox[{\\\"7728\\\", \\\" \\\", \
\\\"x\\\"}], \\\"+\\\", RowBox[{\\\"36814\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"209294\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"-\\\", \
RowBox[{\\\"171326\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\
\"+\\\", RowBox[{\\\"312475\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"5\\\
\"]}], \\\"-\\\", RowBox[{\\\"224812\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"38416\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"7\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 17, " ", 
   "k\[TildeTilde]0.07582214127 is a root of \!\(\*RowBox[{\"288\", \"-\", \
RowBox[{\"7728\", \" \", \"x\"}], \"+\", RowBox[{\"36814\", \" \", \
SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"209294\", \" \", \
SuperscriptBox[\"x\", \"3\"]}], \"-\", RowBox[{\"171326\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"312475\", \" \", \
SuperscriptBox[\"x\", \"5\"]}], \"-\", RowBox[{\"224812\", \" \", \
SuperscriptBox[\"x\", \"6\"]}], \"+\", RowBox[{\"38416\", \" \", \
SuperscriptBox[\"x\", \"7\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738373361596*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"783825e1-df6e-4aef-9671-9e5bc9a92b04"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
SqrtBox[\\\"2\\\"]]\\)\"\>"}],
  SequenceForm["X", 19, " ", "k=\!\(\*FractionBox[\"1\", SqrtBox[\"2\"]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738375242969*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"60b762ca-1efb-4b7e-a74d-25f43464f99d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"4\\\"}]\\)\"\>"}],
  SequenceForm["X", 20, " ", "k=\!\(\*RowBox[{\"4\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738375312147*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"646b061a-348d-414f-a5e8-3c10b272a369"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 21, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738375414105*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"0305a392-681d-4638-9fbb-fabcc9bbcb07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.6372293040 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"171\\\"}], \\\"+\\\", \
RowBox[{\\\"376\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"48\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"1320\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"1864\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\
\"]}], \\\"-\\\", RowBox[{\\\"736\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"5\\\"]}], \\\"+\\\", RowBox[{\\\"480\\\", \\\" \\\", SuperscriptBox[\\\"x\
\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"224\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"7\\\"]}], \\\"+\\\", RowBox[{\\\"32\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 24, " ", 
   "k\[TildeTilde]0.6372293040 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"171\"}], \"+\", RowBox[{\"376\", \" \", \"x\"}], \"+\", RowBox[{\"48\
\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", RowBox[{\"1320\", \" \", \
SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"1864\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"-\", RowBox[{\"736\", \" \", \
SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"480\", \" \", \
SuperscriptBox[\"x\", \"6\"]}], \"-\", RowBox[{\"224\", \" \", \
SuperscriptBox[\"x\", \"7\"]}], \"+\", RowBox[{\"32\", \" \", SuperscriptBox[\
\"x\", \"8\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738376219947*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"a2b91269-02b2-49a5-a4bc-4fbea687c79d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.5981195645 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"625\\\"}], \\\"-\\\", \
RowBox[{\\\"300\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"2548\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"2880\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"4654\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\
\"]}], \\\"-\\\", RowBox[{\\\"1356\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"5\\\"]}], \\\"+\\\", RowBox[{\\\"516\\\", \\\" \\\", SuperscriptBox[\\\"x\
\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"252\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"7\\\"]}], \\\"+\\\", RowBox[{\\\"36\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 25, " ", 
   "k\[TildeTilde]0.5981195645 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"625\"}], \"-\", RowBox[{\"300\", \" \", \"x\"}], \"+\", \
RowBox[{\"2548\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"2880\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"4654\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"-\", \
RowBox[{\"1356\", \" \", SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"516\
\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", RowBox[{\"252\", \" \", \
SuperscriptBox[\"x\", \"7\"]}], \"+\", RowBox[{\"36\", \" \", SuperscriptBox[\
\"x\", \"8\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738376535891*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"a275c228-9cdb-403c-85e9-c748988d8cf1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.7768726611 is the smallest \
positive root of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"9800\\\"}], \
\\\"-\\\", RowBox[{\\\"14568\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\
\\\"61860\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"38042\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"3843\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\
\"]}], \\\"+\\\", RowBox[{\\\"756\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"5\\\"]}], \\\"+\\\", RowBox[{\\\"27\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 27, " ", 
   "k\[TildeTilde]0.7768726611 is the smallest positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"9800\"}], \"-\", RowBox[{\"14568\", \" \", \"x\
\"}], \"+\", RowBox[{\"61860\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"38042\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"3843\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"756\
\", \" \", SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"27\", \" \", \
SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383776315947`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"1d148813-ee37-473f-bf8c-9c23f7661745"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.6181081011 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"576\\\"}], \\\"-\\\", \
RowBox[{\\\"608\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"3008\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"1096\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"387\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"18\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"5\\\"]}], \\\"+\\\", RowBox[{\\\"59\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 28, " ", 
   "k\[TildeTilde]0.6181081011 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"576\"}], \"-\", RowBox[{\"608\", \" \", \"x\"}], \"+\", \
RowBox[{\"3008\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"1096\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"387\
\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"18\", \" \", \
SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"59\", \" \", SuperscriptBox[\
\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738378080896*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"982afaf7-77f7-47c7-aaa4-991f70aa17ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2663306300 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"36\\\"}], \\\"-\\\", \
RowBox[{\\\"152\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"575\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"1658\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"810\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"216\\\", \\\" \\\", SuperscriptBox[\\\"x\
\\\", \\\"5\\\"]}], \\\"+\\\", RowBox[{\\\"27\\\", \\\" \\\", SuperscriptBox[\
\\\"x\\\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 31, " ", 
   "k\[TildeTilde]0.2663306300 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"36\"}], \"-\", RowBox[{\"152\", \" \", \"x\"}], \"+\", RowBox[{\"575\
\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"1658\", \" \", \
SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"810\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"216\", \" \", \
SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"27\", \" \", SuperscriptBox[\
\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738378702156*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"b1d6945b-f25e-49c8-b094-0c590712865b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \
\\\"2\\\"], \\\" \\\", InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"0.638\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[RowBox[List[\\\"-\\\", \\\"2646\\\"]], \\\
\"-\\\", RowBox[List[\\\"2970\\\", \\\" \\\", \\\"#1\\\"]], \\\"+\\\", \
RowBox[List[\\\"4752\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"2\\\"]]], \
\\\"+\\\", RowBox[List[\\\"3920\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\
\"3\\\"]]], \\\"+\\\", RowBox[List[\\\"7521\\\", \\\" \\\", SuperscriptBox[\\\
\"#1\\\", \\\"4\\\"]]], \\\"+\\\", RowBox[List[\\\"2784\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"5\\\"]]], \\\"+\\\", RowBox[List[\\\"636\\\", \
\\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"6\\\"]]], \\\"+\\\", RowBox[List[\\\
\"80\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"7\\\"]]], \\\"+\\\", \
RowBox[List[\\\"4\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"8\\\"]]]]], \
\\\"&\\\"]], \\\",\\\", \\\"2\\\"]], \\\"]\\\"]], Function[Short[Slot[1], \
7]]], 0.6380942287911938`], \\\"NumericalApproximation\\\"], \
Root[Function[Plus[-2646, Times[-2970, Slot[1]], Times[4752, Power[Slot[1], \
2]], Times[3920, Power[Slot[1], 3]], Times[7521, Power[Slot[1], 4]], \
Times[2784, Power[Slot[1], 5]], Times[636, Power[Slot[1], 6]], Times[80, \
Power[Slot[1], 7]], Times[4, Power[Slot[1], 8]]]], 2, 0]]}]\\)\"\>"}],
  SequenceForm[
  "X", 32, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"2\"], \" \", \
InterpretationBox[TemplateBox[List[\"Root\", TemplateBox[List[\"\\\"0.638\\\"\
\", DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[RowBox[List[\"-\", \"2646\"]], \"-\", \
RowBox[List[\"2970\", \" \", \"#1\"]], \"+\", RowBox[List[\"4752\", \" \", \
SuperscriptBox[\"#1\", \"2\"]]], \"+\", RowBox[List[\"3920\", \" \", \
SuperscriptBox[\"#1\", \"3\"]]], \"+\", RowBox[List[\"7521\", \" \", \
SuperscriptBox[\"#1\", \"4\"]]], \"+\", RowBox[List[\"2784\", \" \", \
SuperscriptBox[\"#1\", \"5\"]]], \"+\", RowBox[List[\"636\", \" \", \
SuperscriptBox[\"#1\", \"6\"]]], \"+\", RowBox[List[\"80\", \" \", \
SuperscriptBox[\"#1\", \"7\"]]], \"+\", RowBox[List[\"4\", \" \", \
SuperscriptBox[\"#1\", \"8\"]]]]], \"&\"]], \",\", \"2\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 0.6380942287911938`], \
\"NumericalApproximation\"], Root[Function[Plus[-2646, Times[-2970, Slot[1]], \
Times[4752, Power[Slot[1], 2]], Times[3920, Power[Slot[1], 3]], Times[7521, \
Power[Slot[1], 4]], Times[2784, Power[Slot[1], 5]], Times[636, Power[Slot[1], \
6]], Times[80, Power[Slot[1], 7]], Times[4, Power[Slot[1], 8]]]], 2, 0]]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.82473837934133*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"5a78366c-8ae8-41ce-8066-2fb72e29fb90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \\\"11\
\\\"], \\\" \\\", RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"4\\\"}], \
\\\"+\\\", RowBox[{\\\"3\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}], \\\"+\\\", \
SqrtBox[RowBox[{\\\"3\\\", \\\" \\\", RowBox[{\\\"(\\\", \
RowBox[{RowBox[{\\\"-\\\", \\\"15\\\"}], \\\"+\\\", RowBox[{\\\"14\\\", \\\" \
\\\", SqrtBox[\\\"3\\\"]}]}], \\\")\\\"}]}]]}], \\\")\\\"}]}]\\)\"\>"}],
  SequenceForm[
  "X", 34, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"11\"], \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"4\"}], \"+\", RowBox[{\"3\", \" \", \
SqrtBox[\"3\"]}], \"+\", SqrtBox[RowBox[{\"3\", \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"15\"}], \"+\", RowBox[{\"14\", \" \", \
SqrtBox[\"3\"]}]}], \")\"}]}]]}], \")\"}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738379950036*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"64768a2d-a9a8-4fca-9257-c8d98d24da29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2381181908 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"4\\\", \\\"-\\\", RowBox[{\\\"71\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"8\\\
\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 35, " ", 
   "k\[TildeTilde]0.2381181908 is the smallest positive root of \
\!\(\*RowBox[{\"4\", \"-\", RowBox[{\"71\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"8\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738380046722*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"33f204cf-78f8-4cee-976a-ae306050b505"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1115833933 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"+\\\", RowBox[{\\\"12\\\", \
\\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"195\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"64\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 37, " ", 
   "k\[TildeTilde]0.1115833933 is the smallest positive root of \
\!\(\*RowBox[{\"1\", \"+\", RowBox[{\"12\", \" \", \"x\"}], \"-\", \
RowBox[{\"195\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"64\", \" \", SuperscriptBox[\"x\", \"3\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738380378683*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"d3360662-fd5b-463a-9b54-7322cdfe8a44"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1727656405 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"9\\\"}], \\\"-\\\", RowBox[{\\\"52\
\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"470\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"772\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"-\\\", RowBox[{\\\"33\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\"+\\\", \
RowBox[{\\\"24\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"5\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 38, " ", 
   "k\[TildeTilde]0.1727656405 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"9\"}], \"-\", RowBox[{\"52\", \" \", \"x\"}], \"+\", \
RowBox[{\"470\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"772\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"-\", \
RowBox[{\"33\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"24\", \
\" \", SuperscriptBox[\"x\", \"5\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383805963087`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"e6b3fcfd-0e49-42c0-a2f2-27ec2839f48b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \
\\\"4\\\"], \\\" \\\", InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"0.438\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[\\\"3\\\", \\\"-\\\", \
RowBox[List[\\\"46\\\", \\\" \\\", \\\"#1\\\"]], \\\"+\\\", \
RowBox[List[\\\"84\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"2\\\"]]], \
\\\"+\\\", RowBox[List[\\\"12\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"3\\\"]]], \\\"+\\\", SuperscriptBox[\\\"#1\\\", \\\"4\\\"]]], \
\\\"&\\\"]], \\\",\\\", \\\"2\\\"]], \\\"]\\\"]], Function[Short[Slot[1], \
7]]], 0.43765416404814755`], \\\"NumericalApproximation\\\"], \
Root[Function[Plus[3, Times[-46, Slot[1]], Times[84, Power[Slot[1], 2]], \
Times[12, Power[Slot[1], 3]], Power[Slot[1], 4]]], 2, 0]]}]\\)\"\>"}],
  SequenceForm[
  "X", 39, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"4\"], \" \", \
InterpretationBox[TemplateBox[List[\"Root\", TemplateBox[List[\"\\\"0.438\\\"\
\", DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[\"3\", \"-\", RowBox[List[\"46\", \" \", \
\"#1\"]], \"+\", RowBox[List[\"84\", \" \", SuperscriptBox[\"#1\", \"2\"]]], \
\"+\", RowBox[List[\"12\", \" \", SuperscriptBox[\"#1\", \"3\"]]], \"+\", \
SuperscriptBox[\"#1\", \"4\"]]], \"&\"]], \",\", \"2\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 0.43765416404814755`], \"NumericalApproximation\
\"], Root[Function[Plus[3, Times[-46, Slot[1]], Times[84, Power[Slot[1], 2]], \
Times[12, Power[Slot[1], 3]], Power[Slot[1], 4]]], 2, 0]]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383814553328`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"18ff2e77-230b-4a1e-8550-7392b64ca0f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 40, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383815238132`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"3e8054eb-77bd-4402-8482-eeb7316a1696"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1683749874 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"2\\\", \\\"-\\\", RowBox[{\\\"71\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"16\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 41, " ", 
   "k\[TildeTilde]0.1683749874 is the smallest positive root of \
\!\(\*RowBox[{\"2\", \"-\", RowBox[{\"71\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"16\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738381888608*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"531a34a4-e581-4719-9bb6-9b3bd8ba133e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1285491703 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"1\\\"}], \\\"-\\\", RowBox[{\\\"18\
\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"188\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"96\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", RowBox[{\\\"12\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 42, " ", 
   "k\[TildeTilde]0.1285491703 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"1\"}], \"-\", RowBox[{\"18\", \" \", \"x\"}], \"+\", \
RowBox[{\"188\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"96\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"12\", \
\" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.82473838257099*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"76d82d6b-846c-4b45-b175-34ec3f41ece6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.4001891368 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"16\\\"}], \\\"-\\\", \
RowBox[{\\\"72\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"239\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"96\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"15\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 43, " ", 
   "k\[TildeTilde]0.4001891368 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"16\"}], \"-\", RowBox[{\"72\", \" \", \"x\"}], \"+\", \
RowBox[{\"239\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"96\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"15\", \
\" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738382998005*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"9ec795b3-a3d3-498c-953d-d368b378b7c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2503364708 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"9\\\", \\\"+\\\", RowBox[{\\\"54\\\", \
\\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"398\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"154\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", RowBox[{\\\"2\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 45, " ", 
   "k\[TildeTilde]0.2503364708 is the smallest positive root of \
\!\(\*RowBox[{\"9\", \"+\", RowBox[{\"54\", \" \", \"x\"}], \"-\", \
RowBox[{\"398\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"154\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"2\", \
\" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383843469667`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"8e9b12ba-eff0-4044-966d-0400e7d5d0ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*SqrtBox[RowBox[{\\\"2\\\", \\\" \\\", \
RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"11\\\"}], \\\"+\\\", \
RowBox[{\\\"5\\\", \\\" \\\", SqrtBox[\\\"5\\\"]}]}], \\\")\\\"}]}]]\\)\"\>"}],
  SequenceForm[
  "X", 46, " ", 
   "k=\!\(\*SqrtBox[RowBox[{\"2\", \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"11\"}], \"+\", RowBox[{\"5\", \" \", \
SqrtBox[\"5\"]}]}], \")\"}]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738384471315*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"33c9f67f-bdf7-4af3-8034-ddbc7e6889ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 51, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738387262336*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"ee183f08-97d0-4120-9db1-9cd90999aeba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.100826906 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"158\\\"}], \\\"-\\\", \
RowBox[{\\\"163\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"208\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"64\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"3\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 52, " ", 
   "k\[TildeTilde]1.100826906 is the positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"158\"}], \"-\", RowBox[{\"163\", \" \", \
\"x\"}], \"+\", RowBox[{\"208\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"64\", \" \", SuperscriptBox[\"x\", \"3\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383876186237`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"e6943868-6ff3-49f4-afcc-e77bd7ba2575"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \
\\\"2\\\"], \\\" \\\", InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"1.19\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[RowBox[List[\\\"-\\\", \\\"2928\\\"]], \\\
\"-\\\", RowBox[List[\\\"123707\\\", \\\" \\\", \\\"#1\\\"]], \\\"-\\\", \
RowBox[List[\\\"117148\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"2\\\"]]], \\\"+\\\", RowBox[List[\\\"174796\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"3\\\"]]], \\\"+\\\", \
RowBox[List[\\\"20064\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"4\\\"]]], \\\"-\\\", RowBox[List[\\\"8136\\\", \\\" \\\", SuperscriptBox[\
\\\"#1\\\", \\\"5\\\"]]], \\\"+\\\", RowBox[List[\\\"432\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"6\\\"]]], \\\"+\\\", RowBox[List[\\\"320\\\", \
\\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"7\\\"]]], \\\"-\\\", RowBox[List[\\\
\"104\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"8\\\"]]], \\\"+\\\", \
RowBox[List[\\\"8\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"9\\\"]]]]], \
\\\"&\\\"]], \\\",\\\", \\\"3\\\"]], \\\"]\\\"]], Function[Short[Slot[1], \
7]]], 1.186829654663168`], \\\"NumericalApproximation\\\"], \
Root[Function[Plus[-2928, Times[-123707, Slot[1]], Times[-117148, \
Power[Slot[1], 2]], Times[174796, Power[Slot[1], 3]], Times[20064, \
Power[Slot[1], 4]], Times[-8136, Power[Slot[1], 5]], Times[432, \
Power[Slot[1], 6]], Times[320, Power[Slot[1], 7]], Times[-104, Power[Slot[1], \
8]], Times[8, Power[Slot[1], 9]]]], 3, 0]]}]\\)\"\>"}],
  SequenceForm[
  "X", 53, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"2\"], \" \", \
InterpretationBox[TemplateBox[List[\"Root\", \
TemplateBox[List[\"\\\"1.19\\\"\", \
DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[RowBox[List[\"-\", \"2928\"]], \"-\", \
RowBox[List[\"123707\", \" \", \"#1\"]], \"-\", RowBox[List[\"117148\", \" \
\", SuperscriptBox[\"#1\", \"2\"]]], \"+\", RowBox[List[\"174796\", \" \", \
SuperscriptBox[\"#1\", \"3\"]]], \"+\", RowBox[List[\"20064\", \" \", \
SuperscriptBox[\"#1\", \"4\"]]], \"-\", RowBox[List[\"8136\", \" \", \
SuperscriptBox[\"#1\", \"5\"]]], \"+\", RowBox[List[\"432\", \" \", \
SuperscriptBox[\"#1\", \"6\"]]], \"+\", RowBox[List[\"320\", \" \", \
SuperscriptBox[\"#1\", \"7\"]]], \"-\", RowBox[List[\"104\", \" \", \
SuperscriptBox[\"#1\", \"8\"]]], \"+\", RowBox[List[\"8\", \" \", \
SuperscriptBox[\"#1\", \"9\"]]]]], \"&\"]], \",\", \"3\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 1.186829654663168`], \
\"NumericalApproximation\"], Root[Function[Plus[-2928, Times[-123707, \
Slot[1]], Times[-117148, Power[Slot[1], 2]], Times[174796, Power[Slot[1], \
3]], Times[20064, Power[Slot[1], 4]], Times[-8136, Power[Slot[1], 5]], \
Times[432, Power[Slot[1], 6]], Times[320, Power[Slot[1], 7]], Times[-104, \
Power[Slot[1], 8]], Times[8, Power[Slot[1], 9]]]], 3, 0]]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738398151972*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"37bcf48f-7f6e-434a-a4a6-d19762a5bfd1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1459642759 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"47\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"3\\\
\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 55, " ", 
   "k\[TildeTilde]0.1459642759 is the smallest positive root of \
\!\(\*RowBox[{\"1\", \"-\", RowBox[{\"47\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"3\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.82473839869866*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"6b363bd2-57b0-4a22-a7ff-f9f0924da55d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.3002831060 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"1\\\"}], \\\"+\\\", RowBox[{\\\"11\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]\\)\"\>"}],
  SequenceForm[
  "X", 56, " ", 
   "k\[TildeTilde]0.3002831060 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"1\"}], \"+\", RowBox[{\"11\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", SuperscriptBox[\"x\", \"4\"]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383988170633`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"89e7fd52-f97d-4d38-915e-86df95da73bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
SqrtBox[RowBox[{\\\"37\\\", \\\"+\\\", RowBox[{\\\"14\\\", \\\" \\\", \
SqrtBox[\\\"7\\\"]}]}]]]\\)\"\>"}],
  SequenceForm[
  "X", 57, " ", 
   "k=\!\(\*FractionBox[\"2\", SqrtBox[RowBox[{\"37\", \"+\", RowBox[{\"14\", \
\" \", SqrtBox[\"7\"]}]}]]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247383989502983`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"f6e99cd7-64ad-4f0d-b9ae-148eb9d002bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2192778961 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"4\\\"}], \\\"-\\\", RowBox[{\\\"12\
\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"131\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"30\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", RowBox[{\\\"7\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 58, " ", 
   "k\[TildeTilde]0.2192778961 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"4\"}], \"-\", RowBox[{\"12\", \" \", \"x\"}], \"+\", \
RowBox[{\"131\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"30\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"7\", \
\" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738399411747*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"a9dd7238-579c-4819-b019-607101f039bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 59, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738400027996*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"87da815a-97b9-47d6-88d6-ca8bf6496116"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1190590954 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"71\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"32\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 60, " ", 
   "k\[TildeTilde]0.1190590954 is the smallest positive root of \
\!\(\*RowBox[{\"1\", \"-\", RowBox[{\"71\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"32\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247384006164913`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"81a98151-67f9-4f06-a792-fe427b9d8703"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 61, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738402203143*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"37baa5ea-b377-4251-9a63-c87a8ba13147"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 63, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738404347529*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"69eb9513-dc49-4592-8e97-9c21b2cd07e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"3\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 65, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"3\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247384048533907`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"d62d65ca-d845-47c8-aed2-feef4a9828c1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]1.022102680 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"147\\\"}], \\\"-\\\", \
RowBox[{\\\"366\\\", \\\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"242\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"882\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"-\\\", \
RowBox[{\\\"162\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\"+\
\\\", RowBox[{\\\"8\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"5\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 67, " ", 
   "k\[TildeTilde]1.022102680 is the positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"147\"}], \"-\", RowBox[{\"366\", \" \", \
\"x\"}], \"-\", RowBox[{\"242\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"882\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"-\", \
RowBox[{\"162\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"8\", \
\" \", SuperscriptBox[\"x\", \"5\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738412217746*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"270ea9e8-10da-4e5f-858f-25767e7fad99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 69, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247384131088047`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"5859662d-a225-47d7-8672-40e2ba00de3d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"4\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 71, " ", "k=\!\(\*FractionBox[\"4\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738417056917*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"17d42af1-e33f-45e9-824b-a93a3c2a36bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 72, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247384171353827`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"c7553eff-b38c-4788-88b2-8f211b8eb73f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 74, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738417476637*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"fec28137-3360-42ef-a4f8-02ff1e141278"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 75, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738417771337*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"4b06f3e0-3624-4770-a169-2fef68541819"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 76, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738419660377*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"a12d9a19-f9bf-49d9-bf2f-ea802ae5c5fe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 78, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738420014785*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"9558f5d1-f802-4711-8629-24ab5dfe01ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2780661433 is the smallest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"+\\\", RowBox[{\\\"3\\\", \\\
\" \\\", \\\"x\\\"}], \\\"-\\\", RowBox[{\\\"24\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", SuperscriptBox[\\\"x\\\", \
\\\"3\\\"]}]\\)\"\>"}],
  SequenceForm[
  "X", 79, " ", 
   "k\[TildeTilde]0.2780661433 is the smallest positive root of \
\!\(\*RowBox[{\"1\", \"+\", RowBox[{\"3\", \" \", \"x\"}], \"-\", \
RowBox[{\"24\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", SuperscriptBox[\
\"x\", \"3\"]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738420275412*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"b57a9c3f-d752-41b0-b1ca-8ee12cc4d96e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 80, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247384203495617`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"1d31aa19-9651-4ea8-bab6-28a4668ea3b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.08435922459 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"4\\\"}], \\\"-\\\", RowBox[{\\\"36\
\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"971\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"210\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", RowBox[{\\\"15\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 81, " ", 
   "k\[TildeTilde]0.08435922459 is the positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"4\"}], \"-\", RowBox[{\"36\", \" \", \"x\"}], \
\"+\", RowBox[{\"971\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"210\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"15\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738420990271*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"0047c15b-1ab6-4793-b262-65903532cdaa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1225502342 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"36\\\"}], \\\"-\\\", \
RowBox[{\\\"172\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"2563\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"9612\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \
\\\"+\\\", RowBox[{\\\"3863\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\
\"]}], \\\"+\\\", RowBox[{\\\"840\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"5\\\"]}], \\\"+\\\", RowBox[{\\\"109\\\", \\\" \\\", SuperscriptBox[\\\"x\
\\\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 82, " ", 
   "k\[TildeTilde]0.1225502342 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"36\"}], \"-\", RowBox[{\"172\", \" \", \"x\"}], \"+\", \
RowBox[{\"2563\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"9612\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", \
RowBox[{\"3863\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"840\
\", \" \", SuperscriptBox[\"x\", \"5\"]}], \"+\", RowBox[{\"109\", \" \", \
SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738422622987*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"90a4c351-ab3d-46a7-a5f8-83d13fd89d3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 83, " ", "k=\!\(\*FractionBox[\"2\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.8247384238725986`*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"2f5cbc3c-972d-4eb0-83e8-64cae90f2ae0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 85, " ", "k=\!\(\*FractionBox[\"2\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738424467605*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"0cc465c4-49d9-4a55-be36-ff846f64ba22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 86, " ", "k=\!\(\*FractionBox[\"2\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.82473842484512*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"d4f58172-2c09-4e6a-9809-4cbedd32c0d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \
\\\"6\\\"}], \\\" \\\", RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"3\\\
\"}], \\\"+\\\", RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"2\\\"]}]}], \
\\\")\\\"}]}]\\)\"\>"}],
  SequenceForm[
  "X", 88, " ", 
   "k=\!\(\*RowBox[{RowBox[{\"-\", \"6\"}], \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"3\"}], \"+\", RowBox[{\"2\", \" \", \
SqrtBox[\"2\"]}]}], \")\"}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738425377946*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"cb0f11f8-9b98-46f7-9bae-8c25104026d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1455847155 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"36\\\"}], \\\"-\\\", \
RowBox[{\\\"108\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"2399\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", RowBox[{\\\"280\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"3\\\"]}], \\\"+\\\", \
RowBox[{\\\"28\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 89, " ", 
   "k\[TildeTilde]0.1455847155 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"36\"}], \"-\", RowBox[{\"108\", \" \", \"x\"}], \"+\", \
RowBox[{\"2399\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"280\
\", \" \", SuperscriptBox[\"x\", \"3\"]}], \"+\", RowBox[{\"28\", \" \", \
SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738425814844*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"15ef698a-aa4e-4a5d-8ed0-5ad306ebf58a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 98, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738447629447*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"ad48d724-830f-4f08-babf-90c8f4e839a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 99, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738447964263*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"f3d586b0-d110-499d-9711-78fce3fc8d03"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"2\\\"}]\\)\"\>"}],
  SequenceForm["X", 100, " ", "k=\!\(\*RowBox[{\"2\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824642655757614*^9, 3.8247319969035587`*^9, 
  3.824738448035399*^9},
 CellLabel->
  "During evaluation of \
In[349]:=",ExpressionUUID->"3391a27e-6318-4a54-abd4-50329ce74ef5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", "3"}], ")"}], "^", "2"}], "*", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737531047468*^9, 3.82473756291223*^9}},
 CellLabel->
  "In[492]:=",ExpressionUUID->"970cb16a-67ce-4198-87f7-e0bcc9f9caac"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.847289555704207*^9},
 CellLabel->
  "During evaluation of \
In[492]:=",ExpressionUUID->"27b84f7d-5bfb-4043-9684-ef8fcbc39d14"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.824737548363451*^9, 3.824737559865309*^9}, 
   3.824738448136877*^9, 3.847181778103303*^9, 3.847289555706387*^9},
 CellLabel->
  "Out[493]=",ExpressionUUID->"6f7124ac-d62e-4868-9f58-3fca8bd86a4c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "3", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"R", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737572847533*^9, 3.824737578007482*^9}},
 CellLabel->
  "In[494]:=",ExpressionUUID->"50a51a29-dc85-430e-a395-37801b143bca"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.847289568377192*^9},
 CellLabel->
  "During evaluation of \
In[494]:=",ExpressionUUID->"c0a30cf7-964e-4c35-8810-2345c1e56b7a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247375788487864`*^9, 3.8247384482180643`*^9, 
  3.847181778112403*^9, 3.8472895683794107`*^9},
 CellLabel->
  "Out[495]=",ExpressionUUID->"a8f3bcdc-de9a-4f90-ad02-1007e31df9e2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", "2", ")"}], "^", "2"}], "*", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737586567634*^9, 3.8247375891910543`*^9}},
 CellLabel->
  "In[496]:=",ExpressionUUID->"5aa91260-c425-4d58-983e-9abbe6e9453f"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.847289573860878*^9},
 CellLabel->
  "During evaluation of \
In[496]:=",ExpressionUUID->"6e30164f-a214-45b1-95ae-725ef37d1a90"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247375899562807`*^9, 3.824738448294544*^9, 
  3.8471817781608677`*^9, 3.847289573864613*^9},
 CellLabel->
  "Out[497]=",ExpressionUUID->"f1990fe3-c2b5-4356-aaa2-c593eaf3e19b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "5", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], "*", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737597087571*^9, 3.8247376010712*^9}},
 CellLabel->
  "In[498]:=",ExpressionUUID->"858e485f-d447-458d-8509-37d4c5639026"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.8472895781431923`*^9},
 CellLabel->
  "During evaluation of \
In[498]:=",ExpressionUUID->"022cfe7c-bb6e-48e9-b81a-647de49168d3"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737601836532*^9, 3.8247384483679657`*^9, 
  3.847181778168849*^9, 3.84728957814651*^9},
 CellLabel->
  "Out[499]=",ExpressionUUID->"d4f5ef00-8c1b-4ba5-821a-a9cc46eb8b51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "8", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"2", "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737610607703*^9, 3.824737665567246*^9}},
 CellLabel->
  "In[500]:=",ExpressionUUID->"0e7c3029-cac8-4a0d-b950-626f8701ea47"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.8472895854250402`*^9},
 CellLabel->
  "During evaluation of \
In[500]:=",ExpressionUUID->"9ec6f8d3-3c81-4cca-abec-d9c95c001b2d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.824737616241448*^9, 3.824737666604097*^9}, 
   3.824738448443638*^9, 3.8471817782164497`*^9, 3.8472895854281693`*^9},
 CellLabel->
  "Out[501]=",ExpressionUUID->"609922e8-6fc9-4087-bc6b-c2716e10ff21"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "9", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"R", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{3.824737633687746*^9, 3.824737677895495*^9},
 CellLabel->
  "In[502]:=",ExpressionUUID->"02c90464-a8e1-4028-8056-f439498025c8"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.847289589245553*^9},
 CellLabel->
  "During evaluation of \
In[502]:=",ExpressionUUID->"58db2815-c3a0-4b9c-abf8-493115b3ea23"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737679350404*^9, 3.8247384485164537`*^9, 
  3.847181778224115*^9, 3.847289589249449*^9},
 CellLabel->
  "Out[503]=",ExpressionUUID->"ffe63a8d-7e46-4949-bd85-a8d5a8c654b5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "10", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"R", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737688119878*^9, 3.824737688479393*^9}},
 CellLabel->
  "In[504]:=",ExpressionUUID->"3ecffc69-dbd3-448e-a8ce-6067c8454de7"],

Cell[BoxData["\<\"Equality cannot occur.\"\>"], "Print",
 CellChangeTimes->{3.84728959364135*^9},
 CellLabel->
  "During evaluation of \
In[504]:=",ExpressionUUID->"8a5444ed-a3f5-4c12-8fb0-ad8a8e138a81"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737689625597*^9, 3.8247384485962954`*^9, 
  3.847181778270315*^9, 3.8472895936442947`*^9},
 CellLabel->
  "Out[505]=",ExpressionUUID->"1d7a2b66-ccbb-4887-812d-c563caf9e81b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "11", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247376981119347`*^9, 3.824737705535551*^9}},
 CellLabel->
  "In[506]:=",ExpressionUUID->"017ca0a7-03ac-4e61-a251-e4014b873fb6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737706316462*^9, 3.824738448669911*^9, 
  3.8471817782796183`*^9, 3.847289598300036*^9},
 CellLabel->
  "Out[507]=",ExpressionUUID->"729761b6-2721-4fa5-bf38-1409e0b35865"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "15", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
   RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
    RowBox[{"sq", "<=", 
     RowBox[{"k", "*", 
      RowBox[{"R", "^", "2"}]}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"minK", " ", 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8469348982198153`*^9, 3.8469349272558193`*^9}, {
  3.846934969108111*^9, 3.846934971515592*^9}},
 CellLabel->
  "In[515]:=",ExpressionUUID->"7c2cc2aa-c1c9-4c92-bc1e-5bc530e84fe6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.846935003255883*^9, 3.847181778327973*^9, 
  3.847289872460844*^9},
 CellLabel->
  "Out[517]=",ExpressionUUID->"5b537cdf-d2cc-48a6-8ca5-8d46f9309839"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "19", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "2"}], ")"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.82473772080803*^9, 3.824737732143512*^9}},
 CellLabel->
  "In[518]:=",ExpressionUUID->"9c70e65a-32e5-4deb-a436-7be1f4965ac9"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247377331548777`*^9, 3.8247384487777233`*^9, 
  3.8471817783380833`*^9, 3.847289930338128*^9},
 CellLabel->
  "Out[519]=",ExpressionUUID->"f55c5bb6-0c6a-4e0f-99c9-ae3886482f98"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "20", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"4", "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247377392960873`*^9, 3.8247377445594807`*^9}},
 CellLabel->
  "In[520]:=",ExpressionUUID->"b2e7b7f2-3bac-47ee-b76a-44eee5afff79"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737745829445*^9, 3.824738448851451*^9, 
  3.847181778387092*^9, 3.8472899338010817`*^9},
 CellLabel->
  "Out[521]=",ExpressionUUID->"8d0ea1bb-8570-43f7-99b4-410c5eb76b9a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "21", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247377536239023`*^9, 3.824737761711584*^9}},
 CellLabel->
  "In[522]:=",ExpressionUUID->"5ccefbf2-e3a6-4caf-ab4b-9d50e333f4d6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247377624024553`*^9, 3.824738448929203*^9, 
  3.847181778396315*^9, 3.847289938790985*^9},
 CellLabel->
  "Out[523]=",ExpressionUUID->"9bd01ea2-24e5-43d1-a88d-3d89f84e40b4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "51", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247377798400908`*^9, 3.8247377867836113`*^9}},
 CellLabel->
  "In[524]:=",ExpressionUUID->"f610b0ad-169f-4a46-9957-24f32700d578"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737787430951*^9, 3.8247384490149183`*^9, 
  3.847181778443673*^9, 3.847289943612249*^9},
 CellLabel->
  "Out[525]=",ExpressionUUID->"5c282956-534d-4861-9938-1066a18cbdcc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "61", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737799656477*^9, 3.824737807783906*^9}},
 CellLabel->
  "In[526]:=",ExpressionUUID->"437a03e9-94b0-409c-ba52-7014af8e008d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247378092337217`*^9, 3.824738449214429*^9, 
  3.8471817784529963`*^9, 3.847289959397628*^9},
 CellLabel->
  "Out[527]=",ExpressionUUID->"e5a3659e-f6bc-4cb0-8853-f3d270ae0a00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "63", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"2", "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737819112205*^9, 3.8247378248560658`*^9}},
 CellLabel->
  "In[528]:=",ExpressionUUID->"7466ecc5-c4cf-4177-9ed7-710d6fff5e0b"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737825669751*^9, 3.824738449331648*^9, 
  3.847181778501837*^9, 3.8472899746815968`*^9},
 CellLabel->
  "Out[529]=",ExpressionUUID->"3248c6f7-f0a2-42ba-a38d-10233631ceb1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "65", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "27"}], ")"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737838672435*^9, 3.8247378503197813`*^9}},
 CellLabel->
  "In[530]:=",ExpressionUUID->"82fff8bb-43ef-4d42-8225-82d1d4d80a47"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737851266075*^9, 3.824738449404922*^9, 
  3.847181778511487*^9, 3.847289978337885*^9},
 CellLabel->
  "Out[531]=",ExpressionUUID->"f8b569ac-cea7-458a-ac60-108331631d28"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "69", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"4", "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.82473786204042*^9, 3.824737865887931*^9}},
 CellLabel->
  "In[532]:=",ExpressionUUID->"d898eb0d-e580-4802-9ce1-09885e030ccb"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.82473786661965*^9, 3.8247384494945107`*^9, 
  3.847181778557438*^9, 3.847289985414071*^9},
 CellLabel->
  "Out[533]=",ExpressionUUID->"47371b47-f1be-4829-9fb8-98196b3ddc12"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "71", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"4", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{"R", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737875240484*^9, 3.824737880328141*^9}},
 CellLabel->
  "In[534]:=",ExpressionUUID->"740328db-2b98-47a7-999c-8191be653c50"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737880922204*^9, 3.824738449598815*^9, 
  3.847181778566332*^9, 3.8472899913516493`*^9},
 CellLabel->
  "Out[535]=",ExpressionUUID->"d3fe7bf5-7157-411c-a17e-dd3461460735"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"kR", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"R", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824718944799341*^9, 3.824718982682106*^9}},
 CellLabel->
  "In[384]:=",ExpressionUUID->"af1da1c3-3895-471c-b7d2-4a94badf6a14"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*RowBox[{\\\"\[Infinity]\\\"}]\\)\"\>"}],
  SequenceForm["X", 30, " ", "k=\!\(\*RowBox[{\"\[Infinity]\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824718961886817*^9, 3.8247189920918007`*^9, 
  3.824732088330751*^9, 3.824738458602582*^9},
 CellLabel->
  "During evaluation of \
In[384]:=",ExpressionUUID->"1f2749cd-57a5-4844-814d-a9b9af41d073"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distance of Center to X3 Compared With r", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
   3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
   3.824729944583457*^9}, 
   3.824730141232378*^9},ExpressionUUID->"41ff08af-5594-4ef5-99c4-\
b27812bc6d57"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"kr", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"No", " ", "results", " ", "found"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"r", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824643577703395*^9, 3.824643586999378*^9}, {
   3.824643739416543*^9, 3.824643743608081*^9}, 3.8247306369468613`*^9, {
   3.824730667890188*^9, 3.824730674569975*^9}},
 CellLabel->
  "In[385]:=",ExpressionUUID->"b971f372-e059-4d72-a45c-e5a853ad955f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"kr", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"No", " ", "results", " ", "found"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"r", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824643828240465*^9, 3.824643844120071*^9}, {
  3.82473068149098*^9, 3.824730682133033*^9}},
 CellLabel->
  "In[386]:=",ExpressionUUID->"9fc54a83-5efa-4442-b25f-1a0403a4744b"]
}, Closed]],

Cell[CellGroupData[{

Cell["Distance of Center to X1 Compared With s", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
   3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
   3.824729944583457*^9}, 
   3.824730065992073*^9},ExpressionUUID->"3ef35816-d326-4b78-b976-\
05fbee94fe0a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "15"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8246427659405203`*^9, 3.824642768516038*^9}, 
   3.82473070961917*^9, {3.82473258830711*^9, 3.824732589440363*^9}},
 CellLabel->
  "In[387]:=",ExpressionUUID->"34eb363d-b0de-4891-8be6-bee92a235c7c"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 2, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.8247386689691477`*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"28fd9fed-ce24-4fc5-aa03-1a33ba9c8635"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \\\"27\
\\\"], \\\" \\\", SqrtBox[RowBox[{FractionBox[\\\"1\\\", \\\"2\\\"], \\\" \
\\\", RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"10\\\"}], \\\"+\\\", \
RowBox[{\\\"7\\\", \\\" \\\", SqrtBox[\\\"7\\\"]}]}], \
\\\")\\\"}]}]]}]\\)\"\>"}],
  SequenceForm[
  "X", 6, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"27\"], \" \", \
SqrtBox[RowBox[{FractionBox[\"1\", \"2\"], \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"10\"}], \"+\", RowBox[{\"7\", \" \", \
SqrtBox[\"7\"]}]}], \")\"}]}]]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.8247386693111897`*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"f783870f-34fa-44b6-bb9b-fb85eee2b763"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.08033922809 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"639\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"74871\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"19683\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 7, " ", 
   "k\[TildeTilde]0.08033922809 is the largest positive root of \
\!\(\*RowBox[{\"1\", \"-\", RowBox[{\"639\", \" \", SuperscriptBox[\"x\", \"2\
\"]}], \"+\", RowBox[{\"74871\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"19683\", \" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.8247386694830093`*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"214e3441-70b0-4233-8217-5eeda64667c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 8, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.824738669554544*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"05e7fefa-44c3-4643-94d8-4a7d2985406e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 9, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.8247386696332207`*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"df55a839-7bc6-43bf-8f96-5303dd04564b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 10, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.824738669646492*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"903187b9-085d-4571-b4fb-b34664143b41"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"3\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 11, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"3\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.82473866971566*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"f2a3cbc3-9526-4da8-81f5-18eccd80ae9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.05392364926 is a root of \
\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"1\\\"}], \\\"+\\\", \
RowBox[{\\\"1004\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"-\\\", RowBox[{\\\"224326\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"-\\\", RowBox[{\\\"923732\\\", \\\" \\\", SuperscriptBox[\\\"x\\\
\", \\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"151263\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 12, " ", 
   "k\[TildeTilde]0.05392364926 is a root of \!\(\*RowBox[{RowBox[{\"-\", \"1\
\"}], \"+\", RowBox[{\"1004\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"224326\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"-\", \
RowBox[{\"923732\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"+\", \
RowBox[{\"151263\", \" \", SuperscriptBox[\"x\", \"8\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.824738670250923*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"3fd1d481-7bf0-4f8c-8744-ae2699ad1537"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 13, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"2\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.824738692698401*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"7df562d2-e7fc-40a2-a3fe-afb0a1a41fab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"2\\\", \\\"81\
\\\"], \\\" \\\", SqrtBox[RowBox[{FractionBox[\\\"1\\\", \\\"3\\\"], \\\" \
\\\", RowBox[{\\\"(\\\", RowBox[{\\\"419\\\", \\\"+\\\", RowBox[{\\\"130\\\", \
\\\" \\\", SqrtBox[\\\"10\\\"]}]}], \\\")\\\"}]}]]}]\\)\"\>"}],
  SequenceForm[
  "X", 14, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"2\", \"81\"], \" \", \
SqrtBox[RowBox[{FractionBox[\"1\", \"3\"], \" \", RowBox[{\"(\", \
RowBox[{\"419\", \"+\", RowBox[{\"130\", \" \", SqrtBox[\"10\"]}]}], \
\")\"}]}]]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.8247387156688423`*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"3b8e1cf3-7253-41d5-9af4-ba6152ef8769"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 15, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"2\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8246427765909233`*^9, 3.824732292050699*^9, 
  3.8247325953474083`*^9, 3.824738716430254*^9},
 CellLabel->
  "During evaluation of \
In[387]:=",ExpressionUUID->"80a65add-0b3f-43d9-be93-df3525dee23b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247371722381496`*^9, 3.824737193718904*^9}},
 CellLabel->
  "In[538]:=",ExpressionUUID->"90be3d47-3ec2-45d6-9e7b-0ccb6d0770ba"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737191068122*^9, 3.824738716525354*^9, 
  3.847181778846575*^9, 3.847290414459702*^9},
 CellLabel->
  "Out[539]=",ExpressionUUID->"515424ab-b54b-47f2-8b2d-2830d157d4af"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "8", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"s", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247372163505507`*^9, 3.824737224087245*^9}},
 CellLabel->
  "In[540]:=",ExpressionUUID->"84995965-f268-425d-944a-ad1762eb0ff6"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737224898821*^9, 3.824738716598544*^9, 
  3.847181778853999*^9, 3.847290422703436*^9},
 CellLabel->
  "Out[541]=",ExpressionUUID->"4dbec7be-c96a-4d54-a0d0-7d63ee352873"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "9", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247372358465548`*^9, 3.824737239430264*^9}},
 CellLabel->
  "In[542]:=",ExpressionUUID->"db3ad400-c7f3-4119-afe7-54071a79405e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737239975423*^9, 3.8247387166791697`*^9, 
  3.847181778901863*^9, 3.847290426601128*^9},
 CellLabel->
  "Out[543]=",ExpressionUUID->"0b4b7b41-c493-4bde-a054-febaf19e9b51"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "10", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737247910634*^9, 3.8247372517342176`*^9}},
 CellLabel->
  "In[544]:=",ExpressionUUID->"9ec488a4-75e5-48bc-95e3-28728468928e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737252397739*^9, 3.824738716755929*^9, 
  3.847181778910651*^9, 3.84729043749577*^9},
 CellLabel->
  "Out[545]=",ExpressionUUID->"c19cd00e-a9e9-45f2-ab4d-080e928625a7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "11", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "27"}], ")"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737258566738*^9, 3.824737277326262*^9}},
 CellLabel->
  "In[546]:=",ExpressionUUID->"8bd1ceb3-6849-420d-b954-cb07a73d460c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737278187913*^9, 3.824738716831583*^9, 
  3.84718177895758*^9, 3.847290441135047*^9},
 CellLabel->
  "Out[547]=",ExpressionUUID->"13293024-4d11-42a1-affb-5081e325febf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "13", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "12"}], ")"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737295270796*^9, 3.824737300750278*^9}},
 CellLabel->
  "In[548]:=",ExpressionUUID->"ce4f87f4-2ce2-4ca9-864b-13b5e187041c"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737301637991*^9, 3.8247387172328987`*^9, 
  3.847181778966876*^9, 3.847290448157547*^9},
 CellLabel->
  "Out[549]=",ExpressionUUID->"0e585c86-2341-44ce-90cc-1e30a7858821"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "15", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "12"}], ")"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737313270859*^9, 3.82473732804631*^9}},
 CellLabel->
  "In[550]:=",ExpressionUUID->"be941fc0-40d6-4f1d-b64d-04993347150e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737328782881*^9, 3.824738717471795*^9, 
  3.84718177901484*^9, 3.8472904525993834`*^9},
 CellLabel->
  "Out[551]=",ExpressionUUID->"de4d0cf2-baec-4354-9d33-0cc91aee6292"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "19"}], ",", 
     RowBox[{"i", "\[LessEqual]", "60"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824732660752924*^9, 3.824732667736467*^9}, {
  3.824732996163889*^9, 3.824732996849506*^9}},
 CellLabel->
  "In[402]:=",ExpressionUUID->"d3ad4728-b476-40d8-9240-b95871763dca"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 19, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738717895301*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"acfd950a-e8e1-4ea2-8730-bb075b76dc8b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 21, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738718024877*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"ed6c0c7a-57cc-4453-9afd-517eacc1dde6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"2\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 25, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"2\", \" \", SqrtBox[\"2\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738719243434*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"78bf2eac-e1f0-4c19-8d5f-4612a17b9292"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
SqrtBox[\\\"5\\\"]]\\)\"\>"}],
  SequenceForm["X", 27, " ", "k=\!\(\*FractionBox[\"1\", SqrtBox[\"5\"]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738720386269*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"ab1860f1-a02d-4f5a-98ad-14e133134e92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[\\\"2\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 28, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"2\", \" \", SqrtBox[\"2\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.8247387208287573`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"50de5173-45b4-415c-9df2-7f8b2f7da7fc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*SqrtBox[InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"0.0124\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[\\\"6912\\\", \\\"-\\\", \
RowBox[List[\\\"1542240\\\", \\\" \\\", \\\"#1\\\"]], \\\"+\\\", RowBox[List[\
\\\"43692651\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"2\\\"]]], \\\"+\\\
\", RowBox[List[\\\"2954450875\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"3\\\"]]], \\\"-\\\", RowBox[List[\\\"7055796762\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"4\\\"]]], \\\"-\\\", \
RowBox[List[\\\"19400067810\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"5\\\"]]], \\\"-\\\", RowBox[List[\\\"13713756273\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"6\\\"]]], \\\"+\\\", \
RowBox[List[\\\"71744535\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"7\\\"]]]]], \\\"&\\\"]], \\\",\\\", \\\"3\\\"]], \\\"]\\\"]], \
Function[Short[Slot[1], 7]]], 0.012438792397783742`], \
\\\"NumericalApproximation\\\"], Root[Function[Plus[6912, Times[-1542240, \
Slot[1]], Times[43692651, Power[Slot[1], 2]], Times[2954450875, \
Power[Slot[1], 3]], Times[-7055796762, Power[Slot[1], 4]], \
Times[-19400067810, Power[Slot[1], 5]], Times[-13713756273, Power[Slot[1], \
6]], Times[71744535, Power[Slot[1], 7]]]], 3, 0]]]\\)\"\>"}],
  SequenceForm[
  "X", 31, " ", 
   "k=\!\(\*SqrtBox[InterpretationBox[TemplateBox[List[\"Root\", \
TemplateBox[List[\"\\\"0.0124\\\"\", \
DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[\"6912\", \"-\", RowBox[List[\"1542240\", \
\" \", \"#1\"]], \"+\", RowBox[List[\"43692651\", \" \", \
SuperscriptBox[\"#1\", \"2\"]]], \"+\", RowBox[List[\"2954450875\", \" \", \
SuperscriptBox[\"#1\", \"3\"]]], \"-\", RowBox[List[\"7055796762\", \" \", \
SuperscriptBox[\"#1\", \"4\"]]], \"-\", RowBox[List[\"19400067810\", \" \", \
SuperscriptBox[\"#1\", \"5\"]]], \"-\", RowBox[List[\"13713756273\", \" \", \
SuperscriptBox[\"#1\", \"6\"]]], \"+\", RowBox[List[\"71744535\", \" \", \
SuperscriptBox[\"#1\", \"7\"]]]]], \"&\"]], \",\", \"3\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 0.012438792397783742`], \
\"NumericalApproximation\"], Root[Function[Plus[6912, Times[-1542240, \
Slot[1]], Times[43692651, Power[Slot[1], 2]], Times[2954450875, \
Power[Slot[1], 3]], Times[-7055796762, Power[Slot[1], 4]], \
Times[-19400067810, Power[Slot[1], 5]], Times[-13713756273, Power[Slot[1], \
6]], Times[71744535, Power[Slot[1], 7]]]], 3, 0]]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738721511819*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"510593ef-a9e5-4049-a508-80ffa736d758"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*SqrtBox[InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"0.0173\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[\\\"343\\\", \\\"-\\\", \
RowBox[List[\\\"29649\\\", \\\" \\\", \\\"#1\\\"]], \\\"-\\\", RowBox[List[\\\
\"671146\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"2\\\"]]], \\\"+\\\", \
RowBox[List[\\\"44879438\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"3\\\"]]], \\\"+\\\", RowBox[List[\\\"1315884899\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"4\\\"]]], \\\"+\\\", \
RowBox[List[\\\"12739034515\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"5\\\"]]], \\\"+\\\", RowBox[List[\\\"44636544960\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"6\\\"]]], \\\"+\\\", \
RowBox[List[\\\"53486454208\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"7\\\"]]], \\\"+\\\", RowBox[List[\\\"5768017920\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"8\\\"]]], \\\"+\\\", RowBox[List[\\\"181398528\
\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"9\\\"]]]]], \\\"&\\\"]], \
\\\",\\\", \\\"3\\\"]], \\\"]\\\"]], Function[Short[Slot[1], 7]]], \
0.017280198639797906`], \\\"NumericalApproximation\\\"], \
Root[Function[Plus[343, Times[-29649, Slot[1]], Times[-671146, Power[Slot[1], \
2]], Times[44879438, Power[Slot[1], 3]], Times[1315884899, Power[Slot[1], \
4]], Times[12739034515, Power[Slot[1], 5]], Times[44636544960, Power[Slot[1], \
6]], Times[53486454208, Power[Slot[1], 7]], Times[5768017920, Power[Slot[1], \
8]], Times[181398528, Power[Slot[1], 9]]]], 3, 0]]]\\)\"\>"}],
  SequenceForm[
  "X", 32, " ", 
   "k=\!\(\*SqrtBox[InterpretationBox[TemplateBox[List[\"Root\", \
TemplateBox[List[\"\\\"0.0173\\\"\", \
DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", RowBox[List[RowBox[List[RowBox[List[\"343\
\", \"-\", RowBox[List[\"29649\", \" \", \"#1\"]], \"-\", \
RowBox[List[\"671146\", \" \", SuperscriptBox[\"#1\", \"2\"]]], \"+\", \
RowBox[List[\"44879438\", \" \", SuperscriptBox[\"#1\", \"3\"]]], \"+\", \
RowBox[List[\"1315884899\", \" \", SuperscriptBox[\"#1\", \"4\"]]], \"+\", \
RowBox[List[\"12739034515\", \" \", SuperscriptBox[\"#1\", \"5\"]]], \"+\", \
RowBox[List[\"44636544960\", \" \", SuperscriptBox[\"#1\", \"6\"]]], \"+\", \
RowBox[List[\"53486454208\", \" \", SuperscriptBox[\"#1\", \"7\"]]], \"+\", \
RowBox[List[\"5768017920\", \" \", SuperscriptBox[\"#1\", \"8\"]]], \"+\", \
RowBox[List[\"181398528\", \" \", SuperscriptBox[\"#1\", \"9\"]]]]], \"&\"]], \
\",\", \"3\"]], \"]\"]], Function[Short[Slot[1], 7]]], \
0.017280198639797906`], \"NumericalApproximation\"], Root[Function[Plus[343, \
Times[-29649, Slot[1]], Times[-671146, Power[Slot[1], 2]], Times[44879438, \
Power[Slot[1], 3]], Times[1315884899, Power[Slot[1], 4]], Times[12739034515, \
Power[Slot[1], 5]], Times[44636544960, Power[Slot[1], 6]], Times[53486454208, \
Power[Slot[1], 7]], Times[5768017920, Power[Slot[1], 8]], Times[181398528, \
Power[Slot[1], 9]]]], 3, 0]]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738722247785*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"81a9d756-a83c-4842-a007-8cbb0afa006f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2427916750 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"256\\\", \\\"+\\\", \
RowBox[{\\\"1209\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"-\\\", RowBox[{\\\"961591\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"20538774\\\", \\\" \\\", SuperscriptBox[\\\"x\
\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"148490346\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"842993141\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}], \\\"+\\\", \
RowBox[{\\\"9801\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"12\\\"]}]}]\\)\
\"\>"}],
  SequenceForm[
  "X", 34, " ", 
   "k\[TildeTilde]0.2427916750 is the largest positive root of \!\(\*RowBox[{\
\"256\", \"+\", RowBox[{\"1209\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"-\", RowBox[{\"961591\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"20538774\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"148490346\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\
\"842993141\", \" \", SuperscriptBox[\"x\", \"10\"]}], \"+\", \
RowBox[{\"9801\", \" \", SuperscriptBox[\"x\", \"12\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.8247387228619204`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"7181020f-dedd-44ee-bc51-56f47b6995ec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1278894169 is a root of \
\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"64\\\"}], \\\"+\\\", RowBox[{\\\"9040\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"248284\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\
\"-\\\", RowBox[{\\\"3227633\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"46419964\\\", \\\" \\\", SuperscriptBox[\
\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"5445468\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 35, " ", 
   "k\[TildeTilde]0.1278894169 is a root of \!\(\*RowBox[{RowBox[{\"-\", \"64\
\"}], \"+\", RowBox[{\"9040\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"248284\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"-\", \
RowBox[{\"3227633\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"46419964\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"5445468\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.8247387229492397`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"48638766-5beb-45cf-adce-6a32bbad92ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.04923415291 is a root of \
\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"1\\\"}], \\\"+\\\", \
RowBox[{\\\"2637\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"-\\\", RowBox[{\\\"917919\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"98415\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 37, " ", 
   "k\[TildeTilde]0.04923415291 is a root of \!\(\*RowBox[{RowBox[{\"-\", \"1\
\"}], \"+\", RowBox[{\"2637\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"917919\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"98415\", \" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738723399744*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"b632e649-ab6e-4705-a8fd-c74227598eda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.07437484290 is a root of \
\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"432\\\"}], \\\"+\\\", \
RowBox[{\\\"293832\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\
\"-\\\", RowBox[{\\\"39856739\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"154870839\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"12563829\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", \
RowBox[{\\\"1240029\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\
\\)\"\>"}],
  SequenceForm[
  "X", 38, " ", 
   "k\[TildeTilde]0.07437484290 is a root of \!\(\*RowBox[{RowBox[{\"-\", \
\"432\"}], \"+\", RowBox[{\"293832\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"-\", RowBox[{\"39856739\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"154870839\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", RowBox[{\
\"12563829\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\"1240029\
\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738723627453*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"2ad68ca7-16ed-47d7-baf0-941598b06ef6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
RowBox[{\\\"2\\\", \\\" \\\", SqrtBox[RowBox[{\\\"37\\\", \\\"+\\\", RowBox[{\
\\\"14\\\", \\\" \\\", SqrtBox[\\\"7\\\"]}]}]]}]]\\)\"\>"}],
  SequenceForm[
  "X", 39, " ", 
   "k=\!\(\*FractionBox[\"1\", RowBox[{\"2\", \" \", SqrtBox[RowBox[{\"37\", \
\"+\", RowBox[{\"14\", \" \", SqrtBox[\"7\"]}]}]]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738724283207*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"12b2cbb0-02db-42aa-b6c1-760c2e860e07"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{FractionBox[\\\"1\\\", \
\\\"2\\\"], \\\" \\\", SqrtBox[RowBox[{FractionBox[\\\"1\\\", \\\"2\\\"], \
\\\" \\\", RowBox[{\\\"(\\\", RowBox[{RowBox[{\\\"-\\\", \\\"11\\\"}], \
\\\"+\\\", RowBox[{\\\"5\\\", \\\" \\\", SqrtBox[\\\"5\\\"]}]}], \
\\\")\\\"}]}]]}]\\)\"\>"}],
  SequenceForm[
  "X", 41, " ", 
   "k=\!\(\*RowBox[{FractionBox[\"1\", \"2\"], \" \", \
SqrtBox[RowBox[{FractionBox[\"1\", \"2\"], \" \", RowBox[{\"(\", \
RowBox[{RowBox[{\"-\", \"11\"}], \"+\", RowBox[{\"5\", \" \", \
SqrtBox[\"5\"]}]}], \")\"}]}]]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738724763072*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"a8cf6f42-abb0-43d5-be78-bb4ed44ade22"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.05655018220 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"3399\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"84226\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"275391738\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\
\"6\\\"]}], \\\"+\\\", RowBox[{\\\"18242253\\\", \\\" \\\", SuperscriptBox[\\\
\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"1240029\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 42, " ", 
   "k\[TildeTilde]0.05655018220 is the largest positive root of \
\!\(\*RowBox[{\"1\", \"-\", RowBox[{\"3399\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"84226\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"275391738\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"+\", \
RowBox[{\"18242253\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"1240029\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.8247387249646883`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"99e426d4-c725-4a11-916b-47cd976253d7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1714190611 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"4096\\\", \\\"-\\\", RowBox[{\\\"941568\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"11369456\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"1290716208\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"854793567\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"141717600\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 43, " ", 
   "k\[TildeTilde]0.1714190611 is the largest positive root of \!\(\*RowBox[{\
\"4096\", \"-\", RowBox[{\"941568\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"-\", RowBox[{\"11369456\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"1290716208\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"+\", \
RowBox[{\"854793567\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\
\"141717600\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738725176237*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"bd6d51ac-5e42-4ce9-933d-b8784b0f599f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1121345941 is a root of \
\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"81\\\"}], \\\"+\\\", \
RowBox[{\\\"49329\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"-\\\", RowBox[{\\\"3730615\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"26095743\\\", \\\" \\\", SuperscriptBox[\
\\\"x\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"52415100\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"14880348\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 45, " ", 
   "k\[TildeTilde]0.1121345941 is a root of \!\(\*RowBox[{RowBox[{\"-\", \"81\
\"}], \"+\", RowBox[{\"49329\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"3730615\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"26095743\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"52415100\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"14880348\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.8247387255073643`*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"d82c99c8-bba9-4e56-90ab-00906c2a4799"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.2627056085 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1024\\\", \\\"-\\\", \
RowBox[{\\\"26368\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"85888\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"1149728\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"368500\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", \
RowBox[{\\\"253125\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 46, " ", 
   "k\[TildeTilde]0.2627056085 is the largest positive root of \!\(\*RowBox[{\
\"1024\", \"-\", RowBox[{\"26368\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"85888\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"1149728\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"+\", \
RowBox[{\"368500\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"253125\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738725612451*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"9f7283b1-fcf9-4aa9-995d-4ec2d288c0cf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 51, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738762355556*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"629d8598-94f1-44c0-9688-060dd8f0029f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*SqrtBox[InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"0.0632\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[\\\"8573184\\\", \\\"+\\\", \
RowBox[List[\\\"59441893757\\\", \\\" \\\", \\\"#1\\\"]], \\\"-\\\", \
RowBox[List[\\\"5781140359640\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"2\\\"]]], \\\"+\\\", RowBox[List[\\\"108316716860874\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"3\\\"]]], \\\"-\\\", \
RowBox[List[\\\"586588057074848\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\
\"4\\\"]]], \\\"+\\\", RowBox[List[\\\"1333772414641409\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"5\\\"]]], \\\"-\\\", \
RowBox[List[\\\"96333972437184\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"6\\\"]]], \\\"+\\\", RowBox[List[\\\"14859081780480\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"7\\\"]]], \\\"+\\\", \
RowBox[List[\\\"5208883200\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"8\\\
\"]]], \\\"+\\\", RowBox[List[\\\"967458816\\\", \\\" \\\", SuperscriptBox[\\\
\"#1\\\", \\\"9\\\"]]]]], \\\"&\\\"]], \\\",\\\", \\\"3\\\"]], \\\"]\\\"]], \
Function[Short[Slot[1], 7]]], 0.06321835698874968`], \
\\\"NumericalApproximation\\\"], Root[Function[Plus[8573184, \
Times[59441893757, Slot[1]], Times[-5781140359640, Power[Slot[1], 2]], \
Times[108316716860874, Power[Slot[1], 3]], Times[-586588057074848, \
Power[Slot[1], 4]], Times[1333772414641409, Power[Slot[1], 5]], \
Times[-96333972437184, Power[Slot[1], 6]], Times[14859081780480, \
Power[Slot[1], 7]], Times[5208883200, Power[Slot[1], 8]], Times[967458816, \
Power[Slot[1], 9]]]], 3, 0]]]\\)\"\>"}],
  SequenceForm[
  "X", 53, " ", 
   "k=\!\(\*SqrtBox[InterpretationBox[TemplateBox[List[\"Root\", \
TemplateBox[List[\"\\\"0.0632\\\"\", \
DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[\"8573184\", \"+\", \
RowBox[List[\"59441893757\", \" \", \"#1\"]], \"-\", \
RowBox[List[\"5781140359640\", \" \", SuperscriptBox[\"#1\", \"2\"]]], \"+\", \
RowBox[List[\"108316716860874\", \" \", SuperscriptBox[\"#1\", \"3\"]]], \
\"-\", RowBox[List[\"586588057074848\", \" \", SuperscriptBox[\"#1\", \
\"4\"]]], \"+\", RowBox[List[\"1333772414641409\", \" \", SuperscriptBox[\"#1\
\", \"5\"]]], \"-\", RowBox[List[\"96333972437184\", \" \", \
SuperscriptBox[\"#1\", \"6\"]]], \"+\", RowBox[List[\"14859081780480\", \" \
\", SuperscriptBox[\"#1\", \"7\"]]], \"+\", RowBox[List[\"5208883200\", \" \
\", SuperscriptBox[\"#1\", \"8\"]]], \"+\", RowBox[List[\"967458816\", \" \", \
SuperscriptBox[\"#1\", \"9\"]]]]], \"&\"]], \",\", \"3\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 0.06321835698874968`], \"NumericalApproximation\
\"], Root[Function[Plus[8573184, Times[59441893757, Slot[1]], \
Times[-5781140359640, Power[Slot[1], 2]], Times[108316716860874, \
Power[Slot[1], 3]], Times[-586588057074848, Power[Slot[1], 4]], \
Times[1333772414641409, Power[Slot[1], 5]], Times[-96333972437184, \
Power[Slot[1], 6]], Times[14859081780480, Power[Slot[1], 7]], \
Times[5208883200, Power[Slot[1], 8]], Times[967458816, Power[Slot[1], 9]]]], \
3, 0]]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738813851841*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"0ca6b876-ea7a-466c-a5df-55e257b5e051"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.07420851817 is a root of \
\\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"1\\\"}], \\\"+\\\", RowBox[{\\\"423\\\
\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"-\\\", \
RowBox[{\\\"41350\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"-\\\", RowBox[{\\\"407538\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"6\
\\\"]}], \\\"-\\\", RowBox[{\\\"8026533\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"177147\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 55, " ", 
   "k\[TildeTilde]0.07420851817 is a root of \!\(\*RowBox[{RowBox[{\"-\", \"1\
\"}], \"+\", RowBox[{\"423\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"-\", \
RowBox[{\"41350\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"-\", \
RowBox[{\"407538\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"8026533\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"177147\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738814379735*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"687f6f17-499c-454a-ba9e-9a17b815f90e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1313528043 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"103\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"1342\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"71858\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"92125\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"253125\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 56, " ", 
   "k\[TildeTilde]0.1313528043 is the largest positive root of \!\(\*RowBox[{\
\"1\", \"-\", RowBox[{\"103\", \" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", \
RowBox[{\"1342\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"71858\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"+\", \
RowBox[{\"92125\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"253125\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738814455027*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"d2da4615-6e46-4fca-a14b-600f3e52f832"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1063849234 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"16\\\", \\\"-\\\", \
RowBox[{\\\"3000\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"130081\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"895023\\\", \\\" \\\", SuperscriptBox[\\\"x\\\
\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"400464\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"177147\\\", \\\
\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 57, " ", 
   "k\[TildeTilde]0.1063849234 is the largest positive root of \!\(\*RowBox[{\
\"16\", \"-\", RowBox[{\"3000\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"130081\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"895023\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"400464\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"177147\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738814539131*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"cf4d4b80-ac52-4f59-b98f-432b91f24a3a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.09278411512 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"16\\\", \\\"-\\\", \
RowBox[{\\\"5720\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"292873\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"17972440\\\", \\\" \\\", SuperscriptBox[\\\"x\
\\\", \\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"12707875\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"8128512\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 58, " ", 
   "k\[TildeTilde]0.09278411512 is the largest positive root of \
\!\(\*RowBox[{\"16\", \"-\", RowBox[{\"5720\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"292873\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"17972440\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"+\", \
RowBox[{\"12707875\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", \
RowBox[{\"8128512\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738814748877*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"3a014c16-24cd-454d-8591-626715382d9b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 59, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738815299014*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"02809418-6dbf-400f-8633-b6c12dbfb561"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1046525121 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"9\\\"}], \\\"+\\\", \
RowBox[{\\\"818\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\
\\\", RowBox[{\\\"343\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 60, " ", 
   "k\[TildeTilde]0.1046525121 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"9\"}], \"+\", RowBox[{\"818\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"343\", \" \", SuperscriptBox[\"x\", \"4\"]}]}]\)"],
  
  Editable->False]], "Print",
 CellChangeTimes->{3.8247326693786983`*^9, 3.824732968077232*^9, 
  3.824732998262665*^9, 3.824738815820593*^9},
 CellLabel->
  "During evaluation of \
In[402]:=",ExpressionUUID->"300eceef-825a-440e-b7b1-092026d6fad2"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "19", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737377327106*^9, 3.824737386342641*^9}},
 CellLabel->
  "In[552]:=",ExpressionUUID->"f60f568f-aae2-4cb9-815b-41084e993afc"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247373875908833`*^9, 3.824738815998145*^9, 
  3.847181779092943*^9, 3.847290487029985*^9},
 CellLabel->
  "Out[553]=",ExpressionUUID->"298c35a0-833f-4215-b54a-3f72c8922192"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "21", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247373990631*^9, 3.824737402182632*^9}},
 CellLabel->
  "In[554]:=",ExpressionUUID->"335a1eee-cf68-47de-96f6-aac580619b76"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737402927948*^9, 3.8247388160714893`*^9, 
  3.847181779101514*^9, 3.847290505333787*^9},
 CellLabel->
  "Out[555]=",ExpressionUUID->"1c3522a9-c613-47fc-9fec-87832d6b60e8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "25", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "8"}], ")"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824737420663165*^9, 3.824737429726625*^9}},
 CellLabel->
  "In[556]:=",ExpressionUUID->"9da8f57d-5fc3-469c-a12b-e4d6e2747799"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824737430782998*^9, 3.824738816193885*^9, 
  3.847181779148507*^9, 3.847290510984009*^9},
 CellLabel->
  "Out[557]=",ExpressionUUID->"9ea0bf75-4174-4ae2-90ca-f50e188adcce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "27", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "5"}], ")"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247374444312572`*^9, 3.824737446878727*^9}},
 CellLabel->
  "In[558]:=",ExpressionUUID->"d3b1a840-2179-4493-aca0-6b95172221cd"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.82473744743497*^9, 3.8247388163847857`*^9, 
  3.847181779157444*^9, 3.847290517943049*^9},
 CellLabel->
  "Out[559]=",ExpressionUUID->"e15f9afe-92c8-4cfc-bb7e-a8fe23279f00"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "28", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"1", "/", "8"}], ")"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{3.824737454391152*^9},
 CellLabel->
  "In[560]:=",ExpressionUUID->"1d9a4669-7953-424b-a929-d666fe9fb3b3"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247374589651213`*^9, 3.8247388165329*^9, 
  3.847181779206274*^9, 3.847290522141447*^9},
 CellLabel->
  "Out[561]=",ExpressionUUID->"ee1483c4-e699-4a82-a425-5c391e5a7a02"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "63"}], ",", 
     RowBox[{"i", "\[LessEqual]", "95"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8247329044817543`*^9, 3.824732908993222*^9}},
 CellLabel->
  "In[413]:=",ExpressionUUID->"76a7313f-e45b-4e37-b14c-305da6a58dd8"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 63, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738816623781*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"16e453db-626a-4d55-97e2-e5c05164c87c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.09159894210 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"269\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"17855\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"81\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 65, " ", 
   "k\[TildeTilde]0.09159894210 is the largest positive root of \
\!\(\*RowBox[{\"1\", \"-\", RowBox[{\"269\", \" \", SuperscriptBox[\"x\", \"2\
\"]}], \"+\", RowBox[{\"17855\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"81\", \" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738817172113*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"62be49f3-3e1e-40be-96fa-7e233e19fa5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 67, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738822760271*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"ce5f2a14-385a-462b-95f6-a04a61a5e690"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 69, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738823595299*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"c308f5bf-82a4-4956-9ac7-d98ed068463e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 71, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738828659923*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"2809ae61-7320-44d2-af5c-0a091637652f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 72, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.82473882873282*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"ac795994-7bec-4386-bb85-5415bcdff927"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 75, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738829251423*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"12e9d494-dd45-4361-a2df-05cfb5c3a2f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 76, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388368350983`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"0137fb2e-5055-4579-aceb-2a1e8b3e9062"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 78, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388371354322`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"0b9d9e42-99af-426a-8e9c-6fd69af0eaba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1452643676 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"64\\\", \\\"-\\\", \
RowBox[{\\\"19088\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"755500\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"253125\\\", \\\" \\\", SuperscriptBox[\\\"x\\\
\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 79, " ", 
   "k\[TildeTilde]0.1452643676 is the largest positive root of \!\(\*RowBox[{\
\"64\", \"-\", RowBox[{\"19088\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"755500\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"253125\", \" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388374320583`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"93db3678-a946-4945-a56a-47fd1e9818a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
RowBox[{\\\"3\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 80, " ", 
   "k=\!\(\*FractionBox[\"2\", RowBox[{\"3\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738837531514*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"9abc5f83-99a5-4734-b392-9d0a88031d5c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.03627449530 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"16\\\", \\\"-\\\", \
RowBox[{\\\"44616\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"22171297\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"1896049917\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"123705225\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", \
RowBox[{\\\"22143375\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 81, " ", 
   "k\[TildeTilde]0.03627449530 is the largest positive root of \
\!\(\*RowBox[{\"16\", \"-\", RowBox[{\"44616\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"22171297\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"1896049917\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"123705225\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\
\"22143375\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738837819728*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"51b43b6e-6985-42c2-be16-66c6e85a9fbe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*SqrtBox[InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"2.64\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]], \
\\\"\\\\\\\"\\\\[ThinSpace]\\\\[Times]\\\\[ThinSpace]\\\\\\\"\\\", \
TemplateBox[List[\\\"\\\\\\\"10\\\\\\\"\\\", \\\"\\\\\\\"-3\\\\\\\"\\\"], \
\\\"Superscript\\\", Rule[SyntaxForm, SuperscriptBox]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[\\\"6912\\\", \\\"-\\\", \
RowBox[List[\\\"5489280\\\", \\\" \\\", \\\"#1\\\"]], \\\"+\\\", RowBox[List[\
\\\"1013811536\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"2\\\"]]], \\\"+\
\\\", RowBox[List[\\\"29197253896\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"3\\\"]]], \\\"-\\\", RowBox[List[\\\"515921363941\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"4\\\"]]], \\\"-\\\", \
RowBox[List[\\\"346241467449\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"5\
\\\"]]], \\\"-\\\", RowBox[List[\\\"741842005491\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"6\\\"]]], \\\"+\\\", \
RowBox[List[\\\"1636976061\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"7\\\
\"]]]]], \\\"&\\\"]], \\\",\\\", \\\"3\\\"]], \\\"]\\\"]], \
Function[Short[Slot[1], 7]]], 0.0026439061600645386`], \
\\\"NumericalApproximation\\\"], Root[Function[Plus[6912, Times[-5489280, \
Slot[1]], Times[1013811536, Power[Slot[1], 2]], Times[29197253896, \
Power[Slot[1], 3]], Times[-515921363941, Power[Slot[1], 4]], \
Times[-346241467449, Power[Slot[1], 5]], Times[-741842005491, Power[Slot[1], \
6]], Times[1636976061, Power[Slot[1], 7]]]], 3, 0]]]\\)\"\>"}],
  SequenceForm[
  "X", 82, " ", 
   "k=\!\(\*SqrtBox[InterpretationBox[TemplateBox[List[\"Root\", \
TemplateBox[List[\"\\\"2.64\\\"\", \
DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]], \"\\\"\\[ThinSpace]\\[Times]\\[ThinSpace]\
\\\"\", TemplateBox[List[\"\\\"10\\\"\", \"\\\"-3\\\"\"], \"Superscript\", \
Rule[SyntaxForm, SuperscriptBox]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[\"6912\", \"-\", RowBox[List[\"5489280\", \
\" \", \"#1\"]], \"+\", RowBox[List[\"1013811536\", \" \", \
SuperscriptBox[\"#1\", \"2\"]]], \"+\", RowBox[List[\"29197253896\", \" \", \
SuperscriptBox[\"#1\", \"3\"]]], \"-\", RowBox[List[\"515921363941\", \" \", \
SuperscriptBox[\"#1\", \"4\"]]], \"-\", RowBox[List[\"346241467449\", \" \", \
SuperscriptBox[\"#1\", \"5\"]]], \"-\", RowBox[List[\"741842005491\", \" \", \
SuperscriptBox[\"#1\", \"6\"]]], \"+\", RowBox[List[\"1636976061\", \" \", \
SuperscriptBox[\"#1\", \"7\"]]]]], \"&\"]], \",\", \"3\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 0.0026439061600645386`], \
\"NumericalApproximation\"], Root[Function[Plus[6912, Times[-5489280, \
Slot[1]], Times[1013811536, Power[Slot[1], 2]], Times[29197253896, \
Power[Slot[1], 3]], Times[-515921363941, Power[Slot[1], 4]], \
Times[-346241467449, Power[Slot[1], 5]], Times[-741842005491, Power[Slot[1], \
6]], Times[1636976061, Power[Slot[1], 7]]]], 3, 0]]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738839232048*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"d8a2e892-efc9-429c-9d55-954c3153fded"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 83, " ", "k=\!\(\*FractionBox[\"1\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738840897434*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"6944abd5-1e87-434b-bb44-3dd40233344f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 85, " ", "k=\!\(\*FractionBox[\"1\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738841420252*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"e897412f-e6cf-4d8d-8d84-f6fdefdc8eb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 86, " ", "k=\!\(\*FractionBox[\"1\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388416955013`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"6c9b094b-7f38-4b1c-9386-44e5498cd5a4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.4033194537 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"9\\\"}], \\\"+\\\", \
RowBox[{\\\"3\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"37\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"27\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"3\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 88, " ", 
   "k\[TildeTilde]0.4033194537 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"9\"}], \"+\", RowBox[{\"3\", \" \", \"x\"}], \"+\", RowBox[{\"37\", \
\" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"27\", \" \", \
SuperscriptBox[\"x\", \"3\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388423952637`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"9214113c-7036-4a40-a2ce-713dfe85ce7f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.06196012941 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1296\\\", \\\"-\\\", RowBox[{\\\"912168\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"136761097\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"3364465869\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"624581685\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"182284263\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 89, " ", 
   "k\[TildeTilde]0.06196012941 is the largest positive root of \
\!\(\*RowBox[{\"1296\", \"-\", RowBox[{\"912168\", \" \", \
SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"136761097\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"3364465869\", \" \", \
SuperscriptBox[\"x\", \"6\"]}], \"-\", RowBox[{\"624581685\", \" \", \
SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\"182284263\", \" \", \
SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388426408157`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"69772a3c-921f-47d2-afd3-dedf69f68aff"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "20"}], ",", 
     RowBox[{"i", "\[LessEqual]", "49"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.82473102594748*^9, 3.8247310308828993`*^9}, {
  3.824731071630206*^9, 3.824731072027051*^9}},
 CellLabel->
  "In[562]:=",ExpressionUUID->"a5fe1611-919f-4e6b-9510-7abc9e99e2da"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["i=", 20],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906504635277`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"c9789da0-2dbb-4960-850f-081b4f59838a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21"}],
  SequenceForm["i=", 21],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906505687323`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"8a669ebc-85c5-4213-b7cb-289bf7ef925a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22"}],
  SequenceForm["i=", 22],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290650681305*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"c7a1fd68-4d67-4c85-80b3-60c504a47b7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23"}],
  SequenceForm["i=", 23],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906513245792`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"3e96d0fa-99be-4731-92e3-6e9cfddf5751"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24"}],
  SequenceForm["i=", 24],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290651590197*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"c87a6b69-4ef0-4d75-ae20-9ac8d607c7e0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm["i=", 25],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290652161854*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"2eb5ab33-17ff-42ac-a565-9407cd9b3e11"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26"}],
  SequenceForm["i=", 26],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290652477869*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"fc8c080b-7b0f-4348-8ba4-6a907335b42f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27"}],
  SequenceForm["i=", 27],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.84729065330168*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"443ea404-242f-47e8-ad4b-525bfcbbf7d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28"}],
  SequenceForm["i=", 28],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290654068481*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"e4debd65-abf2-4ba2-b416-deb6f4accee6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29"}],
  SequenceForm["i=", 29],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290654666128*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"967f6aa9-c9c3-4bf5-a8c8-0e9fd421d528"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30"}],
  SequenceForm["i=", 30],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290655581648*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"1b8fe1fe-160e-4115-b144-4846ff03947d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*RowBox[{\\\"\[Infinity]\\\"}]\\)\"\>"}],
  SequenceForm["X", 30, " ", "k=\!\(\*RowBox[{\"\[Infinity]\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290655583819*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"65465627-1646-4457-9338-36b21bd6ec61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31"}],
  SequenceForm["i=", 31],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290655585779*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"c1ebd99c-4b30-471d-9e3b-a5c526816691"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32"}],
  SequenceForm["i=", 32],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290655933382*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"797bcf16-f401-4125-b39c-cfa131b51dc6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33"}],
  SequenceForm["i=", 33],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290662188676*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"cd4be33c-8d45-42b4-87bd-7ffb89d426aa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34"}],
  SequenceForm["i=", 34],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290662667749*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"3916c1b7-fa1e-46af-863f-e6980f99f190"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35"}],
  SequenceForm["i=", 35],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290663290139*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"d9a697b7-998a-4a7f-afd7-cc526ab886ee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36"}],
  SequenceForm["i=", 36],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290663374483*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"5d47e5c8-a8e4-45e8-9f7c-a46c346d6a15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37"}],
  SequenceForm["i=", 37],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906634384317`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"d1f31f2d-83c3-479b-967d-0da530a1e17b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38"}],
  SequenceForm["i=", 38],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906636517057`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"14405f2b-a0fc-4417-9e84-b214facfbf7e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39"}],
  SequenceForm["i=", 39],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290663974823*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"fece1a32-58e3-4aac-a1b8-a79ac369e0d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm["i=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290667627922*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"d8aefddd-a147-42c2-b5ca-7cd867018ca3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41"}],
  SequenceForm["i=", 41],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290667705645*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"49c3158c-0898-4d33-9153-7daa74094798"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42"}],
  SequenceForm["i=", 42],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290668406163*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"cb0a9e85-2ae7-4578-a04e-34e236b19ac5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43"}],
  SequenceForm["i=", 43],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906687627563`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"3ea60479-b887-44fd-aa98-37aef619dbc8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44"}],
  SequenceForm["i=", 44],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.8472906691771603`*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"92837f4d-aef9-4636-a1c4-0846573d1dfa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45"}],
  SequenceForm["i=", 45],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290669391637*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"6bfa8ef1-f1f3-4146-b601-bfacc0d43f90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46"}],
  SequenceForm["i=", 46],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290669601255*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"84926439-3592-40ec-9ba1-0a2b97b0a4d3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47"}],
  SequenceForm["i=", 47],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290669715481*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"3453b983-f819-4a6e-a2d6-d86e2e564b46"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48"}],
  SequenceForm["i=", 48],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290670575223*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"4c9a9528-820f-4cef-a145-13925edfdc9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49"}],
  SequenceForm["i=", 49],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247310320711317`*^9, 3.824731072956888*^9, 
  3.824738859003408*^9, 3.8471817792908297`*^9, 3.847290671366798*^9},
 CellLabel->
  "During evaluation of \
In[562]:=",ExpressionUUID->"3881f79f-aa13-48a7-8ca7-9f83bb87ec09"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X1", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "63"}], ",", 
     RowBox[{"i", "\[LessEqual]", "95"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.8247329044817543`*^9, 3.824732908993222*^9}},
 CellLabel->
  "In[413]:=",ExpressionUUID->"865cca2d-d9d1-4fbf-8cc2-c9ede2b78f42"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 63, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738816623781*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"0c6656de-d4f2-47dc-a9b8-2a98a54e51bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.09159894210 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1\\\", \\\"-\\\", RowBox[{\\\"269\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"17855\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"81\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 65, " ", 
   "k\[TildeTilde]0.09159894210 is the largest positive root of \
\!\(\*RowBox[{\"1\", \"-\", RowBox[{\"269\", \" \", SuperscriptBox[\"x\", \"2\
\"]}], \"+\", RowBox[{\"17855\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"81\", \" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738817172113*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"d788c4d6-3fb8-422c-a83e-09a36f4b1456"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 67, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738822760271*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"b377b391-a1dd-4441-9b13-a6ed3b88013f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 69, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738823595299*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"64fb2d22-38bc-4bd2-919b-2fcb588223b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 71, " ", "k=\!\(\*FractionBox[\"2\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738828659923*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"3cbef5b3-760e-46a6-bb13-ac0e2af2c7a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 72, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.82473882873282*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"cac511ad-d05d-4d2b-9f38-00732c1e5f20"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 75, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738829251423*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"5dea78d9-2909-4f9d-bdb9-2f63732a0caa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 76, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388368350983`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"b34e7bd6-7262-4838-a2b1-56d51c9d4a69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 78, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388371354322`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"66880331-2e24-4fb2-b983-1f893aa7be6d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.1452643676 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"64\\\", \\\"-\\\", \
RowBox[{\\\"19088\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"755500\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\
\\\"]}], \\\"+\\\", RowBox[{\\\"253125\\\", \\\" \\\", SuperscriptBox[\\\"x\\\
\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 79, " ", 
   "k\[TildeTilde]0.1452643676 is the largest positive root of \!\(\*RowBox[{\
\"64\", \"-\", RowBox[{\"19088\", \" \", SuperscriptBox[\"x\", \"2\"]}], \
\"+\", RowBox[{\"755500\", \" \", SuperscriptBox[\"x\", \"4\"]}], \"+\", \
RowBox[{\"253125\", \" \", SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388374320583`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"55729fa7-50d4-4658-87ea-b418f2ef2720"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
RowBox[{\\\"3\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 80, " ", 
   "k=\!\(\*FractionBox[\"2\", RowBox[{\"3\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738837531514*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"f9babf28-6c88-4e5a-88d1-793db3d2d779"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.03627449530 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"16\\\", \\\"-\\\", \
RowBox[{\\\"44616\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \
\\\"+\\\", RowBox[{\\\"22171297\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"1896049917\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"123705225\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", \
RowBox[{\\\"22143375\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 81, " ", 
   "k\[TildeTilde]0.03627449530 is the largest positive root of \
\!\(\*RowBox[{\"16\", \"-\", RowBox[{\"44616\", \" \", SuperscriptBox[\"x\", \
\"2\"]}], \"+\", RowBox[{\"22171297\", \" \", SuperscriptBox[\"x\", \"4\"]}], \
\"+\", RowBox[{\"1896049917\", \" \", SuperscriptBox[\"x\", \"6\"]}], \"-\", \
RowBox[{\"123705225\", \" \", SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\
\"22143375\", \" \", SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738837819728*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"bcb25988-2cdd-4bed-9374-ba57afd0750a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*SqrtBox[InterpretationBox[TemplateBox[List[\\\"Root\\\", \
TemplateBox[List[\\\"\\\\\\\"2.64\\\\\\\"\\\", \
DynamicBox[FEPrivate`FrontEndResource[\\\"FEExpressions\\\", \
\\\"NumericalApproximationElider\\\"]], \
\\\"\\\\\\\"\\\\[ThinSpace]\\\\[Times]\\\\[ThinSpace]\\\\\\\"\\\", \
TemplateBox[List[\\\"\\\\\\\"10\\\\\\\"\\\", \\\"\\\\\\\"-3\\\\\\\"\\\"], \
\\\"Superscript\\\", Rule[SyntaxForm, SuperscriptBox]]], \\\"RowDefault\\\"], \
TagBox[RowBox[List[\\\"Root\\\", \\\"[\\\", \
RowBox[List[RowBox[List[RowBox[List[\\\"6912\\\", \\\"-\\\", \
RowBox[List[\\\"5489280\\\", \\\" \\\", \\\"#1\\\"]], \\\"+\\\", RowBox[List[\
\\\"1013811536\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"2\\\"]]], \\\"+\
\\\", RowBox[List[\\\"29197253896\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \
\\\"3\\\"]]], \\\"-\\\", RowBox[List[\\\"515921363941\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"4\\\"]]], \\\"-\\\", \
RowBox[List[\\\"346241467449\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"5\
\\\"]]], \\\"-\\\", RowBox[List[\\\"741842005491\\\", \\\" \\\", \
SuperscriptBox[\\\"#1\\\", \\\"6\\\"]]], \\\"+\\\", \
RowBox[List[\\\"1636976061\\\", \\\" \\\", SuperscriptBox[\\\"#1\\\", \\\"7\\\
\"]]]]], \\\"&\\\"]], \\\",\\\", \\\"3\\\"]], \\\"]\\\"]], \
Function[Short[Slot[1], 7]]], 0.0026439061600645386`], \
\\\"NumericalApproximation\\\"], Root[Function[Plus[6912, Times[-5489280, \
Slot[1]], Times[1013811536, Power[Slot[1], 2]], Times[29197253896, \
Power[Slot[1], 3]], Times[-515921363941, Power[Slot[1], 4]], \
Times[-346241467449, Power[Slot[1], 5]], Times[-741842005491, Power[Slot[1], \
6]], Times[1636976061, Power[Slot[1], 7]]]], 3, 0]]]\\)\"\>"}],
  SequenceForm[
  "X", 82, " ", 
   "k=\!\(\*SqrtBox[InterpretationBox[TemplateBox[List[\"Root\", \
TemplateBox[List[\"\\\"2.64\\\"\", \
DynamicBox[FEPrivate`FrontEndResource[\"FEExpressions\", \
\"NumericalApproximationElider\"]], \"\\\"\\[ThinSpace]\\[Times]\\[ThinSpace]\
\\\"\", TemplateBox[List[\"\\\"10\\\"\", \"\\\"-3\\\"\"], \"Superscript\", \
Rule[SyntaxForm, SuperscriptBox]]], \"RowDefault\"], \
TagBox[RowBox[List[\"Root\", \"[\", \
RowBox[List[RowBox[List[RowBox[List[\"6912\", \"-\", RowBox[List[\"5489280\", \
\" \", \"#1\"]], \"+\", RowBox[List[\"1013811536\", \" \", \
SuperscriptBox[\"#1\", \"2\"]]], \"+\", RowBox[List[\"29197253896\", \" \", \
SuperscriptBox[\"#1\", \"3\"]]], \"-\", RowBox[List[\"515921363941\", \" \", \
SuperscriptBox[\"#1\", \"4\"]]], \"-\", RowBox[List[\"346241467449\", \" \", \
SuperscriptBox[\"#1\", \"5\"]]], \"-\", RowBox[List[\"741842005491\", \" \", \
SuperscriptBox[\"#1\", \"6\"]]], \"+\", RowBox[List[\"1636976061\", \" \", \
SuperscriptBox[\"#1\", \"7\"]]]]], \"&\"]], \",\", \"3\"]], \"]\"]], \
Function[Short[Slot[1], 7]]], 0.0026439061600645386`], \
\"NumericalApproximation\"], Root[Function[Plus[6912, Times[-5489280, \
Slot[1]], Times[1013811536, Power[Slot[1], 2]], Times[29197253896, \
Power[Slot[1], 3]], Times[-515921363941, Power[Slot[1], 4]], \
Times[-346241467449, Power[Slot[1], 5]], Times[-741842005491, Power[Slot[1], \
6]], Times[1636976061, Power[Slot[1], 7]]]], 3, 0]]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738839232048*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"3d143899-1c9c-4bc5-b7f1-0764d9e698b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 83, " ", "k=\!\(\*FractionBox[\"1\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738840897434*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"9446b0fa-de35-4cea-8d85-d0911ca28b0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 85, " ", "k=\!\(\*FractionBox[\"1\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.824738841420252*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"57585e89-fc9c-419a-9a5e-897f1c6d266d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"5\\\"]\\)\"\>"}],
  SequenceForm["X", 86, " ", "k=\!\(\*FractionBox[\"1\", \"5\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388416955013`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"1eb1bf7e-7004-4c61-a864-77923ecffada"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.4033194537 is the positive root \
of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"9\\\"}], \\\"+\\\", \
RowBox[{\\\"3\\\", \\\" \\\", \\\"x\\\"}], \\\"+\\\", RowBox[{\\\"37\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"27\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"3\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 88, " ", 
   "k\[TildeTilde]0.4033194537 is the positive root of \!\(\*RowBox[{RowBox[{\
\"-\", \"9\"}], \"+\", RowBox[{\"3\", \" \", \"x\"}], \"+\", RowBox[{\"37\", \
\" \", SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"27\", \" \", \
SuperscriptBox[\"x\", \"3\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388423952637`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"85349caa-23d5-47f0-b69a-105bd032bba8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.06196012941 is the largest \
positive root of \\!\\(\\*RowBox[{\\\"1296\\\", \\\"-\\\", RowBox[{\\\"912168\
\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"2\\\"]}], \\\"+\\\", \
RowBox[{\\\"136761097\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \
\\\"+\\\", RowBox[{\\\"3364465869\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"6\\\"]}], \\\"-\\\", RowBox[{\\\"624581685\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"+\\\", RowBox[{\\\"182284263\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 89, " ", 
   "k\[TildeTilde]0.06196012941 is the largest positive root of \
\!\(\*RowBox[{\"1296\", \"-\", RowBox[{\"912168\", \" \", \
SuperscriptBox[\"x\", \"2\"]}], \"+\", RowBox[{\"136761097\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"3364465869\", \" \", \
SuperscriptBox[\"x\", \"6\"]}], \"-\", RowBox[{\"624581685\", \" \", \
SuperscriptBox[\"x\", \"8\"]}], \"+\", RowBox[{\"182284263\", \" \", \
SuperscriptBox[\"x\", \"10\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824732909783894*^9, 3.8247388426408157`*^9},
 CellLabel->
  "During evaluation of \
In[413]:=",ExpressionUUID->"9eff09bc-a639-4cb6-8839-a72c1aaa790e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "80", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", 
       RowBox[{"(", 
        RowBox[{"3", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8472909979656754`*^9, 3.847291016822042*^9}, {
  3.847291079846027*^9, 3.847291096165371*^9}},
 CellLabel->
  "In[564]:=",ExpressionUUID->"04b0a64e-7d6c-4484-906e-d928baac7e23"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.847291097499353*^9},
 CellLabel->
  "Out[565]=",ExpressionUUID->"d5d1ad1c-473f-4789-baa3-558c6f174566"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "83", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "5"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847291118902274*^9, 3.847291125733691*^9}},
 CellLabel->
  "In[566]:=",ExpressionUUID->"e3781560-0c39-4a1b-b887-5f544333de37"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.847291127503553*^9},
 CellLabel->
  "Out[567]=",ExpressionUUID->"81ff0bad-902e-48fc-bebe-1826ebe33b98"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "85", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "5"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8472911372865047`*^9, 3.847291141045644*^9}},
 CellLabel->
  "In[568]:=",ExpressionUUID->"160fa5ac-96b6-4a14-a85e-b1eecaf03383"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.847291144395111*^9},
 CellLabel->
  "Out[569]=",ExpressionUUID->"0d2f5921-145e-442a-89e1-b22db5bd674d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "86", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "5"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.847291150446447*^9, 3.847291157951468*^9}},
 CellLabel->
  "In[572]:=",ExpressionUUID->"bb11acfd-d9f2-458a-83d6-dcb34b4af154"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8472911511574097`*^9, 3.8472911596775*^9}},
 CellLabel->
  "Out[573]=",ExpressionUUID->"53599fb9-4357-4ede-acac-cdc7fbe6c0e7"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distance of Center to X3 Compared With s", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730092064127*^9, 
  3.8247300941359177`*^9}},ExpressionUUID->"8792a679-ab2c-462b-b71e-\
4fafc4e0ef1c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "12"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824717128490209*^9, 3.8247171399751*^9}, 
   3.824731151605568*^9},
 CellLabel->
  "In[574]:=",ExpressionUUID->"dd34f919-01df-40f0-88db-0638a6a05735"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["i=", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497159758*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"2509dfff-dfd1-4bed-b140-080a11c9b6de"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["i=", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.84729149723398*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"ef500f7f-729e-40cc-8f41-f8abf1c67f90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3"}],
  SequenceForm["i=", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497314496*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"d75432bb-21ad-4cf8-89e0-e071236d9328"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["i=", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.84729149731654*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"237af875-ef9d-4413-ae37-cb700c705973"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["i=", 5],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.8472914973981028`*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"5a250256-678b-44d1-baeb-41fdb24d3465"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6"}],
  SequenceForm["i=", 6],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497400084*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"cf33966e-bba5-4f14-84eb-0cc5f7b147c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7"}],
  SequenceForm["i=", 7],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497588542*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"4cf608cd-ce0e-4231-ad72-9ad5d88e90cd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm["i=", 8],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497713636*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"a6b9ffe5-16c9-4726-be3f-cd3ec31f860b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9"}],
  SequenceForm["i=", 9],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497806321*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"c1598484-e5fc-4594-90d5-3f69150de5d9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10"}],
  SequenceForm["i=", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291497908374*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"2cbc2c26-40b1-42f0-8d0e-b3594f2cfc7b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11"}],
  SequenceForm["i=", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.84729149800793*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"cefea85d-87d1-4af6-8ba2-609c78bcfb66"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12"}],
  SequenceForm["i=", 12],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247171462410088`*^9, 3.824731154733274*^9, 
  3.824738900078121*^9, 3.847181779474428*^9, 3.847291498108692*^9},
 CellLabel->
  "During evaluation of \
In[574]:=",ExpressionUUID->"bb3f2673-390d-4c1f-8d09-0981b6308544"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "19"}], ",", 
     RowBox[{"i", "\[LessEqual]", "60"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824717181783786*^9, 3.824717227488736*^9}, {
   3.82473116799885*^9, 3.824731168339484*^9}, 3.824731219438973*^9},
 CellLabel->
  "In[575]:=",ExpressionUUID->"c8ca4482-4326-43d4-9368-e74843c9b4c2"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19"}],
  SequenceForm["i=", 19],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915067877293`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"ac9eeb59-0e72-4658-b55f-cde0ccf329ad"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["i=", 20],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915071662807`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"d1948b96-7a66-4f5f-8a12-478efed59192"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21"}],
  SequenceForm["i=", 21],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291507281341*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"423c1bce-c422-487d-b7fe-894fc1e1a3cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22"}],
  SequenceForm["i=", 22],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291507395163*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"acfe1d78-96a8-439b-bdf4-493e1d227970"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23"}],
  SequenceForm["i=", 23],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291507714793*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"29f11a9c-f74e-4a65-b059-23fa0c9aff8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24"}],
  SequenceForm["i=", 24],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.84729150789436*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"eee21a8e-cf8f-442b-80c4-d693409553da"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm["i=", 25],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291508264223*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c5ff6aa1-8c78-448c-80c9-0b734cd8b7cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26"}],
  SequenceForm["i=", 26],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291508524838*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"2f7f86f5-3fbc-4ae1-93d3-3d0665825acb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27"}],
  SequenceForm["i=", 27],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291508947853*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c74b791a-b5ff-43bf-a4a2-58351e823081"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28"}],
  SequenceForm["i=", 28],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291509492819*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"83fb6247-56f6-4374-bb41-0ee0ca019023"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29"}],
  SequenceForm["i=", 29],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915099100313`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"250daca5-ff23-440b-93b7-df8ecf877546"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30"}],
  SequenceForm["i=", 30],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291510563805*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"f0653d89-5e3a-4fb9-bd0f-aa1a68abc697"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31"}],
  SequenceForm["i=", 31],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291510565613*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c3f5fe06-b8d7-4c6b-9ecc-a09604b10cb1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32"}],
  SequenceForm["i=", 32],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291510862034*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"8016a923-e40f-456d-b24e-482b6781d060"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33"}],
  SequenceForm["i=", 33],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291511531715*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c8002b83-8ea7-4bc0-82d2-1b77748cc114"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34"}],
  SequenceForm["i=", 34],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291512007473*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"b6c0d010-9a1f-457e-afc8-0c39712db9c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35"}],
  SequenceForm["i=", 35],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915125485973`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"948fba2b-a292-4167-879e-fe2b983d1086"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36"}],
  SequenceForm["i=", 36],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291512638796*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"a0077872-369c-4e8f-bbd5-72cc34b58d4b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37"}],
  SequenceForm["i=", 37],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915127227983`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"845c85f2-0234-4c5f-84c8-b2d888043bef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38"}],
  SequenceForm["i=", 38],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291512920389*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"fe93913a-4f8b-4455-b0be-3185d964adab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39"}],
  SequenceForm["i=", 39],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291513248301*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"0d58ff1a-b643-455b-a33d-e197092ecd55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm["i=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915137512007`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"b7e2373e-7876-4384-9913-ae56df68975b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41"}],
  SequenceForm["i=", 41],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915138208313`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"b185495a-2561-4d89-a8a3-3b851d544b17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42"}],
  SequenceForm["i=", 42],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291514287331*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c55d1945-0ccb-46af-81a7-25d9ae1b33c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43"}],
  SequenceForm["i=", 43],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291514589787*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"0eebc374-43c0-46bf-9bb0-21ef642217fb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44"}],
  SequenceForm["i=", 44],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.84729151489891*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"7d56c6c5-903c-4c38-8d78-9a876eb469a0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45"}],
  SequenceForm["i=", 45],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291515136944*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"e920cd63-160e-42fb-9bb5-57de50793e83"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46"}],
  SequenceForm["i=", 46],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291515356678*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"5b050f4d-f4b1-4edb-b8a3-f3d28502eb3e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47"}],
  SequenceForm["i=", 47],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291515474227*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c4871c5b-7074-4460-b4c2-a1efaa1efa5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48"}],
  SequenceForm["i=", 48],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291516024222*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"f47ffc21-9a5f-4a5a-a96b-ed04540f4b80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49"}],
  SequenceForm["i=", 49],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915163989973`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"b9a4ac9a-b34b-41f5-b0cf-78aeb3195027"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50"}],
  SequenceForm["i=", 50],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291517125605*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"4308773c-3eda-4ff6-a801-b6418c643de7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51"}],
  SequenceForm["i=", 51],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.84729152001292*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"34f511d6-bbb0-43f6-b202-84afcef71078"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52"}],
  SequenceForm["i=", 52],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291520138961*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"97a0a58d-f616-4ec4-89b6-a1e3c7c3e543"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 52, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291520310089*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"523b0e03-1a91-4430-8f7b-ab0209bb3305"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53"}],
  SequenceForm["i=", 53],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291520311859*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"c467cf87-c8b2-4eb6-bf74-e6750017e3e1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54"}],
  SequenceForm["i=", 54],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291523400655*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"d9e80a0c-3d16-4540-9545-18a55e571ddc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55"}],
  SequenceForm["i=", 55],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291523934071*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"10e9db2b-db43-4315-97ef-d46e1dc60d9f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56"}],
  SequenceForm["i=", 56],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.8472915240174017`*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"4f406da6-5db0-4d48-8b89-4929ab82f5ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57"}],
  SequenceForm["i=", 57],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291524098741*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"4e99aaa6-9f05-40b7-82f4-f900dd3649db"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58"}],
  SequenceForm["i=", 58],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291524196941*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"7205936f-683b-4f62-b9fe-709a5534208f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59"}],
  SequenceForm["i=", 59],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.84729152444302*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"1501fa03-3b36-489b-976c-6d527ace5b09"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60"}],
  SequenceForm["i=", 60],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824717183850545*^9, 3.824717228410658*^9}, 
   3.824731169506797*^9, 3.82473122069858*^9, 3.824738900965785*^9, 
   3.847181779525999*^9, 3.847291524875574*^9},
 CellLabel->
  "During evaluation of \
In[575]:=",ExpressionUUID->"92750f87-a442-439b-864e-fb0933ddb66b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "52", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", "<", 
   RowBox[{"s", "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824735963331295*^9, 3.824735984411746*^9}},
 CellLabel->
  "In[576]:=",ExpressionUUID->"d4c04829-0a4c-4cd7-98da-25a1dd05d5fe"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247359809029818`*^9, 3.8247389166015387`*^9, 
  3.847181779645974*^9, 3.847291544137846*^9},
 CellLabel->
  "Out[577]=",ExpressionUUID->"393a63ac-3349-4fce-8d41-439388994d08"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], "\[LessEqual]", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "63"}], ",", 
     RowBox[{"i", "\[LessEqual]", "95"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", "<=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824717585928626*^9, 3.82471758620008*^9}, {
  3.824731197214625*^9, 3.824731197819366*^9}},
 CellLabel->
  "In[578]:=",ExpressionUUID->"6c134965-e434-44e6-b6ed-9be4c54d0462"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63"}],
  SequenceForm["i=", 63],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915491148443`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"9e4a35bd-45d6-4921-abb9-62c7daa645e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64"}],
  SequenceForm["i=", 64],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291549279943*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"bf10ff82-d75d-4d31-9a59-bc652382b762"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65"}],
  SequenceForm["i=", 65],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291549822917*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"c1ef5886-4ca9-4058-a560-a5043a10ba57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66"}],
  SequenceForm["i=", 66],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291549824712*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"72cb8b9c-ed8b-49a8-8d65-6b5ee9fe1da9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67"}],
  SequenceForm["i=", 67],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291552267088*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"75692d43-afe4-4546-b698-039ad8e2fd99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68"}],
  SequenceForm["i=", 68],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291553526146*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"fd445ff9-6226-4a2b-97ad-eb4b324efae1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69"}],
  SequenceForm["i=", 69],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291554019001*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"e2ecc04c-f5bc-40c4-8e46-480ca10ac811"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70"}],
  SequenceForm["i=", 70],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291554323153*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"09e964a4-9c26-4b68-9885-454c2b89ecbc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71"}],
  SequenceForm["i=", 71],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291559147307*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"73c739c8-65ca-4bc4-8519-900b49c280bb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72"}],
  SequenceForm["i=", 72],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291559475966*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"6620d897-71f0-4091-86e6-7355f8235673"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73"}],
  SequenceForm["i=", 73],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915596272984`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"62222a6f-b068-421b-bb3a-6b02fc2cff60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74"}],
  SequenceForm["i=", 74],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291560011664*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"768dd8d7-0e66-4e38-b843-a2a4ae2cd5ac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75"}],
  SequenceForm["i=", 75],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291560171774*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"5ec4f361-a9fc-460f-809f-19c615b35590"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76"}],
  SequenceForm["i=", 76],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915603392467`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"c6e858a5-b11d-4715-ab2f-ed010871aaec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77"}],
  SequenceForm["i=", 77],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291560752407*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"302755c7-f19f-4b38-805d-89d32440098b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78"}],
  SequenceForm["i=", 78],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291561249258*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"e9209f61-1117-43f4-8689-c35248f3286b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79"}],
  SequenceForm["i=", 79],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291561419682*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"5edaccd5-1cbb-464f-a92f-c30a53926f29"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80"}],
  SequenceForm["i=", 80],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.84729156148696*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"4374c432-ac2f-44da-8028-4d47a1cedf42"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81"}],
  SequenceForm["i=", 81],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915616292048`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"4e7b5230-165b-4671-9486-aa3670afcaf3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82"}],
  SequenceForm["i=", 82],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291561993106*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"bcb52ee0-e67b-4695-bcac-0089799955f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83"}],
  SequenceForm["i=", 83],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291564873551*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"6ef7510a-5ec7-474d-a8f5-a6e9e58c369f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84"}],
  SequenceForm["i=", 84],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915724483967`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"71d2b944-34af-431e-97ed-3e7c55555d05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85"}],
  SequenceForm["i=", 85],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915727449408`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"c6ab8fe0-2fe8-4088-ab4b-130f2a3e3279"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86"}],
  SequenceForm["i=", 86],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291573040579*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"ad773a55-8932-46a7-b943-ea9f86ac59d6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87"}],
  SequenceForm["i=", 87],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291573290494*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"5c40afd1-ad9d-489f-9e5f-01ce604493eb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88"}],
  SequenceForm["i=", 88],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915748176003`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"082acde6-9f66-4edb-a1fc-a3cd84992a4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89"}],
  SequenceForm["i=", 89],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291575094379*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"f3e1f1ff-40d6-4445-8632-df1171560c34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90"}],
  SequenceForm["i=", 90],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915754686537`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"a6feabfd-ab49-4612-be8e-8bd9702b5beb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91"}],
  SequenceForm["i=", 91],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291575934389*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"014471c1-0c60-438e-89e5-0db86780158b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92"}],
  SequenceForm["i=", 92],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915775856752`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"e25bbf56-e19a-4d10-ab0f-bb8ab6a2fbdb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93"}],
  SequenceForm["i=", 93],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291578007678*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"9da5f98f-c88b-4d7d-a048-9709c4d0ee93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94"}],
  SequenceForm["i=", 94],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.847291584882577*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"e3c1d966-0b67-4d63-b686-cce0675e4186"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95"}],
  SequenceForm["i=", 95],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717587170877*^9, 3.824731245496523*^9, 
  3.824738916612584*^9, 3.847181779684402*^9, 3.8472915875607433`*^9},
 CellLabel->
  "During evaluation of \
In[578]:=",ExpressionUUID->"98c78d7a-c90e-45af-97bb-ca329477301c"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "12"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824717373879921*^9, 3.824717399303905*^9}, 
   3.824731287917644*^9},
 CellLabel->
  "In[579]:=",ExpressionUUID->"785066e8-08c2-4503-b4a1-49317b640d99"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["i=", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291595860162*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"b97af507-33ba-44e9-aff5-6def76d24166"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["i=", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596022187*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"736f9069-de67-4b89-b1ed-04da973b282e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "3"}],
  SequenceForm["i=", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596025559*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"6eb83dc3-e719-4397-9d32-951bb6cfd74d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["i=", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596027182*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"4a160893-315a-46d4-a31e-97a2d65ec465"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["i=", 5],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596194334*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"1e133b1c-c8cc-49d9-9582-d8e91089e53e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6"}],
  SequenceForm["i=", 6],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596196302*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"c1626197-b360-4331-b292-79bd9086a20e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7"}],
  SequenceForm["i=", 7],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.84729159636276*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"337444c1-cf03-4a26-90ec-39e8ce3070c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm["i=", 8],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.8472915965498533`*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"420982cb-ed8e-40b5-885d-bd6c90db7f9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9"}],
  SequenceForm["i=", 9],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596551652*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"604073bb-af5a-468d-8ab4-6738459dfb5f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10"}],
  SequenceForm["i=", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.8472915967371473`*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"8ae5cefd-ffac-4953-8555-3c28b1091397"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11"}],
  SequenceForm["i=", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596739212*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"13c2149b-54c7-43d5-8b65-39dc9d5574f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12"}],
  SequenceForm["i=", 12],
  Editable->False]], "Print",
 CellChangeTimes->{3.82471740561896*^9, 3.824731290992433*^9, 
  3.824738953592169*^9, 3.847181779794808*^9, 3.847291596901042*^9},
 CellLabel->
  "During evaluation of \
In[579]:=",ExpressionUUID->"931534f2-84f3-4e65-9ab0-2d14c8b6e643"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "19"}], ",", 
     RowBox[{"i", "\[LessEqual]", "60"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{
  3.82471742592036*^9, {3.824731303079246*^9, 3.824731303427685*^9}},
 CellLabel->
  "In[422]:=",ExpressionUUID->"ac369f24-a2d0-4708-89e1-43b16bf0d385"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "19"}],
  SequenceForm["i=", 19],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738954517551*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"d7ef3900-0a69-4dbd-a730-fe55fd461af6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "20"}],
  SequenceForm["i=", 20],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389548495893`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"fab21e28-8837-4c73-ad13-81c9f7db9dc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "21"}],
  SequenceForm["i=", 21],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738954929894*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"d25e8e7f-7820-4570-9889-ecbae11f58f5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "22"}],
  SequenceForm["i=", 22],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389550090437`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"949899f1-9163-4cc9-96d7-8457ac6cbffe"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "23"}],
  SequenceForm["i=", 23],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738955285862*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"98319caa-6b99-4718-9906-330a6d32c459"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.8008300855 is the smallest \
positive root of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"49152\\\"}], \\\"+\\\
\", RowBox[{\\\"101712\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"2\\\"]}], \\\"-\\\", RowBox[{\\\"39560\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"4\\\"]}], \\\"+\\\", RowBox[{\\\"729\\\", \\\" \
\\\", SuperscriptBox[\\\"x\\\", \\\"6\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 23, " ", 
   "k\[TildeTilde]0.8008300855 is the smallest positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"49152\"}], \"+\", RowBox[{\"101712\", \" \", \
SuperscriptBox[\"x\", \"2\"]}], \"-\", RowBox[{\"39560\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"+\", RowBox[{\"729\", \" \", \
SuperscriptBox[\"x\", \"6\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738955616674*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"2b69211e-c745-4e2c-955e-f753d454b416"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "24"}],
  SequenceForm["i=", 24],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738955618545*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"3abb1489-b2dd-4a3a-a31b-ce2d7679b19a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "25"}],
  SequenceForm["i=", 25],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738955977947*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"c5d46259-a046-4da3-8eda-c1d55af83d57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "26"}],
  SequenceForm["i=", 26],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389561855803`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"b47c9279-60da-48fe-af09-a082cf0fa1ef"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "27"}],
  SequenceForm["i=", 27],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738956531363*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"89b389f1-e00d-4bd7-b0a1-36a1b9dbbcf2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "28"}],
  SequenceForm["i=", 28],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.82473895692212*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"7e154f0c-c8f2-48fb-aa4b-12dc16411187"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "29"}],
  SequenceForm["i=", 29],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738957264718*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"755e9072-33c6-42fe-9351-75834d9e0581"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "30"}],
  SequenceForm["i=", 30],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389577916393`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"896fc361-5995-42cb-b088-8ffc0c27674a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", \
"\<\"k=\\!\\(\\*RowBox[{\\\"\[Infinity]\\\"}]\\)\"\>"}],
  SequenceForm["X", 30, " ", "k=\!\(\*RowBox[{\"\[Infinity]\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738957793208*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"57840e1b-fb6d-407d-b5bb-d6f9e7409b39"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "31"}],
  SequenceForm["i=", 31],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738957794363*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"787f5503-0579-414c-ab97-8a785cded867"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "32"}],
  SequenceForm["i=", 32],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738958019329*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"d15f8094-9b71-47c3-ab65-a9a63293e867"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "33"}],
  SequenceForm["i=", 33],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738958540077*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"71f998c7-bc47-4794-8a27-6d7451e71652"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "34"}],
  SequenceForm["i=", 34],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389590028067`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"37d6b0c6-d730-4a9f-ac2b-205510c9783a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "35"}],
  SequenceForm["i=", 35],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389595082417`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"bc08955f-19f5-44fd-a8a3-40d6ffde7981"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "36"}],
  SequenceForm["i=", 36],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738959589655*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"e6f91200-dcd5-4621-b4f3-9df986322e45"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 36, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738959687416*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"25044c41-92be-434a-9e88-b3c175718aeb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "37"}],
  SequenceForm["i=", 37],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738959689116*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"24ffba37-aa1e-4964-8462-1b90d292cdcb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "38"}],
  SequenceForm["i=", 38],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738959866064*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"8843134f-bd92-46ce-9b0d-36694a735af8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "39"}],
  SequenceForm["i=", 39],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738960194331*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"3c835345-99dc-4ee7-8d2c-e7d63b4e4757"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "40"}],
  SequenceForm["i=", 40],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738960696875*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"b80c5690-012c-4c1b-96f4-c83e72c80bf8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "41"}],
  SequenceForm["i=", 41],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738960770789*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"f76cbb10-f30e-47dd-bd77-65132659d3b2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "42"}],
  SequenceForm["i=", 42],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738961173877*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"ad4602ec-d54b-45ac-b03a-5568bf7161d1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "43"}],
  SequenceForm["i=", 43],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738961516581*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"f3027705-11ca-4e18-b3ec-32b178b72dcd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "44"}],
  SequenceForm["i=", 44],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389618119164`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"199838d3-3ffc-4284-90bb-578919b50cac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 44, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738962105289*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"7488f821-e8a6-4db6-a14b-024a4a2a5419"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "45"}],
  SequenceForm["i=", 45],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738962107326*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"c462ed5a-443e-4efa-888b-8836ab0195cb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "46"}],
  SequenceForm["i=", 46],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738962321548*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"28e4b844-26c3-4c2a-a14a-ac4e048a738f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "47"}],
  SequenceForm["i=", 47],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738962442691*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"786a7bfd-fe91-4d90-8109-94301ae5c79c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "48"}],
  SequenceForm["i=", 48],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738962883559*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"1b402b75-7bbb-44dc-a193-f91c587cee6e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "49"}],
  SequenceForm["i=", 49],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738963306241*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"440f5c8a-5837-4ad4-b6d3-acd4d2c38d1b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "50"}],
  SequenceForm["i=", 50],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738963944702*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"b99e9204-f043-48b7-95fb-f780ea95807e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "51"}],
  SequenceForm["i=", 51],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738966923292*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"a06b4432-7204-414e-b69e-1cfa30852766"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "52"}],
  SequenceForm["i=", 52],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738967048678*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"29112a5c-7d1c-4db2-b18e-342ffcebc655"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "53"}],
  SequenceForm["i=", 53],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389671676273`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"5e332d6d-804d-4040-9d96-0fb3b38a072e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "54"}],
  SequenceForm["i=", 54],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389701736927`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"907d5cf0-e0bf-4d8e-8952-995d8fe08aaa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "55"}],
  SequenceForm["i=", 55],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738970659689*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"ab0474f0-d890-4648-be78-29ee8595c0df"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "56"}],
  SequenceForm["i=", 56],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738970733026*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"777824f4-9f17-4789-a65d-6b5016ca84bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "57"}],
  SequenceForm["i=", 57],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389708051863`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"8538dc33-e8ab-4c72-8387-090c8ce8a942"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "58"}],
  SequenceForm["i=", 58],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.8247389709041433`*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"2baf7efb-a0e5-434f-a604-da4203519061"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "59"}],
  SequenceForm["i=", 59],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738971138854*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"470c9cc3-0350-4f6e-8cca-40493fab63f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "60"}],
  SequenceForm["i=", 60],
  Editable->False]], "Print",
 CellChangeTimes->{3.824717427452854*^9, 3.824731304627769*^9, 
  3.824738971611638*^9},
 CellLabel->
  "During evaluation of \
In[422]:=",ExpressionUUID->"a909b55a-ace0-4e41-989f-696200e7836e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "36", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247360802755737`*^9, 3.82473613732447*^9}},
 CellLabel->
  "In[581]:=",ExpressionUUID->"628e6a6b-09f5-42db-8563-5eef739fdf6d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.824736112533649*^9, 3.824736138713979*^9}, 
   3.824738972220366*^9, 3.847181779981833*^9, 3.84729188056044*^9},
 CellLabel->
  "Out[582]=",ExpressionUUID->"841b9768-7a06-4729-92be-6bbb63a37b3c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "44", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824736153451844*^9, 3.8247361537793083`*^9}},
 CellLabel->
  "In[583]:=",ExpressionUUID->"3c492f28-7032-462c-a056-ea40bbd7b723"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824736159335127*^9, 3.824738972303953*^9, 
  3.8471817800354023`*^9, 3.847291883896029*^9},
 CellLabel->
  "Out[584]=",ExpressionUUID->"59602773-11c3-4d3f-8adf-df0a7d6cef3c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "largest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{"dist", "[", 
      RowBox[{"X3", ",", "Xi"}], "]"}]}], ">=", 
    RowBox[{"ks", "^", "2"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "63"}], ",", 
     RowBox[{"i", "\[LessEqual]", "95"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"sq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"sq", ">=", 
         RowBox[{"k", "*", 
          RowBox[{"s", "^", "2"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824717470176362*^9, 3.824717482641485*^9}, {
  3.824731331799209*^9, 3.8247313323157597`*^9}},
 CellLabel->
  "In[427]:=",ExpressionUUID->"142499a4-82a9-42f2-834a-97511d64b050"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "63"}],
  SequenceForm["i=", 63],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738972316881*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"a1889319-b99a-4ce7-a086-d9f0042a0a15"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "64"}],
  SequenceForm["i=", 64],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738972463009*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"7df83f3e-dbfb-4430-bc3d-04d61390d8b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "65"}],
  SequenceForm["i=", 65],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738972860392*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"ed2e34d0-e92d-4dbd-8346-aff563875558"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "66"}],
  SequenceForm["i=", 66],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738972928941*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"171587bd-140a-4d34-a41b-9246be1d5b27"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "67"}],
  SequenceForm["i=", 67],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738975763206*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"5bc2b24b-e580-46fd-a351-5a745e4ecb68"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "68"}],
  SequenceForm["i=", 68],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738976777091*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"96c399a7-9615-4a1c-8078-a2f53c2f80c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "69"}],
  SequenceForm["i=", 69],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738977307322*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"75dd7305-681a-43c4-a9e0-cd3c33f2f53a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "70"}],
  SequenceForm["i=", 70],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389775924664`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"d90e813c-d374-40e3-9f35-70396deed566"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "71"}],
  SequenceForm["i=", 71],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738982427622*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"024ae7f0-227d-4e1e-8847-16b4430092b0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "72"}],
  SequenceForm["i=", 72],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738982763406*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"dd6e5d7d-b3f0-44da-9ed8-7d87f38f4e99"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "73"}],
  SequenceForm["i=", 73],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738982864781*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"468cd588-1158-4449-9a14-ec59c58b3cfd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "74"}],
  SequenceForm["i=", 74],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389831996717`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"db5ae223-aaed-4b05-bc1b-7710e571f544"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"2\\\", \
RowBox[{\\\"3\\\", \\\" \\\", SqrtBox[\\\"3\\\"]}]]\\)\"\>"}],
  SequenceForm[
  "X", 74, " ", 
   "k=\!\(\*FractionBox[\"2\", RowBox[{\"3\", \" \", SqrtBox[\"3\"]}]]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389832662287`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"b4625f17-f551-40bc-8704-f6f64dc97c92"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "75"}],
  SequenceForm["i=", 75],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389832679234`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"51e542df-f042-442f-a495-75478b684ead"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "76"}],
  SequenceForm["i=", 76],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738983462661*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"cb2ff916-f90a-42bb-bc30-689696d8e1b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "77"}],
  SequenceForm["i=", 77],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738983898584*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"02d18451-71a2-4501-b1a1-3d1e124a197f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "78"}],
  SequenceForm["i=", 78],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738984211882*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"ddfc4bb3-e829-4374-b827-9ea7281b1e61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "79"}],
  SequenceForm["i=", 79],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738984358976*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"625f73f4-6829-4d7c-a346-dba4c1029039"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "80"}],
  SequenceForm["i=", 80],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738984527554*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"8fbd8e8b-87ad-4554-bcf1-b4a0f9715396"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "81"}],
  SequenceForm["i=", 81],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389846728363`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"191d6acd-426e-4eaa-84b8-e1cb40383c2b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "82"}],
  SequenceForm["i=", 82],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389850247507`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"69a3d250-1c94-4d3b-beba-dce7bb079c0f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "83"}],
  SequenceForm["i=", 83],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389877403393`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"6bbce59c-d7e6-46aa-a156-ecb540152fcf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "84"}],
  SequenceForm["i=", 84],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389954016933`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"4eae3fc3-3983-4b59-8551-d0f9f9e538bd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "85"}],
  SequenceForm["i=", 85],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738995685059*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"a06fcd5c-441d-41f2-a38c-1b4e3fc2229b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "86"}],
  SequenceForm["i=", 86],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738995960204*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"f7754493-0bad-4457-9ed4-daad96a1357b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "87"}],
  SequenceForm["i=", 87],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738996231476*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"3b10efba-eaee-4000-9b01-c1d200b96584"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "88"}],
  SequenceForm["i=", 88],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738997763155*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"bb323268-098f-4171-97b1-ead8ae56866b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "89"}],
  SequenceForm["i=", 89],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.8247389980186567`*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"d004ce13-9c5f-455c-bf0a-a909e0242848"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "90"}],
  SequenceForm["i=", 90],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738998399885*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"8cd509cb-4533-4165-98b9-f6eea73d35e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "91"}],
  SequenceForm["i=", 91],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824738998845591*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"d7d3e55c-5a8f-44fb-9fde-d6a709dbc7d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "92"}],
  SequenceForm["i=", 92],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824739000462283*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"fc8a6494-3460-4247-9323-acde12df7f69"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "93"}],
  SequenceForm["i=", 93],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824739000850093*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"4d4e54fe-bfe8-4942-8911-cdd53a31377d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "94"}],
  SequenceForm["i=", 94],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824739007663208*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"6b1fd183-1ae3-43a7-9869-8d57d7bf2782"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k\[TildeTilde]0.3424270904 is the smallest \
positive root of \\!\\(\\*RowBox[{RowBox[{\\\"-\\\", \\\"50176\\\"}], \\\"+\\\
\", RowBox[{\\\"536064\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \
\\\"2\\\"]}], \\\"-\\\", RowBox[{\\\"451008\\\", \\\" \\\", SuperscriptBox[\\\
\"x\\\", \\\"4\\\"]}], \\\"-\\\", RowBox[{\\\"4773104\\\", \\\" \\\", \
SuperscriptBox[\\\"x\\\", \\\"6\\\"]}], \\\"+\\\", RowBox[{\\\"6782244\\\", \
\\\" \\\", SuperscriptBox[\\\"x\\\", \\\"8\\\"]}], \\\"-\\\", \
RowBox[{\\\"3030537\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"10\\\"]}], \
\\\"+\\\", RowBox[{\\\"54675\\\", \\\" \\\", SuperscriptBox[\\\"x\\\", \\\"12\
\\\"]}]}]\\)\"\>"}],
  SequenceForm[
  "X", 94, " ", 
   "k\[TildeTilde]0.3424270904 is the smallest positive root of \
\!\(\*RowBox[{RowBox[{\"-\", \"50176\"}], \"+\", RowBox[{\"536064\", \" \", \
SuperscriptBox[\"x\", \"2\"]}], \"-\", RowBox[{\"451008\", \" \", \
SuperscriptBox[\"x\", \"4\"]}], \"-\", RowBox[{\"4773104\", \" \", \
SuperscriptBox[\"x\", \"6\"]}], \"+\", RowBox[{\"6782244\", \" \", \
SuperscriptBox[\"x\", \"8\"]}], \"-\", RowBox[{\"3030537\", \" \", \
SuperscriptBox[\"x\", \"10\"]}], \"+\", RowBox[{\"54675\", \" \", \
SuperscriptBox[\"x\", \"12\"]}]}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824739010252399*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"0a21801d-2c11-48a9-9eb7-816cf6ff9650"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "95"}],
  SequenceForm["i=", 95],
  Editable->False]], "Print",
 CellChangeTimes->{{3.82471747550622*^9, 3.82471748317293*^9}, 
   3.8247313331271687`*^9, 3.824739010254518*^9},
 CellLabel->
  "During evaluation of \
In[427]:=",ExpressionUUID->"da6bd803-eadb-47f2-9131-8e31a15725d5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "74", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{"sq", ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"2", "/", 
       RowBox[{"(", 
        RowBox[{"3", 
         RowBox[{"Sqrt", "[", "3", "]"}]}], ")"}]}], ")"}], "^", "2"}], "*", 
    RowBox[{"s", "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824736172163859*^9, 3.8247361858517227`*^9}},
 CellLabel->
  "In[586]:=",ExpressionUUID->"f41dbdd4-aa49-4901-958c-db42caf6da1e"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247361886227427`*^9, 3.824739013114326*^9, 
  3.8471817801651573`*^9, 3.8472919348044167`*^9},
 CellLabel->
  "Out[587]=",ExpressionUUID->"51e46a25-5f7b-4300-9867-c5fb40734f09"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Distances of Center to X1 and X3 Compared With r/R", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730183592462*^9, 3.824730194584065*^9}},
 FormatType->
  "TextForm",ExpressionUUID->"46e3e464-ea0f-4547-8f4a-3b2ebcd51f37"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{
      RowBox[{"dist", "[", 
       RowBox[{"X1", ",", "Xi"}], "]"}], "/", 
      RowBox[{"dist", "[", 
       RowBox[{"X2", ",", "Xi"}], "]"}]}]}], "\[LessEqual]", 
    RowBox[{"k", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "12"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq1", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"sq3", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "3"}], ",", 
        RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{
         RowBox[{"sq1", "/", "sq3"}], "<=", 
         RowBox[{"k", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"minK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "minK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824715301448888*^9, 3.824715335834098*^9}, {
  3.824715374477839*^9, 3.824715483848909*^9}, {3.8247155294268217`*^9, 
  3.824715542233533*^9}, {3.8247156189057903`*^9, 3.824715641025522*^9}, {
  3.824731394989542*^9, 3.824731395460005*^9}},
 CellLabel->
  "In[588]:=",ExpressionUUID->"94504deb-d0ce-4f75-b600-581f969d347b"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 7, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.847291965820924*^9},
 CellLabel->
  "During evaluation of \
In[588]:=",ExpressionUUID->"870efab5-79d0-47eb-bd17-ee74e0efd7e9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 12, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8472919685040817`*^9},
 CellLabel->
  "During evaluation of \
In[588]:=",ExpressionUUID->"2ef11bc6-0763-4ec0-8a4e-b8549283d8e8"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "7", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "7", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247362625190277`*^9, 3.824736273740054*^9}, {
  3.8247363136124983`*^9, 3.824736326670362*^9}, {3.824736361829178*^9, 
  3.8247363729014273`*^9}},
 CellLabel->
  "In[589]:=",ExpressionUUID->"b79ba318-5cab-40b4-b867-9fce2b6a5b5d"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.8247363274994507`*^9, {3.82473636900965*^9, 3.8247363740677423`*^9}, 
   3.8247390172806997`*^9, 3.847181780267548*^9, 3.847291999338213*^9},
 CellLabel->
  "Out[591]=",ExpressionUUID->"0225bc69-7d27-4d2f-9e76-ec5957c51cea"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "12", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "12", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], "<", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824736381596258*^9, 3.824736384211876*^9}},
 CellLabel->
  "In[592]:=",ExpressionUUID->"953cb5fb-8974-4cfb-81da-21cdbb54bb51"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824736388821932*^9, 3.824739018337266*^9, 
  3.847181780279374*^9, 3.847292015663518*^9},
 CellLabel->
  "Out[594]=",ExpressionUUID->"e1f71a0f-0823-4f08-958e-26a9fdcea13c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Find", " ", "the", " ", "smallest", " ", "value", " ", "of", " ", "k", 
     " ", "for", " ", "which", " ", 
     RowBox[{
      RowBox[{"dist", "[", 
       RowBox[{"X1", ",", "Xi"}], "]"}], "/", 
      RowBox[{"dist", "[", 
       RowBox[{"X2", ",", "Xi"}], "]"}]}]}], ">=", 
    RowBox[{"k", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "12"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"sq1", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"sq3", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"i", "\[Equal]", "3"}], ",", 
        RowBox[{"Continue", "[", "]"}]}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<i=\>\"", ",", "i"}], "]"}], ";", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"condition", ",", "minK", ",", "maxK"}], "}"}], "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{
         RowBox[{"sq1", "/", "sq3"}], ">=", 
         RowBox[{"k", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"maxK", ">", "0"}], ",", 
        RowBox[{"Print", "[", 
         RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\< \>\"", ",", 
          RowBox[{"displayRealNumber", "[", 
           RowBox[{"Sqrt", "[", "maxK", "]"}], "]"}]}], "]"}]}], "]"}], 
      ";"}]}], "\[IndentingNewLine]", "]"}], ";"}]}]], "Input",
 CellChangeTimes->{{3.824716792470542*^9, 3.824716821878327*^9}, 
   3.824731413838378*^9},
 CellLabel->
  "In[595]:=",ExpressionUUID->"792d56bf-2095-4ce3-a788-14c798529a25"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "1"}],
  SequenceForm["i=", 1],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.8472920332350903`*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"b74ce206-1669-4785-9197-08f31d72cae2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "2"}],
  SequenceForm["i=", 2],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292033326268*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"6b914b00-4c7f-40e7-b528-ca1cc990c2f8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 2, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292033492199*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"07c2a4ce-1936-4541-b9a6-598c6ac49c3f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "4"}],
  SequenceForm["i=", 4],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.8472920334941273`*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"8e4432f4-9513-40b9-96ef-f03661debade"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"8\\\", \
\\\"9\\\"]\\)\"\>"}],
  SequenceForm["X", 4, " ", "k=\!\(\*FractionBox[\"8\", \"9\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292033972913*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"d3017a91-7292-4675-b8b2-d5d76bd3c8e8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "5"}],
  SequenceForm["i=", 5],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292033974769*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"9cff6c62-7160-4d3c-bd6a-b86dfb65ace3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "6"}],
  SequenceForm["i=", 6],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.84729203430203*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"f9f6dacd-bb4f-498b-aead-04f8bbae191f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"3\\\"]\\)\"\>"}],
  SequenceForm["X", 6, " ", "k=\!\(\*FractionBox[\"1\", \"3\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292034587317*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"87e2791f-d9b3-40d4-a48e-73e8cc2b80c7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "7"}],
  SequenceForm["i=", 7],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292034589478*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"22dea9e1-f809-4742-8809-a7cea8ea9377"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"8\\\", \\\"17\\\"]\\)\
\"\>"}],
  SequenceForm["X", 7, " ", "k=\!\(\*FractionBox[\"8\", \"17\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292035266777*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"59783104-fbc1-401e-9f3a-6bab1d98e793"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "8"}],
  SequenceForm["i=", 8],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292035269088*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"3b8d21f7-f678-4d8c-a50e-558dba52ecbc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 8, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.84729203556317*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"94f023d4-6cfb-45fd-949a-5a9d4072f70f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "9"}],
  SequenceForm["i=", 9],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292035565055*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"46107793-b214-4248-963d-f14edc5b1594"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 9, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292035910118*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"8396cce3-f567-4dd3-82dd-badb11274219"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "10"}],
  SequenceForm["i=", 10],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.84729203591195*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"425bc130-921b-42be-8541-ecc12b57dbff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*FractionBox[\\\"1\\\", \
\\\"2\\\"]\\)\"\>"}],
  SequenceForm["X", 10, " ", "k=\!\(\*FractionBox[\"1\", \"2\"]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292036277986*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"8d4d6ef7-889d-424e-b63a-d51d6d9992d8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "11"}],
  SequenceForm["i=", 11],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.8472920362798843`*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"a9820ff8-f16f-4557-84a2-42d093986eb9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" \"\>", 
   "\[InvisibleSpace]", "\<\"k=\\!\\(\\*RowBox[{\\\"1\\\"}]\\)\"\>"}],
  SequenceForm["X", 11, " ", "k=\!\(\*RowBox[{\"1\"}]\)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.8472920366921663`*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"cbf43e8c-0a6b-48cc-a3b1-35a25cd8f63b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"i=\"\>", "\[InvisibleSpace]", "12"}],
  SequenceForm["i=", 12],
  Editable->False]], "Print",
 CellChangeTimes->{3.8247168258465652`*^9, 3.824731414648424*^9, 
  3.824733208666401*^9, 3.824739018428499*^9, 3.847181780334025*^9, 
  3.847292036694035*^9},
 CellLabel->
  "During evaluation of \
In[595]:=",ExpressionUUID->"70c50341-d99e-469f-b536-9cae0f298157"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247364491720753`*^9, 3.824736462051804*^9}},
 CellLabel->
  "In[596]:=",ExpressionUUID->"1bf487f5-46c8-42c8-b1c8-d94ba5fe86cc"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247364628163347`*^9, 3.824739022702239*^9, 
  3.847181780376607*^9, 3.8472920900663157`*^9},
 CellLabel->
  "Out[598]=",ExpressionUUID->"cdf59c6e-a678-4f0f-803c-20313678ceaf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "4", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "/", "9"}], ")"}], "^", "2"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247364761484213`*^9, 3.8247364877078876`*^9}},
 CellLabel->
  "In[599]:=",ExpressionUUID->"b6ba3cec-ec1f-44f1-9884-9d9a2ad4521f"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824736488663459*^9, 3.824739022991715*^9, 
  3.847181780450233*^9, 3.84729209333702*^9},
 CellLabel->
  "Out[601]=",ExpressionUUID->"578b3758-0b6c-4984-aaf2-9f283b829b10"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "6", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "6", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "3"}], ")"}], "^", "2"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247365027084208`*^9, 3.824736504340047*^9}},
 CellLabel->
  "In[602]:=",ExpressionUUID->"a29b6ca6-9ef3-4b57-aa53-a10fd469ed80"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.82473650904678*^9, 3.824739023109661*^9, 
  3.847181780479062*^9, 3.847292098344298*^9},
 CellLabel->
  "Out[604]=",ExpressionUUID->"a932a418-9a3d-4052-872f-8ae3fb5e7e85"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "7", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "7", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"8", "/", "17"}], ")"}], "^", "2"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247365188683357`*^9, 3.824736540493065*^9}},
 CellLabel->
  "In[605]:=",ExpressionUUID->"b5323e2d-beee-4a15-8995-bf4786c95039"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.8247365284681683`*^9, 3.824736541266185*^9}, 
   3.824739023461116*^9, 3.847181780537122*^9, 3.847292102843235*^9},
 CellLabel->
  "Out[607]=",ExpressionUUID->"6fc41a16-e811-4a85-a4ac-507da8734057"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "8", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "8", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824736552772566*^9, 3.824736558772357*^9}},
 CellLabel->
  "In[608]:=",ExpressionUUID->"c00d42da-d15a-4edf-9930-b4a650fb3e43"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.8247365597785797`*^9, 3.824739023573327*^9, 
  3.8471817805576344`*^9, 3.8472921064475327`*^9},
 CellLabel->
  "Out[610]=",ExpressionUUID->"637360de-ca00-4ec7-ad7b-58a2d062b3b9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "9", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "9", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.824736568132636*^9, 3.8247365755961723`*^9}},
 CellLabel->
  "In[611]:=",ExpressionUUID->"41298c61-8b88-4ecb-946c-85ca34e91b26"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824736576532497*^9, 3.8247390238014097`*^9, 
  3.847181780614441*^9, 3.8472921099297733`*^9},
 CellLabel->
  "Out[613]=",ExpressionUUID->"6a866c7a-3ed6-4bea-b66b-2480573e3a72"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "10", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "10", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", "/", "2"}], ")"}], "^", "2"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247365840364943`*^9, 3.8247365956440573`*^9}},
 CellLabel->
  "In[614]:=",ExpressionUUID->"f74896fc-a801-453b-af29-60653ac5c13a"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{3.824736597465445*^9, 3.824739023931185*^9, 
  3.8471817806336937`*^9, 3.8472921136746273`*^9},
 CellLabel->
  "Out[616]=",ExpressionUUID->"dc7b26ce-4ae9-4bee-8101-647f76efe3e7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"sq1", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "1", "]"}], ",", 
     RowBox[{"x", "[", "11", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"sq3", "=", 
   RowBox[{"squaredDistance", "[", 
    RowBox[{
     RowBox[{"x", "[", "3", "]"}], ",", 
     RowBox[{"x", "[", "11", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
  RowBox[{
   RowBox[{"sq1", "/", "sq3"}], ">", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"r", "/", "R"}], ")"}], "^", "2"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.8247366536287727`*^9, 3.824736666980439*^9}},
 CellLabel->
  "In[617]:=",ExpressionUUID->"a3585368-5cc6-4a0b-9c63-13cc260f4235"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.82473666074478*^9, 3.824736667718514*^9}, 
   3.824739024260255*^9, 3.84718178069051*^9, 3.8472921170731564`*^9},
 CellLabel->
  "Out[619]=",ExpressionUUID->"408b9462-5056-47c6-b0d8-46f9a653ee7d"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Centers Inside/Outside Triangle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730183592462*^9, 3.824730194584065*^9}, {
  3.824815791230557*^9, 
  3.824815814654079*^9}},ExpressionUUID->"593d750f-c507-4838-bbcd-\
2b631137d73a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "inside", " ", "the", " ", "triangle"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"insideTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"u", "*", "v"}], "\[LessEqual]", "0"}], "||", 
             RowBox[{
              RowBox[{"v", "*", "w"}], "\[LessEqual]", "0"}], "||", 
             RowBox[{
              RowBox[{"w", "*", "u"}], "\[LessEqual]", "0"}]}], ")"}], "&&", 
           "triang"}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"insideTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Inside: \>\"", ",", "insideTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824818792568433*^9, 3.824818813080359*^9}, {
  3.82481925065005*^9, 3.82481927608951*^9}},
 CellLabel->
  "In[170]:=",ExpressionUUID->"43d9e8ee-d1ff-42fa-9b47-0943c63a9aac"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Inside: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", ",", 
     "12", ",", "21", ",", "31", ",", "32", ",", "37", ",", "38", ",", "39", 
     ",", "41", ",", "42", ",", "45", ",", "55", ",", "56", ",", "57", ",", 
     "58", ",", "60", ",", "65", ",", "75", ",", "76", ",", "81", ",", "82", 
     ",", "83", ",", "85", ",", "86", ",", "89"}], "}"}]}],
  SequenceForm[
  "Inside: ", {1, 2, 6, 7, 8, 9, 10, 12, 21, 31, 32, 37, 38, 39, 41, 42, 45, 
   55, 56, 57, 58, 60, 65, 75, 76, 81, 82, 83, 85, 86, 89}],
  Editable->False]], "Print",
 CellChangeTimes->{3.8248192844266043`*^9, 3.847181782207224*^9},
 CellLabel->
  "During evaluation of \
In[170]:=",ExpressionUUID->"5f6c0cee-4bd0-41be-ac0b-5180192cbe6d"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "outside", " ", "the", " ", "triangle"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"outsideTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"u", ">", "0"}], "&&", 
               RowBox[{"v", ">", "0"}], "&&", 
               RowBox[{"w", ">", "0"}]}], ")"}], "||", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"u", "<", "0"}], "&&", 
               RowBox[{"v", "<", "0"}], "&&", 
               RowBox[{"w", "<", "0"}]}], ")"}]}], ")"}], "&&", "triang"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"outsideTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Outside: \>\"", ",", "outsideTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824816521953588*^9, 3.824816590617114*^9}, {
   3.824816664139619*^9, 3.824816665921824*^9}, 3.8248168107305593`*^9, {
   3.82481709556339*^9, 3.824817149186946*^9}, {3.824817782822356*^9, 
   3.824817792144402*^9}},
 CellLabel->
  "In[173]:=",ExpressionUUID->"86733931-ef21-4c66-a4f0-85beccfda822"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Outside: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "14", ",", "16", ",", "23", ",", "30", ",", "36", ",", "44", ",", "67", 
     ",", "74", ",", "80", ",", "88", ",", "98", ",", "99", ",", "100"}], 
    "}"}]}],
  SequenceForm[
  "Outside: ", {14, 16, 23, 30, 36, 44, 67, 74, 80, 88, 98, 99, 100}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824816572502006*^9, 3.82481659152953*^9}, 
   3.824816666940893*^9, {3.824817127394652*^9, 3.824817154257947*^9}, 
   3.824817797846272*^9, 3.8471817860127687`*^9},
 CellLabel->
  "During evaluation of \
In[173]:=",ExpressionUUID->"3af84088-3b29-4116-ac06-c6c7c39c1b99"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", "on", 
    " ", "the", " ", "perimeter", " ", "of", " ", "the", " ", "triangle"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"onList", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"u", "\[NotEqual]", "0"}], "&&", 
           RowBox[{"v", "\[NotEqual]", "0"}], "&&", 
           RowBox[{"w", "\[NotEqual]", "0"}], "&&", "triang"}], ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"onList", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<On: \>\"", ",", "onList"}], "]"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824817335499839*^9, 3.8248173549312983`*^9}, {
  3.824817386196165*^9, 3.824817423419971*^9}},
 CellLabel->
  "In[176]:=",ExpressionUUID->"4cd249ab-d3af-46e8-b4af-f1deaeba163d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"On: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", "}"}]}],
  SequenceForm["On: ", {}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.824817410448738*^9, 3.824817425657366*^9}, 
   3.847181787110611*^9},
 CellLabel->
  "During evaluation of \
In[176]:=",ExpressionUUID->"baeacbf1-606f-4409-8b5a-8bb102f63a83"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"outsideIncircle", "\[Intersection]", "insideTriangle"}]], "Input",
 CellChangeTimes->{{3.8248176966803503`*^9, 3.824817756228251*^9}, {
  3.82481780256608*^9, 3.8248178042845163`*^9}},
 CellLabel->
  "In[179]:=",ExpressionUUID->"5ee949e1-5657-449a-abdd-b166d330de4c"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{{3.8248177037319736`*^9, 3.824817719525579*^9}, 
   3.824817757690529*^9, 3.824817805174498*^9, 3.8248194456903353`*^9, 
   3.8471817871727448`*^9},
 CellLabel->
  "Out[179]=",ExpressionUUID->"6064c98c-97f9-48c4-86bb-75b1ee5080cf"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"insideCircumcircle", "\[Intersection]", 
  "outsideTriangle"}]], "Input",
 CellChangeTimes->{{3.824817821061207*^9, 3.824817833508871*^9}},
 CellLabel->
  "In[180]:=",ExpressionUUID->"0fb52fdd-929d-4caa-b2bf-d858b0644d2f"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.824817834543316*^9, 3.847181787180808*^9},
 CellLabel->
  "Out[180]=",ExpressionUUID->"6a28c3b5-3749-46f5-8e5c-7a06dd215c68"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "centers", " ", "that", " ", "must", " ", "lie", " ", 
    "inside", " ", "or", " ", "on", " ", "the", " ", "triangle"}], " ", 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"insideOrOnTriangle", "=", 
     RowBox[{"{", "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"i", "=", "1"}], ",", 
      RowBox[{"i", "\[LessEqual]", "100"}], ",", 
      RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
        RowBox[{
         RowBox[{
          RowBox[{"x", "[", "i", "]"}], "/.", 
          RowBox[{"S", "\[Rule]", 
           RowBox[{"2", 
            RowBox[{"Sqrt", "[", 
             RowBox[{"s", 
              RowBox[{"(", 
               RowBox[{"s", "-", "a"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "b"}], ")"}], 
              RowBox[{"(", 
               RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
         RowBox[{"s", "\[Rule]", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"triang", "=", 
        RowBox[{
         RowBox[{"a", ">", "0"}], "&&", 
         RowBox[{"b", ">", "0"}], "&&", 
         RowBox[{"c", ">", "0"}], "&&", 
         RowBox[{
          RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
         RowBox[{
          RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
         RowBox[{
          RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
       RowBox[{"inst", "=", 
        RowBox[{"FindInstance", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"u", "*", "v"}], "<", "0"}], "||", 
             RowBox[{
              RowBox[{"v", "*", "w"}], "<", "0"}], "||", 
             RowBox[{
              RowBox[{"w", "*", "u"}], "<", "0"}]}], ")"}], "&&", "triang"}], 
          ",", 
          RowBox[{"{", 
           RowBox[{"a", ",", "b", ",", "c"}], "}"}]}], "]"}]}], ";", 
       "\[IndentingNewLine]", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{"inst", "\[Equal]", 
          RowBox[{"{", "}"}]}], ",", 
         RowBox[{"AppendTo", "[", 
          RowBox[{"insideOrOnTriangle", ",", "i"}], "]"}]}], "]"}], ";"}]}], 
     "\[IndentingNewLine]", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<Inside or on: \>\"", ",", "insideOrOnTriangle"}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.824817927221381*^9, 3.824817964461843*^9}, {
  3.824818125279163*^9, 3.824818125790278*^9}, {3.824818159534236*^9, 
  3.824818183206259*^9}, {3.82481830376898*^9, 3.824818323440798*^9}, {
  3.8248183766004057`*^9, 3.824818378430915*^9}, {3.824819465106736*^9, 
  3.824819514146171*^9}},
 CellLabel->
  "In[181]:=",ExpressionUUID->"4e92d83b-8f50-434b-bbcf-54003eae5f18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Inside or on: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
    "1", ",", "2", ",", "6", ",", "7", ",", "8", ",", "9", ",", "10", ",", 
     "11", ",", "12", ",", "21", ",", "31", ",", "32", ",", "37", ",", "38", 
     ",", "39", ",", "41", ",", "42", ",", "45", ",", "55", ",", "56", ",", 
     "57", ",", "58", ",", "59", ",", "60", ",", "65", ",", "75", ",", "76", 
     ",", "81", ",", "82", ",", "83", ",", "85", ",", "86", ",", "89"}], 
    "}"}]}],
  SequenceForm[
  "Inside or on: ", {1, 2, 6, 7, 8, 9, 10, 11, 12, 21, 31, 32, 37, 38, 39, 41,
    42, 45, 55, 56, 57, 58, 59, 60, 65, 75, 76, 81, 82, 83, 85, 86, 89}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.8248181954138527`*^9, {3.824818317655662*^9, 3.8248183244127493`*^9}, 
   3.8248183792354794`*^9, {3.824819501708647*^9, 3.824819516678465*^9}, 
   3.847181788583066*^9},
 CellLabel->
  "During evaluation of \
In[181]:=",ExpressionUUID->"8a11d36d-7fcf-4bbe-be38-987f9b7a378e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"outsideIncircle", "\[Intersection]", 
  "insideOrOnTriangle"}]], "Input",
 CellChangeTimes->{{3.824818010509425*^9, 3.824818012013026*^9}},
 CellLabel->
  "In[184]:=",ExpressionUUID->"997132ed-b9c8-408f-823d-df7e11f28fbf"],

Cell[BoxData[
 RowBox[{"{", "}"}]], "Output",
 CellChangeTimes->{3.824818013191092*^9, 3.824819606636506*^9, 
  3.847181788648081*^9},
 CellLabel->
  "Out[184]=",ExpressionUUID->"b88b2482-40c7-499a-89f3-202939813442"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Condition for Center To Lie on Incircle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730183592462*^9, 3.824730194584065*^9}, {
  3.824815791230557*^9, 3.824815814654079*^9}, {3.824819861490974*^9, 
  3.824819879546664*^9}},ExpressionUUID->"dc5b93d7-8a82-4bd1-b05b-\
518156ce6e6a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "condition", " ", "for", " ", "center", " ", "to", " ", "lie",
     " ", "on", " ", "incircle"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "/.", 
         RowBox[{"S", "\[Rule]", 
          RowBox[{"2", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"s", 
             RowBox[{"(", 
              RowBox[{"s", "-", "a"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "b"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"triang", "=", 
       RowBox[{
        RowBox[{"a", ">", "0"}], "&&", 
        RowBox[{"b", ">", "0"}], "&&", 
        RowBox[{"c", ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
        RowBox[{
         RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
        RowBox[{
         RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"rsq", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"s", "-", "a"}], ")"}], 
         RowBox[{"(", 
          RowBox[{"s", "-", "b"}], ")"}], 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"s", "-", "c"}], ")"}], "/", "s"}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"distsq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "1", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"in", "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"distsq", "<", "rsq"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"out", "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"distsq", ">", "rsq"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"in", "||", "out"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< can never lie on the incircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"condo", "=", 
       RowBox[{"distsq", "\[Equal]", "rsq"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"cond", "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", "condo", "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"cond", "=", 
       RowBox[{"Simplify", "[", "cond", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"cond", "\[Equal]", "True"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", "\"\< must lie on the incircle.\>\""}], 
          "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"cond", "\[Equal]", "False"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< can never lie on the incircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cond2", "=", 
       RowBox[{"Together", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{"cond", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "\[Rule]", 
             RowBox[{"r", "/", "R"}]}], ",", 
            RowBox[{"y", "\[Rule]", 
             RowBox[{"s", "/", "R"}]}]}], "}"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xcond", "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"cond2", "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"r", ">", "0"}], "&&", 
          RowBox[{"s", ">", "0"}], "&&", 
          RowBox[{"R", ">", "0"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"xcond", "\[Equal]", "True"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", "\"\< must lie on the incircle.\>\""}], 
          "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"xcond", "\[Equal]", "False"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< can never lie on the incircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cond3", "=", 
       RowBox[{
        RowBox[{"First", "[", "xcond", "]"}], "-", 
        RowBox[{"Last", "[", "xcond", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"num", "=", 
       RowBox[{"Numerator", "[", "cond3", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"den", "=", 
       RowBox[{"Denominator", "[", "cond3", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\<: \>\"", ",", 
        RowBox[{
         RowBox[{"Factor", "[", "num", "]"}], "\[Equal]", "0"}]}], "]"}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"vars", "=", 
       RowBox[{"Variables", "[", "cond", "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "vars", "]"}], "\[Equal]", "1"}], ",", 
        RowBox[{
         RowBox[{"var", "=", 
          RowBox[{"vars", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\<: \>\"", ",", 
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"cond", "\[Equal]", "0"}], "&&", 
              RowBox[{"var", "\[NotEqual]", "0"}]}], ",", "var"}], "]"}]}], 
          "]"}]}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.824819899043454*^9, 3.824819910890819*^9}, {
   3.8248199446118917`*^9, 3.8248201437077293`*^9}, {3.824820245061442*^9, 
   3.8248202507644672`*^9}, 3.8248203756066933`*^9, {3.8248204309427757`*^9, 
   3.8248204535648413`*^9}, 3.824820488438923*^9, {3.8248205322949543`*^9, 
   3.8248205340856047`*^9}, {3.824821024008523*^9, 3.8248210261270123`*^9}, {
   3.8248210671200113`*^9, 3.82482111187914*^9}, 3.82482114357743*^9, 
   3.824821498259761*^9, {3.8248215353205748`*^9, 3.8248215400085087`*^9}, {
   3.8248217104609957`*^9, 3.824821715865245*^9}, {3.824822008971191*^9, 
   3.824822184970585*^9}, 3.824822290933918*^9, {3.824822354324057*^9, 
   3.82482235673878*^9}, {3.8248224311897497`*^9, 3.8248224332915907`*^9}, {
   3.8248230714862947`*^9, 3.824823126877672*^9}, {3.824823203882504*^9, 
   3.824823234863633*^9}, {3.824823290879771*^9, 3.824823344414423*^9}, {
   3.824823390879559*^9, 3.824823454834103*^9}, {3.8248235244009743`*^9, 
   3.824823525007022*^9}, {3.824823557160995*^9, 3.824823559799274*^9}, {
   3.8248236130095167`*^9, 3.824823641783259*^9}, {3.824823744490122*^9, 
   3.824823745487544*^9}, {3.82482454183596*^9, 3.8248245502191277`*^9}, {
   3.824826183664826*^9, 3.824826233439621*^9}, {3.824826263639901*^9, 
   3.8248262927118673`*^9}, {3.8248269808610086`*^9, 3.824826987681491*^9}, {
   3.824829385114386*^9, 3.824829415109289*^9}, {3.824829447076803*^9, 
   3.824829464657583*^9}},
 CellLabel->
  "In[424]:=",ExpressionUUID->"1d0f9c8f-9bc7-4a42-9170-3f1079b0df84"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 1, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829481858829*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"7d25de29-16af-4e33-b701-e8f8f8e5d583"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", "R"}], "-", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 2, ": ", 
   4 $CellContext`r^2 + (16 $CellContext`r) $CellContext`R - $CellContext`s^2 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829481919724*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"251d6a5d-8642-4ba2-8e5d-1b4be8f02b57"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["r", "2"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R"}], "+", 
     SuperscriptBox["R", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 3, ": ", -$CellContext`r^2 - (
     2 $CellContext`r) $CellContext`R + $CellContext`R^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829481986944*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"9d689378-8e77-44d1-ad28-d6f5d3cef160"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        SqrtBox["2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SqrtBox["2"]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "X", 3, ": ", {{$CellContext`x -> -1 - 2^
      Rational[1, 2]}, {$CellContext`x -> -1 + 2^Rational[1, 2]}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829481988468*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"5963f8ef-6448-460f-8099-798856a25cf0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"4", " ", "r", " ", "R"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 4, ": ", 
   2 $CellContext`r^2 + (4 $CellContext`r) $CellContext`R + 
    4 $CellContext`R^2 - $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482062134*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"76ab69d5-6889-4d7b-8d21-6bdaeb1a92dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", "r"}], "-", "R"}], "\[Equal]", "0"}]}],
  SequenceForm["X", 5, ": ", 4 $CellContext`r - $CellContext`R == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294821343803`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"db4a4947-4425-4c71-b3d7-4454b0ad135d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{"x", "\[Rule]", 
      FractionBox["1", "4"]}], "}"}], "}"}]}],
  SequenceForm["X", 5, ": ", {{$CellContext`x -> Rational[1, 4]}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294821360493`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ad1d44ad-0118-4252-8522-8e0657538d6c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 6, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      48 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 - (
     2 $CellContext`r^2) $CellContext`s^2 - ((
      12 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482294639*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"e7b03aae-7d96-4028-b26d-43e09147aac4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 7, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482370941*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"8a418c21-e142-4c63-a786-cce94e06dc4d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"]}], "-", 
     RowBox[{"16", " ", "r", " ", "R"}], "+", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 8, ": ", 
   4 $CellContext`r^2 - (16 $CellContext`r) $CellContext`R + $CellContext`s^2 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482455324*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"7a073dc8-61b7-400e-a2c9-54d558af3b7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 9, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      48 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294825382223`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"dcade9f0-7b6b-48b0-b65f-3933af05c8c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"16", " ", "r", " ", "R"}], "+", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 10, ": ", $CellContext`r^2 - (
     16 $CellContext`r) $CellContext`R + $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482625133*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4bae3bde-8cbb-4a0e-80de-7eaef358bf4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" must lie on the incircle.\"\>"}],
  SequenceForm["X", 11, " must lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482626582*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4bb4352d-0f96-46c4-af43-e519a996edc0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 12, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829482715818*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"98ca8cb6-fb47-40ef-b25d-a648114736af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"192", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "-", 
     RowBox[{"44", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "-", 
     RowBox[{"112", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "-", 
     RowBox[{"26", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"44", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"20", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "R", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{"11", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 13, ": ", 
   3 $CellContext`r^4 + (36 $CellContext`r^3) $CellContext`R + (
      144 $CellContext`r^2) $CellContext`R^2 + (
      192 $CellContext`r) $CellContext`R^3 - ((4 
      3^Rational[1, 2]) $CellContext`r^3) $CellContext`s - (((44 
       3^Rational[
         1, 2]) $CellContext`r^2) $CellContext`R) $CellContext`s - (((112 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s - (
     26 $CellContext`r^2) $CellContext`s^2 - ((
      44 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     48 $CellContext`R^2) $CellContext`s^2 + ((20 
       3^Rational[1, 2]) $CellContext`r) $CellContext`s^3 + ((4 
       3^Rational[1, 2]) $CellContext`R) $CellContext`s^3 + 
    11 $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482948348344*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"24eb4ca2-b4a6-41a6-a308-66a2418566d2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 14, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829483825575*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"84333982-20a6-4a06-9034-5380826a1e13"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "-", 
     RowBox[{"28", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "-", 
     RowBox[{"48", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "R", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 15, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      48 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 - ((4 
      3^Rational[1, 2]) $CellContext`r^3) $CellContext`s - (((28 
       3^Rational[
         1, 2]) $CellContext`r^2) $CellContext`R) $CellContext`s - (((48 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s + (
      10 $CellContext`r^2) $CellContext`s^2 + ((
       12 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     16 $CellContext`R^2) $CellContext`s^2 + ((4 
       3^Rational[1, 2]) $CellContext`r) $CellContext`s^3 + ((4 
       3^Rational[1, 2]) $CellContext`R) $CellContext`s^3 + $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829484598276*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ac866a79-641c-48b6-b350-39d56c058732"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 16, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294848152246`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2176ba3f-5c2a-49e5-a8f4-3062c07b8a76"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"192", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"12", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "-", 
     RowBox[{"100", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "-", 
     RowBox[{"208", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"116", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"28", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{"12", " ", 
      SqrtBox["3"], " ", "R", " ", 
      SuperscriptBox["s", "3"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 17, ": ", 
   3 $CellContext`r^4 + (36 $CellContext`r^3) $CellContext`R + (
      144 $CellContext`r^2) $CellContext`R^2 + (
      192 $CellContext`r) $CellContext`R^3 - ((12 
      3^Rational[1, 2]) $CellContext`r^3) $CellContext`s - (((100 
       3^Rational[
         1, 2]) $CellContext`r^2) $CellContext`R) $CellContext`s - (((208 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s + (
      22 $CellContext`r^2) $CellContext`s^2 + ((
       116 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     16 $CellContext`R^2) $CellContext`s^2 + ((28 
       3^Rational[1, 2]) $CellContext`r) $CellContext`s^3 + ((12 
       3^Rational[1, 2]) $CellContext`R) $CellContext`s^3 - 
    5 $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829485735865*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ca9bb1c4-4752-41db-8569-d738342d9a94"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"3", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"192", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"12", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "+", 
     RowBox[{"100", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "+", 
     RowBox[{"208", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"116", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"28", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "-", 
     RowBox[{"12", " ", 
      SqrtBox["3"], " ", "R", " ", 
      SuperscriptBox["s", "3"]}], "-", 
     RowBox[{"5", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 18, ": ", 
   3 $CellContext`r^4 + (36 $CellContext`r^3) $CellContext`R + (
      144 $CellContext`r^2) $CellContext`R^2 + (
      192 $CellContext`r) $CellContext`R^3 + ((12 
       3^Rational[1, 2]) $CellContext`r^3) $CellContext`s + (((100 
        3^Rational[
          1, 2]) $CellContext`r^2) $CellContext`R) $CellContext`s + (((208 
        3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s + (
      22 $CellContext`r^2) $CellContext`s^2 + ((
       116 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     16 $CellContext`R^2) $CellContext`s^2 - ((28 
      3^Rational[1, 2]) $CellContext`r) $CellContext`s^3 - ((12 
      3^Rational[1, 2]) $CellContext`R) $CellContext`s^3 - 5 $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829486873848*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"a20a8ef2-a769-4a01-8973-9d58d6aa0326"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"100", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"304", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"448", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"108", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"128", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 19, ": ", $CellContext`r^6 + (16 $CellContext`r^5) $CellContext`R + (
      100 $CellContext`r^4) $CellContext`R^2 + (
      304 $CellContext`r^3) $CellContext`R^3 + (
      448 $CellContext`r^2) $CellContext`R^4 + (
      256 $CellContext`r) $CellContext`R^5 - (
     2 $CellContext`r^4) $CellContext`s^2 - ((
      28 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      108 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      128 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     16 $CellContext`R^4) $CellContext`s^2 + $CellContext`r^2 \
$CellContext`s^4 + ((12 $CellContext`r) $CellContext`R) $CellContext`s^4 + (
      4 $CellContext`R^2) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829487220458*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4734209f-9914-47e9-bdef-f00c1c5cf573"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"8", " ", "r", " ", "R"}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 20, ": ", (8 $CellContext`r) $CellContext`R + 16 $CellContext`R^2 - 
    3 $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829487337891*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"c705ed7b-2065-43bf-a8bd-b9dbe283c946"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 21, ": ", 
   4 $CellContext`r^4 + (18 $CellContext`r^3) $CellContext`R + (
      28 $CellContext`r^2) $CellContext`R^2 + (
      16 $CellContext`r) $CellContext`R^3 - ((
      2 $CellContext`r) $CellContext`R) $CellContext`s^2 - $CellContext`R^2 \
$CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829487435123*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"9e033b68-784d-4883-8bb1-064700c4c5c4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"58", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"44", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"10", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 22, ": ", $CellContext`r^6 + (10 $CellContext`r^5) $CellContext`R + (
      36 $CellContext`r^4) $CellContext`R^2 + (
      58 $CellContext`r^3) $CellContext`R^3 + (
      44 $CellContext`r^2) $CellContext`R^4 + (
      16 $CellContext`r) $CellContext`R^5 - (
     2 $CellContext`r^4) $CellContext`s^2 - ((
      12 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      20 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      10 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - \
$CellContext`R^4 $CellContext`s^2 + $CellContext`r^2 $CellContext`s^4 + ((
       2 $CellContext`r) $CellContext`R) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294878150063`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"19797a95-b8ad-40ff-a2b7-ad55c67466f4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 23, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829487942463*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"1db3582f-d819-4959-a0b9-2885dbee4aff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"40", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"82", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"86", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"36", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"18", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 24, ": ", $CellContext`r^6 + (10 $CellContext`r^5) $CellContext`R + (
      40 $CellContext`r^4) $CellContext`R^2 + (
      82 $CellContext`r^3) $CellContext`R^3 + (
      86 $CellContext`r^2) $CellContext`R^4 + (
      36 $CellContext`r) $CellContext`R^5 - 
    4 $CellContext`R^6 - (
     2 $CellContext`r^4) $CellContext`s^2 - ((
      12 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      24 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      18 $CellContext`r) $CellContext`R^3) $CellContext`s^2 + \
$CellContext`R^4 $CellContext`s^2 + $CellContext`r^2 $CellContext`s^4 + ((
       2 $CellContext`r) $CellContext`R) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829488595052*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"52bb5190-2084-4b8a-afc3-1cebd3bb40b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"41", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"92", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"112", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"26", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"28", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 25, ": ", $CellContext`r^6 + (10 $CellContext`r^5) $CellContext`R + (
      41 $CellContext`r^4) $CellContext`R^2 + (
      92 $CellContext`r^3) $CellContext`R^3 + (
      112 $CellContext`r^2) $CellContext`R^4 + (
      64 $CellContext`r) $CellContext`R^5 - (
     2 $CellContext`r^4) $CellContext`s^2 - ((
      12 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      26 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      28 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     4 $CellContext`R^4) $CellContext`s^2 + $CellContext`r^2 $CellContext`s^4 + \
((2 $CellContext`r) $CellContext`R) $CellContext`s^4 + $CellContext`R^2 \
$CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294890109377`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"e8d86d25-40ef-496d-bd3c-02a04a3dd9cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["r", "6"]}], "-", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "-", 
     RowBox[{"38", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"70", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"64", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"24", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "+", 
     SuperscriptBox["R", "6"], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"14", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 26, ": ", -$CellContext`r^6 - (10 $CellContext`r^5) $CellContext`R - (
     38 $CellContext`r^4) $CellContext`R^2 - (
     70 $CellContext`r^3) $CellContext`R^3 - (
     64 $CellContext`r^2) $CellContext`R^4 - (
     24 $CellContext`r) $CellContext`R^5 + $CellContext`R^6 + (
      2 $CellContext`r^4) $CellContext`s^2 + ((
       12 $CellContext`r^3) $CellContext`R) $CellContext`s^2 + ((
       22 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 + ((
       14 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - \
$CellContext`r^2 $CellContext`s^4 - ((
      2 $CellContext`r) $CellContext`R) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829489637205*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"bbe9b900-cc57-4c15-995d-71d01ce218fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"]}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"224", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"512", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"576", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"13", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"80", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"168", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"128", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["s", "6"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 27, ": ", 
   4 $CellContext`r^6 + (48 $CellContext`r^5) $CellContext`R + (
      224 $CellContext`r^4) $CellContext`R^2 + (
      512 $CellContext`r^3) $CellContext`R^3 + (
      576 $CellContext`r^2) $CellContext`R^4 + (
      256 $CellContext`r) $CellContext`R^5 - (
     13 $CellContext`r^4) $CellContext`s^2 - ((
      80 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      168 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      128 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     16 $CellContext`R^4) $CellContext`s^2 + (
      2 $CellContext`r^2) $CellContext`s^4 - (
     8 $CellContext`R^2) $CellContext`s^4 + 3 $CellContext`s^6 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294902092447`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4be77212-f973-4d39-a3e7-1d046d891b31"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"11", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"49", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"112", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"132", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"14", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"35", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"32", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"3", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 28, ": ", $CellContext`r^6 + (11 $CellContext`r^5) $CellContext`R + (
      49 $CellContext`r^4) $CellContext`R^2 + (
      112 $CellContext`r^3) $CellContext`R^3 + (
      132 $CellContext`r^2) $CellContext`R^4 + (
      64 $CellContext`r) $CellContext`R^5 - (
     2 $CellContext`r^4) $CellContext`s^2 - ((
      14 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      35 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      32 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     4 $CellContext`R^4) $CellContext`s^2 + $CellContext`r^2 $CellContext`s^4 + \
((3 $CellContext`r) $CellContext`R) $CellContext`s^4 + $CellContext`R^2 \
$CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829490757967*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"c08089a6-230e-4ba4-9ee1-592ca9ef1d37"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"16", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"112", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"320", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"448", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"56", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"152", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"160", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     SuperscriptBox["s", "6"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 29, ": ", (16 $CellContext`r^5) $CellContext`R + (
      112 $CellContext`r^4) $CellContext`R^2 + (
      320 $CellContext`r^3) $CellContext`R^3 + (
      448 $CellContext`r^2) $CellContext`R^4 + (
      256 $CellContext`r) $CellContext`R^5 - (
     9 $CellContext`r^4) $CellContext`s^2 - ((
      56 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      152 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      160 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     16 $CellContext`R^4) $CellContext`s^2 + (
      6 $CellContext`r^2) $CellContext`s^4 + ((
       24 $CellContext`r) $CellContext`R) $CellContext`s^4 + (
      8 $CellContext`R^2) $CellContext`s^4 - $CellContext`s^6 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829491623095*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"c5871cb1-e39d-40eb-942d-40f27445c6b7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 30, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294916251287`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"bf0c81cc-d79d-428d-91a3-3a50d030f1b4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"9", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"60", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"112", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"20", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 31, ": ", 
   9 $CellContext`r^4 + (60 $CellContext`r^3) $CellContext`R + (
      112 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 - (
     6 $CellContext`r^2) $CellContext`s^2 - ((
      20 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829491804616*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"016a1275-13da-4e58-b8b3-f45fe9fb34af"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "8"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "+", 
     RowBox[{"160", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"640", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"1280", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"1024", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"148", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"644", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1120", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"576", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"38", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"188", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"280", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"96", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"28", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 32, ": ", $CellContext`r^8 + (20 $CellContext`r^7) $CellContext`R + (
      160 $CellContext`r^6) $CellContext`R^2 + (
      640 $CellContext`r^5) $CellContext`R^3 + (
      1280 $CellContext`r^4) $CellContext`R^4 + (
      1024 $CellContext`r^3) $CellContext`R^5 - (
     12 $CellContext`r^6) $CellContext`s^2 - ((
      148 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
      644 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
      1120 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
      576 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 + (
      38 $CellContext`r^4) $CellContext`s^4 + ((
       188 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
       280 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
       96 $CellContext`r) $CellContext`R^3) $CellContext`s^4 - (
     12 $CellContext`r^2) $CellContext`s^6 - ((
      28 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
     4 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829492338764*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"d777c07a-ae38-42ae-9862-3616898f39b9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 33, ": ", $CellContext`r^4 + (4 $CellContext`r^3) $CellContext`R - (
     2 $CellContext`r^2) $CellContext`s^2 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294926940002`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ce7e0b45-b226-41db-b11c-3ef8f69c1976"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"32", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 34, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      32 $CellContext`r^2) $CellContext`R^2 + (
      32 $CellContext`r) $CellContext`R^3 - (
     2 $CellContext`r^2) $CellContext`s^2 - ((
      12 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829493094206*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"841f77f6-6ccc-4a0c-a23c-db038c78b9b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"12", " ", "r", " ", "R"}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["R", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 35, ": ", 
   4 $CellContext`r^2 + (12 $CellContext`r) $CellContext`R - 
    3 $CellContext`R^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294932068644`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ac1d7cb9-0489-4e69-933a-d865d6777035"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "-", 
          RowBox[{"2", " ", 
           SqrtBox["3"]}]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "3"}], "+", 
          RowBox[{"2", " ", 
           SqrtBox["3"]}]}], ")"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "X", 35, ": ", {{$CellContext`x -> 
     Rational[1, 2] (-3 - 2 3^Rational[1, 2])}, {$CellContext`x -> 
     Rational[1, 2] (-3 + 2 3^Rational[1, 2])}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829493208856*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"08e169e4-1a49-443b-b78a-c869a9b9eb61"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 36, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829493327876*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"b473a08c-ed96-46ae-841d-0da4296058b8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 37, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      48 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 + (
      2 $CellContext`r^2) $CellContext`s^2 + ((
       4 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829493440358*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"d2a4ccfe-0fa5-46bb-9f97-09a512a02255"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"80", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 38, ": ", $CellContext`r^4 + (20 $CellContext`r^3) $CellContext`R + (
      80 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 + (
      2 $CellContext`r^2) $CellContext`s^2 - ((
      12 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482949361071*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"a4ae8d50-cbd8-40ad-9229-6966e234adc3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "8"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "+", 
     RowBox[{"160", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"640", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"1280", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"1024", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"352", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"576", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"96", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 39, ": ", $CellContext`r^8 + (20 $CellContext`r^7) $CellContext`R + (
      160 $CellContext`r^6) $CellContext`R^2 + (
      640 $CellContext`r^5) $CellContext`R^3 + (
      1280 $CellContext`r^4) $CellContext`R^4 + (
      1024 $CellContext`r^3) $CellContext`R^5 + (
      4 $CellContext`r^6) $CellContext`s^2 + ((
       28 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
      4 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
      352 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
      576 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 + (
      6 $CellContext`r^4) $CellContext`s^4 - ((
      4 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
       24 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
       96 $CellContext`r) $CellContext`R^3) $CellContext`s^4 + (
      4 $CellContext`r^2) $CellContext`s^6 - ((
      12 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
     4 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482949407227*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"690e9bc3-cad1-46ba-ac63-5553e7ce8870"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    FractionBox[
     RowBox[{
      SuperscriptBox["r", "2"], "+", 
      RowBox[{"8", " ", "r", " ", "R"}], "-", 
      RowBox[{"4", " ", 
       SuperscriptBox["R", "2"]}]}], 
     SuperscriptBox["R", "2"]], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 40, ": ", $CellContext`R^(-2) ($CellContext`r^2 + (
       8 $CellContext`r) $CellContext`R - 4 $CellContext`R^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829494223711*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"35e32730-da7c-443a-a797-e7fd3b7263f1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "-", 
          SqrtBox["5"]}], ")"}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{"2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", 
          SqrtBox["5"]}], ")"}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "X", 40, ": ", {{$CellContext`x -> 
     2 (-2 - 5^Rational[1, 2])}, {$CellContext`x -> 
     2 (-2 + 5^Rational[1, 2])}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482949422574*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"b83744fe-7fbd-445d-be27-bd5437a0081f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"160", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"640", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"1280", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"1024", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"68", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"260", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"352", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"64", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 41, ": ", $CellContext`r^6 + (20 $CellContext`r^5) $CellContext`R + (
      160 $CellContext`r^4) $CellContext`R^2 + (
      640 $CellContext`r^3) $CellContext`R^3 + (
      1280 $CellContext`r^2) $CellContext`R^4 + (
      1024 $CellContext`r) $CellContext`R^5 - (
     6 $CellContext`r^4) $CellContext`s^2 - ((
      68 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      260 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      352 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     64 $CellContext`R^4) $CellContext`s^2 + (
      9 $CellContext`r^2) $CellContext`s^4 + ((
       24 $CellContext`r) $CellContext`R) $CellContext`s^4 + (
      16 $CellContext`R^2) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829494590968*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"3b23113f-a670-4ffe-9467-027cf735bec3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 42, ": ", $CellContext`r^4 - (4 $CellContext`r^3) $CellContext`R - (
     16 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 + (
      2 $CellContext`r^2) $CellContext`s^2 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829494777257*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4c829551-0a1e-484b-bdac-568fc7115aee"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "-", 
       RowBox[{"16", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["R", "2"]}], "+", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 43, ": ", ($CellContext`r^2 - (
      16 $CellContext`r) $CellContext`R + $CellContext`s^2) ($CellContext`r^2 - 
     16 $CellContext`R^2 + $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294949887543`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"00e20b05-6345-4002-9ade-d073138bb9b3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 44, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829495060109*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"82d70c53-835c-4ecb-8de4-73bb0a5323c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"9", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"108", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"432", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"576", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 45, ": ", 
   9 $CellContext`r^4 + (108 $CellContext`r^3) $CellContext`R + (
      432 $CellContext`r^2) $CellContext`R^2 + (
      576 $CellContext`r) $CellContext`R^3 + (
      6 $CellContext`r^2) $CellContext`s^2 - ((
      12 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     36 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294952446327`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"3776aa38-09fa-476c-8aeb-6eaa97be8c7c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{"6", " ", "r", " ", "R"}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["R", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 46, ": ", $CellContext`r^2 + (6 $CellContext`r) $CellContext`R - 
    3 $CellContext`R^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829495402151*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"8debc739-d316-4675-989c-f450b632f563"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "3"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "3"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox["3"]}]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "X", 46, ": ", {{$CellContext`x -> -3 - 2 
      3^Rational[1, 2]}, {$CellContext`x -> -3 + 2 3^Rational[1, 2]}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829495407935*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"e996a692-a902-4490-9516-a15df4b3cdd3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"9", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"60", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"124", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"88", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"20", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 47, ": ", 
   9 $CellContext`r^4 + (60 $CellContext`r^3) $CellContext`R + (
      124 $CellContext`r^2) $CellContext`R^2 + (
      88 $CellContext`r) $CellContext`R^3 + 
    4 $CellContext`R^4 - (
     6 $CellContext`r^2) $CellContext`s^2 - ((
      20 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     8 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829495790649*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"bb66d203-adbd-4cfc-af01-a7f1fad2b714"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"100", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"304", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"448", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"52", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"140", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"128", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"12", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 48, ": ", $CellContext`r^6 + (16 $CellContext`r^5) $CellContext`R + (
      100 $CellContext`r^4) $CellContext`R^2 + (
      304 $CellContext`r^3) $CellContext`R^3 + (
      448 $CellContext`r^2) $CellContext`R^4 + (
      256 $CellContext`r) $CellContext`R^5 - (
     6 $CellContext`r^4) $CellContext`s^2 - ((
      52 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      140 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      128 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     16 $CellContext`R^4) $CellContext`s^2 + (
      9 $CellContext`r^2) $CellContext`s^4 + ((
       12 $CellContext`r) $CellContext`R) $CellContext`s^4 + (
      4 $CellContext`R^2) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294961354303`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"c0bdbc7d-687c-4074-9261-f969ef0f2c56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"]}], "+", 
     RowBox[{"44", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"181", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"342", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"289", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"86", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     SuperscriptBox["R", "6"], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"82", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"42", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 49, ": ", 
   4 $CellContext`r^6 + (44 $CellContext`r^5) $CellContext`R + (
      181 $CellContext`r^4) $CellContext`R^2 + (
      342 $CellContext`r^3) $CellContext`R^3 + (
      289 $CellContext`r^2) $CellContext`R^4 + (
      86 $CellContext`r) $CellContext`R^5 - $CellContext`R^6 - (
     8 $CellContext`r^4) $CellContext`s^2 - ((
      48 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      82 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      42 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     4 $CellContext`R^4) $CellContext`s^2 + (
      4 $CellContext`r^2) $CellContext`s^4 + ((
       4 $CellContext`r) $CellContext`R) $CellContext`s^4 + $CellContext`R^2 \
$CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294967694883`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"fe66bd0b-d357-4929-b415-958823c1963c"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "8"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "+", 
     RowBox[{"166", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"736", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"1865", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"2668", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"1968", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"]}], "+", 
     RowBox[{"576", " ", "r", " ", 
      SuperscriptBox["R", "7"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"148", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"686", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1480", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1482", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"588", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"38", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"188", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"322", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"216", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"33", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"28", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"10", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 50, ": ", $CellContext`r^8 + (20 $CellContext`r^7) $CellContext`R + (
      166 $CellContext`r^6) $CellContext`R^2 + (
      736 $CellContext`r^5) $CellContext`R^3 + (
      1865 $CellContext`r^4) $CellContext`R^4 + (
      2668 $CellContext`r^3) $CellContext`R^5 + (
      1968 $CellContext`r^2) $CellContext`R^6 + (
      576 $CellContext`r) $CellContext`R^7 - (
     12 $CellContext`r^6) $CellContext`s^2 - ((
      148 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
      686 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
      1480 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
      1482 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 - ((
      588 $CellContext`r) $CellContext`R^5) $CellContext`s^2 - (
     36 $CellContext`R^6) $CellContext`s^2 + (
      38 $CellContext`r^4) $CellContext`s^4 + ((
       188 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
       322 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
       216 $CellContext`r) $CellContext`R^3) $CellContext`s^4 + (
      33 $CellContext`R^4) $CellContext`s^4 - (
     12 $CellContext`r^2) $CellContext`s^6 - ((
      28 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
     10 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829498287269*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"75f7bbde-9fc4-4a6d-9680-3cf6588d0735"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"20", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 51, ": ", $CellContext`r^4 - (4 $CellContext`r^3) $CellContext`R - (
     16 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 + (
      18 $CellContext`r^2) $CellContext`s^2 - ((
      20 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248294985098667`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2285bfa3-0d8f-4e56-a112-21d733fbf3f9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"8", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"14", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 52, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      32 $CellContext`r^2) $CellContext`R^2 + (
      8 $CellContext`r) $CellContext`R^3 + 
    4 $CellContext`R^4 - (
     14 $CellContext`r^2) $CellContext`s^2 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829498909444*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"6e0b8b86-6593-4176-b9d1-ea9b1603056a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "8"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "+", 
     RowBox[{"168", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"768", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"2064", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"3264", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"2816", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"]}], "+", 
     RowBox[{"1024", " ", "r", " ", 
      SuperscriptBox["R", "7"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"76", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"476", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1312", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1664", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"832", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"64", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"76", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"256", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"224", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"20", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 53, ": ", $CellContext`r^8 + (20 $CellContext`r^7) $CellContext`R + (
      168 $CellContext`r^6) $CellContext`R^2 + (
      768 $CellContext`r^5) $CellContext`R^3 + (
      2064 $CellContext`r^4) $CellContext`R^4 + (
      3264 $CellContext`r^3) $CellContext`R^5 + (
      2816 $CellContext`r^2) $CellContext`R^6 + (
      1024 $CellContext`r) $CellContext`R^7 - (
     4 $CellContext`r^6) $CellContext`s^2 - ((
      76 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
      476 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
      1312 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
      1664 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 - ((
      832 $CellContext`r) $CellContext`R^5) $CellContext`s^2 - (
     64 $CellContext`R^6) $CellContext`s^2 - (
     10 $CellContext`r^4) $CellContext`s^4 + ((
       76 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
       256 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
       224 $CellContext`r) $CellContext`R^3) $CellContext`s^4 + (
      48 $CellContext`R^4) $CellContext`s^4 - (
     4 $CellContext`r^2) $CellContext`s^6 - ((
      20 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
     12 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295000051327`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"969bfd09-dd6b-4dbb-b998-0abc562dcf5b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"]}], "+", 
     RowBox[{"44", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"176", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"302", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"198", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"36", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"72", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"26", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 54, ": ", 
   4 $CellContext`r^6 + (44 $CellContext`r^5) $CellContext`R + (
      176 $CellContext`r^4) $CellContext`R^2 + (
      302 $CellContext`r^3) $CellContext`R^3 + (
      198 $CellContext`r^2) $CellContext`R^4 + (
      36 $CellContext`r) $CellContext`R^5 - 
    4 $CellContext`R^6 - (
     8 $CellContext`r^4) $CellContext`s^2 - ((
      48 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      72 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      26 $CellContext`r) $CellContext`R^3) $CellContext`s^2 + \
$CellContext`R^4 $CellContext`s^2 + (
      4 $CellContext`r^2) $CellContext`s^4 + ((
       4 $CellContext`r) $CellContext`R) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482950072574*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"55190e27-c7d6-4a36-ad1e-6702e47a7461"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 55, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482950077145*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"26117700-b3ef-4def-91b9-9769a83a3cb8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 56, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829500824932*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"6f057e6a-3b21-4f61-8f69-1f4269ef3efc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 57, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829500874701*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2612a9d4-5cca-4586-98a4-80e89ca5f6a2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"9", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"92", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 58, ": ", 
   9 $CellContext`r^4 + (48 $CellContext`r^3) $CellContext`R + (
      92 $CellContext`r^2) $CellContext`R^2 + (
      64 $CellContext`r) $CellContext`R^3 - (
     6 $CellContext`r^2) $CellContext`s^2 - ((
      16 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295010671597`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"12bd07cd-a620-4946-83a2-74245b69eca4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "r"}], "-", "R"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"5", " ", "r", " ", "R"}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["r", "5"]}], "+", 
       RowBox[{"25", " ", 
        SuperscriptBox["r", "4"], " ", "R"}], "+", 
       RowBox[{"108", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"176", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"64", " ", "r", " ", 
        SuperscriptBox["R", "4"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"26", " ", 
        SuperscriptBox["r", "2"], " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"34", " ", "r", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"2", " ", "r", " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"R", " ", 
        SuperscriptBox["s", "4"]}]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 59, ": ", ((
      2 $CellContext`r - $CellContext`R) ($CellContext`r^2 + (
        5 $CellContext`r) $CellContext`R + 
      4 $CellContext`R^2 - $CellContext`s^2)) (
     2 $CellContext`r^5 + (25 $CellContext`r^4) $CellContext`R + (
       108 $CellContext`r^3) $CellContext`R^2 + (
       176 $CellContext`r^2) $CellContext`R^3 + (
       64 $CellContext`r) $CellContext`R^4 - (
      4 $CellContext`r^3) $CellContext`s^2 - ((
       26 $CellContext`r^2) $CellContext`R) $CellContext`s^2 - ((
       34 $CellContext`r) $CellContext`R^2) $CellContext`s^2 - (
      3 $CellContext`R^3) $CellContext`s^2 + (
       2 $CellContext`r) $CellContext`s^4 + $CellContext`R $CellContext`s^4) == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829501607172*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"811c8580-c68d-4de7-962b-a4d630900c3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["r", "5"]}], "+", 
     RowBox[{"17", " ", 
      SuperscriptBox["r", "4"], " ", "R"}], "+", 
     RowBox[{"56", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"84", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"48", " ", "r", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"22", " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"2", " ", "r", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"R", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 60, ": ", 
   2 $CellContext`r^5 + (17 $CellContext`r^4) $CellContext`R + (
      56 $CellContext`r^3) $CellContext`R^2 + (
      84 $CellContext`r^2) $CellContext`R^3 + (
      48 $CellContext`r) $CellContext`R^4 - (
     4 $CellContext`r^3) $CellContext`s^2 - ((
      18 $CellContext`r^2) $CellContext`R) $CellContext`s^2 - ((
      22 $CellContext`r) $CellContext`R^2) $CellContext`s^2 - (
     3 $CellContext`R^3) $CellContext`s^2 + (
      2 $CellContext`r) $CellContext`s^4 + $CellContext`R $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295020730658`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2b5f8b38-b061-4fee-a04a-607783d8ec6a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"12", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"48", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"20", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"56", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "3"], " ", "s"}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "3"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 61, ": ", (12 $CellContext`r^2) $CellContext`R^4 + (
      48 $CellContext`r) $CellContext`R^5 + (((20 
        3^Rational[
          1, 2]) $CellContext`r^3) $CellContext`R^2) $CellContext`s + (((56 
        3^Rational[
          1, 2]) $CellContext`r^2) $CellContext`R^3) $CellContext`s + (
      16 $CellContext`r^4) $CellContext`s^2 + ((
       32 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      16 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - (
     3 $CellContext`R^4) $CellContext`s^2 - (((4 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s^3 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829503296665*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"d7c515ed-bc95-42fe-8e6c-1dcd85eeb94f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"27", " ", 
        SuperscriptBox["R", "4"]}], "-", 
       RowBox[{"24", " ", 
        SqrtBox["3"], " ", "r", " ", 
        SuperscriptBox["R", "2"], " ", "s"}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"12", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "4"]}], "+", 
       RowBox[{"48", " ", "r", " ", 
        SuperscriptBox["R", "5"]}], "-", 
       RowBox[{"20", " ", 
        SqrtBox["3"], " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "2"], " ", "s"}], "-", 
       RowBox[{"56", " ", 
        SqrtBox["3"], " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "3"], " ", "s"}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"32", " ", 
        SuperscriptBox["r", "3"], " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "4"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"4", " ", 
        SqrtBox["3"], " ", "r", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "3"]}]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 62, ": ", (
     27 $CellContext`R^4 - (((24 
        3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s + (
       16 $CellContext`r^2) $CellContext`s^2) ((
       12 $CellContext`r^2) $CellContext`R^4 + (
       48 $CellContext`r) $CellContext`R^5 - (((20 
        3^Rational[
          1, 2]) $CellContext`r^3) $CellContext`R^2) $CellContext`s - (((56 
        3^Rational[
          1, 2]) $CellContext`r^2) $CellContext`R^3) $CellContext`s + (
       16 $CellContext`r^4) $CellContext`s^2 + ((
        32 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
       16 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - (
      3 $CellContext`R^4) $CellContext`s^2 + (((4 
         3^Rational[
           1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s^3) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829505079761*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"8ac6bccb-c430-48c6-9542-82997e137a32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 63, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      20 $CellContext`r^2) $CellContext`R^2 + (
      16 $CellContext`r) $CellContext`R^3 - ((
      2 $CellContext`r) $CellContext`R) $CellContext`s^2 - $CellContext`R^2 \
$CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295052319613`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ada2e020-6b29-49a2-b707-b2f8ea9df6f2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"192", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"384", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"256", " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"112", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 64, ": ", $CellContext`r^6 + (8 $CellContext`r^5) $CellContext`R + (
      20 $CellContext`r^4) $CellContext`R^2 - (
     16 $CellContext`r^3) $CellContext`R^3 - (
     192 $CellContext`r^2) $CellContext`R^4 - (
     384 $CellContext`r) $CellContext`R^5 - 
    256 $CellContext`R^6 - (
     2 $CellContext`r^4) $CellContext`s^2 - ((
      12 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      12 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 + ((
       64 $CellContext`r) $CellContext`R^3) $CellContext`s^2 + (
      112 $CellContext`R^4) $CellContext`s^2 + $CellContext`r^2 \
$CellContext`s^4 + ((4 $CellContext`r) $CellContext`R) $CellContext`s^4 - (
     12 $CellContext`R^2) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829506099893*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"e3bacd09-943f-4e23-aa55-0cd0dbccb71d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 65, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295061458063`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"eb32c4ce-9cd6-4832-a11f-1b09c7837acb"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "10"], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "9"], " ", "R"}], "+", 
     RowBox[{"131", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"488", " ", 
      SuperscriptBox["r", "7"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"956", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"848", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"64", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{"256", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "7"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"100", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"468", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"976", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"756", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"128", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"272", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"350", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"200", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"140", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"80", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"60", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"32", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "8"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "8"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 66, ": ", $CellContext`r^10 + (18 $CellContext`r^9) $CellContext`R + (
      131 $CellContext`r^8) $CellContext`R^2 + (
      488 $CellContext`r^7) $CellContext`R^3 + (
      956 $CellContext`r^6) $CellContext`R^4 + (
      848 $CellContext`r^5) $CellContext`R^5 + (
      64 $CellContext`r^4) $CellContext`R^6 - (
     256 $CellContext`r^3) $CellContext`R^7 - (
     8 $CellContext`r^8) $CellContext`s^2 - ((
      100 $CellContext`r^7) $CellContext`R) $CellContext`s^2 - ((
      468 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 - ((
      976 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      756 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 + ((
       128 $CellContext`r^3) $CellContext`R^5) $CellContext`s^2 + ((
       272 $CellContext`r^2) $CellContext`R^6) $CellContext`s^2 + (
      18 $CellContext`r^6) $CellContext`s^4 + ((
       144 $CellContext`r^5) $CellContext`R) $CellContext`s^4 + ((
       350 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       200 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 - ((
      140 $CellContext`r^2) $CellContext`R^4) $CellContext`s^4 - ((
      80 $CellContext`r) $CellContext`R^5) $CellContext`s^4 - (
     16 $CellContext`r^4) $CellContext`s^6 - ((
      60 $CellContext`r^3) $CellContext`R) $CellContext`s^6 - ((
      12 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 + ((
       32 $CellContext`r) $CellContext`R^3) $CellContext`s^6 + (
      4 $CellContext`R^4) $CellContext`s^6 + (
      5 $CellContext`r^2) $CellContext`s^8 - ((
      2 $CellContext`r) $CellContext`R) $CellContext`s^8 - $CellContext`R^2 \
$CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295084544067`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4ac70309-9493-4306-8d7f-f2aa32d64703"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 67, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829508813157*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"061a86cd-3e83-408c-bf1e-094002b8e1e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"37", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"60", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"36", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"26", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 68, ": ", $CellContext`r^6 + (10 $CellContext`r^5) $CellContext`R + (
      37 $CellContext`r^4) $CellContext`R^2 + (
      60 $CellContext`r^3) $CellContext`R^3 + (
      36 $CellContext`r^2) $CellContext`R^4 + 
    4 $CellContext`R^6 - (
     6 $CellContext`r^4) $CellContext`s^2 - ((
      24 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      26 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 + ((
       4 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     4 $CellContext`R^4) $CellContext`s^2 + (
      5 $CellContext`r^2) $CellContext`s^4 - ((
      2 $CellContext`r) $CellContext`R) $CellContext`s^4 + $CellContext`R^2 \
$CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829509671153*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"114dfb9c-49c0-4dd2-8059-20a13547bd97"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"7", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 69, ": ", 
   7 $CellContext`r^4 + (16 $CellContext`r^3) $CellContext`R - (
     6 $CellContext`r^2) $CellContext`s^2 + ((
       16 $CellContext`r) $CellContext`R) $CellContext`s^2 - $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295097758713`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"c9f36294-e8d7-4087-8924-0d28a9d092a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "10"], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "9"], " ", "R"}], "+", 
     RowBox[{"136", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"558", " ", 
      SuperscriptBox["r", "7"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"1339", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"1870", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"1390", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "6"]}], "+", 
     RowBox[{"398", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "7"]}], "-", 
     RowBox[{"38", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "8"]}], "-", 
     RowBox[{"20", " ", "r", " ", 
      SuperscriptBox["R", "9"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "10"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"100", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"496", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1222", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1499", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"728", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"44", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"70", " ", "r", " ", 
      SuperscriptBox["R", "7"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["R", "8"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"392", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"386", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"33", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"70", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"60", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"22", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}], "-", 
     RowBox[{"2", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "8"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 70, ": ", $CellContext`r^10 + (18 $CellContext`r^9) $CellContext`R + (
      136 $CellContext`r^8) $CellContext`R^2 + (
      558 $CellContext`r^7) $CellContext`R^3 + (
      1339 $CellContext`r^6) $CellContext`R^4 + (
      1870 $CellContext`r^5) $CellContext`R^5 + (
      1390 $CellContext`r^4) $CellContext`R^6 + (
      398 $CellContext`r^3) $CellContext`R^7 - (
     38 $CellContext`r^2) $CellContext`R^8 - (
     20 $CellContext`r) $CellContext`R^9 + 
    4 $CellContext`R^10 - (
     8 $CellContext`r^8) $CellContext`s^2 - ((
      100 $CellContext`r^7) $CellContext`R) $CellContext`s^2 - ((
      496 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 - ((
      1222 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      1499 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 - ((
      728 $CellContext`r^3) $CellContext`R^5) $CellContext`s^2 + ((
       44 $CellContext`r^2) $CellContext`R^6) $CellContext`s^2 + ((
       70 $CellContext`r) $CellContext`R^7) $CellContext`s^2 - (
     9 $CellContext`R^8) $CellContext`s^2 + (
      18 $CellContext`r^6) $CellContext`s^4 + ((
       144 $CellContext`r^5) $CellContext`R) $CellContext`s^4 + ((
       392 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       386 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 + ((
       33 $CellContext`r^2) $CellContext`R^4) $CellContext`s^4 - ((
      70 $CellContext`r) $CellContext`R^5) $CellContext`s^4 + (
      6 $CellContext`R^6) $CellContext`s^4 - (
     16 $CellContext`r^4) $CellContext`s^6 - ((
      60 $CellContext`r^3) $CellContext`R) $CellContext`s^6 - ((
      32 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 + ((
       22 $CellContext`r) $CellContext`R^3) $CellContext`s^6 - \
$CellContext`R^4 $CellContext`s^6 + (5 $CellContext`r^2) $CellContext`s^8 - ((
      2 $CellContext`r) $CellContext`R) $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295136660967`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"cbc82b8e-1963-4d62-9362-53ac59c30971"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "6"], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"100", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"304", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"448", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"68", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"64", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 71, ": ", $CellContext`r^6 + (16 $CellContext`r^5) $CellContext`R + (
      100 $CellContext`r^4) $CellContext`R^2 + (
      304 $CellContext`r^3) $CellContext`R^3 + (
      448 $CellContext`r^2) $CellContext`R^4 + (
      256 $CellContext`r) $CellContext`R^5 + (
      2 $CellContext`r^4) $CellContext`s^2 + ((
       20 $CellContext`r^3) $CellContext`R) $CellContext`s^2 + ((
       68 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 + ((
       64 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     16 $CellContext`R^4) $CellContext`s^2 + $CellContext`r^2 \
$CellContext`s^4 + ((4 $CellContext`r) $CellContext`R) $CellContext`s^4 - (
     12 $CellContext`R^2) $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829514186709*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"83ddd3df-a590-408f-aebd-3ff3f6bc506b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "3"], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["r", "2"], " ", "R"}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"r", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"R", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 72, ": ", $CellContext`r^3 + (9 $CellContext`r^2) $CellContext`R + (
      16 $CellContext`r) $CellContext`R^2 - $CellContext`r $CellContext`s^2 - \
$CellContext`R $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295143333817`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"f3b41b24-9664-4818-bc34-6d7037d66820"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 73, ": ", $CellContext`r^4 - (4 $CellContext`r^3) $CellContext`R - (
     16 $CellContext`r^2) $CellContext`R^2 + (
      2 $CellContext`r^2) $CellContext`s^2 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829514668552*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"68f3d730-851f-4285-9c01-fade6a970617"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 74, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829514855403*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"69bd7251-2b3d-4648-a33d-a538b2af6332"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 75, ": ", $CellContext`r^4 + (16 $CellContext`r^3) $CellContext`R + (
      2 $CellContext`r^2) $CellContext`s^2 - ((
      16 $CellContext`r) $CellContext`R) $CellContext`s^2 + $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295149621267`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"d3145936-9982-4251-9c7e-c650bad0b1a1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["r", "8"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"160", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"256", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"40", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 76, ": ", -$CellContext`r^8 - (8 $CellContext`r^7) $CellContext`R - (
     16 $CellContext`r^6) $CellContext`R^2 - (
     4 $CellContext`r^6) $CellContext`s^2 + ((
       8 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
      160 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 + ((
       256 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - (
     6 $CellContext`r^4) $CellContext`s^4 + ((
       40 $CellContext`r^3) $CellContext`R) $CellContext`s^4 - ((
      144 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 - (
     4 $CellContext`r^2) $CellContext`s^6 + ((
       24 $CellContext`r) $CellContext`R) $CellContext`s^6 - $CellContext`s^8 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829515277182*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"b47075a2-9210-4370-86b3-911cb92edf7a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", "r", " ", "R"}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 77, ": ", (2 $CellContext`r) $CellContext`R + 
    5 $CellContext`R^2 - $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829515460043*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"463abc4b-2633-4950-a019-c14a43dca5b5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 78, ": ", $CellContext`r^4 - (2 $CellContext`r^3) $CellContext`R - (
     4 $CellContext`r^2) $CellContext`R^2 + (
      16 $CellContext`r) $CellContext`R^3 - $CellContext`R^2 $CellContext`s^2 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295156542788`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2491e3e9-e854-4e5a-ba60-8f4f73c02550"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"20", " ", "r", " ", "R"}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 79, ": ", 
   4 $CellContext`r^2 + (20 $CellContext`r) $CellContext`R + 
    27 $CellContext`R^2 - 8 $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295158783693`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"9a345d20-355b-4b76-ac25-c65cda43ce5e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 80, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295159513607`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"97d88440-8839-4894-805b-d72c2f7b74dd"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 81, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      20 $CellContext`r^2) $CellContext`R^2 + (
      16 $CellContext`r) $CellContext`R^3 - (
     2 $CellContext`r^2) $CellContext`s^2 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 - $CellContext`R^2 \
$CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295161505823`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"fc427275-0810-4818-a095-32c0c94e1c96"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"9", " ", 
      SuperscriptBox["r", "8"]}], "+", 
     RowBox[{"134", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "+", 
     RowBox[{"760", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"2016", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"2432", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"1024", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"266", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"953", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1184", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"320", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"154", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"222", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"32", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"22", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 82, ": ", 
   9 $CellContext`r^8 + (134 $CellContext`r^7) $CellContext`R + (
      760 $CellContext`r^6) $CellContext`R^2 + (
      2016 $CellContext`r^5) $CellContext`R^3 + (
      2432 $CellContext`r^4) $CellContext`R^4 + (
      1024 $CellContext`r^3) $CellContext`R^5 - (
     24 $CellContext`r^6) $CellContext`s^2 - ((
      266 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
      953 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
      1184 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
      320 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 + (
      22 $CellContext`r^4) $CellContext`s^4 + ((
       154 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
       222 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
       32 $CellContext`r) $CellContext`R^3) $CellContext`s^4 - (
     8 $CellContext`r^2) $CellContext`s^6 - ((
      22 $CellContext`r) $CellContext`R) $CellContext`s^6 - $CellContext`R^2 \
$CellContext`s^6 + $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829517104993*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"d84330b4-593c-4965-9a88-f5d56bb4b4d0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"16", " ", 
      SuperscriptBox["r", "10"]}], "+", 
     RowBox[{"320", " ", 
      SuperscriptBox["r", "9"], " ", "R"}], "+", 
     RowBox[{"2560", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"10240", " ", 
      SuperscriptBox["r", "7"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"20480", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"16384", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"81", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1112", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"5840", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"14080", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"13312", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"76", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"1080", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"3808", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4096", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"54", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"520", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"592", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}], "+", 
     RowBox[{"40", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "8"]}], "-", 
     SuperscriptBox["s", "10"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 83, ": ", 
   16 $CellContext`r^10 + (320 $CellContext`r^9) $CellContext`R + (
      2560 $CellContext`r^8) $CellContext`R^2 + (
      10240 $CellContext`r^7) $CellContext`R^3 + (
      20480 $CellContext`r^6) $CellContext`R^4 + (
      16384 $CellContext`r^5) $CellContext`R^5 - (
     81 $CellContext`r^8) $CellContext`s^2 - ((
      1112 $CellContext`r^7) $CellContext`R) $CellContext`s^2 - ((
      5840 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 - ((
      14080 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      13312 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 + (
      76 $CellContext`r^6) $CellContext`s^4 + ((
       1080 $CellContext`r^5) $CellContext`R) $CellContext`s^4 + ((
       3808 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       4096 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 - (
     54 $CellContext`r^4) $CellContext`s^6 - ((
      520 $CellContext`r^3) $CellContext`R) $CellContext`s^6 - ((
      592 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 + (
      28 $CellContext`r^2) $CellContext`s^8 + ((
       40 $CellContext`r) $CellContext`R) $CellContext`s^8 - \
$CellContext`s^10 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248295240359993`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"3ee9d1a1-17ff-4999-80a0-c9b54cab1a51"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 84, ": ", $CellContext`r^4 + (4 $CellContext`r^3) $CellContext`R + (
      8 $CellContext`r^2) $CellContext`R^2 - 
    16 $CellContext`R^4 - ((
      4 $CellContext`r) $CellContext`R) $CellContext`s^2 + (
      4 $CellContext`R^2) $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829524687769*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"c07b489e-91ba-42d4-95f1-551641a594ba"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 85, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      16 $CellContext`r^2) $CellContext`R^2 + (
      2 $CellContext`r^2) $CellContext`s^2 - ((
      24 $CellContext`r) $CellContext`R) $CellContext`s^2 + $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829524870556*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"58031dd0-8a6e-403b-a478-c836a09202a3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"7", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 86, ": ", 
   7 $CellContext`r^4 + (16 $CellContext`r^3) $CellContext`R + (
      22 $CellContext`r^2) $CellContext`s^2 + ((
       16 $CellContext`r) $CellContext`R) $CellContext`s^2 - $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829525035324*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"4d57d395-e59d-4850-a473-256e0acf2129"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"64", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"20", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"64", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"20", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 87, ": ", ($CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
       64 $CellContext`r^2) $CellContext`R^2 + (
       2 $CellContext`r^2) $CellContext`s^2 - ((
       20 $CellContext`r) $CellContext`R) $CellContext`s^2 + \
$CellContext`s^4) ($CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
       48 $CellContext`r^2) $CellContext`R^2 + (
       64 $CellContext`r) $CellContext`R^3 + (
       2 $CellContext`r^2) $CellContext`s^2 - ((
       20 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
      16 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829525497601*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"cac50e81-54b6-46ee-bcbf-f486c82ad458"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 88, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829525586808*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"648763d5-73b2-4274-baf6-6f2fb055ed58"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"36", " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"216", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"324", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"144", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"9", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 89, ": ", 
   36 $CellContext`r^4 + (216 $CellContext`r^3) $CellContext`R + (
      324 $CellContext`r^2) $CellContext`R^2 + (
      144 $CellContext`r) $CellContext`R^3 - (
     24 $CellContext`r^2) $CellContext`s^2 - ((
      24 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     9 $CellContext`R^2) $CellContext`s^2 + 4 $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829525866477*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"af9cc69b-1bf8-408d-a14a-ef600cc3ba4f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"20", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"4", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 90, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      22 $CellContext`r^2) $CellContext`R^2 + (
      20 $CellContext`r) $CellContext`R^3 - 
    3 $CellContext`R^4 - ((4 $CellContext`r) $CellContext`R) $CellContext`s^2 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482952654742*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"48bf66c9-80e6-455e-99df-e8d794069022"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["r", "5"], " ", "R"}], "+", 
     RowBox[{"17", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"56", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"92", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"72", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"42", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"72", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"18", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     SuperscriptBox["s", "6"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 91, ": ", (2 $CellContext`r^5) $CellContext`R + (
      17 $CellContext`r^4) $CellContext`R^2 + (
      56 $CellContext`r^3) $CellContext`R^3 + (
      92 $CellContext`r^2) $CellContext`R^4 + (
      72 $CellContext`r) $CellContext`R^5 + 
    4 $CellContext`R^6 - $CellContext`r^4 $CellContext`s^2 - ((
      12 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      42 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      72 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     8 $CellContext`R^4) $CellContext`s^2 - (
     2 $CellContext`r^2) $CellContext`s^4 + ((
       18 $CellContext`r) $CellContext`R) $CellContext`s^4 + (
      5 $CellContext`R^2) $CellContext`s^4 - $CellContext`s^6 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482952749428*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"60de870c-0973-498f-9f85-addfbcb30ec3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"16", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"128", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"320", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"88", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"160", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     SuperscriptBox["s", "6"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 92, ": ", (16 $CellContext`r^4) $CellContext`R^2 + (
      128 $CellContext`r^3) $CellContext`R^3 + (
      320 $CellContext`r^2) $CellContext`R^4 + (
      256 $CellContext`r) $CellContext`R^5 - $CellContext`r^4 \
$CellContext`s^2 - ((8 $CellContext`r^3) $CellContext`R) $CellContext`s^2 - ((
      88 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 - ((
      160 $CellContext`r) $CellContext`R^3) $CellContext`s^2 - (
     16 $CellContext`R^4) $CellContext`s^2 - (
     2 $CellContext`r^2) $CellContext`s^4 + ((
       24 $CellContext`r) $CellContext`R) $CellContext`s^4 + (
      8 $CellContext`R^2) $CellContext`s^4 - $CellContext`s^6 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482952795993*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"01971f48-6696-4494-8613-d3f1b4d4e979"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "7"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"154", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"404", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"442", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "6"]}], "-", 
     RowBox[{"68", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "7"]}], "-", 
     RowBox[{"478", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "8"]}], "-", 
     RowBox[{"236", " ", "r", " ", 
      SuperscriptBox["R", "9"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "10"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"180", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"428", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"144", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"1064", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"660", " ", "r", " ", 
      SuperscriptBox["R", "7"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["R", "8"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"104", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"678", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"612", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"34", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"40", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"100", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"212", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}], "-", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "8"]}], "-", 
     RowBox[{"10", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "8"]}], "+", 
     SuperscriptBox["s", "10"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 93, ": ", (2 $CellContext`r^8) $CellContext`R^2 + (
      28 $CellContext`r^7) $CellContext`R^3 + (
      154 $CellContext`r^6) $CellContext`R^4 + (
      404 $CellContext`r^5) $CellContext`R^5 + (
      442 $CellContext`r^4) $CellContext`R^6 - (
     68 $CellContext`r^3) $CellContext`R^7 - (
     478 $CellContext`r^2) $CellContext`R^8 - (
     236 $CellContext`r) $CellContext`R^9 + 
    4 $CellContext`R^10 + $CellContext`r^8 $CellContext`s^2 + ((
       8 $CellContext`r^7) $CellContext`R) $CellContext`s^2 - ((
      4 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 - ((
      180 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      428 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 + ((
       144 $CellContext`r^3) $CellContext`R^5) $CellContext`s^2 + ((
       1064 $CellContext`r^2) $CellContext`R^6) $CellContext`s^2 + ((
       660 $CellContext`r) $CellContext`R^7) $CellContext`s^2 + (
      7 $CellContext`R^8) $CellContext`s^2 + (
      4 $CellContext`r^6) $CellContext`s^4 - ((
      8 $CellContext`r^5) $CellContext`R) $CellContext`s^4 + ((
       104 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       4 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 - ((
      678 $CellContext`r^2) $CellContext`R^4) $CellContext`s^4 - ((
      612 $CellContext`r) $CellContext`R^5) $CellContext`s^4 - (
     34 $CellContext`R^6) $CellContext`s^4 + (
      6 $CellContext`r^4) $CellContext`s^6 - ((
      40 $CellContext`r^3) $CellContext`R) $CellContext`s^6 + ((
       100 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 + ((
       212 $CellContext`r) $CellContext`R^3) $CellContext`s^6 + (
      32 $CellContext`R^4) $CellContext`s^6 + (
      4 $CellContext`r^2) $CellContext`s^8 - ((
      24 $CellContext`r) $CellContext`R) $CellContext`s^8 - (
     10 $CellContext`R^2) $CellContext`s^8 + $CellContext`s^10 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829533979146*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"bf446cea-e3a1-4565-9a4d-0c7c2c52c906"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"36", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"432", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"1944", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "6"]}], "+", 
     RowBox[{"4032", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "7"]}], "+", 
     RowBox[{"3780", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "8"]}], "+", 
     RowBox[{"1296", " ", "r", " ", 
      SuperscriptBox["R", "9"]}], "-", 
     RowBox[{
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"120", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"78", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2040", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"3708", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1944", " ", "r", " ", 
      SuperscriptBox["R", "7"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"81", " ", 
      SuperscriptBox["R", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"124", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"112", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"1176", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"1080", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"108", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"40", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"108", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"264", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"54", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}], "+", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "8"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "8"]}], "-", 
     SuperscriptBox["s", "10"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 94, ": ", (36 $CellContext`r^6) $CellContext`R^4 + (
      432 $CellContext`r^5) $CellContext`R^5 + (
      1944 $CellContext`r^4) $CellContext`R^6 + (
      4032 $CellContext`r^3) $CellContext`R^7 + (
      3780 $CellContext`r^2) $CellContext`R^8 + (
      1296 $CellContext`r) $CellContext`R^9 - $CellContext`r^8 \
$CellContext`s^2 - ((8 $CellContext`r^7) $CellContext`R) $CellContext`s^2 - ((
      4 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 + ((
       120 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      78 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 - ((
      2040 $CellContext`r^3) $CellContext`R^5) $CellContext`s^2 - ((
      3708 $CellContext`r^2) $CellContext`R^6) $CellContext`s^2 - ((
      1944 $CellContext`r) $CellContext`R^7) $CellContext`s^2 - (
     81 $CellContext`R^8) $CellContext`s^2 - (
     4 $CellContext`r^6) $CellContext`s^4 + ((
       8 $CellContext`r^5) $CellContext`R) $CellContext`s^4 - ((
      124 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       112 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 + ((
       1176 $CellContext`r^2) $CellContext`R^4) $CellContext`s^4 + ((
       1080 $CellContext`r) $CellContext`R^5) $CellContext`s^4 + (
      108 $CellContext`R^6) $CellContext`s^4 - (
     6 $CellContext`r^4) $CellContext`s^6 + ((
       40 $CellContext`r^3) $CellContext`R) $CellContext`s^6 - ((
      108 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 - ((
      264 $CellContext`r) $CellContext`R^3) $CellContext`s^6 - (
     54 $CellContext`R^4) $CellContext`s^6 - (
     4 $CellContext`r^2) $CellContext`s^8 + ((
       24 $CellContext`r) $CellContext`R) $CellContext`s^8 + (
      12 $CellContext`R^2) $CellContext`s^8 - $CellContext`s^10 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829562111281*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"17d9978e-6cf6-4ab2-a24f-a5e5633f2aa7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "15"}], " ", 
      SuperscriptBox["r", "8"]}], "-", 
     RowBox[{"152", " ", 
      SuperscriptBox["r", "7"], " ", "R"}], "-", 
     RowBox[{"584", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"1056", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"880", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"256", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"]}], "-", 
     RowBox[{"268", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"456", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"1256", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"896", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"416", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"328", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"40", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"160", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"24", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     SuperscriptBox["s", "8"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 95, ": ", (-15) $CellContext`r^8 - (
     152 $CellContext`r^7) $CellContext`R - (
     584 $CellContext`r^6) $CellContext`R^2 - (
     1056 $CellContext`r^5) $CellContext`R^3 - (
     880 $CellContext`r^4) $CellContext`R^4 - (
     256 $CellContext`r^3) $CellContext`R^5 - (
     268 $CellContext`r^6) $CellContext`s^2 - ((
      456 $CellContext`r^5) $CellContext`R) $CellContext`s^2 + ((
       1256 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 + ((
       896 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
      416 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 - ((
      256 $CellContext`r) $CellContext`R^5) $CellContext`s^2 + (
      22 $CellContext`r^4) $CellContext`s^4 - ((
      328 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
       40 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
       160 $CellContext`r) $CellContext`R^3) $CellContext`s^4 + (
      16 $CellContext`R^4) $CellContext`s^4 + (
      20 $CellContext`r^2) $CellContext`s^6 - ((
      24 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
     8 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829569199708*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"25140cef-85ab-40fe-8528-faba213e1c1f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"-", "2"}], " ", 
      SuperscriptBox["r", "10"]}], "-", 
     RowBox[{"36", " ", 
      SuperscriptBox["r", "9"], " ", "R"}], "-", 
     RowBox[{"252", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"816", " ", 
      SuperscriptBox["r", "7"], " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"896", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"1536", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"5280", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "6"]}], "+", 
     RowBox[{"5312", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "7"]}], "+", 
     RowBox[{"2464", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "8"]}], "+", 
     RowBox[{"576", " ", "r", " ", 
      SuperscriptBox["R", "9"]}], "+", 
     RowBox[{"64", " ", 
      SuperscriptBox["R", "10"]}], "+", 
     RowBox[{"39", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"424", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"1512", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"1376", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2616", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"5216", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"3360", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1024", " ", "r", " ", 
      SuperscriptBox["R", "7"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"144", " ", 
      SuperscriptBox["R", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"160", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"688", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"48", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"1488", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"1552", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"672", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"128", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"66", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"104", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"264", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"192", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"56", " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{"10", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}], "+", 
     RowBox[{"20", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "8"]}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "8"]}], "-", 
     SuperscriptBox["s", "10"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 96, ": ", (-2) $CellContext`r^10 - (
     36 $CellContext`r^9) $CellContext`R - (
     252 $CellContext`r^8) $CellContext`R^2 - (
     816 $CellContext`r^7) $CellContext`R^3 - (
     896 $CellContext`r^6) $CellContext`R^4 + (
      1536 $CellContext`r^5) $CellContext`R^5 + (
      5280 $CellContext`r^4) $CellContext`R^6 + (
      5312 $CellContext`r^3) $CellContext`R^7 + (
      2464 $CellContext`r^2) $CellContext`R^8 + (
      576 $CellContext`r) $CellContext`R^9 + 
    64 $CellContext`R^10 + (
      39 $CellContext`r^8) $CellContext`s^2 + ((
       424 $CellContext`r^7) $CellContext`R) $CellContext`s^2 + ((
       1512 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 + ((
       1376 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      2616 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 - ((
      5216 $CellContext`r^3) $CellContext`R^5) $CellContext`s^2 - ((
      3360 $CellContext`r^2) $CellContext`R^6) $CellContext`s^2 - ((
      1024 $CellContext`r) $CellContext`R^7) $CellContext`s^2 - (
     144 $CellContext`R^8) $CellContext`s^2 - (
     160 $CellContext`r^6) $CellContext`s^4 - ((
      688 $CellContext`r^5) $CellContext`R) $CellContext`s^4 - ((
      48 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       1488 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 + ((
       1552 $CellContext`r^2) $CellContext`R^4) $CellContext`s^4 + ((
       672 $CellContext`r) $CellContext`R^5) $CellContext`s^4 + (
      128 $CellContext`R^6) $CellContext`s^4 + (
      66 $CellContext`r^4) $CellContext`s^6 - ((
      104 $CellContext`r^3) $CellContext`R) $CellContext`s^6 - ((
      264 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 - ((
      192 $CellContext`r) $CellContext`R^3) $CellContext`s^6 - (
     56 $CellContext`R^4) $CellContext`s^6 + (
      10 $CellContext`r^2) $CellContext`s^8 + ((
       20 $CellContext`r) $CellContext`R) $CellContext`s^8 + (
      12 $CellContext`R^2) $CellContext`s^8 - $CellContext`s^10 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829584219845*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"681d1409-ca90-4265-9b04-a08f21866cc2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "10"], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "9"], " ", "R"}], "+", 
     RowBox[{"172", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"832", " ", 
      SuperscriptBox["r", "7"], " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"2484", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"4720", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "5"]}], "+", 
     RowBox[{"5664", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "6"]}], "+", 
     RowBox[{"4096", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "7"]}], "+", 
     RowBox[{"1600", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "8"]}], "+", 
     RowBox[{"256", " ", "r", " ", 
      SuperscriptBox["R", "9"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "8"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"148", " ", 
      SuperscriptBox["r", "7"], " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"736", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1900", " ", 
      SuperscriptBox["r", "5"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2745", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2248", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"1016", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"224", " ", "r", " ", 
      SuperscriptBox["R", "7"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"16", " ", 
      SuperscriptBox["R", "8"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"38", " ", 
      SuperscriptBox["r", "6"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"188", " ", 
      SuperscriptBox["r", "5"], " ", "R", " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"380", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"432", " ", 
      SuperscriptBox["r", "3"], " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"230", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"56", " ", "r", " ", 
      SuperscriptBox["R", "5"], " ", 
      SuperscriptBox["s", "4"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "6"], " ", 
      SuperscriptBox["s", "4"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "4"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "3"], " ", "R", " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{"4", " ", "r", " ", 
      SuperscriptBox["R", "3"], " ", 
      SuperscriptBox["s", "6"]}], "-", 
     RowBox[{
      SuperscriptBox["R", "4"], " ", 
      SuperscriptBox["s", "6"]}], "+", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "8"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 97, ": ", $CellContext`r^10 + (20 $CellContext`r^9) $CellContext`R + (
      172 $CellContext`r^8) $CellContext`R^2 + (
      832 $CellContext`r^7) $CellContext`R^3 + (
      2484 $CellContext`r^6) $CellContext`R^4 + (
      4720 $CellContext`r^5) $CellContext`R^5 + (
      5664 $CellContext`r^4) $CellContext`R^6 + (
      4096 $CellContext`r^3) $CellContext`R^7 + (
      1600 $CellContext`r^2) $CellContext`R^8 + (
      256 $CellContext`r) $CellContext`R^9 - (
     12 $CellContext`r^8) $CellContext`s^2 - ((
      148 $CellContext`r^7) $CellContext`R) $CellContext`s^2 - ((
      736 $CellContext`r^6) $CellContext`R^2) $CellContext`s^2 - ((
      1900 $CellContext`r^5) $CellContext`R^3) $CellContext`s^2 - ((
      2745 $CellContext`r^4) $CellContext`R^4) $CellContext`s^2 - ((
      2248 $CellContext`r^3) $CellContext`R^5) $CellContext`s^2 - ((
      1016 $CellContext`r^2) $CellContext`R^6) $CellContext`s^2 - ((
      224 $CellContext`r) $CellContext`R^7) $CellContext`s^2 - (
     16 $CellContext`R^8) $CellContext`s^2 + (
      38 $CellContext`r^6) $CellContext`s^4 + ((
       188 $CellContext`r^5) $CellContext`R) $CellContext`s^4 + ((
       380 $CellContext`r^4) $CellContext`R^2) $CellContext`s^4 + ((
       432 $CellContext`r^3) $CellContext`R^3) $CellContext`s^4 + ((
       230 $CellContext`r^2) $CellContext`R^4) $CellContext`s^4 + ((
       56 $CellContext`r) $CellContext`R^5) $CellContext`s^4 + (
      8 $CellContext`R^6) $CellContext`s^4 - (
     12 $CellContext`r^4) $CellContext`s^6 - ((
      28 $CellContext`r^3) $CellContext`R) $CellContext`s^6 - ((
      24 $CellContext`r^2) $CellContext`R^2) $CellContext`s^6 - ((
      4 $CellContext`r) $CellContext`R^3) $CellContext`s^6 - $CellContext`R^4 \
$CellContext`s^6 + $CellContext`r^2 $CellContext`s^8 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829630908469*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2ac57115-1311-445a-82e3-0cb84ef0916d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 98, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.8248296311193533`*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"602686ca-af6b-4976-a5d7-0c6483146a18"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 99, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829631220997*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"ae183a54-c825-4934-a3f5-494b4b2ef766"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" can never lie on the incircle.\"\>"}],
  SequenceForm["X", 100, " can never lie on the incircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.824829631275886*^9},
 CellLabel->
  "During evaluation of \
In[424]:=",ExpressionUUID->"2ed8b8d7-10d2-446f-bd96-cd00c80110bd"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Condition for Center To Lie on Circumcircle", "Section",
 CellChangeTimes->{{3.824729812416472*^9, 3.824729830635277*^9}, {
  3.82472987891963*^9, 3.824729880399238*^9}, {3.824729921591786*^9, 
  3.824729944583457*^9}, {3.824730183592462*^9, 3.824730194584065*^9}, {
  3.824815791230557*^9, 3.824815814654079*^9}, {3.824819861490974*^9, 
  3.824819879546664*^9}, {3.824827091200869*^9, 
  3.8248270925685453`*^9}},ExpressionUUID->"9ce664cb-1b1c-49b3-92a3-\
87ce80434cd9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "condition", " ", "for", " ", "center", " ", "to", " ", "lie",
     " ", "on", " ", "circumcircle"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"For", "[", 
    RowBox[{
     RowBox[{"i", "=", "1"}], ",", 
     RowBox[{"i", "\[LessEqual]", "100"}], ",", 
     RowBox[{"i", "++"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"u", ",", "v", ",", "w"}], "}"}], "=", 
       RowBox[{
        RowBox[{
         RowBox[{"x", "[", "i", "]"}], "/.", 
         RowBox[{"S", "\[Rule]", 
          RowBox[{"2", 
           RowBox[{"Sqrt", "[", 
            RowBox[{"s", 
             RowBox[{"(", 
              RowBox[{"s", "-", "a"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "b"}], ")"}], 
             RowBox[{"(", 
              RowBox[{"s", "-", "c"}], ")"}]}], "]"}]}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"triang", "=", 
       RowBox[{
        RowBox[{"a", ">", "0"}], "&&", 
        RowBox[{"b", ">", "0"}], "&&", 
        RowBox[{"c", ">", "0"}], "&&", 
        RowBox[{
         RowBox[{"a", "+", "b"}], ">", "c"}], "&&", 
        RowBox[{
         RowBox[{"b", "+", "c"}], ">", "a"}], "&&", 
        RowBox[{
         RowBox[{"c", "+", "a"}], ">", "b"}]}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"Rsq", "=", 
       RowBox[{
        RowBox[{
         RowBox[{"a", "^", "2"}], 
         RowBox[{"b", "^", "2"}], 
         RowBox[{
          RowBox[{"c", "^", "2"}], "/", 
          RowBox[{"(", 
           RowBox[{"16", "s", 
            RowBox[{"(", 
             RowBox[{"s", "-", "a"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"s", "-", "b"}], ")"}], 
            RowBox[{"(", 
             RowBox[{"s", "-", "c"}], ")"}]}], ")"}]}]}], "/.", 
        RowBox[{"s", "\[Rule]", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"a", "+", "b", "+", "c"}], ")"}], "/", "2"}]}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"distsq", "=", 
       RowBox[{"squaredDistance", "[", 
        RowBox[{
         RowBox[{"x", "[", "3", "]"}], ",", 
         RowBox[{"x", "[", "i", "]"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"in", "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"distsq", "<", "Rsq"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"out", "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", 
        RowBox[{"distsq", ">", "Rsq"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"in", "||", "out"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< can never lie on the circumcircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"condo", "=", 
       RowBox[{"distsq", "\[Equal]", "Rsq"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"cond", "=", 
       RowBox[{"proveTriangleInequalityUsingBlundon", "[", "condo", "]"}]}], 
      ";", "\[IndentingNewLine]", 
      RowBox[{"cond", "=", 
       RowBox[{"Simplify", "[", "cond", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"cond", "\[Equal]", "True"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< must lie on the circumcircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"cond", "\[Equal]", "False"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< can never lie on the circumcircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cond2", "=", 
       RowBox[{"Together", "[", 
        RowBox[{"Simplify", "[", 
         RowBox[{"cond", "/.", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "\[Rule]", 
             RowBox[{"r", "/", "R"}]}], ",", 
            RowBox[{"y", "\[Rule]", 
             RowBox[{"s", "/", "R"}]}]}], "}"}]}], "]"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"xcond", "=", 
       RowBox[{"Simplify", "[", 
        RowBox[{
         RowBox[{"cond2", "\[Equal]", "0"}], ",", 
         RowBox[{
          RowBox[{"r", ">", "0"}], "&&", 
          RowBox[{"s", ">", "0"}], "&&", 
          RowBox[{"R", ">", "0"}]}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"xcond", "\[Equal]", "True"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< must lie on the circumcircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"xcond", "\[Equal]", "False"}], ",", 
        RowBox[{
         RowBox[{"Print", "[", 
          RowBox[{
          "\"\<X\>\"", ",", "i", ",", 
           "\"\< can never lie on the circumcircle.\>\""}], "]"}], ";", 
         RowBox[{"Continue", "[", "]"}]}]}], "]"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"cond3", "=", 
       RowBox[{
        RowBox[{"First", "[", "xcond", "]"}], "-", 
        RowBox[{"Last", "[", "xcond", "]"}]}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"num", "=", 
       RowBox[{"Numerator", "[", "cond3", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"den", "=", 
       RowBox[{"Denominator", "[", "cond3", "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"Print", "[", 
       RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\<: \>\"", ",", 
        RowBox[{
         RowBox[{"Factor", "[", "num", "]"}], "\[Equal]", "0"}]}], "]"}], ";",
       "\[IndentingNewLine]", 
      RowBox[{"vars", "=", 
       RowBox[{"Variables", "[", "cond", "]"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"Length", "[", "vars", "]"}], "\[Equal]", "1"}], ",", 
        RowBox[{
         RowBox[{"var", "=", 
          RowBox[{"vars", "[", 
           RowBox[{"[", "1", "]"}], "]"}]}], ";", 
         RowBox[{"Print", "[", 
          RowBox[{"\"\<X\>\"", ",", "i", ",", "\"\<: \>\"", ",", 
           RowBox[{"Solve", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"cond", "\[Equal]", "0"}], "&&", 
              RowBox[{"var", "\[NotEqual]", "0"}]}], ",", "var"}], "]"}]}], 
          "]"}]}]}], "]"}], ";"}]}], "\[IndentingNewLine]", "]"}], 
   ";"}]}]], "Input",
 CellChangeTimes->{{3.824819899043454*^9, 3.824819910890819*^9}, {
   3.8248199446118917`*^9, 3.8248201437077293`*^9}, {3.824820245061442*^9, 
   3.8248202507644672`*^9}, 3.8248203756066933`*^9, {3.8248204309427757`*^9, 
   3.8248204535648413`*^9}, 3.824820488438923*^9, {3.8248205322949543`*^9, 
   3.8248205340856047`*^9}, {3.824821024008523*^9, 3.8248210261270123`*^9}, {
   3.8248210671200113`*^9, 3.82482111187914*^9}, 3.82482114357743*^9, 
   3.824821498259761*^9, {3.8248215353205748`*^9, 3.8248215400085087`*^9}, {
   3.8248217104609957`*^9, 3.824821715865245*^9}, {3.824822008971191*^9, 
   3.824822184970585*^9}, 3.824822290933918*^9, {3.824822354324057*^9, 
   3.82482235673878*^9}, {3.8248224311897497`*^9, 3.8248224332915907`*^9}, {
   3.8248230714862947`*^9, 3.824823126877672*^9}, {3.824823203882504*^9, 
   3.824823234863633*^9}, {3.824823290879771*^9, 3.824823344414423*^9}, {
   3.824823390879559*^9, 3.824823454834103*^9}, {3.8248235244009743`*^9, 
   3.824823525007022*^9}, {3.824823557160995*^9, 3.824823559799274*^9}, {
   3.8248236130095167`*^9, 3.824823641783259*^9}, {3.824823744490122*^9, 
   3.824823745487544*^9}, {3.82482454183596*^9, 3.8248245502191277`*^9}, {
   3.824826183664826*^9, 3.824826233439621*^9}, {3.824826263639901*^9, 
   3.8248262927118673`*^9}, {3.8248269808610086`*^9, 3.824826987681491*^9}, {
   3.824827099315085*^9, 3.824827125229443*^9}, 3.824828662213231*^9, {
   3.8248287327194223`*^9, 3.824828761215345*^9}, {3.824828793791444*^9, 
   3.824828800599268*^9}, {3.824829119897756*^9, 3.8248292169563313`*^9}, {
   3.824829257766465*^9, 3.8248292705371313`*^9}},
 CellLabel->
  "In[423]:=",ExpressionUUID->"a1629a2b-d531-4108-9782-01c8c3a4c247"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 1, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272486062*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"f87a5950-ce5d-45df-aef5-0e086bf88ce9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "2", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 2, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292725335703`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"f8e4dee3-b40f-4418-9fba-d35dd0e791ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "3", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 3, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272535747*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"39735b56-dfaa-49c8-a14e-6054f8b15e90"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 4, ": ", ($CellContext`r + 
     2 $CellContext`R - $CellContext`s) ($CellContext`r + 
     2 $CellContext`R + $CellContext`s) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272621479*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"a9a0df59-ca30-4252-a58e-ca09beb8251a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "5", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"]}], "+", 
     RowBox[{"8", " ", "r", " ", "R"}], "+", 
     RowBox[{"5", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 5, ": ", 
   2 $CellContext`r^2 + (8 $CellContext`r) $CellContext`R + 
    5 $CellContext`R^2 - 2 $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272708907*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"a7a7d2cc-1dc4-4cc7-a9e8-67ac2b1b1df4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "6", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 6, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272771018*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"3eb7a338-a23f-44b2-8dba-133074709dae"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "7", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 7, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272842024*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"1cbf82d2-ef81-4121-9aef-7c2ad3d46fe6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "8", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 8, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272843609*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"929dbb38-dd83-4525-a533-c27b587715e3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "9", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 9, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272918498*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"4471de10-bca8-4118-9dac-c5c40bebc5a7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "10", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 10, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829272920033*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"3e40e540-813a-4add-881c-4f1567d1d039"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "11", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 11, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292730066767`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"e5856f58-0b01-4db8-b32b-b43ba7bfda05"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "12", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 12, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.82482927309199*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"5a48b65d-5d15-48bd-b6b4-e9ec2aedf428"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "13", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"19", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"12", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "-", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "-", 
     RowBox[{"18", " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"3", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"8", " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 13, ": ", 
   3^Rational[1, 2] $CellContext`r^4 + ((8 
       3^Rational[1, 2]) $CellContext`r^3) $CellContext`R + ((19 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`R^2 + ((12 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^3 - (
     8 $CellContext`r^3) $CellContext`s - ((
      32 $CellContext`r^2) $CellContext`R) $CellContext`s - ((
      18 $CellContext`r) $CellContext`R^2) $CellContext`s + ((2 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`s^2 - (((8 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R) $CellContext`s^2 - ((
      3 3^Rational[1, 2]) $CellContext`R^2) $CellContext`s^2 + (
      8 $CellContext`r) $CellContext`s^3 + 3^Rational[1, 2] $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829273884472*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"1109c3ef-a5d7-4040-9ba6-738fb8c1d0a6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "14", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"19", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"12", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "+", 
     RowBox[{"18", " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"3", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 14, ": ", 
   3^Rational[1, 2] $CellContext`r^4 + ((8 
       3^Rational[1, 2]) $CellContext`r^3) $CellContext`R + ((19 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`R^2 + ((12 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^3 + (
      8 $CellContext`r^3) $CellContext`s + ((
       32 $CellContext`r^2) $CellContext`R) $CellContext`s + ((
       18 $CellContext`r) $CellContext`R^2) $CellContext`s + ((2 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`s^2 - (((8 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R) $CellContext`s^2 - ((
      3 3^Rational[1, 2]) $CellContext`R^2) $CellContext`s^2 - (
     8 $CellContext`r) $CellContext`s^3 + 3^Rational[1, 2] $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829274638069*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"f2609042-b433-4691-a442-cbd01e0e7262"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "15", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 15, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829274763864*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"a10f3637-2584-404f-a6e2-a687f63c5e8d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "16", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 16, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829274926646*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"89f80e72-5a66-4fb7-afac-2d9ecab90cec"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "17", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"17", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "-", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "-", 
     RowBox[{"2", " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     RowBox[{"8", " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 17, ": ", 
   3^Rational[1, 2] $CellContext`r^4 + ((8 
       3^Rational[1, 2]) $CellContext`r^3) $CellContext`R + ((17 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`R^2 + ((4 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^3 - (
     8 $CellContext`r^3) $CellContext`s - ((
      32 $CellContext`r^2) $CellContext`R) $CellContext`s - ((
      2 $CellContext`r) $CellContext`R^2) $CellContext`s + ((2 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`s^2 - (((8 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     3^Rational[1, 2] $CellContext`R^2) $CellContext`s^2 + (
      8 $CellContext`r) $CellContext`s^3 + 3^Rational[1, 2] $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829275847777*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"5aa9f8e8-e591-4e16-b477-b15a2ad07c32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "18", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "4"]}], "+", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"17", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"4", " ", 
      SqrtBox["3"], " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "s"}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", "R", " ", "s"}], "+", 
     RowBox[{"2", " ", "r", " ", 
      SuperscriptBox["R", "2"], " ", "s"}], "+", 
     RowBox[{"2", " ", 
      SqrtBox["3"], " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SqrtBox["3"], " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", 
      SuperscriptBox["s", "3"]}], "+", 
     RowBox[{
      SqrtBox["3"], " ", 
      SuperscriptBox["s", "4"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 18, ": ", 
   3^Rational[1, 2] $CellContext`r^4 + ((8 
       3^Rational[1, 2]) $CellContext`r^3) $CellContext`R + ((17 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`R^2 + ((4 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R^3 + (
      8 $CellContext`r^3) $CellContext`s + ((
       32 $CellContext`r^2) $CellContext`R) $CellContext`s + ((
       2 $CellContext`r) $CellContext`R^2) $CellContext`s + ((2 
       3^Rational[1, 2]) $CellContext`r^2) $CellContext`s^2 - (((8 
       3^Rational[1, 2]) $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     3^Rational[1, 2] $CellContext`R^2) $CellContext`s^2 - (
     8 $CellContext`r) $CellContext`s^3 + 3^Rational[1, 2] $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292766001863`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"65f41cbf-442c-44ef-83bd-e05f42e85bda"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "19", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 19, ": ", ($CellContext`r + 
     2 $CellContext`R - $CellContext`s) ($CellContext`r + 
     2 $CellContext`R + $CellContext`s) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829276770026*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"93a95566-2f38-4ac2-b709-ede8acf41de2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "20", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 20, ": ", ($CellContext`r + 
     2 $CellContext`R - $CellContext`s) ($CellContext`r + 
     2 $CellContext`R + $CellContext`s) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829276884171*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"b43e6ae3-d674-49f6-a665-262e16643751"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "21", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 21, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829277010026*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"0a89f7e3-4159-4237-886a-33014f56374e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "22", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 22, ": ", (($CellContext`r + 
      2 $CellContext`R - $CellContext`s) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r^2 + (
       4 $CellContext`r) $CellContext`R - $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292771634407`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"fd8afac9-359c-415a-9d22-ed8f937b4174"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "23", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 23, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829277277562*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"f535da30-7467-4739-bc51-16ec0246fd19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "24", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 24, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829277435369*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"0487d180-30da-4c42-b34b-09635b125279"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "25", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 25, ": ", (($CellContext`r + 
      2 $CellContext`R - $CellContext`s) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r^2 + (
       4 $CellContext`r) $CellContext`R - $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829277680772*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"8813785c-a309-47c1-a921-288b0b05ab24"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "26", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"24", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"7", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 26, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      22 $CellContext`r^2) $CellContext`R^2 + (
      24 $CellContext`r) $CellContext`R^3 + 
    7 $CellContext`R^4 - (
     2 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     6 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829278129677*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"307d3060-78a9-4a1e-9a00-17367caa5ec3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "27", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"2", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"6", " ", "r", " ", "R"}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["R", "2"]}], "+", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 27, ": ", ((($CellContext`r + 
       2 $CellContext`R - $CellContext`s) ($CellContext`r + 
       2 $CellContext`R + $CellContext`s)) ($CellContext`r^2 + (
        2 $CellContext`r) $CellContext`R + $CellContext`s^2)) \
($CellContext`r^2 + (6 $CellContext`r) $CellContext`R + 
     8 $CellContext`R^2 + $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829278630373*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"cbdd8c17-5282-4cde-bbb9-ab949f690a60"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "28", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "r"}], "-", 
        RowBox[{"2", " ", "R"}], "+", "s"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"2", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 28, ": ", ((-(-$CellContext`r - 
       2 $CellContext`R + $CellContext`s)) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r^2 + (
       2 $CellContext`r) $CellContext`R + $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829278974283*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"0e336e94-297a-4069-aa69-948dffc4af84"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "29", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{"r", "+", 
        RowBox[{"2", " ", "R"}], "-", "s"}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"2", " ", "r", " ", "R"}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"2", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 29, ": ", (((-($CellContext`r + 
        2 $CellContext`R - $CellContext`s)) ($CellContext`r + 
       2 $CellContext`R + $CellContext`s)) (-$CellContext`r^2 + (
        2 $CellContext`r) $CellContext`R + 
      4 $CellContext`R^2 - $CellContext`s^2)) ($CellContext`r^2 + (
       2 $CellContext`r) $CellContext`R + $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292797972918`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"e7223b38-6eea-441b-9d3b-9d5e47ff645b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "30", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 30, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829279799*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"4a11d5ef-1c01-4b3d-93a3-c3aa59dacf40"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "31", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 31, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829279915386*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"18a066b8-e450-4852-87cd-d64dc7776f3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 32, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829279917194*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"879a27cd-74f4-4bf6-88bc-54e716c07002"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "33", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", "R"}], "+", 
       RowBox[{"4", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 33, ": ", (($CellContext`r + 
      2 $CellContext`R - $CellContext`s) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r $CellContext`R + 
     4 $CellContext`R^2 - $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829280266992*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"1b53304b-1a7d-4569-a197-bc7d6d78af19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "34", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", "R"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 34, ": ", (($CellContext`r - $CellContext`R) ($CellContext`r + 
      2 $CellContext`R - $CellContext`s)) ($CellContext`r + 
     2 $CellContext`R + $CellContext`s) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829280652731*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"3e2c8bfc-3a21-4a17-9f42-11e376def6c3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "35", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 35, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829280769885*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"6bed031c-7775-4ba2-80dd-042fd9e8fa56"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "36", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 36, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829280771522*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"73893276-47c3-4f6c-8f45-f0779152b64f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "37", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 37, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829280910524*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"76cd8c80-a869-473a-b8ac-9abcb1d9052e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "38", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 38, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829280912382*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"fc25ed59-ec31-44b2-a6d1-a72bf676b765"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "39", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 39, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281029031*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"cf9ba40f-a841-44b7-8882-77edb5f40cc4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "40", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 40, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281037595*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"47f2525d-68af-4dc2-8c71-659cd79cac06"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "41", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 41, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281151712*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"c7850b6d-d523-4799-8e6c-05384a413f79"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "42", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 42, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292811533527`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"8264bf63-0da2-4d6c-98ee-9bcc9788e9c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "43", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"20", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 43, ": ", $CellContext`r^4 + (12 $CellContext`r^3) $CellContext`R + (
      32 $CellContext`r^2) $CellContext`R^2 + (
      2 $CellContext`r^2) $CellContext`s^2 - ((
      20 $CellContext`r) $CellContext`R) $CellContext`s^2 + $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281295417*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"7a4f1f4c-da24-471f-ae1c-f7db70853422"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "44", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 44, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281410202*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"50ea506c-1ca4-44e5-ae96-7c7578f51f5d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "45", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 45, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281411978*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"96717e7f-74f2-4b03-8722-25e1e2dad888"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{"2", " ", "r", " ", "R"}], "-", 
     SuperscriptBox["R", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 46, ": ", $CellContext`r^2 + (
      2 $CellContext`r) $CellContext`R - $CellContext`R^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281579626*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"00b84e9c-0528-40e6-a22c-a2c4dcb5af32"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "46", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "-", 
        SqrtBox["2"]}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", "\[Rule]", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SqrtBox["2"]}]}], "}"}]}], "}"}]}],
  SequenceForm[
  "X", 46, ": ", {{$CellContext`x -> -1 - 2^
      Rational[1, 2]}, {$CellContext`x -> -1 + 2^Rational[1, 2]}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281586972*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"3008a2a0-f436-450d-996d-39398c35e5d4"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "47", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "3"], "+", 
     RowBox[{"3", " ", 
      SuperscriptBox["r", "2"], " ", "R"}], "+", 
     RowBox[{"2", " ", "r", " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"r", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"R", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 47, ": ", $CellContext`r^3 + (3 $CellContext`r^2) $CellContext`R + (
      2 $CellContext`r) $CellContext`R^2 + 
    2 $CellContext`R^3 + $CellContext`r $CellContext`s^2 - $CellContext`R \
$CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829281854065*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"c99a522c-e39a-4135-ba50-ecc7589dc2e2"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "48", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"]}], "+", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 48, ": ", $CellContext`r^2 - 4 $CellContext`R^2 + $CellContext`s^2 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292819897823`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"fcfbdec6-dae3-4e8c-b5fa-1230183d4fd7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "49", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"24", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"32", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"13", " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 49, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      24 $CellContext`r^2) $CellContext`R^2 + (
      32 $CellContext`r) $CellContext`R^3 + 
    13 $CellContext`R^4 + (2 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     8 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829282379919*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"247a8047-1c01-41c2-ba5b-0fedd5d2f4c0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "50", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"48", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"27", " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 50, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      28 $CellContext`r^2) $CellContext`R^2 + (
      48 $CellContext`r) $CellContext`R^3 + 
    27 $CellContext`R^4 + (2 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     12 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829282780449*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"4b70706e-3dab-4261-b9ee-576116ea8803"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "51", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"20", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"16", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"18", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 51, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      20 $CellContext`r^2) $CellContext`R^2 + (
      16 $CellContext`r) $CellContext`R^3 + (
      18 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829283013523*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"74659deb-b957-4ee3-9f32-2b1d8c4cf0c5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "52", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"16", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{"14", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 52, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      16 $CellContext`r^2) $CellContext`R^2 - 
    4 $CellContext`R^4 - (
     14 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 + $CellContext`s^4 == 
   0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292833185253`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"ef65587f-b017-40f1-b942-6ef51fb1283b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "53", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"23", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"28", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["R", "4"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"8", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"7", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 53, ": ", (($CellContext`r + 
      2 $CellContext`R - $CellContext`s) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r^4 + (
       8 $CellContext`r^3) $CellContext`R + (
       23 $CellContext`r^2) $CellContext`R^2 + (
       28 $CellContext`r) $CellContext`R^3 + 
     12 $CellContext`R^4 - (
      6 $CellContext`r^2) $CellContext`s^2 - ((
       8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
      7 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292840331917`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"2c9e6da6-6817-4ffa-8db1-41138ead9f80"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "54", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"24", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 54, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      22 $CellContext`r^2) $CellContext`R^2 + (
      24 $CellContext`r) $CellContext`R^3 + 
    8 $CellContext`R^4 + (2 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     6 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829284459766*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"5eb8499c-6535-4087-a06d-29db9a17d058"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "55", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 55, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829284575748*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"044e09fc-98a2-4f11-a790-e442e66ad010"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "56", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 56, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248292845775843`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"72fbbbd4-e234-46d2-ac4d-4f66df0c0c3b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "57", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 57, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829284692017*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"51651cea-c5cd-4761-8246-afcc87ef9058"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "58", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 58, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829284693803*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"163fa8a0-4a6b-4033-b129-1d334d761723"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "59", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 59, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829284911777*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"4f746cd5-6740-4758-a874-2ebe4411eef1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "60", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 60, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829285080208*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"53a0aacd-7141-476e-b343-5920c3c38169"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "61", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 61, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829285259684*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"2e5d2439-54d7-45eb-a997-436f9df6313a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "62", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"27", " ", 
        SuperscriptBox["R", "4"]}], "-", 
       RowBox[{"24", " ", 
        SqrtBox["3"], " ", "r", " ", 
        SuperscriptBox["R", "2"], " ", "s"}], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"12", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"12", " ", 
        SqrtBox["3"], " ", "r", " ", 
        SuperscriptBox["R", "2"], " ", "s"}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 62, ": ", (
     27 $CellContext`R^4 - (((24 
        3^Rational[1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s + (
       16 $CellContext`r^2) $CellContext`s^2) ((
       3 $CellContext`r^2) $CellContext`R^2 + (
       12 $CellContext`r) $CellContext`R^3 + (((12 
         3^Rational[
           1, 2]) $CellContext`r) $CellContext`R^2) $CellContext`s - (
      8 $CellContext`r^2) $CellContext`s^2 - (
      3 $CellContext`R^2) $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829285775899*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"7818031f-16b8-45dd-b2d0-6c1fecb5b0bf"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "63", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 63, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829285888959*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"9557c278-c029-46b9-84f9-c5c94077d3ff"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "64", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"28", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"48", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"32", " ", 
      SuperscriptBox["R", "4"]}], "-", 
     RowBox[{
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 64, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      28 $CellContext`r^2) $CellContext`R^2 + (
      48 $CellContext`r) $CellContext`R^3 + 
    32 $CellContext`R^4 - $CellContext`r^2 $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     12 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829286291016*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"cf1d4f19-b016-4c7a-9c49-e01bf884c059"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "65", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 65, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829286402718*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"b1de59e7-0198-4936-a872-4dfeb63a787f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "66", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["r", "2"]}], "-", 
        RowBox[{"4", " ", "r", " ", "R"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["R", "2"]}], "+", 
        SuperscriptBox["s", "2"]}], ")"}]}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "8"], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "7"], " ", "R"}], "+", 
       RowBox[{"100", " ", 
        SuperscriptBox["r", "6"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"304", " ", 
        SuperscriptBox["r", "5"], " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"448", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "4"]}], "+", 
       RowBox[{"256", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "5"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "6"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"80", " ", 
        SuperscriptBox["r", "5"], " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"284", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"416", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"208", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "4"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"80", " ", 
        SuperscriptBox["r", "3"], " ", "R", " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"124", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"48", " ", "r", " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "4"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "6"]}], "-", 
       RowBox[{"16", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "6"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "6"]}], "+", 
       SuperscriptBox["s", "8"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 66, ": ", (-(-$CellContext`r^2 - (4 $CellContext`r) $CellContext`R - 
      3 $CellContext`R^2 + $CellContext`s^2)) ($CellContext`r^8 + (
       16 $CellContext`r^7) $CellContext`R + (
       100 $CellContext`r^6) $CellContext`R^2 + (
       304 $CellContext`r^5) $CellContext`R^3 + (
       448 $CellContext`r^4) $CellContext`R^4 + (
       256 $CellContext`r^3) $CellContext`R^5 - (
      8 $CellContext`r^6) $CellContext`s^2 - ((
       80 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
       284 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
       416 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
       208 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 + (
       14 $CellContext`r^4) $CellContext`s^4 + ((
        80 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
        124 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
        48 $CellContext`r) $CellContext`R^3) $CellContext`s^4 - (
      8 $CellContext`r^2) $CellContext`s^6 - ((
       16 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
      4 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293433569317`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"7489d745-314d-420b-aa9b-e014a65447f7"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "67", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"8", " ", "r", " ", "R"}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "8"], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "7"], " ", "R"}], "+", 
       RowBox[{"100", " ", 
        SuperscriptBox["r", "6"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"304", " ", 
        SuperscriptBox["r", "5"], " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"448", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "4"]}], "+", 
       RowBox[{"256", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "5"]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "6"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"144", " ", 
        SuperscriptBox["r", "5"], " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"468", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"640", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"300", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "4"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"30", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"144", " ", 
        SuperscriptBox["r", "3"], " ", "R", " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"180", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"48", " ", "r", " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "4"]}], "-", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "6"]}], "-", 
       RowBox[{"16", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "6"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "6"]}], "+", 
       SuperscriptBox["s", "8"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 67, ": ", ((2 $CellContext`r^2 + (8 $CellContext`r) $CellContext`R + 
      9 $CellContext`R^2 - 
      2 $CellContext`s^2) ($CellContext`r^2 + (
        4 $CellContext`r) $CellContext`R - $CellContext`s^2)) \
($CellContext`r^8 + (16 $CellContext`r^7) $CellContext`R + (
       100 $CellContext`r^6) $CellContext`R^2 + (
       304 $CellContext`r^5) $CellContext`R^3 + (
       448 $CellContext`r^4) $CellContext`R^4 + (
       256 $CellContext`r^3) $CellContext`R^5 - (
      16 $CellContext`r^6) $CellContext`s^2 - ((
       144 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
       468 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
       640 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
       300 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 + (
       30 $CellContext`r^4) $CellContext`s^4 + ((
        144 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
        180 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
        48 $CellContext`r) $CellContext`R^3) $CellContext`s^4 - (
      16 $CellContext`r^2) $CellContext`s^6 - ((
       16 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
      4 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829343956608*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"5d4e6386-8b73-420f-a3aa-482417148af3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "68", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"5", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"2", " ", "r", " ", "s"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"2", " ", "r", " ", "s"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 68, ": ", (($CellContext`r^2 + (4 $CellContext`r) $CellContext`R + 
      5 $CellContext`R^2 - $CellContext`s^2) ($CellContext`r^2 + (
        4 $CellContext`r) $CellContext`R + 
      2 $CellContext`R^2 - (
       2 $CellContext`r) $CellContext`s - $CellContext`s^2)) \
($CellContext`r^2 + (4 $CellContext`r) $CellContext`R + 
     2 $CellContext`R^2 + (
       2 $CellContext`r) $CellContext`s - $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829344655374*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"6d892375-f84b-4aae-b68d-9721b5afef9d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "69", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 69, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829344709502*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"178cb983-43c5-42c1-9699-42a093a3eade"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "70", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "8"], "+", 
       RowBox[{"16", " ", 
        SuperscriptBox["r", "7"], " ", "R"}], "+", 
       RowBox[{"104", " ", 
        SuperscriptBox["r", "6"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"352", " ", 
        SuperscriptBox["r", "5"], " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"661", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "4"]}], "+", 
       RowBox[{"680", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "5"]}], "+", 
       RowBox[{"358", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "6"]}], "+", 
       RowBox[{"88", " ", "r", " ", 
        SuperscriptBox["R", "7"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["R", "8"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "6"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"80", " ", 
        SuperscriptBox["r", "5"], " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"304", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"544", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"462", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "4"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"168", " ", "r", " ", 
        SuperscriptBox["R", "5"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"22", " ", 
        SuperscriptBox["R", "6"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"14", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"80", " ", 
        SuperscriptBox["r", "3"], " ", "R", " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"144", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"96", " ", "r", " ", 
        SuperscriptBox["R", "3"], " ", 
        SuperscriptBox["s", "4"]}], "+", 
       RowBox[{"21", " ", 
        SuperscriptBox["R", "4"], " ", 
        SuperscriptBox["s", "4"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "6"]}], "-", 
       RowBox[{"16", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "6"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "6"]}], "+", 
       SuperscriptBox["s", "8"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 70, ": ", (($CellContext`r + 
      2 $CellContext`R - $CellContext`s) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r^8 + (
       16 $CellContext`r^7) $CellContext`R + (
       104 $CellContext`r^6) $CellContext`R^2 + (
       352 $CellContext`r^5) $CellContext`R^3 + (
       661 $CellContext`r^4) $CellContext`R^4 + (
       680 $CellContext`r^3) $CellContext`R^5 + (
       358 $CellContext`r^2) $CellContext`R^6 + (
       88 $CellContext`r) $CellContext`R^7 + 
     8 $CellContext`R^8 - (
      8 $CellContext`r^6) $CellContext`s^2 - ((
       80 $CellContext`r^5) $CellContext`R) $CellContext`s^2 - ((
       304 $CellContext`r^4) $CellContext`R^2) $CellContext`s^2 - ((
       544 $CellContext`r^3) $CellContext`R^3) $CellContext`s^2 - ((
       462 $CellContext`r^2) $CellContext`R^4) $CellContext`s^2 - ((
       168 $CellContext`r) $CellContext`R^5) $CellContext`s^2 - (
      22 $CellContext`R^6) $CellContext`s^2 + (
       14 $CellContext`r^4) $CellContext`s^4 + ((
        80 $CellContext`r^3) $CellContext`R) $CellContext`s^4 + ((
        144 $CellContext`r^2) $CellContext`R^2) $CellContext`s^4 + ((
        96 $CellContext`r) $CellContext`R^3) $CellContext`s^4 + (
       21 $CellContext`R^4) $CellContext`s^4 - (
      8 $CellContext`r^2) $CellContext`s^6 - ((
       16 $CellContext`r) $CellContext`R) $CellContext`s^6 - (
      8 $CellContext`R^2) $CellContext`s^6 + $CellContext`s^8) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829348260356*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"9c4a271a-432c-4bd8-bedb-99a3331d9b8a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "71", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 71, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829348352356*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"809af1f2-1da8-4f76-9161-ac735331c2ab"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "72", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 72, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293484139223`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"ceb52880-7a5f-4351-b1a5-14370dadb374"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "73", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{"8", " ", "r", " ", "R"}], "+", 
     RowBox[{"12", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 73, ": ", $CellContext`r^2 + (8 $CellContext`r) $CellContext`R + 
    12 $CellContext`R^2 - 3 $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293486623783`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"476e90fb-eec2-46d6-81ef-27333b5ee9c8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "74", 
   "\[InvisibleSpace]", "\<\" must lie on the circumcircle.\"\>"}],
  SequenceForm["X", 74, " must lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829348762272*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"a6d8b89d-d427-4eba-b67d-5c93baadc8cc"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "75", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 75, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293488169937`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"71f9e628-31f7-44d3-aaf3-155904386259"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "76", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 76, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293488922253`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"250db1ca-e214-442c-a524-e23ed86fc2e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "77", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{"2", " ", "r", " ", "R"}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     SuperscriptBox["s", "2"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 77, ": ", $CellContext`r^2 + (2 $CellContext`r) $CellContext`R + 
    4 $CellContext`R^2 - $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829349103661*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"ae411fae-444f-49dc-a861-53d0876c7e77"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "78", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 78, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829349189723*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"00b02ef3-4a22-483b-8bc1-39daa3497f34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "79", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{"6", " ", "r", " ", "R"}], "+", 
     RowBox[{"9", " ", 
      SuperscriptBox["R", "2"]}], "-", 
     RowBox[{"3", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 79, ": ", $CellContext`r^2 + (6 $CellContext`r) $CellContext`R + 
    9 $CellContext`R^2 - 3 $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829349404132*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"593c0320-303e-4d3d-8840-b1544260a6e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "80", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "r"}], "-", "R"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"6", " ", "r", " ", "R"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 80, ": ", (2 $CellContext`r - $CellContext`R) (
     3 $CellContext`r^2 + (6 $CellContext`r) $CellContext`R + 
     3 $CellContext`R^2 - $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293496071367`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"9c8f0416-69a5-4119-a855-f37d56f8f51d"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "81", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 81, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293497109747`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"f09df232-2b43-44e0-89cb-f0b1e97d67c6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "82", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 82, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829349914319*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"95797d2a-7721-4d93-9602-d8b67a92531a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "83", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 83, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829350074266*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"7fb2dc98-f7bd-4237-b8d7-b326123e03a8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "84", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"4", " ", "r", " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"r", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"2", " ", "R", " ", 
      SuperscriptBox["s", "2"]}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 84, ": ", (4 $CellContext`r) $CellContext`R^2 + 
    8 $CellContext`R^3 + $CellContext`r $CellContext`s^2 - (
     2 $CellContext`R) $CellContext`s^2 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829350798031*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"82c24f91-90dd-47b4-8d4d-c1a91d93e938"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "85", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 85, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.82482935089472*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"7e37985e-aebb-4689-9a08-fcec41009db0"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "86", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 86, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829350958387*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"28ca8b8c-e28e-4215-9ea5-3e18e882d240"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "87", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "-", 
       RowBox[{"8", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "6"], "+", 
       RowBox[{"12", " ", 
        SuperscriptBox["r", "5"], " ", "R"}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"64", " ", 
        SuperscriptBox["r", "3"], " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "3"], " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"48", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "4"]}], "-", 
       RowBox[{"20", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "4"]}], "+", 
       SuperscriptBox["s", "6"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 87, ": ", ($CellContext`r^2 - (
      8 $CellContext`r) $CellContext`R + $CellContext`s^2) ($CellContext`r^6 + \
(12 $CellContext`r^5) $CellContext`R + (
       48 $CellContext`r^4) $CellContext`R^2 + (
       64 $CellContext`r^3) $CellContext`R^3 + (
       3 $CellContext`r^4) $CellContext`s^2 - ((
       8 $CellContext`r^3) $CellContext`R) $CellContext`s^2 + ((
        48 $CellContext`r^2) $CellContext`R^2) $CellContext`s^2 + (
       3 $CellContext`r^2) $CellContext`s^4 - ((
       20 $CellContext`r) $CellContext`R) $CellContext`s^4 + \
$CellContext`s^6) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829351429044*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"444cc585-880d-4255-ab0f-7e47021c06d5"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "88", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"12", " ", "r", " ", "R"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"9", " ", 
        SuperscriptBox["r", "2"]}], "-", 
       RowBox[{"18", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 88, ": ", (
     3 $CellContext`r^2 + (
       12 $CellContext`r) $CellContext`R - $CellContext`s^2) (
     9 $CellContext`r^2 - (
      18 $CellContext`r) $CellContext`R + $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.82482935161504*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"1867cb44-80f8-480a-b63e-985139a4d073"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "89", 
   "\[InvisibleSpace]", "\<\" can never lie on the circumcircle.\"\>"}],
  SequenceForm["X", 89, " can never lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829351692066*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"49d9bab9-e8aa-476b-8ca1-fa18d8c15f85"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "90", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "-", "R"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"r", " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"r", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"R", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 90, ": ", ($CellContext`r - $CellContext`R) ($CellContext`r \
$CellContext`R^2 + 
     3 $CellContext`R^3 + $CellContext`r $CellContext`s^2 - $CellContext`R \
$CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829352345173*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"88b41eca-64dc-4c0d-99f7-6e988a6bc78a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "91", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"6", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"2", " ", "r", " ", "s"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"2", " ", "r", " ", "s"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 91, ": ", ((3 $CellContext`r^2 + (6 $CellContext`r) $CellContext`R + 
      2 $CellContext`R^2 - $CellContext`s^2) ($CellContext`r^2 + (
        4 $CellContext`r) $CellContext`R + 
      2 $CellContext`R^2 - (
       2 $CellContext`r) $CellContext`s - $CellContext`s^2)) \
($CellContext`r^2 + (4 $CellContext`r) $CellContext`R + 
     2 $CellContext`R^2 + (
       2 $CellContext`r) $CellContext`s - $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829353308539*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"0649a8cf-fdcb-4664-bf96-7a5c6b63b39a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "92", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"6", " ", "r", " ", "R"}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 92, ": ", (($CellContext`r + 
      2 $CellContext`R - $CellContext`s) ($CellContext`r + 
      2 $CellContext`R + $CellContext`s)) ($CellContext`r^2 + (
       6 $CellContext`r) $CellContext`R + 8 $CellContext`R^2 - 
     3 $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829353619424*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"5332b63f-88df-48ce-8446-d3729e80abc1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "93", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "-", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"r", "+", 
       RowBox[{"2", " ", "R"}], "+", "s"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"8", " ", "r", " ", "R"}], "+", 
       RowBox[{"7", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["R", "2"], "-", 
       RowBox[{"4", " ", "r", " ", "s"}], "-", 
       RowBox[{"2", " ", "R", " ", "s"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       SuperscriptBox["R", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "s"}], "+", 
       RowBox[{"2", " ", "R", " ", "s"}], "+", 
       SuperscriptBox["s", "2"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 93, ": ", (((($CellContext`r + 
        2 $CellContext`R - $CellContext`s) ($CellContext`r + 
        2 $CellContext`R + $CellContext`s)) (
       2 $CellContext`r^2 + (8 $CellContext`r) $CellContext`R + 
       7 $CellContext`R^2 - 
       2 $CellContext`s^2)) ($CellContext`r^2 + (
        4 $CellContext`r) $CellContext`R + $CellContext`R^2 - (
       4 $CellContext`r) $CellContext`s - (
       2 $CellContext`R) $CellContext`s + $CellContext`s^2)) \
($CellContext`r^2 + (4 $CellContext`r) $CellContext`R + $CellContext`R^2 + (
       4 $CellContext`r) $CellContext`s + (
       2 $CellContext`R) $CellContext`s + $CellContext`s^2) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.82482935553951*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"07932f38-68fb-4db0-87ae-d6fbc288f8a9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "94", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"6", " ", "r", " ", "R"}], "+", 
       RowBox[{"9", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["s", "2"]}]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"3", " ", 
        SuperscriptBox["r", "2"]}], "+", 
       RowBox[{"6", " ", "r", " ", "R"}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"19", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"12", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"8", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"3", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 94, ": ", (($CellContext`r^2 + (6 $CellContext`r) $CellContext`R + 
      9 $CellContext`R^2 - 3 $CellContext`s^2) (
      3 $CellContext`r^2 + (6 $CellContext`r) $CellContext`R + 
      3 $CellContext`R^2 - $CellContext`s^2)) ($CellContext`r^4 + (
       8 $CellContext`r^3) $CellContext`R + (
       19 $CellContext`r^2) $CellContext`R^2 + (
       12 $CellContext`r) $CellContext`R^3 - (
      6 $CellContext`r^2) $CellContext`s^2 - ((
       8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
      3 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829356667241*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"c4f543e4-0f2b-4699-a828-decdd74d5d0b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "95", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "4"], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["r", "3"], " ", "R"}], "+", 
     RowBox[{"22", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["R", "2"]}], "+", 
     RowBox[{"24", " ", "r", " ", 
      SuperscriptBox["R", "3"]}], "+", 
     RowBox[{"8", " ", 
      SuperscriptBox["R", "4"]}], "+", 
     RowBox[{"2", " ", 
      SuperscriptBox["r", "2"], " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"8", " ", "r", " ", "R", " ", 
      SuperscriptBox["s", "2"]}], "-", 
     RowBox[{"6", " ", 
      SuperscriptBox["R", "2"], " ", 
      SuperscriptBox["s", "2"]}], "+", 
     SuperscriptBox["s", "4"]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 95, ": ", $CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
      22 $CellContext`r^2) $CellContext`R^2 + (
      24 $CellContext`r) $CellContext`R^3 + 
    8 $CellContext`R^4 + (2 $CellContext`r^2) $CellContext`s^2 - ((
      8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
     6 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4 == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829357113997*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"ff7814d2-e699-42a5-beab-f7022270bc02"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "96", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "-", 
       RowBox[{"2", " ", "r", " ", "s"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       RowBox[{"4", " ", "r", " ", "R"}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"2", " ", "r", " ", "s"}], "-", 
       SuperscriptBox["s", "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"22", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"24", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["R", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"8", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 96, ": ", (($CellContext`r^2 + (4 $CellContext`r) $CellContext`R + 
      2 $CellContext`R^2 - (
       2 $CellContext`r) $CellContext`s - $CellContext`s^2) ($CellContext`r^2 + \
(4 $CellContext`r) $CellContext`R + 
      2 $CellContext`R^2 + (
        2 $CellContext`r) $CellContext`s - $CellContext`s^2)) \
($CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
       22 $CellContext`r^2) $CellContext`R^2 + (
       24 $CellContext`r) $CellContext`R^3 + 
     8 $CellContext`R^4 + (2 $CellContext`r^2) $CellContext`s^2 - ((
       8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
      6 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829359310554*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"95099ab1-9791-46c4-b86e-beeae88c6f1f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "97", 
   "\[InvisibleSpace]", "\<\": \"\>", "\[InvisibleSpace]", 
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"22", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"24", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["R", "4"]}], "+", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"8", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["r", "4"], "+", 
       RowBox[{"8", " ", 
        SuperscriptBox["r", "3"], " ", "R"}], "+", 
       RowBox[{"20", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["R", "2"]}], "+", 
       RowBox[{"16", " ", "r", " ", 
        SuperscriptBox["R", "3"]}], "-", 
       RowBox[{"6", " ", 
        SuperscriptBox["r", "2"], " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"8", " ", "r", " ", "R", " ", 
        SuperscriptBox["s", "2"]}], "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["R", "2"], " ", 
        SuperscriptBox["s", "2"]}], "+", 
       SuperscriptBox["s", "4"]}], ")"}]}], "\[Equal]", "0"}]}],
  SequenceForm[
  "X", 97, ": ", ($CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
       22 $CellContext`r^2) $CellContext`R^2 + (
       24 $CellContext`r) $CellContext`R^3 + 
     8 $CellContext`R^4 + (2 $CellContext`r^2) $CellContext`s^2 - ((
       8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
      6 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4) \
($CellContext`r^4 + (8 $CellContext`r^3) $CellContext`R + (
       20 $CellContext`r^2) $CellContext`R^2 + (
       16 $CellContext`r) $CellContext`R^3 - (
      6 $CellContext`r^2) $CellContext`s^2 - ((
       8 $CellContext`r) $CellContext`R) $CellContext`s^2 - (
      4 $CellContext`R^2) $CellContext`s^2 + $CellContext`s^4) == 0],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829360528611*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"7b61dc06-d7c0-48e5-bdf4-26d130dd5f19"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "98", 
   "\[InvisibleSpace]", "\<\" must lie on the circumcircle.\"\>"}],
  SequenceForm["X", 98, " must lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829360589797*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"4090c1eb-260f-4bfb-ba1d-d8828c94ef4e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "99", 
   "\[InvisibleSpace]", "\<\" must lie on the circumcircle.\"\>"}],
  SequenceForm["X", 99, " must lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.824829360640483*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"14ce6de0-2900-4e37-bcb2-8dceaa96a0f6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"X\"\>", "\[InvisibleSpace]", "100", 
   "\[InvisibleSpace]", "\<\" must lie on the circumcircle.\"\>"}],
  SequenceForm["X", 100, " must lie on the circumcircle."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.824820144560998*^9, 3.8248202515681963`*^9, 3.824820375997581*^9, {
   3.824820438903634*^9, 3.824820454424255*^9}, 3.8248204895757647`*^9, 
   3.824820534819707*^9, 3.8248210273560553`*^9, {3.824821099261422*^9, 
   3.824821113230373*^9}, 3.8248211441274137`*^9, 3.8248221861003323`*^9, 
   3.824822291399987*^9, 3.8248223574656773`*^9, 3.8248224340877113`*^9, 
   3.8248225506608353`*^9, 3.824823026330349*^9, 3.824823127835392*^9, {
   3.824823227660913*^9, 3.824823235364655*^9}, {3.824823291655038*^9, 
   3.8248233453131857`*^9}, 3.824823455764717*^9, 3.824823531990466*^9, 
   3.824823564462819*^9, {3.824823613486958*^9, 3.824823642840652*^9}, 
   3.824823746605085*^9, 3.8248245515869713`*^9, 3.824826302012659*^9, 
   3.8248269893108587`*^9, 3.82482713808533*^9, 3.824828837746069*^9, 
   3.824829224075395*^9, 3.8248293606424627`*^9},
 CellLabel->
  "During evaluation of \
In[423]:=",ExpressionUUID->"3fe6b4b2-77c6-4450-b377-6d0ef38c15d8"]
}, Open  ]]
}, Open  ]]
}, Closed]]
},
WindowSize->{873, 1156},
WindowMargins->{{251, Automatic}, {Automatic, 44}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 1250, 24, 265, "Text",ExpressionUUID->"984c0623-88fe-447b-bc88-37db9b647f0e",
 Evaluatable->False],
Cell[CellGroupData[{
Cell[1833, 48, 190, 3, 67, "Section",ExpressionUUID->"58f4c69c-5afe-42ac-8396-9ab23b31de6d"],
Cell[2026, 53, 162808, 4554, 4154, "Input",ExpressionUUID->"103026ca-9a33-45ac-8b84-90962100f555"]
}, Closed]],
Cell[CellGroupData[{
Cell[164871, 4612, 152, 3, 53, "Section",ExpressionUUID->"6938e9d1-ceb8-4305-b323-0cc213693416"],
Cell[165026, 4617, 503, 12, 58, "Text",ExpressionUUID->"1f9d2c39-46b8-489a-a814-40703670efc1"],
Cell[165532, 4631, 2989, 81, 367, "Input",ExpressionUUID->"2c26ce4c-5a53-4812-be0e-c5e07af7088e"]
}, Closed]],
Cell[CellGroupData[{
Cell[168558, 4717, 180, 3, 53, "Section",ExpressionUUID->"3ad4c45e-5f2c-4f9c-bc0b-81ce67b2a5a7"],
Cell[CellGroupData[{
Cell[168763, 4724, 1459, 36, 178, "Input",ExpressionUUID->"6ce1e6e6-ed6d-4f62-9584-eb94f51ae1bc"],
Cell[170225, 4762, 545, 12, 24, "Print",ExpressionUUID->"8defe32f-058c-47f6-a1ab-1e4648d3e96d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170807, 4779, 1466, 37, 178, "Input",ExpressionUUID->"a31d1b59-f53d-46a3-9e44-9b7f6233c4a8"],
Cell[172276, 4818, 544, 12, 24, "Print",ExpressionUUID->"541229c6-743c-4df5-87de-ad1c66b5da8c"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[172869, 4836, 255, 4, 53, "Section",ExpressionUUID->"19a12d2a-3888-4aff-9dd5-cf417bc4ae03"],
Cell[CellGroupData[{
Cell[173149, 4844, 1475, 36, 178, "Input",ExpressionUUID->"58e8a09b-7a3d-4c5e-8c0a-d80156ed19dd"],
Cell[174627, 4882, 895, 16, 44, "Print",ExpressionUUID->"9e3e7a5f-689e-4e1c-b40e-8b4ba4b4111d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[175559, 4903, 1482, 37, 178, "Input",ExpressionUUID->"d2b05f36-4d74-409b-9116-742188a3dc5a"],
Cell[177044, 4942, 444, 10, 24, "Print",ExpressionUUID->"b25c7936-25b9-4f24-b85f-7099c334613b"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[177537, 4958, 305, 5, 53, "Section",ExpressionUUID->"54313b8c-dba1-4fdc-9efe-9742071ed321"],
Cell[CellGroupData[{
Cell[177867, 4967, 2367, 53, 157, "Input",ExpressionUUID->"5c14dd3e-400d-40b0-a9ac-fb0b8881975e"],
Cell[CellGroupData[{
Cell[180259, 5024, 428, 10, 24, "Print",ExpressionUUID->"de1d775e-5714-4324-beda-c3eb93ec015a"],
Cell[180690, 5036, 430, 10, 24, "Print",ExpressionUUID->"6f2ed661-570a-41a4-b535-2b26d2528629"],
Cell[181123, 5048, 432, 10, 24, "Print",ExpressionUUID->"50efbd35-8341-4101-9324-97f3bea6204e"],
Cell[181558, 5060, 430, 10, 24, "Print",ExpressionUUID->"bcdef3ef-db67-4488-af9f-354ac63c655f"],
Cell[181991, 5072, 430, 10, 24, "Print",ExpressionUUID->"032eed27-c5b3-4d20-bd0f-f49f9af01e52"],
Cell[182424, 5084, 432, 10, 24, "Print",ExpressionUUID->"04876e50-3125-457d-9c55-bdd760e7393b"],
Cell[182859, 5096, 432, 10, 24, "Print",ExpressionUUID->"5d64c95e-564c-4ce6-84bb-cd0c205bec3a"],
Cell[183294, 5108, 430, 10, 24, "Print",ExpressionUUID->"5e3d29a9-0e30-44f1-a0f8-3ac736f93f29"],
Cell[183727, 5120, 430, 10, 24, "Print",ExpressionUUID->"5fb22373-346a-4c5e-9196-8ed61c1263c0"],
Cell[184160, 5132, 430, 10, 24, "Print",ExpressionUUID->"11a88837-e8f5-474e-8080-db04b159af47"],
Cell[184593, 5144, 430, 10, 24, "Print",ExpressionUUID->"e78e99ba-a22b-4b4f-a9f1-b91005236b65"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[185072, 5160, 488, 12, 52, "Input",ExpressionUUID->"01c288ba-fc76-4050-86c6-da57f0f49aef"],
Cell[185563, 5174, 329, 6, 34, "Output",ExpressionUUID->"c713ea0a-a95d-4eff-b690-e3ae458834cc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[185929, 5185, 489, 12, 52, "Input",ExpressionUUID->"e367f5b4-cee5-4f24-8927-0e5f631ebb06"],
Cell[186421, 5199, 208, 4, 34, "Output",ExpressionUUID->"20130af8-d731-4ce8-9559-b4555b3ece3a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[186666, 5208, 486, 12, 52, "Input",ExpressionUUID->"69b93cd6-529e-4163-9a75-305a92dec0f8"],
Cell[187155, 5222, 272, 5, 34, "Output",ExpressionUUID->"7f15e2ac-f7d5-4e7f-a7d8-52decf833093"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187464, 5232, 507, 13, 52, "Input",ExpressionUUID->"7679636a-ffbf-45b0-9784-069acf737272"],
Cell[187974, 5247, 273, 5, 34, "Output",ExpressionUUID->"b81540a7-ee1e-4c0b-a63a-cf0212fe1c36"]
}, Open  ]],
Cell[CellGroupData[{
Cell[188284, 5257, 506, 13, 52, "Input",ExpressionUUID->"0bc53e1d-8add-4136-95e5-b46b15035fc1"],
Cell[188793, 5272, 271, 5, 34, "Output",ExpressionUUID->"742ed91a-c919-4241-bcf0-31835094bdde"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189101, 5282, 487, 12, 52, "Input",ExpressionUUID->"8784ec1c-4a77-4d19-8f51-4cd72aaae3f5"],
Cell[189591, 5296, 251, 4, 34, "Output",ExpressionUUID->"6792c18e-1816-4ca2-8a24-6253de788947"]
}, Open  ]],
Cell[CellGroupData[{
Cell[189879, 5305, 463, 12, 52, "Input",ExpressionUUID->"fbcad1b5-6d74-4a11-b7ed-1cb337fcb3fc"],
Cell[190345, 5319, 274, 5, 34, "Output",ExpressionUUID->"ad60c4e4-22bd-422f-837e-f2e3551e8f03"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190656, 5329, 463, 12, 52, "Input",ExpressionUUID->"cb01f7ef-ccb9-4a90-9796-0ccb6275e25a"],
Cell[191122, 5343, 276, 5, 34, "Output",ExpressionUUID->"6ce16700-61bf-4764-af78-5db824264277"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191435, 5353, 489, 12, 52, "Input",ExpressionUUID->"97d323ad-2d50-459d-bb13-3d087ce9772a"],
Cell[191927, 5367, 278, 5, 34, "Output",ExpressionUUID->"6af84c50-e9e9-44e4-b17a-fa675da3989d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[192242, 5377, 509, 13, 52, "Input",ExpressionUUID->"36d41fae-4108-42d8-b0d4-ae6115365bec"],
Cell[192754, 5392, 298, 5, 34, "Output",ExpressionUUID->"eb8be919-ecfc-43fc-b2dd-5fb5573faaf9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193089, 5402, 509, 13, 52, "Input",ExpressionUUID->"3e962060-2652-4d41-b4c4-18978c3a4583"],
Cell[193601, 5417, 276, 5, 34, "Output",ExpressionUUID->"a6c09331-8ab7-4e84-ab13-1ee05652be50"]
}, Open  ]],
Cell[CellGroupData[{
Cell[193914, 5427, 208, 4, 30, "Input",ExpressionUUID->"150908d4-a2bd-42fc-bd65-ab3a062e218f"],
Cell[194125, 5433, 159, 3, 34, "Output",ExpressionUUID->"e235f3e3-9343-4038-b408-9508293da7ec"]
}, Open  ]],
Cell[CellGroupData[{
Cell[194321, 5441, 639, 16, 52, "Input",ExpressionUUID->"b74a9fd7-5246-4e57-97f6-5f7b9222868c"],
Cell[194963, 5459, 179, 3, 34, "Output",ExpressionUUID->"3bfa7051-fe83-44ac-9456-ae8cb0c7633c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195179, 5467, 542, 14, 52, "Input",ExpressionUUID->"00e7ab42-a7ba-4d44-9e39-1baae7aee23d"],
Cell[195724, 5483, 157, 3, 34, "Output",ExpressionUUID->"6699e85f-4743-428a-8104-de4ddcde153e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[195918, 5491, 517, 14, 52, "Input",ExpressionUUID->"8f43f534-33f5-43ad-9591-0ef5d5e95517"],
Cell[196438, 5507, 157, 3, 34, "Output",ExpressionUUID->"2a50a769-29e9-40b4-9e32-063dcfd9215b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[196632, 5515, 517, 14, 52, "Input",ExpressionUUID->"21a981a2-daa9-4a35-9b2c-548f275f8fd2"],
Cell[197152, 5531, 159, 3, 34, "Output",ExpressionUUID->"00bbd2b5-d24c-475f-a890-b97a0a0ce4ef"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197348, 5539, 4909, 99, 346, "Input",ExpressionUUID->"abc39306-2178-44dc-b7c3-3510a1112983"],
Cell[CellGroupData[{
Cell[202282, 5642, 473, 11, 24, "Print",ExpressionUUID->"b147d515-a8fc-4227-af20-4bb87fe7eb72"],
Cell[202758, 5655, 740, 16, 40, "Print",ExpressionUUID->"eaa086e5-9e68-404b-97db-9f0eeda559b8"],
Cell[203501, 5673, 578, 14, 26, "Print",ExpressionUUID->"c5697832-9f3c-4373-be82-959043696a75"],
Cell[204082, 5689, 544, 13, 40, "Print",ExpressionUUID->"9d1aad74-2382-412c-819d-50573d83f6ca"],
Cell[204629, 5704, 520, 12, 24, "Print",ExpressionUUID->"6a1c70d5-4b4e-4ebd-bc6d-b6381f9df1f5"],
Cell[205152, 5718, 520, 12, 24, "Print",ExpressionUUID->"948c01c1-06ef-4f33-85ec-2cfe6b02e033"],
Cell[205675, 5732, 562, 13, 43, "Print",ExpressionUUID->"f0e8eb7d-3c90-4cac-a702-0fcf868bce1d"],
Cell[206240, 5747, 345, 9, 24, "Print",ExpressionUUID->"66c53944-b64f-430c-a157-4a68ae570688"],
Cell[206588, 5758, 345, 9, 24, "Print",ExpressionUUID->"ba604a8e-26d7-4097-abee-394c5fc3ffb8"],
Cell[206936, 5769, 518, 12, 24, "Print",ExpressionUUID->"82f0658d-d2d5-4e25-9e2b-deeb21e487e2"],
Cell[207457, 5783, 518, 12, 24, "Print",ExpressionUUID->"03356b87-261e-471b-a271-fa0be97cd4e5"],
Cell[207978, 5797, 471, 11, 24, "Print",ExpressionUUID->"f8234067-4a20-4795-9c64-e6e6c74b58b2"],
Cell[208452, 5810, 544, 13, 40, "Print",ExpressionUUID->"8d5d3498-6030-40fe-b5a5-3b157112a78b"],
Cell[208999, 5825, 517, 12, 24, "Print",ExpressionUUID->"a6e539c8-ca7d-4d31-a5ed-9fd8709dbcc2"],
Cell[209519, 5839, 518, 12, 24, "Print",ExpressionUUID->"bee8af58-31d8-4c51-85c5-467a26e6b059"],
Cell[210040, 5853, 522, 12, 24, "Print",ExpressionUUID->"41f7fe4f-c3be-48c0-b02d-29951090449f"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[210611, 5871, 231, 5, 30, "Input",ExpressionUUID->"cf15d2a9-27da-4e11-9e29-a995f89e7061"],
Cell[210845, 5878, 178, 4, 51, "Output",ExpressionUUID->"cb986441-a066-44b8-8efc-7f6d3582b502"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211060, 5887, 541, 14, 52, "Input",ExpressionUUID->"8f1f74ef-ef98-4a7e-a7d1-753dd2e184ae"],
Cell[211604, 5903, 157, 3, 34, "Output",ExpressionUUID->"9b8a27ab-f55f-4168-b6ab-abb311670f0f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[211798, 5911, 541, 14, 52, "Input",ExpressionUUID->"5c7a25d1-bb74-4f3d-9612-64f0d424c4dc"],
Cell[212342, 5927, 156, 3, 34, "Output",ExpressionUUID->"2b16ad2e-4b5a-4435-a9d9-cedc84eb3d40"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212535, 5935, 541, 14, 52, "Input",ExpressionUUID->"b16381dd-7fc3-479d-b712-722d4fb2d067"],
Cell[213079, 5951, 157, 3, 34, "Output",ExpressionUUID->"65b389f4-a6a5-4ec9-b456-7eabaf0e1971"]
}, Open  ]],
Cell[CellGroupData[{
Cell[213273, 5959, 541, 14, 52, "Input",ExpressionUUID->"45db1638-a92d-4b4f-bc82-14c4aa2c27e6"],
Cell[213817, 5975, 157, 3, 34, "Output",ExpressionUUID->"dfef9626-8c89-4c32-93b7-a03e8477a2ad"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214011, 5983, 541, 14, 52, "Input",ExpressionUUID->"6385f828-c6e2-493c-9c97-e9ab0b53808b"],
Cell[214555, 5999, 159, 3, 34, "Output",ExpressionUUID->"7492c2f1-5b6f-4eac-8505-cd29d8d48de6"]
}, Open  ]],
Cell[CellGroupData[{
Cell[214751, 6007, 543, 14, 52, "Input",ExpressionUUID->"67b93b19-5a13-4e23-859a-5892d1ab5b0f"],
Cell[215297, 6023, 183, 3, 34, "Output",ExpressionUUID->"8c80572e-3ece-46c5-8d19-bc0341a8e2c2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[215517, 6031, 541, 14, 52, "Input",ExpressionUUID->"3bf86feb-557f-4178-8685-382dad977864"],
Cell[216061, 6047, 183, 3, 34, "Output",ExpressionUUID->"6abbf565-ac93-4348-8e24-de0ec13bf21f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[216281, 6055, 517, 14, 52, "Input",ExpressionUUID->"74447847-131b-44d0-8c13-0f2fb877a032"],
Cell[216801, 6071, 157, 3, 34, "Output",ExpressionUUID->"113e09bf-2a13-4345-977b-7d16388a3224"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[217007, 6080, 351, 5, 53, "Section",ExpressionUUID->"7ca174cb-99ab-4f6f-bacf-b6daf7cc3eea"],
Cell[CellGroupData[{
Cell[217383, 6089, 4218, 89, 346, "Input",ExpressionUUID->"ed9a2e38-03af-41d0-888e-39e2379ebe51"],
Cell[CellGroupData[{
Cell[221626, 6182, 540, 12, 24, "Print",ExpressionUUID->"656385ff-c01f-4c86-a5b3-59330218a677"],
Cell[222169, 6196, 564, 13, 40, "Print",ExpressionUUID->"e0a3c25c-43ec-4359-8942-a9f0b39dccc2"],
Cell[222736, 6211, 588, 14, 44, "Print",ExpressionUUID->"adc70595-6b22-4151-8fff-a56885687c33"],
Cell[223327, 6227, 590, 14, 44, "Print",ExpressionUUID->"4f9a01a4-df71-40eb-9751-3abbde322fc4"],
Cell[223920, 6243, 369, 9, 24, "Print",ExpressionUUID->"d26fc958-76a7-41d1-96cd-067b434323ac"],
Cell[224292, 6254, 367, 9, 24, "Print",ExpressionUUID->"6a81eb8b-69c7-4a95-a348-455e52e3e225"],
Cell[224662, 6265, 1364, 25, 45, "Print",ExpressionUUID->"f29e4f11-e73d-41d0-a254-d281b1e904f7"],
Cell[226029, 6292, 540, 12, 24, "Print",ExpressionUUID->"e11ace65-41d3-4783-9f3e-fd65bc890374"],
Cell[226572, 6306, 590, 14, 44, "Print",ExpressionUUID->"8e5ee8ce-ca56-4624-bbe3-0189a4790e2d"],
Cell[227165, 6322, 1368, 25, 45, "Print",ExpressionUUID->"d7039594-ffd6-48bc-8cac-a71dbb19b75e"],
Cell[228536, 6349, 1084, 22, 25, "Print",ExpressionUUID->"57977b6b-32b3-4fa0-9bc0-bdd02e9a00b9"],
Cell[229623, 6373, 1240, 24, 25, "Print",ExpressionUUID->"92363534-1fd7-4929-a432-338b5075c16e"],
Cell[230866, 6399, 856, 17, 40, "Print",ExpressionUUID->"1e97435b-6337-4fad-b2aa-d49ad2804e46"],
Cell[231725, 6418, 832, 17, 46, "Print",ExpressionUUID->"f3ae8c57-20f8-40c2-b919-b130e93931a0"],
Cell[232560, 6437, 586, 13, 43, "Print",ExpressionUUID->"ec2629fc-c36d-47e4-ab56-c2326acb5e90"],
Cell[233149, 6452, 540, 12, 24, "Print",ExpressionUUID->"c2a07d5b-4985-402e-a760-bc29140c5f6d"],
Cell[233692, 6466, 1206, 23, 25, "Print",ExpressionUUID->"67ccfda7-6fba-447e-bcae-d6e67eafa560"],
Cell[234901, 6491, 795, 17, 28, "Print",ExpressionUUID->"489bb86a-5fc0-4b26-a569-b185a7b58116"],
Cell[235699, 6510, 1056, 20, 25, "Print",ExpressionUUID->"d8d96903-59ba-4cf8-8fc0-de97f278662d"],
Cell[236758, 6532, 568, 13, 40, "Print",ExpressionUUID->"f6f86d00-cd95-4ebe-9237-dc1607f17306"],
Cell[237329, 6547, 662, 15, 26, "Print",ExpressionUUID->"6075cb52-9136-46d6-9eb9-e756f6df3c33"]
}, Open  ]]
}, Open  ]],
Cell[238018, 6566, 374, 9, 30, "Input",ExpressionUUID->"40faa276-5603-410a-8329-dee6fa43096b"],
Cell[CellGroupData[{
Cell[238417, 6579, 612, 16, 52, "Input",ExpressionUUID->"b4b2fbb8-98df-4dd7-8d1d-ce7b624929a9"],
Cell[239032, 6597, 160, 3, 34, "Output",ExpressionUUID->"a7e3e11f-00b7-4013-8a73-6aa87270391d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[239229, 6605, 553, 15, 30, "Input",ExpressionUUID->"d3740d7f-ec2d-408e-862b-b46678292e37"],
Cell[239785, 6622, 878, 23, 41, "Output",ExpressionUUID->"7e585a72-0041-495a-909a-b635aed3dd3e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[240700, 6650, 231, 5, 30, "Input",ExpressionUUID->"8c26f2a2-a259-434b-85ca-aa68921d68af"],
Cell[240934, 6657, 220, 3, 34, "Output",ExpressionUUID->"809e916e-9fbb-466f-996e-4c9a0f7f0eab"]
}, Open  ]],
Cell[CellGroupData[{
Cell[241191, 6665, 350, 8, 30, "Input",ExpressionUUID->"f9a34fb6-efe1-425d-89a3-c907f0ee5a19"],
Cell[CellGroupData[{
Cell[241566, 6677, 2876, 67, 31, "Print",ExpressionUUID->"3e2eb207-d92c-400c-8fe0-f17a1db5f46a"],
Cell[244445, 6746, 2857, 66, 31, "Print",ExpressionUUID->"307ec12d-2b8b-4e37-b591-491996cc7ee9"],
Cell[247305, 6814, 3922, 94, 31, "Print",ExpressionUUID->"197d7cbf-a5ef-4187-98e4-c3b70e7c48b3"]
}, Open  ]],
Cell[251242, 6911, 160, 3, 34, "Output",ExpressionUUID->"acd008ae-6907-4192-b685-d3c98d2c7104"]
}, Open  ]],
Cell[CellGroupData[{
Cell[251439, 6919, 432, 11, 30, "Input",ExpressionUUID->"ae9746a9-e9f8-404e-8f42-34fe49b7dcfe"],
Cell[251874, 6932, 157, 3, 34, "Output",ExpressionUUID->"686c543b-a4fa-4be6-ac8e-9d2ce5d9b449"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252068, 6940, 270, 6, 30, "Input",ExpressionUUID->"ab1f5e37-fb3d-4107-9775-38a0fb74f9a5"],
Cell[252341, 6948, 156, 3, 34, "Output",ExpressionUUID->"a0f5130f-67cb-4768-b9fc-294ff37b0c40"]
}, Open  ]],
Cell[CellGroupData[{
Cell[252534, 6956, 255, 6, 30, "Input",ExpressionUUID->"b6bc18b3-86d3-433d-bfab-ad2819c2d904"],
Cell[252792, 6964, 222, 3, 34, "Output",ExpressionUUID->"ec357ab1-01c4-4fc8-a87b-de445d985592"]
}, Open  ]],
Cell[CellGroupData[{
Cell[253051, 6972, 320, 7, 30, "Input",ExpressionUUID->"0ca9f0f2-9d45-4c8c-a7c8-0fbe63c77b72"],
Cell[253374, 6981, 162, 3, 34, "Output",ExpressionUUID->"b4c6547e-77d6-47eb-ba6a-3f42a2b1ac5f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[253573, 6989, 371, 9, 30, "Input",ExpressionUUID->"76fe387b-689e-461c-b7f2-9da3a9b21560"],
Cell[253947, 7000, 181, 3, 34, "Output",ExpressionUUID->"4f9c4b22-e52e-4562-9c95-8808b50ef7d8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254165, 7008, 347, 9, 30, "Input",ExpressionUUID->"2aeb42b8-f1af-4504-8e92-2a7fe8a00244"],
Cell[254515, 7019, 206, 4, 24, "Print",ExpressionUUID->"70d9aef2-6787-499e-92e9-b6640d9d334b"],
Cell[254724, 7025, 156, 3, 34, "Output",ExpressionUUID->"cf5daee3-74a3-4a9d-a3a8-7711a72df972"]
}, Open  ]],
Cell[CellGroupData[{
Cell[254917, 7033, 379, 9, 30, "Input",ExpressionUUID->"f3e2a8ae-ba8f-4ea3-bbd8-b259e05f4ecd"],
Cell[255299, 7044, 203, 4, 24, "Print",ExpressionUUID->"b41b2dbe-8374-4e4f-81af-b0ae17fda360"],
Cell[255505, 7050, 158, 3, 34, "Output",ExpressionUUID->"9ca956fa-f3df-4dba-9a1a-df1823b4e9a1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[255700, 7058, 544, 15, 52, "Input",ExpressionUUID->"8313d55f-019e-4b0e-b21a-f301a051005f"],
Cell[256247, 7075, 5302, 133, 92, "Print",ExpressionUUID->"f13828e1-bee2-4d10-8f9b-170a06f5e731"],
Cell[261552, 7210, 160, 3, 34, "Output",ExpressionUUID->"8c107c30-fc0d-4091-845e-85807c81aa6b"]
}, Open  ]],
Cell[261727, 7216, 326, 9, 30, "Input",ExpressionUUID->"5ffa2589-1cc3-4b42-b345-5f67749699ea"],
Cell[CellGroupData[{
Cell[262078, 7229, 344, 8, 30, "Input",ExpressionUUID->"e8bb4581-2df4-4c99-ac3e-1577319f620a"],
Cell[262425, 7239, 181, 3, 34, "Output",ExpressionUUID->"2b50b1a7-8904-4b52-9894-b7b6430a862d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[262643, 7247, 2150, 51, 157, "Input",ExpressionUUID->"4dbf02f2-3523-489a-a1e8-98effa1ea576"],
Cell[CellGroupData[{
Cell[264818, 7302, 454, 10, 24, "Print",ExpressionUUID->"2f651193-5a95-4e7b-88bb-7336996ea316"],
Cell[265275, 7314, 454, 10, 24, "Print",ExpressionUUID->"7c64b38e-dd62-4345-99e6-d2fddbf08583"],
Cell[265732, 7326, 478, 11, 24, "Print",ExpressionUUID->"d4357da0-ae7a-4ac3-bb9f-5786082a8e7e"],
Cell[266213, 7339, 454, 10, 24, "Print",ExpressionUUID->"131b0b1c-2b57-4119-9970-c048383a1cfc"],
Cell[266670, 7351, 454, 10, 24, "Print",ExpressionUUID->"a1049440-f488-4162-b1ac-1941f9106839"],
Cell[267127, 7363, 480, 11, 40, "Print",ExpressionUUID->"18f8ffea-c110-4049-b570-62b2b55a6d0f"],
Cell[267610, 7376, 454, 10, 24, "Print",ExpressionUUID->"2cf8db4b-6ddf-4899-b0b9-50578a3d5051"],
Cell[268067, 7388, 497, 11, 43, "Print",ExpressionUUID->"2ea7ea8b-9213-49d5-855f-1d58d5fa423b"],
Cell[268567, 7401, 454, 10, 24, "Print",ExpressionUUID->"800953e7-ca94-44c9-9448-f0f5426db1aa"],
Cell[269024, 7413, 454, 10, 24, "Print",ExpressionUUID->"107daa41-0b19-4f87-8d1a-8d78fa24c151"],
Cell[269481, 7425, 456, 10, 24, "Print",ExpressionUUID->"8466a7c9-2ed3-4b51-9c30-5113631a374a"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[269986, 7441, 585, 16, 52, "Input",ExpressionUUID->"e0a433f7-b4ef-4f51-b384-e4439fca03e4"],
Cell[270574, 7459, 530, 15, 43, "Print",ExpressionUUID->"3d96b3d1-3412-44d7-94e7-51674a396a7a"],
Cell[271107, 7476, 246, 4, 34, "Output",ExpressionUUID->"34dc8fe3-d984-4930-ad2d-1d3b6aee0630"]
}, Open  ]],
Cell[CellGroupData[{
Cell[271390, 7485, 623, 17, 52, "Input",ExpressionUUID->"bb31822a-9dfb-489b-baec-cb38cd325b88"],
Cell[CellGroupData[{
Cell[272038, 7506, 2440, 62, 59, "Print",ExpressionUUID->"7c34f7de-8574-42b4-bba8-2db25f187951"],
Cell[274481, 7570, 221, 4, 44, "Print",ExpressionUUID->"8fb5446e-6901-4461-b1f7-c4277d5eb6de"],
Cell[274705, 7576, 2434, 61, 58, "Print",ExpressionUUID->"6fed21da-a009-4f20-85b0-bad9bda85647"],
Cell[277142, 7639, 2309, 58, 90, "Print",ExpressionUUID->"62e5bb2d-cec8-4d47-8500-a5b2033e2dd2"],
Cell[279454, 7699, 223, 4, 44, "Print",ExpressionUUID->"a9c87a0c-1de7-4eef-ace0-cf01adaef6a6"],
Cell[279680, 7705, 2316, 57, 90, "Print",ExpressionUUID->"fd1bd553-8d7a-4aa0-a029-954d81f2bfc2"],
Cell[281999, 7764, 529, 15, 43, "Print",ExpressionUUID->"e13d900d-a879-48f3-aba5-8d90bf6247cf"]
}, Open  ]],
Cell[282543, 7782, 246, 4, 34, "Output",ExpressionUUID->"46bea1c0-b0e4-4e13-a9bd-5dab58f852b2"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[282838, 7792, 307, 5, 53, "Section",ExpressionUUID->"943fb183-e47b-48fb-8b8c-212614e9fb5f"],
Cell[CellGroupData[{
Cell[283170, 7801, 1567, 40, 136, "Input",ExpressionUUID->"da803e98-18ba-40db-ab34-0be7c8935fd7"],
Cell[CellGroupData[{
Cell[284762, 7845, 503, 12, 40, "Print",ExpressionUUID->"7f13da8d-aa54-4bb5-940a-adbd9e0b36c7"],
Cell[285268, 7859, 477, 11, 24, "Print",ExpressionUUID->"f997a964-2d3e-485e-82d5-4f85f8490bf2"],
Cell[285748, 7872, 479, 11, 24, "Print",ExpressionUUID->"31a5afcb-fcbd-4ca5-b65e-ae38602b1808"],
Cell[286230, 7885, 503, 12, 40, "Print",ExpressionUUID->"f76b985a-a3f3-47ca-9c19-d509054c5540"],
Cell[286736, 7899, 1162, 23, 25, "Print",ExpressionUUID->"085d0ccc-5b44-430a-84d9-b8ef8a58c451"],
Cell[287901, 7924, 996, 20, 25, "Print",ExpressionUUID->"68a0ad8c-c79e-4839-b381-23a34b4012d4"],
Cell[288900, 7946, 477, 11, 24, "Print",ExpressionUUID->"0732d269-12f3-4518-8e88-26bc25c5ded9"],
Cell[289380, 7959, 479, 11, 24, "Print",ExpressionUUID->"7c831cd5-484a-4c6a-84ca-819b2cd59220"],
Cell[289862, 7972, 481, 11, 24, "Print",ExpressionUUID->"1b16e6c8-f339-4a4e-b5a9-5e3bd83e9c09"],
Cell[290346, 7985, 505, 12, 40, "Print",ExpressionUUID->"4d5ec8ee-2138-4a01-9d2f-a89c774425f4"],
Cell[290854, 7999, 761, 17, 40, "Print",ExpressionUUID->"6df85db7-67e6-4bd4-8ee3-97185eba9f89"],
Cell[291618, 8018, 1156, 22, 25, "Print",ExpressionUUID->"9ae44b7c-7b90-4ae7-8856-b9eec197cfc7"],
Cell[292777, 8042, 1152, 22, 25, "Print",ExpressionUUID->"e2f3a35a-918a-4f09-8408-56b528814513"],
Cell[293932, 8066, 1470, 27, 25, "Print",ExpressionUUID->"82422b25-7211-48eb-98a2-a4843edc59af"],
Cell[295405, 8095, 1606, 29, 25, "Print",ExpressionUUID->"783825e1-df6e-4aef-9671-9e5bc9a92b04"],
Cell[297014, 8126, 523, 12, 44, "Print",ExpressionUUID->"60b762ca-1efb-4b7e-a74d-25f43464f99d"],
Cell[297540, 8140, 479, 11, 24, "Print",ExpressionUUID->"646b061a-348d-414f-a5e8-3c10b272a369"],
Cell[298022, 8153, 505, 12, 40, "Print",ExpressionUUID->"0305a392-681d-4638-9fbb-fabcc9bbcb07"],
Cell[298530, 8167, 1780, 31, 25, "Print",ExpressionUUID->"a2b91269-02b2-49a5-a4bc-4fbea687c79d"],
Cell[300313, 8200, 1786, 31, 45, "Print",ExpressionUUID->"a275c228-9cdb-403c-85e9-c748988d8cf1"],
Cell[302102, 8233, 1514, 27, 25, "Print",ExpressionUUID->"1d148813-ee37-473f-bf8c-9c23f7661745"],
Cell[303619, 8262, 1480, 27, 25, "Print",ExpressionUUID->"982afaf7-77f7-47c7-aaa4-991f70aa17ef"],
Cell[305102, 8291, 1478, 27, 25, "Print",ExpressionUUID->"b1d6945b-f25e-49c8-b094-0c590712865b"],
Cell[306583, 8320, 3269, 52, 40, "Print",ExpressionUUID->"5a78366c-8ae8-41ce-8066-2fb72e29fb90"],
Cell[309855, 8374, 1148, 22, 50, "Print",ExpressionUUID->"64768a2d-a9a8-4fca-9257-c8d98d24da29"],
Cell[311006, 8398, 898, 18, 25, "Print",ExpressionUUID->"33f204cf-78f8-4cee-976a-ae306050b505"],
Cell[311907, 8418, 1000, 20, 25, "Print",ExpressionUUID->"d3360662-fd5b-463a-9b54-7322cdfe8a44"],
Cell[312910, 8440, 1322, 25, 25, "Print",ExpressionUUID->"e6b3fcfd-0e49-42c0-a2f2-27ec2839f48b"],
Cell[314235, 8467, 2202, 38, 40, "Print",ExpressionUUID->"18ff2e77-230b-4a1e-8550-7392b64ca0f4"],
Cell[316440, 8507, 481, 11, 24, "Print",ExpressionUUID->"3e8054eb-77bd-4402-8482-eeb7316a1696"],
Cell[316924, 8520, 902, 19, 25, "Print",ExpressionUUID->"531a34a4-e581-4719-9bb6-9b3bd8ba133e"],
Cell[317829, 8541, 1167, 22, 25, "Print",ExpressionUUID->"76d82d6b-846c-4b45-b175-34ec3f41ece6"],
Cell[318999, 8565, 1172, 23, 25, "Print",ExpressionUUID->"9ec795b3-a3d3-498c-953d-d368b378b7c3"],
Cell[320174, 8590, 1150, 22, 25, "Print",ExpressionUUID->"8e9b12ba-eff0-4044-966d-0400e7d5d0ad"],
Cell[321327, 8614, 774, 17, 46, "Print",ExpressionUUID->"33c9f67f-bdf7-4af3-8034-ddbc7e6889ff"],
Cell[322104, 8633, 505, 12, 40, "Print",ExpressionUUID->"ee183f08-97d0-4120-9db1-9cd90999aeba"],
Cell[322612, 8647, 1028, 21, 25, "Print",ExpressionUUID->"e6943868-6ff3-49f4-afcc-e77bd7ba2575"],
Cell[323643, 8670, 3534, 58, 40, "Print",ExpressionUUID->"37bcf48f-7f6e-434a-a4a6-d19762a5bfd1"],
Cell[327180, 8730, 897, 18, 25, "Print",ExpressionUUID->"6b363bd2-57b0-4a22-a7ff-f9f0924da55d"],
Cell[328080, 8750, 864, 18, 25, "Print",ExpressionUUID->"89e7fd52-f97d-4d38-915e-86df95da73bb"],
Cell[328947, 8770, 670, 16, 49, "Print",ExpressionUUID->"f6e99cd7-64ad-4f0d-b9ae-148eb9d002bb"],
Cell[329620, 8788, 1166, 22, 25, "Print",ExpressionUUID->"a9dd7238-579c-4819-b019-607101f039bd"],
Cell[330789, 8812, 479, 11, 24, "Print",ExpressionUUID->"87da815a-97b9-47d6-88d6-ca8bf6496116"],
Cell[331271, 8825, 904, 19, 25, "Print",ExpressionUUID->"81a98151-67f9-4f06-a792-fe427b9d8703"],
Cell[332178, 8846, 505, 12, 40, "Print",ExpressionUUID->"37baa5ea-b377-4251-9a63-c87a8ba13147"],
Cell[332686, 8860, 479, 11, 24, "Print",ExpressionUUID->"69eb9513-dc49-4592-8e97-9c21b2cd07e0"],
Cell[333168, 8873, 588, 14, 44, "Print",ExpressionUUID->"d62d65ca-d845-47c8-aed2-feef4a9828c1"],
Cell[333759, 8889, 1324, 25, 25, "Print",ExpressionUUID->"270ea9e8-10da-4e5f-858f-25767e7fad99"],
Cell[335086, 8916, 481, 11, 24, "Print",ExpressionUUID->"5859662d-a225-47d7-8672-40e2ba00de3d"],
Cell[335570, 8929, 505, 12, 40, "Print",ExpressionUUID->"17d42af1-e33f-45e9-824b-a93a3c2a36bf"],
Cell[336078, 8943, 481, 11, 24, "Print",ExpressionUUID->"c7553eff-b38c-4788-88b2-8f211b8eb73f"],
Cell[336562, 8956, 479, 11, 24, "Print",ExpressionUUID->"fec28137-3360-42ef-a4f8-02ff1e141278"],
Cell[337044, 8969, 479, 11, 24, "Print",ExpressionUUID->"4b06f3e0-3624-4770-a169-2fef68541819"],
Cell[337526, 8982, 479, 11, 24, "Print",ExpressionUUID->"a12d9a19-f9bf-49d9-bf2f-ea802ae5c5fe"],
Cell[338008, 8995, 479, 11, 24, "Print",ExpressionUUID->"9558f5d1-f802-4711-8629-24ab5dfe01ba"],
Cell[338490, 9008, 938, 20, 25, "Print",ExpressionUUID->"b57a9c3f-d752-41b0-b1ca-8ee12cc4d96e"],
Cell[339431, 9030, 481, 11, 24, "Print",ExpressionUUID->"1d31aa19-9651-4ea8-bab6-28a4668ea3b1"],
Cell[339915, 9043, 1172, 22, 25, "Print",ExpressionUUID->"0047c15b-1ab6-4793-b262-65903532cdaa"],
Cell[341090, 9067, 1484, 27, 25, "Print",ExpressionUUID->"90a4c351-ab3d-46a7-a5f8-83d13fd89d3b"],
Cell[342577, 9096, 507, 12, 40, "Print",ExpressionUUID->"2f5cbc3c-972d-4eb0-83e8-64cae90f2ae0"],
Cell[343087, 9110, 505, 12, 40, "Print",ExpressionUUID->"0cc465c4-49d9-4a55-be36-ff846f64ba22"],
Cell[343595, 9124, 504, 12, 40, "Print",ExpressionUUID->"d4f58172-2c09-4e6a-9809-4cbedd32c0d4"],
Cell[344102, 9138, 794, 18, 28, "Print",ExpressionUUID->"cb0f11f8-9b98-46f7-9bae-8c25104026d9"],
Cell[344899, 9158, 1178, 23, 25, "Print",ExpressionUUID->"15ef698a-aa4e-4a5d-8ed0-5ad306ebf58a"],
Cell[346080, 9183, 479, 11, 24, "Print",ExpressionUUID->"ad48d724-830f-4f08-babf-90c8f4e839a1"],
Cell[346562, 9196, 479, 11, 24, "Print",ExpressionUUID->"f3d586b0-d110-499d-9711-78fce3fc8d03"],
Cell[347044, 9209, 481, 11, 24, "Print",ExpressionUUID->"3391a27e-6318-4a54-abd4-50329ce74ef5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[347574, 9226, 588, 16, 52, "Input",ExpressionUUID->"970cb16a-67ce-4198-87f7-e0bcc9f9caac"],
Cell[348165, 9244, 204, 4, 24, "Print",ExpressionUUID->"27b84f7d-5bfb-4043-9684-ef8fcbc39d14"],
Cell[348372, 9250, 250, 4, 34, "Output",ExpressionUUID->"6f7124ac-d62e-4868-9f58-3fca8bd86a4c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[348659, 9259, 486, 12, 52, "Input",ExpressionUUID->"50a51a29-dc85-430e-a395-37801b143bca"],
Cell[349148, 9273, 204, 4, 24, "Print",ExpressionUUID->"c0a30cf7-964e-4c35-8810-2345c1e56b7a"],
Cell[349355, 9279, 231, 4, 34, "Output",ExpressionUUID->"a8f3bcdc-de9a-4f90-ad02-1007e31df9e2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[349623, 9288, 564, 15, 52, "Input",ExpressionUUID->"5aa91260-c425-4d58-983e-9abbe6e9453f"],
Cell[350190, 9305, 204, 4, 24, "Print",ExpressionUUID->"6e30164f-a214-45b1-95ae-725ef37d1a90"],
Cell[350397, 9311, 229, 4, 34, "Output",ExpressionUUID->"f1990fe3-c2b5-4356-aaa2-c593eaf3e19b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[350663, 9320, 587, 16, 52, "Input",ExpressionUUID->"858e485f-d447-458d-8509-37d4c5639026"],
Cell[351253, 9338, 206, 4, 24, "Print",ExpressionUUID->"022cfe7c-bb6e-48e9-b81a-647de49168d3"],
Cell[351462, 9344, 226, 4, 34, "Output",ExpressionUUID->"d4f5ef00-8c1b-4ba5-821a-a9cc46eb8b51"]
}, Open  ]],
Cell[CellGroupData[{
Cell[351725, 9353, 531, 14, 52, "Input",ExpressionUUID->"0e7c3029-cac8-4a0d-b950-626f8701ea47"],
Cell[352259, 9369, 206, 4, 24, "Print",ExpressionUUID->"9ec6f8d3-3c81-4cca-abec-d9c95c001b2d"],
Cell[352468, 9375, 254, 4, 34, "Output",ExpressionUUID->"609922e8-6fc9-4087-bc6b-c2716e10ff21"]
}, Open  ]],
Cell[CellGroupData[{
Cell[352759, 9384, 484, 12, 52, "Input",ExpressionUUID->"02c90464-a8e1-4028-8056-f439498025c8"],
Cell[353246, 9398, 204, 4, 24, "Print",ExpressionUUID->"58db2815-c3a0-4b9c-abf8-493115b3ea23"],
Cell[353453, 9404, 227, 4, 34, "Output",ExpressionUUID->"ffe63a8d-7e46-4949-bd85-a8d5a8c654b5"]
}, Open  ]],
Cell[CellGroupData[{
Cell[353717, 9413, 487, 12, 52, "Input",ExpressionUUID->"3ecffc69-dbd3-448e-a8ce-6067c8454de7"],
Cell[354207, 9427, 203, 4, 24, "Print",ExpressionUUID->"8a5444ed-a3f5-4c12-8fb0-ad8a8e138a81"],
Cell[354413, 9433, 229, 4, 34, "Output",ExpressionUUID->"1d7a2b66-ccbb-4887-812d-c563caf9e81b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[354679, 9442, 587, 16, 52, "Input",ExpressionUUID->"017ca0a7-03ac-4e61-a251-e4014b873fb6"],
Cell[355269, 9460, 227, 4, 34, "Output",ExpressionUUID->"729761b6-2721-4fa5-bf38-1409e0b35865"]
}, Open  ]],
Cell[CellGroupData[{
Cell[355533, 9469, 852, 22, 73, "Input",ExpressionUUID->"7c2cc2aa-c1c9-4c92-bc1e-5bc530e84fe6"],
Cell[356388, 9493, 203, 4, 34, "Output",ExpressionUUID->"5b537cdf-d2cc-48a6-8ca5-8d46f9309839"]
}, Open  ]],
Cell[CellGroupData[{
Cell[356628, 9502, 557, 15, 52, "Input",ExpressionUUID->"9c70e65a-32e5-4deb-a436-7be1f4965ac9"],
Cell[357188, 9519, 231, 4, 34, "Output",ExpressionUUID->"f55c5bb6-0c6a-4e0f-99c9-ae3886482f98"]
}, Open  ]],
Cell[CellGroupData[{
Cell[357456, 9528, 536, 14, 52, "Input",ExpressionUUID->"b2e7b7f2-3bac-47ee-b76a-44eee5afff79"],
Cell[357995, 9544, 227, 4, 34, "Output",ExpressionUUID->"8d0ea1bb-8570-43f7-99b4-410c5eb76b9a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[358259, 9553, 587, 16, 52, "Input",ExpressionUUID->"5ccefbf2-e3a6-4caf-ab4b-9d50e333f4d6"],
Cell[358849, 9571, 227, 4, 34, "Output",ExpressionUUID->"9bd01ea2-24e5-43d1-a88d-3d89f84e40b4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359113, 9580, 589, 16, 52, "Input",ExpressionUUID->"f610b0ad-169f-4a46-9957-24f32700d578"],
Cell[359705, 9598, 227, 4, 34, "Output",ExpressionUUID->"5c282956-534d-4861-9938-1066a18cbdcc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[359969, 9607, 585, 16, 52, "Input",ExpressionUUID->"437a03e9-94b0-409c-ba52-7014af8e008d"],
Cell[360557, 9625, 229, 4, 34, "Output",ExpressionUUID->"e5a3659e-f6bc-4cb0-8853-f3d270ae0a00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[360823, 9634, 534, 14, 52, "Input",ExpressionUUID->"7466ecc5-c4cf-4177-9ed7-710d6fff5e0b"],
Cell[361360, 9650, 227, 4, 34, "Output",ExpressionUUID->"3248c6f7-f0a2-42ba-a38d-10233631ceb1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[361624, 9659, 561, 15, 52, "Input",ExpressionUUID->"82fff8bb-43ef-4d42-8225-82d1d4d80a47"],
Cell[362188, 9676, 225, 4, 34, "Output",ExpressionUUID->"f8b569ac-cea7-458a-ac60-108331631d28"]
}, Open  ]],
Cell[CellGroupData[{
Cell[362450, 9685, 531, 14, 52, "Input",ExpressionUUID->"d898eb0d-e580-4802-9ce1-09885e030ccb"],
Cell[362984, 9701, 226, 4, 34, "Output",ExpressionUUID->"47371b47-f1be-4829-9fb8-98196b3ddc12"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363247, 9710, 585, 16, 52, "Input",ExpressionUUID->"740328db-2b98-47a7-999c-8191be653c50"],
Cell[363835, 9728, 227, 4, 34, "Output",ExpressionUUID->"d3fe7bf5-7157-411c-a17e-dd3461460735"]
}, Open  ]],
Cell[CellGroupData[{
Cell[364099, 9737, 1554, 40, 136, "Input",ExpressionUUID->"af1da1c3-3895-471c-b7d2-4a94badf6a14"],
Cell[365656, 9779, 523, 12, 24, "Print",ExpressionUUID->"1f2749cd-57a5-4844-814d-a9b9af41d073"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[366228, 9797, 307, 5, 53, "Section",ExpressionUUID->"41ff08af-5594-4ef5-99c4-b27812bc6d57"],
Cell[366538, 9804, 1800, 45, 157, "Input",ExpressionUUID->"b971f372-e059-4d72-a45c-e5a853ad955f"],
Cell[368341, 9851, 1724, 44, 157, "Input",ExpressionUUID->"9fc54a83-5efa-4442-b25f-1a0403a4744b"]
}, Closed]],
Cell[CellGroupData[{
Cell[370102, 9900, 307, 5, 53, "Section",ExpressionUUID->"3ef35816-d326-4b78-b976-05fbee94fe0a"],
Cell[CellGroupData[{
Cell[370434, 9909, 1636, 41, 136, "Input",ExpressionUUID->"34eb363d-b0de-4891-8be6-bee92a235c7c"],
Cell[CellGroupData[{
Cell[372095, 9954, 529, 12, 40, "Print",ExpressionUUID->"28fd9fed-ce24-4fc5-aa03-1a33ba9c8635"],
Cell[372627, 9968, 950, 20, 47, "Print",ExpressionUUID->"f783870f-34fa-44b6-bb9b-fb85eee2b763"],
Cell[373580, 9990, 1088, 21, 25, "Print",ExpressionUUID->"214e3441-70b0-4233-8217-5eeda64667c9"],
Cell[374671, 10013, 501, 11, 24, "Print",ExpressionUUID->"05e7fefa-44c3-4643-94d8-4a7d2985406e"],
Cell[375175, 10026, 529, 12, 40, "Print",ExpressionUUID->"df55a839-7bc6-43bf-8f96-5303dd04564b"],
Cell[375707, 10040, 529, 12, 40, "Print",ExpressionUUID->"903187b9-085d-4571-b4fb-b34664143b41"],
Cell[376239, 10054, 609, 14, 44, "Print",ExpressionUUID->"f2a3cbc3-9526-4da8-81f5-18eccd80ae9d"],
Cell[376851, 10070, 1250, 23, 25, "Print",ExpressionUUID->"3fd1d481-7bf0-4f8c-8744-ae2699ad1537"],
Cell[378104, 10095, 610, 14, 44, "Print",ExpressionUUID->"7df562d2-e7fc-40a2-a3fe-afb0a1a41fab"],
Cell[378717, 10111, 920, 19, 47, "Print",ExpressionUUID->"3b8e1cf3-7253-41d5-9af4-ba6152ef8769"],
Cell[379640, 10132, 610, 14, 44, "Print",ExpressionUUID->"80a65add-0b3f-43d9-be93-df3525dee23b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[380299, 10152, 591, 16, 52, "Input",ExpressionUUID->"90be3d47-3ec2-45d6-9e7b-0ccb6d0770ba"],
Cell[380893, 10170, 225, 4, 34, "Output",ExpressionUUID->"515424ab-b54b-47f2-8b2d-2830d157d4af"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381155, 10179, 488, 12, 52, "Input",ExpressionUUID->"84995965-f268-425d-944a-ad1762eb0ff6"],
Cell[381646, 10193, 225, 4, 34, "Output",ExpressionUUID->"4dbec7be-c96a-4d54-a0d0-7d63ee352873"]
}, Open  ]],
Cell[CellGroupData[{
Cell[381908, 10202, 591, 16, 52, "Input",ExpressionUUID->"db3ad400-c7f3-4119-afe7-54071a79405e"],
Cell[382502, 10220, 227, 4, 34, "Output",ExpressionUUID->"0b4b7b41-c493-4bde-a054-febaf19e9b51"]
}, Open  ]],
Cell[CellGroupData[{
Cell[382766, 10229, 592, 16, 52, "Input",ExpressionUUID->"9ec488a4-75e5-48bc-95e3-28728468928e"],
Cell[383361, 10247, 224, 4, 34, "Output",ExpressionUUID->"c19cd00e-a9e9-45f2-ab4d-080e928625a7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[383622, 10256, 564, 15, 52, "Input",ExpressionUUID->"8bd1ceb3-6849-420d-b954-cb07a73d460c"],
Cell[384189, 10273, 224, 4, 34, "Output",ExpressionUUID->"13293024-4d11-42a1-affb-5081e325febf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384450, 10282, 564, 15, 52, "Input",ExpressionUUID->"ce4f87f4-2ce2-4ca9-864b-13b5e187041c"],
Cell[385017, 10299, 227, 4, 34, "Output",ExpressionUUID->"0e585c86-2341-44ce-90cc-1e30a7858821"]
}, Open  ]],
Cell[CellGroupData[{
Cell[385281, 10308, 563, 15, 52, "Input",ExpressionUUID->"be941fc0-40d6-4f1d-b64d-04993347150e"],
Cell[385847, 10325, 226, 4, 34, "Output",ExpressionUUID->"de4d0cf2-baec-4354-9d33-0cc91aee6292"]
}, Open  ]],
Cell[CellGroupData[{
Cell[386110, 10334, 1614, 41, 136, "Input",ExpressionUUID->"d3ad4728-b476-40d8-9240-b95871763dca"],
Cell[CellGroupData[{
Cell[387749, 10379, 527, 12, 40, "Print",ExpressionUUID->"acfd950a-e8e1-4ea2-8730-bb075b76dc8b"],
Cell[388279, 10393, 527, 12, 40, "Print",ExpressionUUID->"ed6c0c7a-57cc-4453-9afd-517eacc1dde6"],
Cell[388809, 10407, 608, 14, 44, "Print",ExpressionUUID->"78bf2eac-e1f0-4c19-8d5f-4612a17b9292"],
Cell[389420, 10423, 545, 12, 44, "Print",ExpressionUUID->"ab1860f1-a02d-4f5a-98ad-14e133134e92"],
Cell[389968, 10437, 610, 14, 44, "Print",ExpressionUUID->"50de5173-45b4-415c-9df2-7f8b2f7da7fc"],
Cell[390581, 10453, 3126, 53, 47, "Print",ExpressionUUID->"510593ef-a9e5-4049-a508-80ffa736d758"],
Cell[393710, 10508, 3604, 58, 47, "Print",ExpressionUUID->"81a9d756-a83c-4842-a007-8cbb0afa006f"],
Cell[397317, 10568, 1582, 28, 45, "Print",ExpressionUUID->"7181020f-dedd-44ee-bc51-56f47b6995ec"],
Cell[398902, 10598, 1416, 25, 25, "Print",ExpressionUUID->"48638766-5beb-45cf-adce-6a32bbad92ff"],
Cell[400321, 10625, 1090, 21, 25, "Print",ExpressionUUID->"b632e649-ab6e-4705-a8fd-c74227598eda"],
Cell[401414, 10648, 1432, 26, 25, "Print",ExpressionUUID->"2ad68ca7-16ed-47d7-baf0-941598b06ef6"],
Cell[402849, 10676, 746, 16, 49, "Print",ExpressionUUID->"12b2cbb0-02db-42aa-b6c1-760c2e860e07"],
Cell[403598, 10694, 946, 20, 47, "Print",ExpressionUUID->"a8cf6f42-abb0-43d5-be78-bb4ed44ade22"],
Cell[404547, 10716, 1418, 25, 45, "Print",ExpressionUUID->"99e426d4-c725-4a11-916b-47cd976253d7"],
Cell[405968, 10743, 1438, 25, 45, "Print",ExpressionUUID->"bd6d51ac-5e42-4ce9-933d-b8784b0f599f"],
Cell[407409, 10770, 1424, 25, 25, "Print",ExpressionUUID->"d82c99c8-bba9-4e56-90ab-00906c2a4799"],
Cell[408836, 10797, 1414, 26, 25, "Print",ExpressionUUID->"9f7283b1-fcf9-4aa9-995d-4ec2d288c0cf"],
Cell[410253, 10825, 527, 12, 40, "Print",ExpressionUUID->"629d8598-94f1-44c0-9688-060dd8f0029f"],
Cell[410783, 10839, 3774, 63, 47, "Print",ExpressionUUID->"0ca6b876-ea7a-466c-a5df-55e257b5e051"],
Cell[414560, 10904, 1404, 25, 25, "Print",ExpressionUUID->"687f6f17-499c-454a-ba9e-9a17b815f90e"],
Cell[415967, 10931, 1394, 25, 25, "Print",ExpressionUUID->"d2da4615-6e46-4fca-a14b-600f3e52f832"],
Cell[417364, 10958, 1406, 25, 25, "Print",ExpressionUUID->"cf4d4b80-ac52-4f59-b98f-432b91f24a3a"],
Cell[418773, 10985, 1418, 25, 45, "Print",ExpressionUUID->"3a014c16-24cd-454d-8591-626715382d9b"],
Cell[420194, 11012, 501, 11, 24, "Print",ExpressionUUID->"02809418-6dbf-400f-8633-b6c12dbfb561"],
Cell[420698, 11025, 951, 20, 25, "Print",ExpressionUUID->"300eceef-825a-440e-b7b1-092026d6fad2"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[421698, 11051, 590, 16, 52, "Input",ExpressionUUID->"f60f568f-aae2-4cb9-815b-41084e993afc"],
Cell[422291, 11069, 227, 4, 34, "Output",ExpressionUUID->"298c35a0-833f-4215-b54a-3f72c8922192"]
}, Open  ]],
Cell[CellGroupData[{
Cell[422555, 11078, 588, 16, 52, "Input",ExpressionUUID->"335a1eee-cf68-47de-96f6-aac580619b76"],
Cell[423146, 11096, 227, 4, 34, "Output",ExpressionUUID->"1c3522a9-c613-47fc-9fec-87832d6b60e8"]
}, Open  ]],
Cell[CellGroupData[{
Cell[423410, 11105, 563, 15, 52, "Input",ExpressionUUID->"9da8f57d-5fc3-469c-a12b-e4d6e2747799"],
Cell[423976, 11122, 225, 4, 34, "Output",ExpressionUUID->"9ea0bf75-4174-4ae2-90ca-f50e188adcce"]
}, Open  ]],
Cell[CellGroupData[{
Cell[424238, 11131, 565, 15, 52, "Input",ExpressionUUID->"d3b1a840-2179-4493-aca0-6b95172221cd"],
Cell[424806, 11148, 226, 4, 34, "Output",ExpressionUUID->"e15f9afe-92c8-4cfc-bb7e-a8fe23279f00"]
}, Open  ]],
Cell[CellGroupData[{
Cell[425069, 11157, 539, 15, 52, "Input",ExpressionUUID->"1d9a4669-7953-424b-a929-d666fe9fb3b3"],
Cell[425611, 11174, 225, 4, 34, "Output",ExpressionUUID->"ee1483c4-e699-4a82-a425-5c391e5a7a02"]
}, Open  ]],
Cell[CellGroupData[{
Cell[425873, 11183, 1567, 40, 136, "Input",ExpressionUUID->"76a7313f-e45b-4e37-b14c-305da6a58dd8"],
Cell[CellGroupData[{
Cell[427465, 11227, 452, 10, 24, "Print",ExpressionUUID->"16e453db-626a-4d55-97e2-e5c05164c87c"],
Cell[427920, 11239, 1031, 20, 25, "Print",ExpressionUUID->"62be49f3-3e1e-40be-96fa-7e233e19fa5e"],
Cell[428954, 11261, 478, 11, 40, "Print",ExpressionUUID->"ce5f2a14-385a-462b-95f6-a04a61a5e690"],
Cell[429435, 11274, 452, 10, 24, "Print",ExpressionUUID->"c308f5bf-82a4-4956-9ac7-d98ed068463e"],
Cell[429890, 11286, 478, 11, 40, "Print",ExpressionUUID->"2809ae61-7320-44d2-af5c-0a091637652f"],
Cell[430371, 11299, 451, 10, 24, "Print",ExpressionUUID->"ac795994-7bec-4386-bb85-5415bcdff927"],
Cell[430825, 11311, 452, 10, 24, "Print",ExpressionUUID->"12e9d494-dd45-4361-a2df-05cfb5c3a2f9"],
Cell[431280, 11323, 454, 10, 24, "Print",ExpressionUUID->"0137fb2e-5055-4579-aceb-2a1e8b3e9062"],
Cell[431737, 11335, 454, 10, 24, "Print",ExpressionUUID->"0b9d9e42-99af-426a-8e9c-6fd69af0eaba"],
Cell[432194, 11347, 1047, 20, 25, "Print",ExpressionUUID->"93db3678-a946-4945-a56a-47fd1e9818a0"],
Cell[433244, 11369, 559, 13, 44, "Print",ExpressionUUID->"9abc5f83-99a5-4734-b392-9d0a88031d5c"],
Cell[433806, 11384, 1385, 25, 45, "Print",ExpressionUUID->"51b43b6e-6985-42c2-be16-66c6e85a9fbe"],
Cell[435194, 11411, 3469, 57, 47, "Print",ExpressionUUID->"d8a2e892-efc9-429c-9d55-954c3153fded"],
Cell[438666, 11470, 478, 11, 40, "Print",ExpressionUUID->"6944abd5-1e87-434b-bb44-3dd40233344f"],
Cell[439147, 11483, 478, 11, 40, "Print",ExpressionUUID->"e897412f-e6cf-4d8d-8d84-f6fdefdc8eb8"],
Cell[439628, 11496, 480, 11, 40, "Print",ExpressionUUID->"6c9b094b-7f38-4b1c-9386-44e5498cd5a4"],
Cell[440111, 11509, 993, 20, 25, "Print",ExpressionUUID->"9214113c-7036-4a40-a2ce-713dfe85ce7f"],
Cell[441107, 11531, 1397, 25, 45, "Print",ExpressionUUID->"69772a3c-921f-47d2-afd3-dedf69f68aff"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[442553, 11562, 1710, 43, 157, "Input",ExpressionUUID->"a5fe1611-919f-4e6b-9510-7abc9e99e2da"],
Cell[CellGroupData[{
Cell[444288, 11609, 387, 9, 24, "Print",ExpressionUUID->"c9789da0-2dbb-4960-850f-081b4f59838a"],
Cell[444678, 11620, 387, 9, 24, "Print",ExpressionUUID->"8a669ebc-85c5-4213-b7cb-289bf7ef925a"],
Cell[445068, 11631, 385, 9, 24, "Print",ExpressionUUID->"c7a1fd68-4d67-4c85-80b3-60c504a47b7a"],
Cell[445456, 11642, 387, 9, 24, "Print",ExpressionUUID->"3e96d0fa-99be-4731-92e3-6e9cfddf5751"],
Cell[445846, 11653, 385, 9, 24, "Print",ExpressionUUID->"c87a6b69-4ef0-4d75-ae20-9ac8d607c7e0"],
Cell[446234, 11664, 385, 9, 24, "Print",ExpressionUUID->"2eb5ab33-17ff-42ac-a565-9407cd9b3e11"],
Cell[446622, 11675, 385, 9, 24, "Print",ExpressionUUID->"fc8c080b-7b0f-4348-8ba4-6a907335b42f"],
Cell[447010, 11686, 384, 9, 24, "Print",ExpressionUUID->"443ea404-242f-47e8-ad4b-525bfcbbf7d4"],
Cell[447397, 11697, 385, 9, 24, "Print",ExpressionUUID->"e4debd65-abf2-4ba2-b416-deb6f4accee6"],
Cell[447785, 11708, 385, 9, 24, "Print",ExpressionUUID->"967f6aa9-c9c3-4bf5-a8c8-0e9fd421d528"],
Cell[448173, 11719, 385, 9, 24, "Print",ExpressionUUID->"1b8fe1fe-160e-4115-b144-4846ff03947d"],
Cell[448561, 11730, 547, 12, 24, "Print",ExpressionUUID->"65465627-1646-4457-9338-36b21bd6ec61"],
Cell[449111, 11744, 385, 9, 24, "Print",ExpressionUUID->"c1ebd99c-4b30-471d-9e3b-a5c526816691"],
Cell[449499, 11755, 385, 9, 24, "Print",ExpressionUUID->"797bcf16-f401-4125-b39c-cfa131b51dc6"],
Cell[449887, 11766, 385, 9, 24, "Print",ExpressionUUID->"cd4be33c-8d45-42b4-87bd-7ffb89d426aa"],
Cell[450275, 11777, 385, 9, 24, "Print",ExpressionUUID->"3916c1b7-fa1e-46af-863f-e6980f99f190"],
Cell[450663, 11788, 385, 9, 24, "Print",ExpressionUUID->"d9a697b7-998a-4a7f-afd7-cc526ab886ee"],
Cell[451051, 11799, 385, 9, 24, "Print",ExpressionUUID->"5d47e5c8-a8e4-45e8-9f7c-a46c346d6a15"],
Cell[451439, 11810, 387, 9, 24, "Print",ExpressionUUID->"d1f31f2d-83c3-479b-967d-0da530a1e17b"],
Cell[451829, 11821, 387, 9, 24, "Print",ExpressionUUID->"14405f2b-a0fc-4417-9e84-b214facfbf7e"],
Cell[452219, 11832, 385, 9, 24, "Print",ExpressionUUID->"fece1a32-58e3-4aac-a1b8-a79ac369e0d5"],
Cell[452607, 11843, 385, 9, 24, "Print",ExpressionUUID->"d8aefddd-a147-42c2-b5ca-7cd867018ca3"],
Cell[452995, 11854, 385, 9, 24, "Print",ExpressionUUID->"49c3158c-0898-4d33-9153-7daa74094798"],
Cell[453383, 11865, 385, 9, 24, "Print",ExpressionUUID->"cb0a9e85-2ae7-4578-a04e-34e236b19ac5"],
Cell[453771, 11876, 387, 9, 24, "Print",ExpressionUUID->"3ea60479-b887-44fd-aa98-37aef619dbc8"],
Cell[454161, 11887, 387, 9, 24, "Print",ExpressionUUID->"92837f4d-aef9-4636-a1c4-0846573d1dfa"],
Cell[454551, 11898, 385, 9, 24, "Print",ExpressionUUID->"6bfa8ef1-f1f3-4146-b601-bfacc0d43f90"],
Cell[454939, 11909, 385, 9, 24, "Print",ExpressionUUID->"84926439-3592-40ec-9ba1-0a2b97b0a4d3"],
Cell[455327, 11920, 385, 9, 24, "Print",ExpressionUUID->"3453b983-f819-4a6e-a2d6-d86e2e564b46"],
Cell[455715, 11931, 385, 9, 24, "Print",ExpressionUUID->"4c9a9528-820f-4cef-a145-13925edfdc9a"],
Cell[456103, 11942, 385, 9, 24, "Print",ExpressionUUID->"3881f79f-aa13-48a7-8ca7-9f83bb87ec09"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[456537, 11957, 1567, 40, 136, "Input",ExpressionUUID->"865cca2d-d9d1-4fbf-8cc2-c9ede2b78f42"],
Cell[CellGroupData[{
Cell[458129, 12001, 452, 10, 24, "Print",ExpressionUUID->"0c6656de-d4f2-47dc-a9b8-2a98a54e51bd"],
Cell[458584, 12013, 1031, 20, 25, "Print",ExpressionUUID->"d788c4d6-3fb8-422c-a83e-09a36f4b1456"],
Cell[459618, 12035, 478, 11, 40, "Print",ExpressionUUID->"b377b391-a1dd-4441-9b13-a6ed3b88013f"],
Cell[460099, 12048, 452, 10, 24, "Print",ExpressionUUID->"64fb2d22-38bc-4bd2-919b-2fcb588223b8"],
Cell[460554, 12060, 478, 11, 40, "Print",ExpressionUUID->"3cbef5b3-760e-46a6-bb13-ac0e2af2c7a3"],
Cell[461035, 12073, 451, 10, 24, "Print",ExpressionUUID->"cac511ad-d05d-4d2b-9f38-00732c1e5f20"],
Cell[461489, 12085, 452, 10, 24, "Print",ExpressionUUID->"5dea78d9-2909-4f9d-bdb9-2f63732a0caa"],
Cell[461944, 12097, 454, 10, 24, "Print",ExpressionUUID->"b34e7bd6-7262-4838-a2b1-56d51c9d4a69"],
Cell[462401, 12109, 454, 10, 24, "Print",ExpressionUUID->"66880331-2e24-4fb2-b983-1f893aa7be6d"],
Cell[462858, 12121, 1047, 20, 25, "Print",ExpressionUUID->"55729fa7-50d4-4658-87ea-b418f2ef2720"],
Cell[463908, 12143, 559, 13, 44, "Print",ExpressionUUID->"f9babf28-6c88-4e5a-88d1-793db3d2d779"],
Cell[464470, 12158, 1385, 25, 45, "Print",ExpressionUUID->"bcb25988-2cdd-4bed-9374-ba57afd0750a"],
Cell[465858, 12185, 3469, 57, 47, "Print",ExpressionUUID->"3d143899-1c9c-4bc5-b7f1-0764d9e698b7"],
Cell[469330, 12244, 478, 11, 40, "Print",ExpressionUUID->"9446b0fa-de35-4cea-8d85-d0911ca28b0b"],
Cell[469811, 12257, 478, 11, 40, "Print",ExpressionUUID->"57585e89-fc9c-419a-9a5e-897f1c6d266d"],
Cell[470292, 12270, 480, 11, 40, "Print",ExpressionUUID->"1eb1bf7e-7004-4c61-a864-77923ecffada"],
Cell[470775, 12283, 993, 20, 25, "Print",ExpressionUUID->"85349caa-23d5-47f0-b69a-105bd032bba8"],
Cell[471771, 12305, 1397, 25, 45, "Print",ExpressionUUID->"9eff09bc-a639-4cb6-8839-a72c1aaa790e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[473217, 12336, 731, 20, 52, "Input",ExpressionUUID->"04b0a64e-7d6c-4484-906e-d928baac7e23"],
Cell[473951, 12358, 156, 3, 34, "Output",ExpressionUUID->"d5d1ad1c-473f-4789-baa3-558c6f174566"]
}, Open  ]],
Cell[CellGroupData[{
Cell[474144, 12366, 590, 16, 52, "Input",ExpressionUUID->"e3781560-0c39-4a1b-b887-5f544333de37"],
Cell[474737, 12384, 156, 3, 34, "Output",ExpressionUUID->"81ff0bad-902e-48fc-bebe-1826ebe33b98"]
}, Open  ]],
Cell[CellGroupData[{
Cell[474930, 12392, 592, 16, 52, "Input",ExpressionUUID->"160fa5ac-96b6-4a14-a85e-b1eecaf03383"],
Cell[475525, 12410, 156, 3, 34, "Output",ExpressionUUID->"0d2f5921-145e-442a-89e1-b22db5bd674d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[475718, 12418, 590, 16, 52, "Input",ExpressionUUID->"bb11acfd-d9f2-458a-83d6-dcb34b4af154"],
Cell[476311, 12436, 180, 3, 34, "Output",ExpressionUUID->"53599fb9-4357-4ede-acac-cdc7fbe6c0e7"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[476540, 12445, 330, 5, 53, "Section",ExpressionUUID->"8792a679-ab2c-462b-b71e-4fafc4e0ef1c"],
Cell[CellGroupData[{
Cell[476895, 12454, 1694, 43, 157, "Input",ExpressionUUID->"dd34f919-01df-40f0-88db-0638a6a05735"],
Cell[CellGroupData[{
Cell[478614, 12501, 381, 9, 24, "Print",ExpressionUUID->"2509dfff-dfd1-4bed-b140-080a11c9b6de"],
Cell[478998, 12512, 380, 9, 24, "Print",ExpressionUUID->"ef500f7f-729e-40cc-8f41-f8abf1c67f90"],
Cell[479381, 12523, 381, 9, 24, "Print",ExpressionUUID->"d75432bb-21ad-4cf8-89e0-e071236d9328"],
Cell[479765, 12534, 380, 9, 24, "Print",ExpressionUUID->"237af875-ef9d-4413-ae37-cb700c705973"],
Cell[480148, 12545, 383, 9, 24, "Print",ExpressionUUID->"5a250256-678b-44d1-baeb-41fdb24d3465"],
Cell[480534, 12556, 381, 9, 24, "Print",ExpressionUUID->"cf33966e-bba5-4f14-84eb-0cc5f7b147c8"],
Cell[480918, 12567, 381, 9, 24, "Print",ExpressionUUID->"4cf608cd-ce0e-4231-ad72-9ad5d88e90cd"],
Cell[481302, 12578, 381, 9, 24, "Print",ExpressionUUID->"a6b9ffe5-16c9-4726-be3f-cd3ec31f860b"],
Cell[481686, 12589, 381, 9, 24, "Print",ExpressionUUID->"c1598484-e5fc-4594-90d5-3f69150de5d9"],
Cell[482070, 12600, 383, 9, 24, "Print",ExpressionUUID->"2cbc2c26-40b1-42f0-8d0e-b3594f2cfc7b"],
Cell[482456, 12611, 382, 9, 24, "Print",ExpressionUUID->"cefea85d-87d1-4af6-8ba2-609c78bcfb66"],
Cell[482841, 12622, 383, 9, 24, "Print",ExpressionUUID->"bb3f2673-390d-4c1f-8d09-0981b6308544"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[483273, 12637, 1742, 43, 157, "Input",ExpressionUUID->"c8ca4482-4326-43d4-9368-e74843c9b4c2"],
Cell[CellGroupData[{
Cell[485040, 12684, 433, 10, 24, "Print",ExpressionUUID->"ac9eeb59-0e72-4658-b55f-cde0ccf329ad"],
Cell[485476, 12696, 433, 10, 24, "Print",ExpressionUUID->"d1948b96-7a66-4f5f-8a12-478efed59192"],
Cell[485912, 12708, 431, 10, 24, "Print",ExpressionUUID->"423c1bce-c422-487d-b7fe-894fc1e1a3cc"],
Cell[486346, 12720, 431, 10, 24, "Print",ExpressionUUID->"acfe1d78-96a8-439b-bdf4-493e1d227970"],
Cell[486780, 12732, 431, 10, 24, "Print",ExpressionUUID->"29f11a9c-f74e-4a65-b059-23fa0c9aff8d"],
Cell[487214, 12744, 430, 10, 24, "Print",ExpressionUUID->"eee21a8e-cf8f-442b-80c4-d693409553da"],
Cell[487647, 12756, 431, 10, 24, "Print",ExpressionUUID->"c5ff6aa1-8c78-448c-80c9-0b734cd8b7cb"],
Cell[488081, 12768, 431, 10, 24, "Print",ExpressionUUID->"2f7f86f5-3fbc-4ae1-93d3-3d0665825acb"],
Cell[488515, 12780, 431, 10, 24, "Print",ExpressionUUID->"c74b791a-b5ff-43bf-a4a2-58351e823081"],
Cell[488949, 12792, 431, 10, 24, "Print",ExpressionUUID->"83fb6247-56f6-4374-bb41-0ee0ca019023"],
Cell[489383, 12804, 433, 10, 24, "Print",ExpressionUUID->"250daca5-ff23-440b-93b7-df8ecf877546"],
Cell[489819, 12816, 431, 10, 24, "Print",ExpressionUUID->"f0653d89-5e3a-4fb9-bd0f-aa1a68abc697"],
Cell[490253, 12828, 431, 10, 24, "Print",ExpressionUUID->"c3f5fe06-b8d7-4c6b-9ecc-a09604b10cb1"],
Cell[490687, 12840, 431, 10, 24, "Print",ExpressionUUID->"8016a923-e40f-456d-b24e-482b6781d060"],
Cell[491121, 12852, 431, 10, 24, "Print",ExpressionUUID->"c8002b83-8ea7-4bc0-82d2-1b77748cc114"],
Cell[491555, 12864, 431, 10, 24, "Print",ExpressionUUID->"b6c0d010-9a1f-457e-afc8-0c39712db9c3"],
Cell[491989, 12876, 433, 10, 24, "Print",ExpressionUUID->"948fba2b-a292-4167-879e-fe2b983d1086"],
Cell[492425, 12888, 431, 10, 24, "Print",ExpressionUUID->"a0077872-369c-4e8f-bbd5-72cc34b58d4b"],
Cell[492859, 12900, 433, 10, 24, "Print",ExpressionUUID->"845c85f2-0234-4c5f-84c8-b2d888043bef"],
Cell[493295, 12912, 431, 10, 24, "Print",ExpressionUUID->"fe93913a-4f8b-4455-b0be-3185d964adab"],
Cell[493729, 12924, 431, 10, 24, "Print",ExpressionUUID->"0d58ff1a-b643-455b-a33d-e197092ecd55"],
Cell[494163, 12936, 433, 10, 24, "Print",ExpressionUUID->"b7e2373e-7876-4384-9913-ae56df68975b"],
Cell[494599, 12948, 433, 10, 24, "Print",ExpressionUUID->"b185495a-2561-4d89-a8a3-3b851d544b17"],
Cell[495035, 12960, 431, 10, 24, "Print",ExpressionUUID->"c55d1945-0ccb-46af-81a7-25d9ae1b33c4"],
Cell[495469, 12972, 431, 10, 24, "Print",ExpressionUUID->"0eebc374-43c0-46bf-9bb0-21ef642217fb"],
Cell[495903, 12984, 430, 10, 24, "Print",ExpressionUUID->"7d56c6c5-903c-4c38-8d78-9a876eb469a0"],
Cell[496336, 12996, 431, 10, 24, "Print",ExpressionUUID->"e920cd63-160e-42fb-9bb5-57de50793e83"],
Cell[496770, 13008, 431, 10, 24, "Print",ExpressionUUID->"5b050f4d-f4b1-4edb-b8a3-f3d28502eb3e"],
Cell[497204, 13020, 431, 10, 24, "Print",ExpressionUUID->"c4871c5b-7074-4460-b4c2-a1efaa1efa5e"],
Cell[497638, 13032, 431, 10, 24, "Print",ExpressionUUID->"f47ffc21-9a5f-4a5a-a96b-ed04540f4b80"],
Cell[498072, 13044, 433, 10, 24, "Print",ExpressionUUID->"b9a4ac9a-b34b-41f5-b0cf-78aeb3195027"],
Cell[498508, 13056, 431, 10, 24, "Print",ExpressionUUID->"4308773c-3eda-4ff6-a801-b6418c643de7"],
Cell[498942, 13068, 430, 10, 24, "Print",ExpressionUUID->"34f511d6-bbb0-43f6-b202-84afcef71078"],
Cell[499375, 13080, 431, 10, 24, "Print",ExpressionUUID->"97a0a58d-f616-4ec4-89b6-a1e3c7c3e543"],
Cell[499809, 13092, 571, 12, 24, "Print",ExpressionUUID->"523b0e03-1a91-4430-8f7b-ab0209bb3305"],
Cell[500383, 13106, 431, 10, 24, "Print",ExpressionUUID->"c467cf87-c8b2-4eb6-bf74-e6750017e3e1"],
Cell[500817, 13118, 431, 10, 24, "Print",ExpressionUUID->"d9e80a0c-3d16-4540-9545-18a55e571ddc"],
Cell[501251, 13130, 431, 10, 24, "Print",ExpressionUUID->"10e9db2b-db43-4315-97ef-d46e1dc60d9f"],
Cell[501685, 13142, 433, 10, 24, "Print",ExpressionUUID->"4f406da6-5db0-4d48-8b89-4929ab82f5ab"],
Cell[502121, 13154, 431, 10, 24, "Print",ExpressionUUID->"4e99aaa6-9f05-40b7-82f4-f900dd3649db"],
Cell[502555, 13166, 431, 10, 24, "Print",ExpressionUUID->"7205936f-683b-4f62-b9fe-709a5534208f"],
Cell[502989, 13178, 430, 10, 24, "Print",ExpressionUUID->"1501fa03-3b36-489b-976c-6d527ace5b09"],
Cell[503422, 13190, 431, 10, 24, "Print",ExpressionUUID->"92750f87-a442-439b-864e-fb0933ddb66b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[503902, 13206, 487, 12, 52, "Input",ExpressionUUID->"d4c04829-0a4c-4cd7-98da-25a1dd05d5fe"],
Cell[504392, 13220, 229, 4, 34, "Output",ExpressionUUID->"393a63ac-3349-4fce-8d41-439388994d08"]
}, Open  ]],
Cell[CellGroupData[{
Cell[504658, 13229, 1719, 43, 157, "Input",ExpressionUUID->"6c134965-e434-44e6-b6ed-9be4c54d0462"],
Cell[CellGroupData[{
Cell[506402, 13276, 383, 9, 24, "Print",ExpressionUUID->"9e4a35bd-45d6-4921-abb9-62c7daa645e6"],
Cell[506788, 13287, 381, 9, 24, "Print",ExpressionUUID->"bf10ff82-d75d-4d31-9a59-bc652382b762"],
Cell[507172, 13298, 381, 9, 24, "Print",ExpressionUUID->"c1ef5886-4ca9-4058-a560-a5043a10ba57"],
Cell[507556, 13309, 381, 9, 24, "Print",ExpressionUUID->"72cb8b9c-ed8b-49a8-8d65-6b5ee9fe1da9"],
Cell[507940, 13320, 381, 9, 24, "Print",ExpressionUUID->"75692d43-afe4-4546-b698-039ad8e2fd99"],
Cell[508324, 13331, 381, 9, 24, "Print",ExpressionUUID->"fd445ff9-6226-4a2b-97ad-eb4b324efae1"],
Cell[508708, 13342, 381, 9, 24, "Print",ExpressionUUID->"e2ecc04c-f5bc-40c4-8e46-480ca10ac811"],
Cell[509092, 13353, 381, 9, 24, "Print",ExpressionUUID->"09e964a4-9c26-4b68-9885-454c2b89ecbc"],
Cell[509476, 13364, 381, 9, 24, "Print",ExpressionUUID->"73c739c8-65ca-4bc4-8519-900b49c280bb"],
Cell[509860, 13375, 381, 9, 24, "Print",ExpressionUUID->"6620d897-71f0-4091-86e6-7355f8235673"],
Cell[510244, 13386, 383, 9, 24, "Print",ExpressionUUID->"62222a6f-b068-421b-bb3a-6b02fc2cff60"],
Cell[510630, 13397, 381, 9, 24, "Print",ExpressionUUID->"768dd8d7-0e66-4e38-b843-a2a4ae2cd5ac"],
Cell[511014, 13408, 381, 9, 24, "Print",ExpressionUUID->"5ec4f361-a9fc-460f-809f-19c615b35590"],
Cell[511398, 13419, 383, 9, 24, "Print",ExpressionUUID->"c6e858a5-b11d-4715-ab2f-ed010871aaec"],
Cell[511784, 13430, 381, 9, 24, "Print",ExpressionUUID->"302755c7-f19f-4b38-805d-89d32440098b"],
Cell[512168, 13441, 381, 9, 24, "Print",ExpressionUUID->"e9209f61-1117-43f4-8689-c35248f3286b"],
Cell[512552, 13452, 381, 9, 24, "Print",ExpressionUUID->"5edaccd5-1cbb-464f-a92f-c30a53926f29"],
Cell[512936, 13463, 380, 9, 24, "Print",ExpressionUUID->"4374c432-ac2f-44da-8028-4d47a1cedf42"],
Cell[513319, 13474, 383, 9, 24, "Print",ExpressionUUID->"4e7b5230-165b-4671-9486-aa3670afcaf3"],
Cell[513705, 13485, 381, 9, 24, "Print",ExpressionUUID->"bcb52ee0-e67b-4695-bcac-0089799955f2"],
Cell[514089, 13496, 381, 9, 24, "Print",ExpressionUUID->"6ef7510a-5ec7-474d-a8f5-a6e9e58c369f"],
Cell[514473, 13507, 383, 9, 24, "Print",ExpressionUUID->"71d2b944-34af-431e-97ed-3e7c55555d05"],
Cell[514859, 13518, 383, 9, 24, "Print",ExpressionUUID->"c6ab8fe0-2fe8-4088-ab4b-130f2a3e3279"],
Cell[515245, 13529, 381, 9, 24, "Print",ExpressionUUID->"ad773a55-8932-46a7-b943-ea9f86ac59d6"],
Cell[515629, 13540, 381, 9, 24, "Print",ExpressionUUID->"5c40afd1-ad9d-489f-9e5f-01ce604493eb"],
Cell[516013, 13551, 383, 9, 24, "Print",ExpressionUUID->"082acde6-9f66-4edb-a1fc-a3cd84992a4d"],
Cell[516399, 13562, 381, 9, 24, "Print",ExpressionUUID->"f3e1f1ff-40d6-4445-8632-df1171560c34"],
Cell[516783, 13573, 383, 9, 24, "Print",ExpressionUUID->"a6feabfd-ab49-4612-be8e-8bd9702b5beb"],
Cell[517169, 13584, 381, 9, 24, "Print",ExpressionUUID->"014471c1-0c60-438e-89e5-0db86780158b"],
Cell[517553, 13595, 383, 9, 24, "Print",ExpressionUUID->"e25bbf56-e19a-4d10-ab0f-bb8ab6a2fbdb"],
Cell[517939, 13606, 381, 9, 24, "Print",ExpressionUUID->"9da5f98f-c88b-4d7d-a048-9709c4d0ee93"],
Cell[518323, 13617, 381, 9, 24, "Print",ExpressionUUID->"e3c1d966-0b67-4d63-b686-cce0675e4186"],
Cell[518707, 13628, 383, 9, 24, "Print",ExpressionUUID->"98c78d7a-c90e-45af-97bb-ca329477301c"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[519139, 13643, 1685, 43, 157, "Input",ExpressionUUID->"785066e8-08c2-4503-b4a1-49317b640d99"],
Cell[CellGroupData[{
Cell[520849, 13690, 378, 9, 24, "Print",ExpressionUUID->"b97af507-33ba-44e9-aff5-6def76d24166"],
Cell[521230, 13701, 378, 9, 24, "Print",ExpressionUUID->"736f9069-de67-4b89-b1ed-04da973b282e"],
Cell[521611, 13712, 378, 9, 24, "Print",ExpressionUUID->"6eb83dc3-e719-4397-9d32-951bb6cfd74d"],
Cell[521992, 13723, 378, 9, 24, "Print",ExpressionUUID->"4a160893-315a-46d4-a31e-97a2d65ec465"],
Cell[522373, 13734, 378, 9, 24, "Print",ExpressionUUID->"1e133b1c-c8cc-49d9-9582-d8e91089e53e"],
Cell[522754, 13745, 378, 9, 24, "Print",ExpressionUUID->"c1626197-b360-4331-b292-79bd9086a20e"],
Cell[523135, 13756, 377, 9, 24, "Print",ExpressionUUID->"337444c1-cf03-4a26-90ec-39e8ce3070c9"],
Cell[523515, 13767, 380, 9, 24, "Print",ExpressionUUID->"420982cb-ed8e-40b5-885d-bd6c90db7f9d"],
Cell[523898, 13778, 378, 9, 24, "Print",ExpressionUUID->"604073bb-af5a-468d-8ab4-6738459dfb5f"],
Cell[524279, 13789, 382, 9, 24, "Print",ExpressionUUID->"8ae5cefd-ffac-4953-8555-3c28b1091397"],
Cell[524664, 13800, 380, 9, 24, "Print",ExpressionUUID->"13c2149b-54c7-43d5-8b65-39dc9d5574f5"],
Cell[525047, 13811, 380, 9, 24, "Print",ExpressionUUID->"931534f2-84f3-4e65-9ab0-2d14c8b6e643"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[525476, 13826, 1684, 43, 157, "Input",ExpressionUUID->"ac369f24-a2d0-4708-89e1-43b16bf0d385"],
Cell[CellGroupData[{
Cell[527185, 13873, 337, 9, 24, "Print",ExpressionUUID->"d7ef3900-0a69-4dbd-a730-fe55fd461af6"],
Cell[527525, 13884, 339, 9, 24, "Print",ExpressionUUID->"fab21e28-8837-4c73-ad13-81c9f7db9dc0"],
Cell[527867, 13895, 337, 9, 24, "Print",ExpressionUUID->"d25e8e7f-7820-4570-9889-ecbae11f58f5"],
Cell[528207, 13906, 339, 9, 24, "Print",ExpressionUUID->"949899f1-9163-4cc9-96d7-8457ac6cbffe"],
Cell[528549, 13917, 337, 9, 24, "Print",ExpressionUUID->"98319caa-6b99-4718-9906-330a6d32c459"],
Cell[528889, 13928, 1112, 22, 25, "Print",ExpressionUUID->"2b69211e-c745-4e2c-955e-f753d454b416"],
Cell[530004, 13952, 337, 9, 24, "Print",ExpressionUUID->"3abb1489-b2dd-4a3a-a31b-ce2d7679b19a"],
Cell[530344, 13963, 337, 9, 24, "Print",ExpressionUUID->"c5d46259-a046-4da3-8eda-c1d55af83d57"],
Cell[530684, 13974, 339, 9, 24, "Print",ExpressionUUID->"b47c9279-60da-48fe-af09-a082cf0fa1ef"],
Cell[531026, 13985, 337, 9, 24, "Print",ExpressionUUID->"89b389f1-e00d-4bd7-b0a1-36a1b9dbbcf2"],
Cell[531366, 13996, 336, 9, 24, "Print",ExpressionUUID->"7e154f0c-c8f2-48fb-aa4b-12dc16411187"],
Cell[531705, 14007, 337, 9, 24, "Print",ExpressionUUID->"755e9072-33c6-42fe-9351-75834d9e0581"],
Cell[532045, 14018, 339, 9, 24, "Print",ExpressionUUID->"896fc361-5995-42cb-b088-8ffc0c27674a"],
Cell[532387, 14029, 499, 12, 24, "Print",ExpressionUUID->"57840e1b-fb6d-407d-b5bb-d6f9e7409b39"],
Cell[532889, 14043, 337, 9, 24, "Print",ExpressionUUID->"787f5503-0579-414c-ab97-8a785cded867"],
Cell[533229, 14054, 337, 9, 24, "Print",ExpressionUUID->"d15f8094-9b71-47c3-ab65-a9a63293e867"],
Cell[533569, 14065, 337, 9, 24, "Print",ExpressionUUID->"71f998c7-bc47-4794-8a27-6d7451e71652"],
Cell[533909, 14076, 339, 9, 24, "Print",ExpressionUUID->"37d6b0c6-d730-4a9f-ac2b-205510c9783a"],
Cell[534251, 14087, 339, 9, 24, "Print",ExpressionUUID->"bc08955f-19f5-44fd-a8a3-40d6ffde7981"],
Cell[534593, 14098, 337, 9, 24, "Print",ExpressionUUID->"e6f91200-dcd5-4621-b4f3-9df986322e45"],
Cell[534933, 14109, 503, 12, 40, "Print",ExpressionUUID->"25044c41-92be-434a-9e88-b3c175718aeb"],
Cell[535439, 14123, 337, 9, 24, "Print",ExpressionUUID->"24ffba37-aa1e-4964-8462-1b90d292cdcb"],
Cell[535779, 14134, 337, 9, 24, "Print",ExpressionUUID->"8843134f-bd92-46ce-9b0d-36694a735af8"],
Cell[536119, 14145, 337, 9, 24, "Print",ExpressionUUID->"3c835345-99dc-4ee7-8d2c-e7d63b4e4757"],
Cell[536459, 14156, 337, 9, 24, "Print",ExpressionUUID->"b80c5690-012c-4c1b-96f4-c83e72c80bf8"],
Cell[536799, 14167, 337, 9, 24, "Print",ExpressionUUID->"f76cbb10-f30e-47dd-bd77-65132659d3b2"],
Cell[537139, 14178, 337, 9, 24, "Print",ExpressionUUID->"ad4602ec-d54b-45ac-b03a-5568bf7161d1"],
Cell[537479, 14189, 337, 9, 24, "Print",ExpressionUUID->"f3027705-11ca-4e18-b3ec-32b178b72dcd"],
Cell[537819, 14200, 339, 9, 24, "Print",ExpressionUUID->"199838d3-3ffc-4284-90bb-578919b50cac"],
Cell[538161, 14211, 503, 12, 40, "Print",ExpressionUUID->"7488f821-e8a6-4db6-a14b-024a4a2a5419"],
Cell[538667, 14225, 337, 9, 24, "Print",ExpressionUUID->"c462ed5a-443e-4efa-888b-8836ab0195cb"],
Cell[539007, 14236, 337, 9, 24, "Print",ExpressionUUID->"28e4b844-26c3-4c2a-a14a-ac4e048a738f"],
Cell[539347, 14247, 337, 9, 24, "Print",ExpressionUUID->"786a7bfd-fe91-4d90-8109-94301ae5c79c"],
Cell[539687, 14258, 337, 9, 24, "Print",ExpressionUUID->"1b402b75-7bbb-44dc-a193-f91c587cee6e"],
Cell[540027, 14269, 337, 9, 24, "Print",ExpressionUUID->"440f5c8a-5837-4ad4-b6d3-acd4d2c38d1b"],
Cell[540367, 14280, 337, 9, 24, "Print",ExpressionUUID->"b99e9204-f043-48b7-95fb-f780ea95807e"],
Cell[540707, 14291, 337, 9, 24, "Print",ExpressionUUID->"a06b4432-7204-414e-b69e-1cfa30852766"],
Cell[541047, 14302, 337, 9, 24, "Print",ExpressionUUID->"29112a5c-7d1c-4db2-b18e-342ffcebc655"],
Cell[541387, 14313, 339, 9, 24, "Print",ExpressionUUID->"5e332d6d-804d-4040-9d96-0fb3b38a072e"],
Cell[541729, 14324, 339, 9, 24, "Print",ExpressionUUID->"907d5cf0-e0bf-4d8e-8952-995d8fe08aaa"],
Cell[542071, 14335, 337, 9, 24, "Print",ExpressionUUID->"ab0474f0-d890-4648-be78-29ee8595c0df"],
Cell[542411, 14346, 337, 9, 24, "Print",ExpressionUUID->"777824f4-9f17-4789-a65d-6b5016ca84bf"],
Cell[542751, 14357, 339, 9, 24, "Print",ExpressionUUID->"8538dc33-e8ab-4c72-8387-090c8ce8a942"],
Cell[543093, 14368, 339, 9, 24, "Print",ExpressionUUID->"2baf7efb-a0e5-434f-a604-da4203519061"],
Cell[543435, 14379, 337, 9, 24, "Print",ExpressionUUID->"470c9cc3-0350-4f6e-8cca-40493fab63f9"],
Cell[543775, 14390, 337, 9, 24, "Print",ExpressionUUID->"a909b55a-ace0-4e41-989f-696200e7836e"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[544161, 14405, 591, 16, 52, "Input",ExpressionUUID->"628e6a6b-09f5-42db-8563-5eef739fdf6d"],
Cell[544755, 14423, 249, 4, 34, "Output",ExpressionUUID->"841b9768-7a06-4729-92be-6bbb63a37b3c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[545041, 14432, 592, 16, 52, "Input",ExpressionUUID->"3c492f28-7032-462c-a056-ea40bbd7b723"],
Cell[545636, 14450, 227, 4, 34, "Output",ExpressionUUID->"59602773-11c3-4d3f-8adf-df0a7d6cef3c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[545900, 14459, 1711, 43, 157, "Input",ExpressionUUID->"142499a4-82a9-42f2-834a-97511d64b050"],
Cell[CellGroupData[{
Cell[547636, 14506, 362, 9, 24, "Print",ExpressionUUID->"a1889319-b99a-4ce7-a086-d9f0042a0a15"],
Cell[548001, 14517, 362, 9, 24, "Print",ExpressionUUID->"7df83f3e-dbfb-4430-bc3d-04d61390d8b8"],
Cell[548366, 14528, 362, 9, 24, "Print",ExpressionUUID->"ed2e34d0-e92d-4dbd-8346-aff563875558"],
Cell[548731, 14539, 362, 9, 24, "Print",ExpressionUUID->"171587bd-140a-4d34-a41b-9246be1d5b27"],
Cell[549096, 14550, 362, 9, 24, "Print",ExpressionUUID->"5bc2b24b-e580-46fd-a351-5a745e4ecb68"],
Cell[549461, 14561, 362, 9, 24, "Print",ExpressionUUID->"96c399a7-9615-4a1c-8078-a2f53c2f80c5"],
Cell[549826, 14572, 362, 9, 24, "Print",ExpressionUUID->"75dd7305-681a-43c4-a9e0-cd3c33f2f53a"],
Cell[550191, 14583, 364, 9, 24, "Print",ExpressionUUID->"d90e813c-d374-40e3-9f35-70396deed566"],
Cell[550558, 14594, 362, 9, 24, "Print",ExpressionUUID->"024ae7f0-227d-4e1e-8847-16b4430092b0"],
Cell[550923, 14605, 362, 9, 24, "Print",ExpressionUUID->"dd6e5d7d-b3f0-44da-9ed8-7d87f38f4e99"],
Cell[551288, 14616, 362, 9, 24, "Print",ExpressionUUID->"468cd588-1158-4449-9a14-ec59c58b3cfd"],
Cell[551653, 14627, 364, 9, 24, "Print",ExpressionUUID->"db5ae223-aaed-4b05-bc1b-7710e571f544"],
Cell[552020, 14638, 611, 14, 44, "Print",ExpressionUUID->"b4625f17-f551-40bc-8704-f6f64dc97c92"],
Cell[552634, 14654, 364, 9, 24, "Print",ExpressionUUID->"51e542df-f042-442f-a495-75478b684ead"],
Cell[553001, 14665, 362, 9, 24, "Print",ExpressionUUID->"cb2ff916-f90a-42bb-bc30-689696d8e1b3"],
Cell[553366, 14676, 362, 9, 24, "Print",ExpressionUUID->"02d18451-71a2-4501-b1a1-3d1e124a197f"],
Cell[553731, 14687, 362, 9, 24, "Print",ExpressionUUID->"ddfc4bb3-e829-4374-b827-9ea7281b1e61"],
Cell[554096, 14698, 362, 9, 24, "Print",ExpressionUUID->"625f73f4-6829-4d7c-a346-dba4c1029039"],
Cell[554461, 14709, 362, 9, 24, "Print",ExpressionUUID->"8fbd8e8b-87ad-4554-bcf1-b4a0f9715396"],
Cell[554826, 14720, 364, 9, 24, "Print",ExpressionUUID->"191d6acd-426e-4eaa-84b8-e1cb40383c2b"],
Cell[555193, 14731, 364, 9, 24, "Print",ExpressionUUID->"69a3d250-1c94-4d3b-beba-dce7bb079c0f"],
Cell[555560, 14742, 364, 9, 24, "Print",ExpressionUUID->"6bbce59c-d7e6-46aa-a156-ecb540152fcf"],
Cell[555927, 14753, 364, 9, 24, "Print",ExpressionUUID->"4eae3fc3-3983-4b59-8551-d0f9f9e538bd"],
Cell[556294, 14764, 362, 9, 24, "Print",ExpressionUUID->"a06fcd5c-441d-41f2-a38c-1b4e3fc2229b"],
Cell[556659, 14775, 362, 9, 24, "Print",ExpressionUUID->"f7754493-0bad-4457-9ed4-daad96a1357b"],
Cell[557024, 14786, 362, 9, 24, "Print",ExpressionUUID->"3b10efba-eaee-4000-9b01-c1d200b96584"],
Cell[557389, 14797, 362, 9, 24, "Print",ExpressionUUID->"bb323268-098f-4171-97b1-ead8ae56866b"],
Cell[557754, 14808, 364, 9, 24, "Print",ExpressionUUID->"d004ce13-9c5f-455c-bf0a-a909e0242848"],
Cell[558121, 14819, 362, 9, 24, "Print",ExpressionUUID->"8cd509cb-4533-4165-98b9-f6eea73d35e3"],
Cell[558486, 14830, 362, 9, 24, "Print",ExpressionUUID->"d7d3e55c-5a8f-44fb-9fde-d6a709dbc7d4"],
Cell[558851, 14841, 362, 9, 24, "Print",ExpressionUUID->"fc8a6494-3460-4247-9323-acde12df7f69"],
Cell[559216, 14852, 362, 9, 24, "Print",ExpressionUUID->"4d4e54fe-bfe8-4942-8911-cdd53a31377d"],
Cell[559581, 14863, 362, 9, 24, "Print",ExpressionUUID->"6b1fd183-1ae3-43a7-9869-8d57d7bf2782"],
Cell[559946, 14874, 1623, 29, 45, "Print",ExpressionUUID->"0a21801d-2c11-48a9-9eb7-816cf6ff9650"],
Cell[561572, 14905, 362, 9, 24, "Print",ExpressionUUID->"da6bd803-eadb-47f2-9131-8e31a15725d5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[561983, 14920, 682, 19, 52, "Input",ExpressionUUID->"f41dbdd4-aa49-4901-958c-db42caf6da1e"],
Cell[562668, 14941, 231, 4, 34, "Output",ExpressionUUID->"51e46a25-5f7b-4300-9867-c5fb40734f09"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[562948, 14951, 361, 5, 53, "Section",ExpressionUUID->"46e3e464-ea0f-4547-8f4a-3b2ebcd51f37"],
Cell[CellGroupData[{
Cell[563334, 14960, 2419, 64, 178, "Input",ExpressionUUID->"94504deb-d0ce-4f75-b600-581f969d347b"],
Cell[CellGroupData[{
Cell[565778, 15028, 428, 10, 24, "Print",ExpressionUUID->"870efab5-79d0-47eb-bd17-ee74e0efd7e9"],
Cell[566209, 15040, 432, 10, 24, "Print",ExpressionUUID->"2ef11bc6-0763-4ec0-8a4e-b8549283d8e8"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[566690, 15056, 869, 23, 73, "Input",ExpressionUUID->"b79ba318-5cab-40b4-b867-9fce2b6a5b5d"],
Cell[567562, 15081, 280, 5, 34, "Output",ExpressionUUID->"0225bc69-7d27-4d2f-9e76-ec5957c51cea"]
}, Open  ]],
Cell[CellGroupData[{
Cell[567879, 15091, 767, 21, 73, "Input",ExpressionUUID->"953cb5fb-8974-4cfb-81da-21cdbb54bb51"],
Cell[568649, 15114, 225, 4, 34, "Output",ExpressionUUID->"e1f71a0f-0823-4f08-958e-26a9fdcea13c"]
}, Open  ]],
Cell[CellGroupData[{
Cell[568911, 15123, 2344, 64, 199, "Input",ExpressionUUID->"792d56bf-2095-4ce3-a788-14c798529a25"],
Cell[CellGroupData[{
Cell[571280, 15191, 408, 10, 24, "Print",ExpressionUUID->"b74ce206-1669-4785-9197-08f31d72cae2"],
Cell[571691, 15203, 406, 10, 24, "Print",ExpressionUUID->"6b914b00-4c7f-40e7-b528-ca1cc990c2f8"],
Cell[572100, 15215, 572, 13, 40, "Print",ExpressionUUID->"07c2a4ce-1936-4541-b9a6-598c6ac49c3f"],
Cell[572675, 15230, 408, 10, 24, "Print",ExpressionUUID->"8e4432f4-9513-40b9-96ef-f03661debade"],
Cell[573086, 15242, 572, 13, 40, "Print",ExpressionUUID->"d3017a91-7292-4675-b8b2-d5d76bd3c8e8"],
Cell[573661, 15257, 406, 10, 24, "Print",ExpressionUUID->"9cff6c62-7160-4d3c-bd6a-b86dfb65ace3"],
Cell[574070, 15269, 405, 10, 24, "Print",ExpressionUUID->"f9f6dacd-bb4f-498b-aead-04f8bbae191f"],
Cell[574478, 15281, 572, 13, 40, "Print",ExpressionUUID->"87e2791f-d9b3-40d4-a48e-73e8cc2b80c7"],
Cell[575053, 15296, 406, 10, 24, "Print",ExpressionUUID->"22dea9e1-f809-4742-8809-a7cea8ea9377"],
Cell[575462, 15308, 574, 13, 40, "Print",ExpressionUUID->"59783104-fbc1-401e-9f3a-6bab1d98e793"],
Cell[576039, 15323, 406, 10, 24, "Print",ExpressionUUID->"3b8d21f7-f678-4d8c-a50e-558dba52ecbc"],
Cell[576448, 15335, 545, 12, 24, "Print",ExpressionUUID->"94f023d4-6cfb-45fd-949a-5a9d4072f70f"],
Cell[576996, 15349, 406, 10, 24, "Print",ExpressionUUID->"46107793-b214-4248-963d-f14edc5b1594"],
Cell[577405, 15361, 546, 12, 24, "Print",ExpressionUUID->"8396cce3-f567-4dd3-82dd-badb11274219"],
Cell[577954, 15375, 407, 10, 24, "Print",ExpressionUUID->"425bc130-921b-42be-8541-ecc12b57dbff"],
Cell[578364, 15387, 574, 13, 40, "Print",ExpressionUUID->"8d4d6ef7-889d-424e-b63a-d51d6d9992d8"],
Cell[578941, 15402, 410, 10, 24, "Print",ExpressionUUID->"a9820ff8-f16f-4557-84a2-42d093986eb9"],
Cell[579354, 15414, 550, 12, 24, "Print",ExpressionUUID->"cbf43e8c-0a6b-48cc-a3b1-35a25cd8f63b"],
Cell[579907, 15428, 408, 10, 24, "Print",ExpressionUUID->"70c50341-d99e-469f-b536-9cae0f298157"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[580364, 15444, 867, 25, 73, "Input",ExpressionUUID->"1bf487f5-46c8-42c8-b1c8-d94ba5fe86cc"],
Cell[581234, 15471, 229, 4, 34, "Output",ExpressionUUID->"cdf59c6e-a678-4f0f-803c-20313678ceaf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[581500, 15480, 869, 25, 73, "Input",ExpressionUUID->"b6ba3cec-ec1f-44f1-9884-9d9a2ad4521f"],
Cell[582372, 15507, 224, 4, 34, "Output",ExpressionUUID->"578b3758-0b6c-4984-aaf2-9f283b829b10"]
}, Open  ]],
Cell[CellGroupData[{
Cell[582633, 15516, 867, 25, 73, "Input",ExpressionUUID->"a29b6ca6-9ef3-4b57-aa53-a10fd469ed80"],
Cell[583503, 15543, 224, 4, 34, "Output",ExpressionUUID->"a932a418-9a3d-4052-872f-8ae3fb5e7e85"]
}, Open  ]],
Cell[CellGroupData[{
Cell[583764, 15552, 868, 25, 73, "Input",ExpressionUUID->"b5323e2d-beee-4a15-8995-bf4786c95039"],
Cell[584635, 15579, 252, 4, 34, "Output",ExpressionUUID->"6fc41a16-e811-4a85-a4ac-507da8734057"]
}, Open  ]],
Cell[CellGroupData[{
Cell[584924, 15588, 765, 21, 73, "Input",ExpressionUUID->"c00d42da-d15a-4edf-9930-b4a650fb3e43"],
Cell[585692, 15611, 231, 4, 34, "Output",ExpressionUUID->"637360de-ca00-4ec7-ad7b-58a2d062b3b9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[585960, 15620, 767, 21, 73, "Input",ExpressionUUID->"41298c61-8b88-4ecb-946c-85ca34e91b26"],
Cell[586730, 15643, 229, 4, 34, "Output",ExpressionUUID->"6a866c7a-3ed6-4bea-b66b-2480573e3a72"]
}, Open  ]],
Cell[CellGroupData[{
Cell[586996, 15652, 871, 25, 73, "Input",ExpressionUUID->"f74896fc-a801-453b-af29-60653ac5c13a"],
Cell[587870, 15679, 229, 4, 34, "Output",ExpressionUUID->"dc7b26ce-4ae9-4bee-8101-647f76efe3e7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[588136, 15688, 769, 21, 73, "Input",ExpressionUUID->"a3585368-5cc6-4a0b-9c63-13cc260f4235"],
Cell[588908, 15711, 250, 4, 34, "Output",ExpressionUUID->"408b9462-5056-47c6-b0d8-46f9a653ee7d"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[589207, 15721, 368, 6, 53, "Section",ExpressionUUID->"593d750f-c507-4838-bbcd-2b631137d73a"],
Cell[CellGroupData[{
Cell[589600, 15731, 2893, 80, 199, "Input",ExpressionUUID->"43d9e8ee-d1ff-42fa-9b47-0943c63a9aac"],
Cell[592496, 15813, 841, 17, 70, "Print",ExpressionUUID->"5f6c0cee-4bd0-41be-ac0b-5180192cbe6d"]
}, Open  ]],
Cell[CellGroupData[{
Cell[593374, 15835, 3150, 86, 199, "Input",ExpressionUUID->"86733931-ef21-4c66-a4f0-85beccfda822"],
Cell[596527, 15923, 691, 16, 70, "Print",ExpressionUUID->"3af84088-3b29-4116-ac06-c6c7c39c1b99"]
}, Open  ]],
Cell[CellGroupData[{
Cell[597255, 15944, 2721, 73, 199, "Input",ExpressionUUID->"4cd249ab-d3af-46e8-b4af-f1deaeba163d"],
Cell[599979, 16019, 362, 10, 70, "Print",ExpressionUUID->"baeacbf1-606f-4409-8b5a-8bb102f63a83"]
}, Open  ]],
Cell[CellGroupData[{
Cell[600378, 16034, 291, 5, 30, "Input",ExpressionUUID->"5ee949e1-5657-449a-abdd-b166d330de4c"],
Cell[600672, 16041, 296, 6, 70, "Output",ExpressionUUID->"6064c98c-97f9-48c4-86bb-75b1ee5080cf"]
}, Open  ]],
Cell[CellGroupData[{
Cell[601005, 16052, 246, 5, 30, "Input",ExpressionUUID->"0fb52fdd-929d-4caa-b2bf-d858b0644d2f"],
Cell[601254, 16059, 192, 4, 70, "Output",ExpressionUUID->"6a28c3b5-3749-46f5-8e5c-7a06dd215c68"]
}, Open  ]],
Cell[CellGroupData[{
Cell[601483, 16068, 3096, 83, 199, "Input",ExpressionUUID->"4e92d83b-8f50-434b-bbcf-54003eae5f18"],
Cell[604582, 16153, 1017, 21, 70, "Print",ExpressionUUID->"8a11d36d-7fcf-4bbe-be38-987f9b7a378e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[605636, 16179, 246, 5, 30, "Input",ExpressionUUID->"997132ed-b9c8-408f-823d-df7e11f28fbf"],
Cell[605885, 16186, 217, 5, 70, "Output",ExpressionUUID->"b88b2482-40c7-499a-89f3-202939813442"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[606151, 16197, 422, 6, 53, "Section",ExpressionUUID->"dc5b93d7-8a82-4bd1-b05b-518156ce6e6a"],
Cell[CellGroupData[{
Cell[606598, 16207, 8302, 204, 556, "Input",ExpressionUUID->"1d0f9c8f-9bc7-4a42-9170-3f1079b0df84"],
Cell[CellGroupData[{
Cell[614925, 16415, 1146, 20, 24, "Print",ExpressionUUID->"7d25de29-16af-4e33-b701-e8f8f8e5d583"],
Cell[616074, 16437, 1390, 29, 25, "Print",ExpressionUUID->"251d6a5d-8642-4ba2-8e5d-1b4be8f02b57"],
Cell[617467, 16468, 1380, 28, 25, "Print",ExpressionUUID->"9d689378-8e77-44d1-ad28-d6f5d3cef160"],
Cell[618850, 16498, 1519, 34, 28, "Print",ExpressionUUID->"5963f8ef-6448-460f-8099-798856a25cf0"],
Cell[620372, 16534, 1474, 31, 25, "Print",ExpressionUUID->"76ab69d5-6889-4d7b-8d21-6bdaeb1a92dd"],
Cell[621849, 16567, 1238, 23, 24, "Print",ExpressionUUID->"db4a4947-4425-4c71-b3d7-4454b0ad135d"],
Cell[623090, 16592, 1260, 24, 40, "Print",ExpressionUUID->"ad1d44ad-0118-4252-8522-8e0657538d6c"],
Cell[624353, 16618, 2099, 45, 25, "Print",ExpressionUUID->"e7b03aae-7d96-4028-b26d-43e09147aac4"],
Cell[626455, 16665, 1146, 20, 24, "Print",ExpressionUUID->"8a418c21-e142-4c63-a786-cce94e06dc4d"],
Cell[627604, 16687, 1390, 29, 25, "Print",ExpressionUUID->"7a073dc8-61b7-400e-a2c9-54d558af3b7c"],
Cell[628997, 16718, 1895, 40, 25, "Print",ExpressionUUID->"dcade9f0-7b6b-48b0-b65f-3933af05c8c4"],
Cell[630895, 16760, 1361, 27, 25, "Print",ExpressionUUID->"4bae3bde-8cbb-4a0e-80de-7eaef358bf4e"],
Cell[632259, 16789, 1138, 20, 24, "Print",ExpressionUUID->"4bb4352d-0f96-46c4-af43-e519a996edc0"],
Cell[633400, 16811, 1148, 20, 24, "Print",ExpressionUUID->"98ca8cb6-fb47-40ef-b25d-a648114736af"],
Cell[634551, 16833, 3073, 70, 47, "Print",ExpressionUUID->"24eb4ca2-b4a6-41a6-a308-66a2418566d2"],
Cell[637627, 16905, 1148, 20, 24, "Print",ExpressionUUID->"84333982-20a6-4a06-9034-5380826a1e13"],
Cell[638778, 16927, 3003, 67, 47, "Print",ExpressionUUID->"ac866a79-641c-48b6-b350-39d56c058732"],
Cell[641784, 16996, 1150, 20, 24, "Print",ExpressionUUID->"2176ba3f-5c2a-49e5-a8f4-3062c07b8a76"],
Cell[642937, 17018, 3082, 70, 47, "Print",ExpressionUUID->"ca9bb1c4-4752-41db-8569-d738342d9a94"],
Cell[646022, 17090, 3083, 70, 47, "Print",ExpressionUUID->"a20a8ef2-a769-4a01-8973-9d58d6aa0326"],
Cell[649108, 17162, 3197, 72, 46, "Print",ExpressionUUID->"4734209f-9914-47e9-bdef-f00c1c5cf573"],
Cell[652308, 17236, 1418, 29, 25, "Print",ExpressionUUID->"c705ed7b-2065-43bf-a8bd-b9dbe283c946"],
Cell[653729, 17267, 1910, 42, 25, "Print",ExpressionUUID->"9e033b68-784d-4883-8bb1-064700c4c5c4"],
Cell[655642, 17311, 3022, 68, 45, "Print",ExpressionUUID->"19797a95-b8ad-40ff-a2b7-ad55c67466f4"],
Cell[658667, 17381, 1148, 20, 24, "Print",ExpressionUUID->"1db3582f-d819-4959-a0b9-2885dbee4aff"],
Cell[659818, 17403, 3110, 71, 46, "Print",ExpressionUUID->"52bb5190-2084-4b8a-afc3-1cebd3bb40b4"],
Cell[662931, 17476, 3166, 72, 46, "Print",ExpressionUUID->"e8d86d25-40ef-496d-bd3c-02a04a3dd9cc"],
Cell[666100, 17550, 2970, 67, 45, "Print",ExpressionUUID->"bbe9b900-cc57-4c15-995d-71d01ce218fa"],
Cell[669073, 17619, 3196, 74, 46, "Print",ExpressionUUID->"4be77212-f973-4d39-a3e7-1d046d891b31"],
Cell[672272, 17695, 3166, 72, 46, "Print",ExpressionUUID->"c08089a6-230e-4ba4-9ee1-592ca9ef1d37"],
Cell[675441, 17769, 3224, 73, 46, "Print",ExpressionUUID->"c5871cb1-e39d-40eb-942d-40f27445c6b7"],
Cell[678668, 17844, 1150, 20, 24, "Print",ExpressionUUID->"bf0c81cc-d79d-428d-91a3-3a50d030f1b4"],
Cell[679821, 17866, 2136, 47, 25, "Print",ExpressionUUID->"016a1275-13da-4e58-b8b3-f45fe9fb34af"],
Cell[681960, 17915, 4131, 94, 46, "Print",ExpressionUUID->"d777c07a-ae38-42ae-9862-3616898f39b9"],
Cell[686094, 18011, 1827, 38, 25, "Print",ExpressionUUID->"ce7e0b45-b226-41db-b11c-3ef8f69c1976"],
Cell[687924, 18051, 2101, 45, 25, "Print",ExpressionUUID->"841f77f6-6ccc-4a0c-a23c-db038c78b9b3"],
Cell[690028, 18098, 1424, 30, 25, "Print",ExpressionUUID->"ac1d7cb9-0489-4e69-933a-d865d6777035"],
Cell[691455, 18130, 1808, 43, 40, "Print",ExpressionUUID->"08e169e4-1a49-443b-b78a-c869a9b9eb61"],
Cell[693266, 18175, 1148, 20, 24, "Print",ExpressionUUID->"b473a08c-ed96-46ae-841d-0da4296058b8"],
Cell[694417, 18197, 2101, 45, 25, "Print",ExpressionUUID->"d2a4ccfe-0fa5-46bb-9f97-09a512a02255"],
Cell[696521, 18244, 2101, 45, 25, "Print",ExpressionUUID->"a4ae8d50-cbd8-40ad-9229-6966e234adc3"],
Cell[698625, 18291, 4112, 94, 46, "Print",ExpressionUUID->"690e9bc3-cad1-46ba-ac63-5553e7ce8870"],
Cell[702740, 18387, 1467, 30, 44, "Print",ExpressionUUID->"35e32730-da7c-443a-a797-e7fd3b7263f1"],
Cell[704210, 18419, 1659, 39, 28, "Print",ExpressionUUID->"b83744fe-7fbd-445d-be27-bd5437a0081f"],
Cell[705872, 18460, 3230, 73, 46, "Print",ExpressionUUID->"3b23113f-a670-4ffe-9467-027cf735bec3"],
Cell[709105, 18535, 2097, 45, 25, "Print",ExpressionUUID->"4c829551-0a1e-484b-bdac-568fc7115aee"],
Cell[711205, 18582, 1671, 36, 27, "Print",ExpressionUUID->"00e20b05-6345-4002-9ade-d073138bb9b3"],
Cell[712879, 18620, 1148, 20, 24, "Print",ExpressionUUID->"82d70c53-835c-4ecb-8de4-73bb0a5323c8"],
Cell[714030, 18642, 2145, 47, 25, "Print",ExpressionUUID->"3776aa38-09fa-476c-8aeb-6eaa97be8c7c"],
Cell[716178, 18691, 1387, 28, 25, "Print",ExpressionUUID->"8debc739-d316-4675-989c-f450b632f563"],
Cell[717568, 18721, 1585, 36, 28, "Print",ExpressionUUID->"e996a692-a902-4490-9516-a15df4b3cdd3"],
Cell[719156, 18759, 2226, 50, 25, "Print",ExpressionUUID->"bb66d203-adbd-4cfc-af01-a7f1fad2b714"],
Cell[721385, 18811, 3226, 73, 46, "Print",ExpressionUUID->"c0bdbc7d-687c-4074-9261-f969ef0f2c56"],
Cell[724614, 18886, 3286, 76, 46, "Print",ExpressionUUID->"fe66bd0b-d357-4929-b415-958823c1963c"],
Cell[727903, 18964, 4896, 113, 66, "Print",ExpressionUUID->"75f7bbde-9fc4-4a6d-9680-3cf6588d0735"],
Cell[732802, 19079, 2103, 45, 25, "Print",ExpressionUUID->"2285bfa3-0d8f-4e56-a112-21d733fbf3f9"],
Cell[734908, 19126, 2189, 48, 25, "Print",ExpressionUUID->"6e0b8b86-6593-4176-b9d1-ea9b1603056a"],
Cell[737100, 19176, 4891, 113, 66, "Print",ExpressionUUID->"969bfd09-dd6b-4dbb-b998-0abc562dcf5b"],
Cell[741994, 19291, 3169, 74, 46, "Print",ExpressionUUID->"55190e27-c7d6-4a36-ad1e-6702e47a7461"],
Cell[745166, 19367, 1147, 20, 24, "Print",ExpressionUUID->"26117700-b3ef-4def-91b9-9769a83a3cb8"],
Cell[746316, 19389, 1148, 20, 24, "Print",ExpressionUUID->"6f057e6a-3b21-4f61-8f69-1f4269ef3efc"],
Cell[747467, 19411, 1148, 20, 24, "Print",ExpressionUUID->"2612a9d4-5cca-4586-98a4-80e89ca5f6a2"],
Cell[748618, 19433, 2136, 47, 25, "Print",ExpressionUUID->"12bd07cd-a620-4946-83a2-74245b69eca4"],
Cell[750757, 19482, 3257, 76, 49, "Print",ExpressionUUID->"811c8580-c68d-4de7-962b-a4d630900c3b"],
Cell[754017, 19560, 2660, 61, 25, "Print",ExpressionUUID->"2b5f8b38-b061-4fee-a04a-607783d8ec6a"],
Cell[756680, 19623, 2808, 64, 26, "Print",ExpressionUUID->"d7c515ed-bc95-42fe-8e6c-1dcd85eeb94f"],
Cell[759491, 19689, 3435, 80, 50, "Print",ExpressionUUID->"8ac6bccb-c430-48c6-9542-82997e137a32"],
Cell[762929, 19771, 1877, 40, 25, "Print",ExpressionUUID->"ada2e020-6b29-49a2-b707-b2f8ea9df6f2"],
Cell[764809, 19813, 3281, 75, 46, "Print",ExpressionUUID->"e3bacd09-943f-4e23-aa55-0cd0dbccb71d"],
Cell[768093, 19890, 1150, 20, 24, "Print",ExpressionUUID->"eb32c4ce-9cd6-4832-a11f-1b09c7837acb"],
Cell[769246, 19912, 6059, 142, 66, "Print",ExpressionUUID->"4ac70309-9493-4306-8d7f-f2aa32d64703"],
Cell[775308, 20056, 1148, 20, 24, "Print",ExpressionUUID->"061a86cd-3e83-408c-bf1e-094002b8e1e3"],
Cell[776459, 20078, 3156, 73, 46, "Print",ExpressionUUID->"114dfb9c-49c0-4dd2-8059-20a13547bd97"],
Cell[779618, 20153, 1721, 37, 25, "Print",ExpressionUUID->"c9f36294-e8d7-4087-8924-0d28a9d092a9"],
Cell[781342, 20192, 6750, 159, 86, "Print",ExpressionUUID->"cbc82b8e-1963-4d62-9362-53ac59c30971"],
Cell[788095, 20353, 3196, 72, 46, "Print",ExpressionUUID->"83ddd3df-a590-408f-aebd-3ff3f6bc506b"],
Cell[791294, 20427, 1648, 34, 25, "Print",ExpressionUUID->"f3b41b24-9664-4818-bc34-6d7037d66820"],
Cell[792945, 20463, 1976, 42, 25, "Print",ExpressionUUID->"68f3d730-851f-4285-9c01-fade6a970617"],
Cell[794924, 20507, 1148, 20, 24, "Print",ExpressionUUID->"69bd7251-2b3d-4648-a33d-a538b2af6332"],
Cell[796075, 20529, 1688, 35, 25, "Print",ExpressionUUID->"d3145936-9982-4251-9c7e-c650bad0b1a1"],
Cell[797766, 20566, 3140, 71, 46, "Print",ExpressionUUID->"b47075a2-9210-4370-86b3-911cb92edf7a"],
Cell[800909, 20639, 1387, 28, 25, "Print",ExpressionUUID->"463abc4b-2633-4950-a019-c14a43dca5b5"],
Cell[802299, 20669, 1730, 37, 25, "Print",ExpressionUUID->"2491e3e9-e854-4e5a-ba60-8f4f73c02550"],
Cell[804032, 20708, 1511, 32, 25, "Print",ExpressionUUID->"9a345d20-355b-4b76-ac25-c65cda43ce5e"],
Cell[805546, 20742, 1150, 20, 24, "Print",ExpressionUUID->"97d88440-8839-4894-805b-d72c2f7b74dd"],
Cell[806699, 20764, 2081, 45, 25, "Print",ExpressionUUID->"fc427275-0810-4818-a095-32c0c94e1c96"],
Cell[808783, 20811, 4148, 96, 46, "Print",ExpressionUUID->"d84330b4-593c-4965-9a88-f5d56bb4b4d0"],
Cell[812934, 20909, 4628, 107, 66, "Print",ExpressionUUID->"3ee9d1a1-17ff-4999-80a0-c9b54cab1a51"],
Cell[817565, 21018, 1863, 40, 25, "Print",ExpressionUUID->"c07b489e-91ba-42d4-95f1-551641a594ba"],
Cell[819431, 21060, 1835, 39, 25, "Print",ExpressionUUID->"58031dd0-8a6e-403b-a478-c836a09202a3"],
Cell[821269, 21101, 1722, 37, 25, "Print",ExpressionUUID->"4d57d395-e59d-4850-a473-256e0acf2129"],
Cell[822994, 21140, 2934, 65, 27, "Print",ExpressionUUID->"cac50e81-54b6-46ee-bcbf-f486c82ad458"],
Cell[825931, 21207, 1148, 20, 24, "Print",ExpressionUUID->"648763d5-73b2-4274-baf6-6f2fb055ed58"],
Cell[827082, 21229, 2173, 48, 25, "Print",ExpressionUUID->"af9cc69b-1bf8-408d-a14a-ef600cc3ba4f"],
Cell[829258, 21279, 1831, 39, 25, "Print",ExpressionUUID->"48bf66c9-80e6-455e-99df-e8d794069022"],
Cell[831092, 21320, 3276, 75, 46, "Print",ExpressionUUID->"60de870c-0973-498f-9f85-addfbcb30ec3"],
Cell[834371, 21397, 3070, 69, 46, "Print",ExpressionUUID->"01971f48-6696-4494-8613-d3f1b4d4e979"],
Cell[837444, 21468, 6770, 160, 86, "Print",ExpressionUUID->"bf446cea-e3a1-4565-9a4d-0c7c2c52c906"],
Cell[844217, 21630, 6394, 149, 85, "Print",ExpressionUUID->"17d9978e-6cf6-4ab2-a24f-a5e5633f2aa7"],
Cell[850614, 21781, 4524, 105, 46, "Print",ExpressionUUID->"25140cef-85ab-40fe-8528-faba213e1c1f"],
Cell[855141, 21888, 7092, 168, 86, "Print",ExpressionUUID->"681d1409-ca90-4265-9b04-a08f21866cc2"],
Cell[862236, 22058, 6516, 153, 86, "Print",ExpressionUUID->"2ac57115-1311-445a-82e3-0cb84ef0916d"],
Cell[868755, 22213, 1150, 20, 24, "Print",ExpressionUUID->"602686ca-af6b-4976-a5d7-0c6483146a18"],
Cell[869908, 22235, 1148, 20, 24, "Print",ExpressionUUID->"ae183a54-c825-4934-a3f5-494b4b2ef766"],
Cell[871059, 22257, 1150, 20, 24, "Print",ExpressionUUID->"2ed8b8d7-10d2-446f-bd96-cd00c80110bd"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[872270, 22284, 477, 7, 53, "Section",ExpressionUUID->"9ce664cb-1b1c-49b3-92a3-87ce80434cd9"],
Cell[CellGroupData[{
Cell[872772, 22295, 8683, 211, 556, "Input",ExpressionUUID->"a1629a2b-d531-4108-9782-01c8c3a4c247"],
Cell[CellGroupData[{
Cell[881480, 22510, 1223, 21, 24, "Print",ExpressionUUID->"f87a5950-ce5d-45df-aef5-0e086bf88ce9"],
Cell[882706, 22533, 1225, 21, 24, "Print",ExpressionUUID->"f8e4dee3-b40f-4418-9fba-d35dd0e791ed"],
Cell[883934, 22556, 1223, 21, 24, "Print",ExpressionUUID->"39735b56-dfaa-49c8-a14e-6054f8b15e90"],
Cell[885160, 22579, 1548, 32, 24, "Print",ExpressionUUID->"a9a0df59-ca30-4252-a58e-ca09beb8251a"],
Cell[886711, 22613, 1572, 33, 25, "Print",ExpressionUUID->"a7a7d2cc-1dc4-4cc7-a9e8-67ac2b1b1df4"],
Cell[888286, 22648, 1223, 21, 24, "Print",ExpressionUUID->"3eb7a338-a23f-44b2-8dba-133074709dae"],
Cell[889512, 22671, 1223, 21, 24, "Print",ExpressionUUID->"1cbf82d2-ef81-4121-9aef-7c2ad3d46fe6"],
Cell[890738, 22694, 1223, 21, 24, "Print",ExpressionUUID->"929dbb38-dd83-4525-a533-c27b587715e3"],
Cell[891964, 22717, 1223, 21, 24, "Print",ExpressionUUID->"4471de10-bca8-4118-9dac-c5c40bebc5a7"],
Cell[893190, 22740, 1225, 21, 24, "Print",ExpressionUUID->"3e40e540-813a-4add-881c-4f1567d1d039"],
Cell[894418, 22763, 1227, 21, 24, "Print",ExpressionUUID->"e5856f58-0b01-4db8-b32b-b43ba7bfda05"],
Cell[895648, 22786, 1224, 21, 24, "Print",ExpressionUUID->"5a48b65d-5d15-48bd-b6b4-e9ec2aedf428"],
Cell[896875, 22809, 3111, 71, 47, "Print",ExpressionUUID->"1109c3ef-a5d7-4040-9ba6-738fb8c1d0a6"],
Cell[899989, 22882, 3113, 71, 47, "Print",ExpressionUUID->"f2609042-b433-4691-a442-cbd01e0e7262"],
Cell[903105, 22955, 1225, 21, 24, "Print",ExpressionUUID->"a10f3637-2584-404f-a6e2-a687f63c5e8d"],
Cell[904333, 22978, 1225, 21, 24, "Print",ExpressionUUID->"89f80e72-5a66-4fb7-afac-2d9ecab90cec"],
Cell[905561, 23001, 3092, 71, 47, "Print",ExpressionUUID->"5aa9f8e8-e591-4e16-b477-b15a2ad07c32"],
Cell[908656, 23074, 3096, 71, 47, "Print",ExpressionUUID->"65f41cbf-442c-44ef-83bd-e05f42e85bda"],
Cell[911755, 23147, 1550, 32, 24, "Print",ExpressionUUID->"93a95566-2f38-4ac2-b709-ede8acf41de2"],
Cell[913308, 23181, 1550, 32, 24, "Print",ExpressionUUID->"b43e6ae3-d674-49f6-a665-262e16643751"],
Cell[914861, 23215, 1225, 21, 24, "Print",ExpressionUUID->"0a89f7e3-4159-4237-886a-33014f56374e"],
Cell[916089, 23238, 1807, 38, 27, "Print",ExpressionUUID->"fd8afac9-359c-415a-9d22-ed8f937b4174"],
Cell[917899, 23278, 1225, 21, 24, "Print",ExpressionUUID->"f535da30-7467-4739-bc51-16ec0246fd19"],
Cell[919127, 23301, 1225, 21, 24, "Print",ExpressionUUID->"0487d180-30da-4c42-b34b-09635b125279"],
Cell[920355, 23324, 1805, 38, 27, "Print",ExpressionUUID->"8813785c-a309-47c1-a921-288b0b05ab24"],
Cell[922163, 23364, 2256, 49, 25, "Print",ExpressionUUID->"307d3060-78a9-4a1e-9a00-17367caa5ec3"],
Cell[924422, 23415, 2150, 47, 27, "Print",ExpressionUUID->"cbdd8c17-5282-4cde-bbb9-ab949f690a60"],
Cell[926575, 23464, 1858, 40, 27, "Print",ExpressionUUID->"0e336e94-297a-4069-aa69-948dffc4af84"],
Cell[928436, 23506, 2212, 49, 27, "Print",ExpressionUUID->"e7223b38-6eea-441b-9d3b-9d5e47ff645b"],
Cell[930651, 23557, 1222, 21, 24, "Print",ExpressionUUID->"4a11d5ef-1c01-4b3d-93a3-c3aa59dacf40"],
Cell[931876, 23580, 1225, 21, 24, "Print",ExpressionUUID->"18a066b8-e450-4852-87cd-d64dc7776f3b"],
Cell[933104, 23603, 1225, 21, 24, "Print",ExpressionUUID->"879a27cd-74f4-4bf6-88bc-54e716c07002"],
Cell[934332, 23626, 1820, 39, 27, "Print",ExpressionUUID->"1b53304b-1a7d-4569-a197-bc7d6d78af19"],
Cell[936155, 23667, 1650, 34, 24, "Print",ExpressionUUID->"3e2c8bfc-3a21-4a17-9f42-11e376def6c3"],
Cell[937808, 23703, 1225, 21, 24, "Print",ExpressionUUID->"6bed031c-7775-4ba2-80dd-042fd9e8fa56"],
Cell[939036, 23726, 1225, 21, 24, "Print",ExpressionUUID->"73893276-47c3-4f6c-8f45-f0779152b64f"],
Cell[940264, 23749, 1225, 21, 24, "Print",ExpressionUUID->"76cd8c80-a869-473a-b8ac-9abcb1d9052e"],
Cell[941492, 23772, 1225, 21, 24, "Print",ExpressionUUID->"fc25ed59-ec31-44b2-a6d1-a72bf676b765"],
Cell[942720, 23795, 1225, 21, 24, "Print",ExpressionUUID->"cf9ba40f-a841-44b7-8882-77edb5f40cc4"],
Cell[943948, 23818, 1225, 21, 24, "Print",ExpressionUUID->"47f2525d-68af-4dc2-8c71-659cd79cac06"],
Cell[945176, 23841, 1225, 21, 24, "Print",ExpressionUUID->"c7850b6d-d523-4799-8e6c-05384a413f79"],
Cell[946404, 23864, 1227, 21, 24, "Print",ExpressionUUID->"8264bf63-0da2-4d6c-98ee-9bcc9788e9c5"],
Cell[947634, 23887, 1906, 40, 25, "Print",ExpressionUUID->"7a4f1f4c-da24-471f-ae1c-f7db70853422"],
Cell[949543, 23929, 1225, 21, 24, "Print",ExpressionUUID->"50ea506c-1ca4-44e5-ae96-7c7578f51f5d"],
Cell[950771, 23952, 1225, 21, 24, "Print",ExpressionUUID->"96717e7f-74f2-4b03-8722-25e1e2dad888"],
Cell[951999, 23975, 1429, 28, 25, "Print",ExpressionUUID->"00b84e9c-0528-40e6-a22c-a2c4dcb5af32"],
Cell[953431, 24005, 1590, 35, 28, "Print",ExpressionUUID->"3008a2a0-f436-450d-996d-39398c35e5d4"],
Cell[955024, 24042, 1803, 38, 25, "Print",ExpressionUUID->"c99a522c-e39a-4135-ba50-ecc7589dc2e2"],
Cell[956830, 24082, 1431, 29, 25, "Print",ExpressionUUID->"fcfbdec6-dae3-4e8c-b5fa-1230183d4fd7"],
Cell[958264, 24113, 2252, 48, 25, "Print",ExpressionUUID->"247a8047-1c01-41c2-ba5b-0fedd5d2f4c0"],
Cell[960519, 24163, 2254, 48, 25, "Print",ExpressionUUID->"4b70706e-3dab-4261-b9ee-576116ea8803"],
Cell[962776, 24213, 2169, 46, 25, "Print",ExpressionUUID->"74659deb-b957-4ee3-9f32-2b1d8c4cf0c5"],
Cell[964948, 24261, 1995, 43, 25, "Print",ExpressionUUID->"ef65587f-b017-40f1-b942-6ef51fb1283b"],
Cell[966946, 24306, 2681, 60, 27, "Print",ExpressionUUID->"2c9e6da6-6817-4ffa-8db1-41138ead9f80"],
Cell[969630, 24368, 2250, 48, 25, "Print",ExpressionUUID->"5eb8499c-6535-4087-a06d-29db9a17d058"],
Cell[971883, 24418, 1225, 21, 24, "Print",ExpressionUUID->"044e09fc-98a2-4f11-a790-e442e66ad010"],
Cell[973111, 24441, 1227, 21, 24, "Print",ExpressionUUID->"72fbbbd4-e234-46d2-ac4d-4f66df0c0c3b"],
Cell[974341, 24464, 1225, 21, 24, "Print",ExpressionUUID->"51651cea-c5cd-4761-8246-afcc87ef9058"],
Cell[975569, 24487, 1225, 21, 24, "Print",ExpressionUUID->"163fa8a0-4a6b-4033-b129-1d334d761723"],
Cell[976797, 24510, 1225, 21, 24, "Print",ExpressionUUID->"4f746cd5-6740-4758-a874-2ebe4411eef1"],
Cell[978025, 24533, 1225, 21, 24, "Print",ExpressionUUID->"53a0aacd-7141-476e-b343-5920c3c38169"],
Cell[979253, 24556, 1225, 21, 24, "Print",ExpressionUUID->"2e5d2439-54d7-45eb-a997-436f9df6313a"],
Cell[980481, 24579, 2578, 59, 28, "Print",ExpressionUUID->"7818031f-16b8-45dd-b2d0-6c1fecb5b0bf"],
Cell[983062, 24640, 1225, 21, 24, "Print",ExpressionUUID->"9557c278-c029-46b9-84f9-c5c94077d3ff"],
Cell[984290, 24663, 2240, 48, 25, "Print",ExpressionUUID->"cf1d4f19-b016-4c7a-9c49-e01bf884c059"],
Cell[986533, 24713, 1225, 21, 24, "Print",ExpressionUUID->"b1de59e7-0198-4936-a872-4dfeb63a787f"],
Cell[987761, 24736, 4763, 108, 49, "Print",ExpressionUUID->"7489d745-314d-420b-aa9b-e014a65447f7"],
Cell[992527, 24846, 5029, 115, 71, "Print",ExpressionUUID->"5d4e6386-8b73-420f-a3aa-482417148af3"],
Cell[997559, 24963, 2443, 54, 27, "Print",ExpressionUUID->"6d892375-f84b-4aae-b68d-9721b5afef9d"],
Cell[1000005, 25019, 1225, 21, 24, "Print",ExpressionUUID->"178cb983-43c5-42c1-9699-42a093a3eade"],
Cell[1001233, 25042, 5572, 128, 68, "Print",ExpressionUUID->"9c4a271a-432c-4bd8-bedb-99a3331d9b8a"],
Cell[1006808, 25172, 1225, 21, 24, "Print",ExpressionUUID->"809af1f2-1da8-4f76-9161-ac735331c2ab"],
Cell[1008036, 25195, 1227, 21, 24, "Print",ExpressionUUID->"ceb52880-7a5f-4351-b1a5-14370dadb374"],
Cell[1009266, 25218, 1545, 31, 25, "Print",ExpressionUUID->"476e90fb-eec2-46d6-81ef-27333b5ee9c8"],
Cell[1010814, 25251, 1215, 21, 24, "Print",ExpressionUUID->"a6d8b89d-d427-4eba-b67d-5c93baadc8cc"],
Cell[1012032, 25274, 1227, 21, 24, "Print",ExpressionUUID->"71f9e628-31f7-44d3-aaf3-155904386259"],
Cell[1013262, 25297, 1227, 21, 24, "Print",ExpressionUUID->"250db1ca-e214-442c-a524-e23ed86fc2e6"],
Cell[1014492, 25320, 1512, 30, 25, "Print",ExpressionUUID->"ae411fae-444f-49dc-a861-53d0876c7e77"],
Cell[1016007, 25352, 1225, 21, 24, "Print",ExpressionUUID->"00b02ef3-4a22-483b-8bc1-39daa3497f34"],
Cell[1017235, 25375, 1541, 31, 25, "Print",ExpressionUUID->"593c0320-303e-4d3d-8840-b1544260a6e6"],
Cell[1018779, 25408, 1734, 37, 27, "Print",ExpressionUUID->"9c8f0416-69a5-4119-a855-f37d56f8f51d"],
Cell[1020516, 25447, 1227, 21, 24, "Print",ExpressionUUID->"f09df232-2b43-44e0-89cb-f0b1e97d67c6"],
Cell[1021746, 25470, 1225, 21, 24, "Print",ExpressionUUID->"95797d2a-7721-4d93-9602-d8b67a92531a"],
Cell[1022974, 25493, 1225, 21, 24, "Print",ExpressionUUID->"7fb2dc98-f7bd-4237-b8d7-b326123e03a8"],
Cell[1024202, 25516, 1646, 34, 25, "Print",ExpressionUUID->"82c24f91-90dd-47b4-8d4d-c1a91d93e938"],
Cell[1025851, 25552, 1224, 21, 24, "Print",ExpressionUUID->"7e37985e-aebb-4689-9a08-fcec41009db0"],
Cell[1027078, 25575, 1225, 21, 24, "Print",ExpressionUUID->"28ca8b8c-e28e-4215-9ea5-3e18e882d240"],
Cell[1028306, 25598, 2943, 66, 27, "Print",ExpressionUUID->"444cc585-880d-4255-ab0f-7e47021c06d5"],
Cell[1031252, 25666, 1808, 40, 27, "Print",ExpressionUUID->"1867cb44-80f8-480a-b63e-985139a4d073"],
Cell[1033063, 25708, 1225, 21, 24, "Print",ExpressionUUID->"49d9bab9-e8aa-476b-8ca1-fa18d8c15f85"],
Cell[1034291, 25731, 1775, 39, 27, "Print",ExpressionUUID->"88b41eca-64dc-4c0d-99f7-6e988a6bc78a"],
Cell[1036069, 25772, 2474, 55, 27, "Print",ExpressionUUID->"0649a8cf-fdcb-4664-bf96-7a5c6b63b39a"],
Cell[1038546, 25829, 1931, 42, 27, "Print",ExpressionUUID->"5332b63f-88df-48ce-8446-d3729e80abc1"],
Cell[1040480, 25873, 2960, 66, 47, "Print",ExpressionUUID->"07932f38-68fb-4db0-87ae-d6fbc288f8a9"],
Cell[1043443, 25941, 3007, 68, 27, "Print",ExpressionUUID->"c4f543e4-0f2b-4699-a828-decdd74d5d0b"],
Cell[1046453, 26011, 2250, 48, 25, "Print",ExpressionUUID->"ff7814d2-e699-42a5-beab-f7022270bc02"],
Cell[1048706, 26061, 3207, 72, 49, "Print",ExpressionUUID->"95099ab1-9791-46c4-b86e-beeae88c6f1f"],
Cell[1051916, 26135, 3360, 75, 49, "Print",ExpressionUUID->"7b61dc06-d7c0-48e5-bdf4-26d130dd5f19"],
Cell[1055279, 26212, 1215, 21, 24, "Print",ExpressionUUID->"4090c1eb-260f-4bfb-ba1d-d8828c94ef4e"],
Cell[1056497, 26235, 1215, 21, 24, "Print",ExpressionUUID->"14ce6de0-2900-4e37-bcb2-8dceaa96a0f6"],
Cell[1057715, 26258, 1219, 21, 24, "Print",ExpressionUUID->"3fe6b4b2-77c6-4450-b377-6d0ef38c15d8"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}
]
*)

